/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "RTCCertCache.h"

namespace mozilla::dom {

nsTArray<UniquePtr<GeneratedCertificate>> RTCCertCache::sCertCache;
mozilla::StaticMutex RTCCertCache::sRTCCertCacheLock MOZ_UNANNOTATED;

void RTCCertCache::CacheCert(UniquePtr<GeneratedCertificate> aCert) {
  StaticMutexAutoLock CacheLock(sRTCCertCacheLock);
  for (size_t i = 0; i < sCertCache.Length(); i++) {
    if (!sCertCache[i]) {
      sCertCache[i] = std::move(aCert);
      return;
    }
  }
  sCertCache.AppendElement(std::move(aCert));
}

GeneratedCertificate* RTCCertCache::LookupCert(
    const CertFingerprint aCertFingerprint) {
  StaticMutexAutoLock CacheLock(sRTCCertCacheLock);
  for (size_t i = 0; i < sCertCache.Length(); i++) {
    if (sCertCache[i] &&
        sCertCache[i]->mCertFingerprint.Match(&aCertFingerprint)) {
      return sCertCache[i].get();
    }
  }
  return nullptr;
}

void RTCCertCache::RemoveCert(const CertFingerprint aCertFingerprint) {
  StaticMutexAutoLock CacheLock(sRTCCertCacheLock);
  for (size_t i = 0; i < sCertCache.Length(); i++) {
    if (sCertCache[i] &&
        sCertCache[i]->mCertFingerprint.Match(&aCertFingerprint)) {
      sCertCache[i] = nullptr;
      break;
    }
  }
}

}  // namespace mozilla::dom
