/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef mozilla_dom_RTCCertService_h_
#define mozilla_dom_RTCCertService_h_

#include "mozilla/dom/PRTCCertServiceTransactionChild.h"
#include "nsIRTCCertService.h"
#include "mozilla/RefPtr.h"

namespace mozilla::dom {

already_AddRefed<nsIRTCCertService> NewRTCCertService();

class RTCCertServiceTransactionChild : public PRTCCertServiceTransactionChild {
 public:
  NS_INLINE_DECL_THREADSAFE_REFCOUNTING(RTCCertServiceTransactionChild);

 private:
  ~RTCCertServiceTransactionChild() = default;
};

class RTCCertService final : public nsIRTCCertService {
 public:
  NS_DECL_THREADSAFE_ISUPPORTS
  NS_DECL_NSIRTCCERTSERVICE

  RTCCertService() = default;

 private:
  ~RTCCertService() = default;

  RefPtr<RTCCertServiceTransactionChild> mChild;

  // |mChild| can only be initted asynchronously, |mInitPromise| resolves
  // when that happens. The |Then| calls make it convenient to dispatch API
  // calls to main, which is a bonus.
  // Init promise is not exclusive; this lets us call |Then| on it for every
  // API call we get, instead of creating another promise each time.
  typedef MozPromise<bool, nsCString, false> InitPromise;
  RefPtr<InitPromise> mInitPromise;
};

}  // namespace mozilla::dom

#endif  // mozilla_dom_CertServiceChild_h
