/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

// This file is a Mako template: http://www.makotemplates.org/

// Please note that valid Rust syntax may be mangled by the Mako parser.
// For example, Vec&Foo> will be mangled as Vec&Foo>. To work around these issues, the code
// can be escaped. In the above example, Vec<&Foo> or Vec< &Foo> achieves the desired result of Vec&Foo>.



use app_units::Au;
use servo_arc::{Arc, UniqueArc};
use std::{ops, ptr};
use std::{fmt, mem};

#[cfg(feature = "servo")] use euclid::SideOffsets2D;
#[cfg(feature = "gecko")] use crate::gecko_bindings::structs::{self, nsCSSPropertyID};
#[cfg(feature = "servo")] use crate::logical_geometry::LogicalMargin;
#[cfg(feature = "servo")] use crate::computed_values;
use crate::logical_geometry::WritingMode;
use malloc_size_of::{MallocSizeOf, MallocSizeOfOps};
use crate::computed_value_flags::*;
use cssparser::Parser;
use crate::media_queries::Device;
use crate::parser::ParserContext;
use crate::selector_parser::PseudoElement;
use crate::stylist::Stylist;
#[cfg(feature = "servo")] use servo_config::prefs;
use style_traits::{CssWriter, KeywordsCollectFn, ParseError, SpecifiedValueInfo, StyleParseErrorKind, ToCss};
use crate::stylesheets::{CssRuleType, CssRuleTypes, Origin};
use crate::logical_geometry::{LogicalAxis, LogicalCorner, LogicalSide};
use crate::use_counters::UseCounters;
use crate::rule_tree::StrongRuleNode;
use crate::str::CssStringWriter;
use crate::values::{
    computed,
    resolved,
    specified::{font::SystemFont, length::LineHeightBase},
};
use std::cell::Cell;
use super::{
    PropertyDeclarationId, PropertyId, NonCustomPropertyId,
    NonCustomPropertyIdSet, PropertyFlags, SourcePropertyDeclaration,
    LonghandIdSet, VariableDeclaration, CustomDeclaration,
    WideKeywordDeclaration, NonCustomPropertyIterator,
};



/// Conversion with fewer impls than From/Into
pub trait MaybeBoxed<Out> {
    /// Convert
    fn maybe_boxed(self) -> Out;
}

impl<T> MaybeBoxed<T> for T {
    #[inline]
    fn maybe_boxed(self) -> T { self }
}

impl<T> MaybeBoxed<Box<T>> for T {
    #[inline]
    fn maybe_boxed(self) -> Box<T> { Box::new(self) }
}

macro_rules! expanded {
    ( $( $name: ident: $value: expr ),+ ) => {
        expanded!( $( $name: $value, )+ )
    };
    ( $( $name: ident: $value: expr, )+ ) => {
        Longhands {
            $(
                $name: MaybeBoxed::maybe_boxed($value),
            )+
        }
    }
}

/// A module with all the code for longhand properties.
#[allow(missing_docs)]
pub mod longhands {
    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#background-color
    pub mod background_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Color::TRANSPARENT_BLACK }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::transparent() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_background_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundColor)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-image
    pub mod background_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Image as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Image as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Image::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Image::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Image as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-image.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-image.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundImage,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_image();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_image::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_image(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundImage)
        }
    }




    
    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds-4/#propdef-background-position-x
    pub mod background_position_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::position::HorizontalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::position::HorizontalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero_percent() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::position::HorizontalPosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-position-x.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::repeatable_list::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::repeatable_list::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-position-x.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundPositionX,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_position_x();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_position_x::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_position_x(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundPositionX)
        }
    }



    
    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds-4/#propdef-background-position-y
    pub mod background_position_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::position::VerticalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::position::VerticalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero_percent() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::initial_specified_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::position::VerticalPosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-position-y.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::repeatable_list::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::repeatable_list::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-position-y.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundPositionY,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_position_y();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_position_y::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_position_y(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundPositionY)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-repeat
    pub mod background_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BackgroundRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BackgroundRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundRepeat::repeat() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundRepeat::repeat() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BackgroundRepeat as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-repeat.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-repeat.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundRepeat,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_repeat();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_repeat::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_repeat(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundRepeat)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-attachment
    pub mod background_attachment {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Scroll,
            
            Fixed,
            
            Local,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Scroll
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Scroll
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-attachment.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-attachment.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundAttachment,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_attachment();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_attachment::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_attachment(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundAttachment)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-clip
    pub mod background_clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            BorderBox,
            
            PaddingBox,
            
            ContentBox,
            
            Text,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-clip.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-clip.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundClip,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_clip();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_clip::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_clip(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundClip)
        }
    }





    

    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-origin
    pub mod background_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            PaddingBox,
            
            BorderBox,
            
            ContentBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::PaddingBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::PaddingBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-origin.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-origin.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundOrigin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_origin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_origin::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_origin(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundOrigin)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-size
    pub mod background_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BackgroundSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BackgroundSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundSize::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundSize::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BackgroundSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for background-size.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::repeatable_list::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::repeatable_list::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-size.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundSize,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_size();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_size::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_size(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundSize)
        }
    }




// https://drafts.fxtf.org/compositing/#background-blend-mode

    

    
        
    
    
    /// https://drafts.fxtf.org/compositing/#background-blend-mode
    pub mod background_blend_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            Multiply,
            
            Screen,
            
            Overlay,
            
            Darken,
            
            Lighten,
            
            ColorDodge,
            
            ColorBurn,
            
            HardLight,
            
            SoftLight,
            
            Difference,
            
            Exclusion,
            
            Hue,
            
            Saturation,
            
            Color,
            
            Luminosity,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for background-blend-mode.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of background-blend-mode.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackgroundBlendMode,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_background_blend_mode();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::background_blend_mode::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_background();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_background_blend_mode(iter);
                }
                context.builder.put_background(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackgroundBlendMode)
        }
    }




    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-color
    pub mod border_top_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderTopColor.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_top_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_top_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-style
    pub mod border_top_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderTopStyle.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_top_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_top_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-width
    pub mod border_top_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderTopWidth.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_top_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderSideWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_top_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderTopWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-color
    pub mod border_right_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderRightColor.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_right_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_right_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-style
    pub mod border_right_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderRightStyle.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_right_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_right_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-right-width
    pub mod border_right_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderRightWidth.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_right_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderSideWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_right_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderRightWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-color
    pub mod border_bottom_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderBottomColor.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_bottom_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_bottom_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-style
    pub mod border_bottom_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderBottomStyle.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_bottom_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_bottom_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-width
    pub mod border_bottom_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderBottomWidth.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_bottom_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderSideWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_bottom_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBottomWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-color
    pub mod border_left_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Color::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderLeftColor.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_left_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_left_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-style
    pub mod border_left_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderLeftStyle.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_left_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_left_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-left-width
    pub mod border_left_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::BorderSideWidth::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderLeftWidth.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_left_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderSideWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_left_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderLeftWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-color
    pub mod border_block_start_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-style
    pub mod border_block_start_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start-width
    pub mod border_block_start_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderSideWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockStartWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-color
    pub mod border_block_end_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-style
    pub mod border_block_end_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end-width
    pub mod border_block_end_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderSideWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderBlockEndWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-color
    pub mod border_inline_start_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-style
    pub mod border_inline_start_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start-width
    pub mod border_inline_start_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderSideWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineStartWidth)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-color
    pub mod border_inline_end_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndColor)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-style
    pub mod border_inline_end_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndStyle)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end-width
    pub mod border_inline_end_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderSideWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderInlineEndWidth)
        }
    }



    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-left-radius
    pub mod border_top_left_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderTopLeftRadius.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_top_left_radius();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::BorderCornerRadius>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_top_left_radius(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderTopLeftRadius)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-top-right-radius
    pub mod border_top_right_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderTopRightRadius.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_top_right_radius();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::BorderCornerRadius>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_top_right_radius(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderTopRightRadius)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-right-radius
    pub mod border_bottom_right_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderBottomRightRadius.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_bottom_right_radius();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::BorderCornerRadius>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_bottom_right_radius(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderBottomRightRadius)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-bottom-left-radius
    pub mod border_bottom_left_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::BorderBottomLeftRadius.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_bottom_left_radius();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::BorderCornerRadius>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_bottom_left_radius(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderBottomLeftRadius)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-start-start-radius
    pub mod border_start_start_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderStartStartRadius)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-start-end-radius
    pub mod border_start_end_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderStartEndRadius)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-end-start-radius
    pub mod border_end_start_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderEndStartRadius)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-border-end-end-radius
    pub mod border_end_end_radius {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderCornerRadius as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderCornerRadius as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderCornerRadius::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderCornerRadius as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderEndEndRadius)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-break/#propdef-box-decoration-break
    pub mod box_decoration_break {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Slice,
            
            Clone,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Slice
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Slice
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BoxDecorationBreak,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_box_decoration_break();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::box_decoration_break::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_box_decoration_break(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxDecorationBreak)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-float-edge)
    pub mod _moz_float_edge {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            ContentBox,
            
            MarginBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ContentBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ContentBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozFloatEdge,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_float_edge();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_float_edge::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_float_edge(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozFloatEdge)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#the-background-image
    pub mod border_image_source {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Image as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Image as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Image::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Image::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Image as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BorderImageSource,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_image_source();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Image>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_image_source(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderImageSource)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-outset
    pub mod border_image_outset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthOrNumberRect as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthOrNumberRect as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::rect::Rect::all(computed::NonNegativeLengthOrNumber::zero()) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { generics::rect::Rect::all(specified::NonNegativeLengthOrNumber::zero()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthOrNumberRect as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BorderImageOutset,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_image_outset();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::NonNegativeLengthOrNumberRect>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_image_outset(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageOutset)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#the-border-image-repeat
    pub mod border_image_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderImageRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderImageRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderImageRepeat::stretch() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderImageRepeat::stretch() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderImageRepeat as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BorderImageRepeat,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_image_repeat();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderImageRepeat>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_image_repeat(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderImageRepeat)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-width
    pub mod border_image_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderImageWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderImageWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderImageWidth::all(computed::BorderImageSideWidth::one()) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderImageWidth::all(specified::BorderImageSideWidth::one()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderImageWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BorderImageWidth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_image_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::BorderImageWidth>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_image_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageWidth)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-backgrounds/#border-image-slice
    pub mod border_image_slice {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderImageSlice as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderImageSlice as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderImageSlice::hundred_percent() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderImageSlice::hundred_percent() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderImageSlice as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BorderImageSlice,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_border_image_slice();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::BorderImageSlice>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_image_slice(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderImageSlice)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    
        
    
    /// https://drafts.csswg.org/css-display/#propdef-display
    pub mod display {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Display as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Display as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Display::inline() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Display::inline() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Display as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Display,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_display();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Display>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_display(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Display)
        }
    }




    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_top_layer {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            None,
            
            Top,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozTopLayer,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_top_layer();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_top_layer::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_top_layer(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTopLayer)
        }
    }



// An internal-only property for elements in a top layer
// https://fullscreen.spec.whatwg.org/#top-layer

    

    
        
    



    

    
        
    
    /// https://drafts.csswg.org/css-position/#position-property
    pub mod position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Static,
            
            Absolute,
            
            Relative,
            
            Fixed,
            
            Sticky,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Static
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Static
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
            
impl computed_value::T {
    pub fn is_absolutely_positioned(self) -> bool {
        matches!(self, Self::Absolute | Self::Fixed)
    }
    pub fn is_relative(self) -> bool {
        self == Self::Relative
    }
}

        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Position,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_position();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::position::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Position)
        }
    }



// Changes do not invalidate our element. We handle notify/invalidating
// elements that reference anchor-name elsewhere.

    
        
    
    /// https://drafts.csswg.org/css-anchor-position-1/#propdef-anchor-name
    pub mod anchor_name {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnchorName as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnchorName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnchorName::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnchorName as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnchorName,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_anchor_name();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::AnchorName>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_anchor_name(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnchorName)
        }
    }



// Changes do not invalidate our element. We handle notify/invalidating
// any affected descendants elsewhere.

    
        
    
    /// https://drafts.csswg.org/css-anchor-position-1/#propdef-scope
    pub mod anchor_scope {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnchorScope as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnchorScope as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnchorScope::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnchorScope as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnchorScope,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_anchor_scope();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::AnchorScope>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_anchor_scope(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnchorScope)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-float
    pub mod float {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Float as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Float as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Float::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Float::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Float as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Float,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_float();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Float>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_float(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Float)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css2/#propdef-clear
    pub mod clear {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Clear as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Clear as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Clear::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Clear as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Clear,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_clear();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Clear>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_clear(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Clear)
        }
    }




    
        
    
    /// https://www.w3.org/TR/CSS2/visudet.html#propdef-vertical-align
    pub mod vertical_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::VerticalAlign as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::VerticalAlign as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::VerticalAlign::baseline() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::VerticalAlign as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::VerticalAlign,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_vertical_align();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::VerticalAlign>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_vertical_align(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::VerticalAlign)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-inline-3/#baseline-source
    pub mod baseline_source {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BaselineSource as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BaselineSource as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BaselineSource::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BaselineSource as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BaselineSource,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_baseline_source();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BaselineSource>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_baseline_source(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BaselineSource)
        }
    }



// CSS 2.1, Section 11 - Visual effects


    

    
        
    


    
    
        
    
    /// Internal, may be standardized in the future:               https://developer.mozilla.org/en-US/docs/Web/CSS/overflow-clip-box
    pub mod overflow_clip_box_inline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverflowClipBox as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverflowClipBox as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowClipBox::PaddingBox }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverflowClipBox as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OverflowClipBoxInline,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overflow_clip_box_inline();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OverflowClipBox>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overflow_clip_box_inline(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowClipBoxInline)
        }
    }


    
    
        
    
    /// Internal, may be standardized in the future:               https://developer.mozilla.org/en-US/docs/Web/CSS/overflow-clip-box
    pub mod overflow_clip_box_block {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverflowClipBox as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverflowClipBox as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowClipBox::PaddingBox }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverflowClipBox as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OverflowClipBoxBlock,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overflow_clip_box_block();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OverflowClipBox>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overflow_clip_box_block(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowClipBoxBlock)
        }
    }



    
    
    
        
    
    /// https://drafts.csswg.org/css-overflow-3/#propdef-overflow-y
    pub mod overflow_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Overflow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Overflow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Overflow::Visible }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Overflow as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::OverflowY.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overflow_y();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Overflow>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overflow_y(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowY)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-overflow-3/#propdef-overflow-x
    pub mod overflow_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Overflow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Overflow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Overflow::Visible }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Overflow as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::OverflowX.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overflow_x();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Overflow>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overflow_x(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowX)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-overflow-3/#propdef-overflow-block
    pub mod overflow_block {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Overflow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Overflow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Overflow::Visible }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Overflow as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowBlock)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-overflow-3/#propdef-overflow-inline
    pub mod overflow_inline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Overflow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Overflow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Overflow::Visible }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Overflow as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowInline)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-scroll-anchoring/#exclusion-api
    pub mod overflow_anchor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverflowAnchor as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverflowAnchor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowAnchor::Auto }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::OverflowAnchor::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverflowAnchor as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OverflowAnchor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overflow_anchor();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OverflowAnchor>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overflow_anchor(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowAnchor)
        }
    }






    
        
    
    /// https://drafts.csswg.org/css-transforms/#propdef-transform
    pub mod transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Transform as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Transform as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Transform::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Transform as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Transform,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transform();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Transform>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_transform(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Transform)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#individual-transforms
    pub mod rotate {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Rotate as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Rotate as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Rotate::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Rotate as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Rotate,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_rotate();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::Rotate>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_rotate(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Rotate)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#individual-transforms
    pub mod scale {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Scale as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Scale as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Scale::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Scale as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Scale,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scale();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::Scale>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_scale(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Scale)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#individual-transforms
    pub mod translate {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Translate as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Translate as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Translate::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Translate as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Translate,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_translate();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::Translate>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_translate(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Translate)
        }
    }



// Motion Path Module Level 1

    
        
    
    /// https://drafts.fxtf.org/motion-1/#offset-path-property
    pub mod offset_path {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OffsetPath as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OffsetPath as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OffsetPath::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OffsetPath as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OffsetPath,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_offset_path();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OffsetPath>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_offset_path(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetPath)
        }
    }



// Motion Path Module Level 1

    
        
    
    /// https://drafts.fxtf.org/motion-1/#offset-distance-property
    pub mod offset_distance {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OffsetDistance,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_offset_distance();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_offset_distance(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetDistance)
        }
    }



// Motion Path Module Level 1

    
        
    
    /// https://drafts.fxtf.org/motion-1/#offset-rotate-property
    pub mod offset_rotate {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OffsetRotate as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OffsetRotate as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OffsetRotate::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OffsetRotate as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OffsetRotate,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_offset_rotate();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OffsetRotate>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_offset_rotate(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OffsetRotate)
        }
    }



// Motion Path Module Level 1

    
        
    
    /// https://drafts.fxtf.org/motion-1/#offset-anchor-property
    pub mod offset_anchor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PositionOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PositionOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PositionOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PositionOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OffsetAnchor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_offset_anchor();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::PositionOrAuto>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_offset_anchor(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::OffsetAnchor)
        }
    }



// Motion Path Module Level 1

    
        
    
    /// https://drafts.fxtf.org/motion-1/#offset-position-property
    pub mod offset_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OffsetPosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OffsetPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OffsetPosition::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OffsetPosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OffsetPosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_offset_position();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::OffsetPosition>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_offset_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::OffsetPosition)
        }
    }



// CSSOM View Module
// https://www.w3.org/TR/cssom-view-1/

    

    
        
    
    /// https://drafts.csswg.org/cssom-view/#propdef-scroll-behavior
    pub mod scroll_behavior {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Smooth,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollBehavior,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_behavior();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::scroll_behavior::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_behavior(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollBehavior)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#scroll-snap-align
    pub mod scroll_snap_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollSnapAlign as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollSnapAlign as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapAlign::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollSnapAlign as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollSnapAlign,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_snap_align();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ScrollSnapAlign>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_snap_align(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapAlign)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#scroll-snap-type
    pub mod scroll_snap_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollSnapType as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollSnapType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapType::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollSnapType as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollSnapType,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_snap_type();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ScrollSnapType>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_snap_type(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapType)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#scroll-snap-stop
    pub mod scroll_snap_stop {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollSnapStop as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollSnapStop as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollSnapStop::Normal }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollSnapStop as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollSnapStop,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_snap_stop();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ScrollSnapStop>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_snap_stop(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollSnapStop)
        }
    }



    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverscrollBehavior as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::OverscrollBehaviorY.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overscroll_behavior_y();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OverscrollBehavior>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overscroll_behavior_y(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorY)
        }
    }


    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverscrollBehavior as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::OverscrollBehaviorX.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overscroll_behavior_x();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OverscrollBehavior>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overscroll_behavior_x(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorX)
        }
    }


    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_block {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverscrollBehavior as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorBlock)
        }
    }


    
    
        
    
    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior_inline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverscrollBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverscrollBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverscrollBehavior::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverscrollBehavior as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverscrollBehaviorInline)
        }
    }



// Compositing and Blending Level 1
// http://www.w3.org/TR/compositing-1/

    

    
        
    
    /// https://drafts.fxtf.org/compositing/#isolation
    pub mod isolation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Isolate,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Isolation,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_isolation();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::isolation::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_isolation(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Isolation)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-break/#propdef-break-after
    pub mod break_after {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BreakBetween as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BreakBetween as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BreakBetween::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BreakBetween as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BreakAfter,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_break_after();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BreakBetween>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_break_after(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BreakAfter)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-break/#propdef-break-before
    pub mod break_before {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BreakBetween as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BreakBetween as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BreakBetween::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BreakBetween as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BreakBefore,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_break_before();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BreakBetween>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_break_before(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BreakBefore)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-break/#propdef-break-inside
    pub mod break_inside {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BreakWithin as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BreakWithin as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BreakWithin::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BreakWithin as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BreakInside,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_break_inside();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BreakWithin>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_break_inside(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BreakInside)
        }
    }



// CSS Basic User Interface Module Level 3
// http://dev.w3.org/csswg/css-ui

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-resize
    pub mod resize {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Resize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Resize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Resize::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Resize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Resize,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_resize();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Resize>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_resize(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Resize)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms/#perspective
    pub mod perspective {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Perspective as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Perspective as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Perspective::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Perspective as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Perspective,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_perspective();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Perspective>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_perspective(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Perspective)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#perspective-origin-property
    pub mod perspective_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::position::Position::center() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Position as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PerspectiveOrigin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_perspective_origin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::Position>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_perspective_origin(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::PerspectiveOrigin)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-transforms/#backface-visibility-property
    pub mod backface_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Visible,
            
            Hidden,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackfaceVisibility,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_backface_visibility();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::backface_visibility::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_backface_visibility(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackfaceVisibility)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms/#transform-box
    pub mod transform_box {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TransformBox as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TransformBox as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformBox::ViewBox }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TransformBox as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransformBox,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transform_box();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TransformBox>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_transform_box(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransformBox)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms-2/#transform-style-property
    pub mod transform_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TransformStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TransformStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformStyle::Flat }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TransformStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransformStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transform_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TransformStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_transform_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransformStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-transforms/#transform-origin-property
    pub mod transform_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TransformOrigin as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TransformOrigin as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformOrigin::initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TransformOrigin as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransformOrigin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transform_origin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::TransformOrigin>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_transform_origin(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TransformOrigin)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-contain/#contain-property
    pub mod contain {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Contain as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Contain as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::Contain::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Contain as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Contain,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_contain();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Contain>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_contain(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Contain)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-contain/#content-visibility
    pub mod content_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ContentVisibility as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ContentVisibility as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ContentVisibility::Visible }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ContentVisibility as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ContentVisibility,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_content_visibility();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ContentVisibility>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_content_visibility(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ContentVisibility)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-contain-3/#container-type
    pub mod container_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ContainerType as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ContainerType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ContainerType::Normal }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ContainerType as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ContainerType,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_container_type();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ContainerType>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_container_type(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ContainerType)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-contain-3/#container-name
    pub mod container_name {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ContainerName as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ContainerName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ContainerName::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ContainerName as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ContainerName,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_container_name();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ContainerName>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_container_name(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ContainerName)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui-4/#propdef-appearance
    pub mod appearance {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Appearance as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Appearance as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Appearance::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Appearance as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Appearance,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_appearance();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Appearance>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_appearance(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Appearance)
        }
    }



// The inherent widget type of an element, selected by specifying
// `appearance: auto`.

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_default_appearance {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Appearance as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Appearance as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Appearance::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Appearance as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozDefaultAppearance,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_default_appearance();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Appearance>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_default_appearance(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozDefaultAppearance)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-orient)
    pub mod _moz_orient {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Inline,
            
            Block,
            
            Horizontal,
            
            Vertical,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Inline
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Inline
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozOrient,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_orient();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_orient::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_orient(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozOrient)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-will-change/#will-change
    pub mod will_change {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::WillChange as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::WillChange as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::WillChange::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::WillChange as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WillChange,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_will_change();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::WillChange>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_will_change(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WillChange)
        }
    }



// The spec issue for the parse_method: https://github.com/w3c/csswg-drafts/issues/4102.

    
        
    
    /// https://drafts.csswg.org/css-shapes/#shape-image-threshold-property
    pub mod shape_image_threshold {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Opacity as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ShapeImageThreshold,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_shape_image_threshold();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Opacity>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_shape_image_threshold(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeImageThreshold)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-shapes/#shape-margin-property
    pub mod shape_margin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ShapeMargin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_shape_margin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_shape_margin(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeMargin)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-shapes/#shape-outside-property
    pub mod shape_outside {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::basic_shape::ShapeOutside as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::basic_shape::ShapeOutside as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::basic_shape::ShapeOutside::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::basic_shape::ShapeOutside as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ShapeOutside,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_shape_outside();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::basic_shape::ShapeOutside>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_shape_outside(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeOutside)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#touch-action
    pub mod touch_action {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TouchAction as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TouchAction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TouchAction::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TouchAction as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TouchAction,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_touch_action();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TouchAction>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_touch_action(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TouchAction)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-overflow-3/#line-clamp
    pub mod _webkit_line_clamp {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LineClamp as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LineClamp as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LineClamp::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LineClamp as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WebkitLineClamp,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__webkit_line_clamp();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LineClamp>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__webkit_line_clamp(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitLineClamp)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-overflow-3/#scrollbar-gutter-property
    pub mod scrollbar_gutter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollbarGutter as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollbarGutter as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollbarGutter::AUTO }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollbarGutter as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollbarGutter,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scrollbar_gutter();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ScrollbarGutter>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scrollbar_gutter(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollbarGutter)
        }
    }




    
        
    
    /// Non-standard (https://github.com/atanassov/css-zoom/ is the closest)
    pub mod zoom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Zoom as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Zoom as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::box_::Zoom::ONE }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Zoom as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Zoom,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_zoom();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Zoom>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_zoom(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Zoom)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-width
    pub mod column_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::length::NonNegativeLengthOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::length::NonNegativeLengthOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::length::NonNegativeLengthOrAuto::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::length::NonNegativeLengthOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::length::NonNegativeLengthOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnWidth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::length::NonNegativeLengthOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnWidth)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-count
    pub mod column_count {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ColumnCount as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ColumnCount as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ColumnCount::Auto }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::ColumnCount::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ColumnCount as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnCount,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_count();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ColumnCount>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_count(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnCount)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-fill
    pub mod column_fill {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Balance,
            
            Auto,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Balance
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Balance
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnFill,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_fill();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::column_fill::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_fill(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnFill)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-width
    pub mod column_rule_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::medium() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderSideWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnRuleWidth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_rule_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderSideWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_rule_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleWidth)
        }
    }



// https://drafts.csswg.org/css-multicol-1/#crc

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-color
    pub mod column_rule_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnRuleColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_rule_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_rule_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleColor)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-span
    pub mod column_span {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            None,
            
            All,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnSpan,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_span();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::column_span::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_span(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnSpan)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule-style
    pub mod column_rule_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderStyle::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderStyle::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnRuleStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_rule_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_rule_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnRuleStyle)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-content/#propdef-content
    pub mod content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Content as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Content as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Content::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Content::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Content as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Content,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_content();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Content>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_content(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Content)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-counter-increment
    pub mod counter_increment {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::CounterIncrement as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::CounterIncrement as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::CounterIncrement as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::CounterIncrement,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_counter_increment();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::CounterIncrement>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_counter_increment(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CounterIncrement)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists-3/#propdef-counter-reset
    pub mod counter_reset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::CounterReset as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::CounterReset as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::CounterReset as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::CounterReset,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_counter_reset();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::CounterReset>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_counter_reset(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CounterReset)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists-3/#propdef-counter-set
    pub mod counter_set {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::CounterSet as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::CounterSet as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::CounterSet as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::CounterSet,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_counter_set();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::CounterSet>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_counter_set(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CounterSet)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-color/#transparency
    pub mod opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Opacity as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Opacity,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_opacity();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Opacity>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_opacity(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Opacity)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-backgrounds/#box-shadow
    pub mod box_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BoxShadow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BoxShadow as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BoxShadow as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for box-shadow.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    crate::OwnedSlice<T>;

            pub type UnderlyingOwnedList<T> =
                    crate::OwnedSlice<T>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(if_empty = "none", iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;

            impl From<ComputedList> for UnderlyingList<single_value::T> {
                #[inline]
                fn from(l: ComputedList) -> Self {
                    l.0
                }
            }
            impl From<UnderlyingList<single_value::T>> for ComputedList {
                #[inline]
                fn from(l: UnderlyingList<single_value::T>) -> Self {
                    List(l)
                }
            }


            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::with_zero::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::with_zero::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of box-shadow.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::List(Default::default())
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

            if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue(Default::default()))
            }

            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;


        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BoxShadow,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_box_shadow();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::box_shadow::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_box_shadow(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxShadow)
        }
    }





    
        
    
    /// https://drafts.fxtf.org/css-masking/#clip-property
    pub mod clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ClipRectOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ClipRectOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ClipRectOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::ClipRectOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Clip,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_clip();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::ClipRectOrAuto>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_clip(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Clip)
        }
    }




    
        
    
    
    /// https://drafts.fxtf.org/filters/#propdef-filter
    pub mod filter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Filter as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Filter as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Filter as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for filter.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    crate::OwnedSlice<T>;

            pub type UnderlyingOwnedList<T> =
                    crate::OwnedSlice<T>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            pub struct OwnedList<T>(
                #[css(if_empty = "none", iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;

            impl From<ComputedList> for UnderlyingList<single_value::T> {
                #[inline]
                fn from(l: ComputedList) -> Self {
                    l.0
                }
            }
            impl From<UnderlyingList<single_value::T>> for ComputedList {
                #[inline]
                fn from(l: UnderlyingList<single_value::T>) -> Self {
                    List(l)
                }
            }


            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::with_zero::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::with_zero::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of filter.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::List(Default::default())
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

            if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue(Default::default()))
            }

            let v = style_traits::Space::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;


        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Filter,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_filter();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::filter::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_filter(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Filter)
        }
    }





    
        
    
    
    /// https://drafts.fxtf.org/filter-effects-2/#propdef-backdrop-filter
    pub mod backdrop_filter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Filter as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Filter as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Filter as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for backdrop-filter.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    crate::OwnedSlice<T>;

            pub type UnderlyingOwnedList<T> =
                    crate::OwnedSlice<T>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            pub struct OwnedList<T>(
                #[css(if_empty = "none", iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;

            impl From<ComputedList> for UnderlyingList<single_value::T> {
                #[inline]
                fn from(l: ComputedList) -> Self {
                    l.0
                }
            }
            impl From<UnderlyingList<single_value::T>> for ComputedList {
                #[inline]
                fn from(l: UnderlyingList<single_value::T>) -> Self {
                    List(l)
                }
            }


            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::with_zero::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::with_zero::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of backdrop-filter.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::List(Default::default())
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

            if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue(Default::default()))
            }

            let v = style_traits::Space::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;


        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BackdropFilter,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_backdrop_filter();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::backdrop_filter::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_backdrop_filter(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BackdropFilter)
        }
    }





    

    
        
    
    /// https://drafts.fxtf.org/compositing/#propdef-mix-blend-mode
    pub mod mix_blend_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            Multiply,
            
            Screen,
            
            Overlay,
            
            Darken,
            
            Lighten,
            
            ColorDodge,
            
            ColorBurn,
            
            HardLight,
            
            SoftLight,
            
            Difference,
            
            Exclusion,
            
            Hue,
            
            Saturation,
            
            Color,
            
            Luminosity,
            
            PlusLighter,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MixBlendMode,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mix_blend_mode();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mix_blend_mode::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_mix_blend_mode(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MixBlendMode)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-family
    pub mod font_family {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontFamily as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontFamily as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontFamily::serif() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontFamily as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontFamily,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_family();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontFamily>()
                },
            };

            if let Some(sf) = specified_value.get_system() {
                longhands::system_font::resolve_system_font(sf, context);
            }

                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_family(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontFamily)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-style
    pub mod font_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontStyle::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontStyle::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_style();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontStyle>()
                },
            };

            if let Some(sf) = specified_value.get_system() {
                longhands::system_font::resolve_system_font(sf, context);
            }

                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontStyle)
        }
    }






    

    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-caps
    pub mod font_variant_caps {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            SmallCaps,
            
            AllSmallCaps,
            
            PetiteCaps,
            
            AllPetiteCaps,
            
            Unicase,
            
            TitlingCaps,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariantCaps,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variant_caps();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::font_variant_caps::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variant_caps(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantCaps)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-weight
    pub mod font_weight {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontWeight as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontWeight as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontWeight::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontWeight::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontWeight as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontWeight,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_weight();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontWeight>()
                },
            };

            if let Some(sf) = specified_value.get_system() {
                longhands::system_font::resolve_system_font(sf, context);
            }

                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_weight(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontWeight)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-size
    pub mod font_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSize::medium() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSize::medium() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::FontSize::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontSize,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_size();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontSize>()
                },
            };

            if let Some(sf) = specified_value.get_system() {
                longhands::system_font::resolve_system_font(sf, context);
            }

                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_size(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSize)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-size-adjust
    pub mod font_size_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontSizeAdjust as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontSizeAdjust as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSizeAdjust::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSizeAdjust::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontSizeAdjust as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontSizeAdjust,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_size_adjust();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontSizeAdjust>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_size_adjust(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSizeAdjust)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-4/#font-synthesis-weight
    pub mod font_synthesis_weight {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontSynthesis as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontSynthesis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSynthesis::Auto }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSynthesis::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontSynthesis as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontSynthesisWeight,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_synthesis_weight();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontSynthesis>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_synthesis_weight(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSynthesisWeight)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-4/#font-synthesis-style
    pub mod font_synthesis_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontSynthesis as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontSynthesis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSynthesis::Auto }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSynthesis::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontSynthesis as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontSynthesisStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_synthesis_style();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontSynthesis>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_synthesis_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSynthesisStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-4/#font-synthesis-small-caps
    pub mod font_synthesis_small_caps {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontSynthesis as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontSynthesis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSynthesis::Auto }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSynthesis::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontSynthesis as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontSynthesisSmallCaps,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_synthesis_small_caps();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontSynthesis>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_synthesis_small_caps(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSynthesisSmallCaps)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-4/#font-synthesis-position
    pub mod font_synthesis_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontSynthesis as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontSynthesis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontSynthesis::Auto }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontSynthesis::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontSynthesis as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontSynthesisPosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_synthesis_position();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontSynthesis>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_synthesis_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontSynthesisPosition)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-stretch
    pub mod font_stretch {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontStretch as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontStretch as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontStretch::hundred() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontStretch::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontStretch as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontStretch,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_stretch();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontStretch>()
                },
            };

            if let Some(sf) = specified_value.get_system() {
                longhands::system_font::resolve_system_font(sf, context);
            }

                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_stretch(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontStretch)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-kerning
    pub mod font_kerning {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            None,
            
            Normal,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontKerning,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_kerning();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::font_kerning::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_kerning(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontKerning)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-alternates
    pub mod font_variant_alternates {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontVariantAlternates as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontVariantAlternates as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantAlternates::default() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantAlternates::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontVariantAlternates as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariantAlternates,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variant_alternates();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontVariantAlternates>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variant_alternates(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantAlternates)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-east-asian
    pub mod font_variant_east_asian {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontVariantEastAsian as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontVariantEastAsian as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantEastAsian::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantEastAsian::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontVariantEastAsian as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariantEastAsian,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variant_east_asian();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontVariantEastAsian>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variant_east_asian(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantEastAsian)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-emoji
    pub mod font_variant_emoji {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            Text,
            
            Emoji,
            
            Unicode,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariantEmoji,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variant_emoji();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::font_variant_emoji::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variant_emoji(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantEmoji)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-ligatures
    pub mod font_variant_ligatures {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontVariantLigatures as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontVariantLigatures as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantLigatures::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantLigatures::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontVariantLigatures as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariantLigatures,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variant_ligatures();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontVariantLigatures>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variant_ligatures(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantLigatures)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-numeric
    pub mod font_variant_numeric {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontVariantNumeric as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontVariantNumeric as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariantNumeric::empty() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariantNumeric::empty() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontVariantNumeric as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariantNumeric,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variant_numeric();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontVariantNumeric>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variant_numeric(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantNumeric)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-variant-position
    pub mod font_variant_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            Sub,
            
            Super,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariantPosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variant_position();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::font_variant_position::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variant_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariantPosition)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#propdef-font-feature-settings
    pub mod font_feature_settings {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontFeatureSettings as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontFeatureSettings as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontFeatureSettings::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontFeatureSettings::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontFeatureSettings as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontFeatureSettings,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_feature_settings();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontFeatureSettings>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_feature_settings(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontFeatureSettings)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-4/#propdef-font-variation-settings
    pub mod font_variation_settings {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontVariationSettings as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontVariationSettings as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontVariationSettings::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontVariationSettings::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontVariationSettings as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontVariationSettings,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_variation_settings();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontVariationSettings>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_variation_settings(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontVariationSettings)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts-3/#propdef-font-language-override
    pub mod font_language_override {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontLanguageOverride as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontLanguageOverride as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontLanguageOverride::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontLanguageOverride::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontLanguageOverride as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontLanguageOverride,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_language_override();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontLanguageOverride>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_language_override(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontLanguageOverride)
        }
    }




    

    
        
    
    /// https://www.w3.org/TR/css-fonts-4/#font-optical-sizing-def
    pub mod font_optical_sizing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            None,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontOpticalSizing,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_optical_sizing();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::font_optical_sizing::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_optical_sizing(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontOpticalSizing)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-fonts/#font-palette-prop
    pub mod font_palette {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FontPalette as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FontPalette as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FontPalette::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::FontPalette::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FontPalette as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FontPalette,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_font_palette();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FontPalette>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_font_palette(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FontPalette)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _x_lang {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::XLang as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::XLang as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XLang::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::XLang as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::XLang,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__x_lang();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::XLang>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__x_lang(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XLang)
        }
    }




    
        
    
    /// https://mathml-refresh.github.io/mathml-core/#the-math-script-level-property
    pub mod math_depth {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::MathDepth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::MathDepth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::MathDepth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MathDepth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_math_depth();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::MathDepth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_math_depth(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MathDepth)
        }
    }




    

    
        
    
    /// https://mathml-refresh.github.io/mathml-core/#the-math-style-property
    pub mod math_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            Compact,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use crate::gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: u32
                    = structs::StyleMathStyle::Normal as u32;
                // We can't match on enum values if we're matching on a u32
                const COMPACT: u32
                    = structs::StyleMathStyle::Compact as u32;
            match kw  {
                    NORMAL => SpecifiedValue::Normal,
                    COMPACT => SpecifiedValue::Compact,
                _ => panic!("Found unexpected value in style struct for math-style property"),
            }
        }
    }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MathStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_math_style();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::math_style::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_math_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MathStyle)
        }
    }




    

    
        
    
    /// Internal (not web-exposed)
    pub mod _moz_math_variant {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            None,
            
            Normal,
            
            Bold,
            
            Italic,
            
            BoldItalic,
            
            Script,
            
            BoldScript,
            
            Fraktur,
            
            DoubleStruck,
            
            BoldFraktur,
            
            SansSerif,
            
            BoldSansSerif,
            
            SansSerifItalic,
            
            SansSerifBoldItalic,
            
            Monospace,
            
            Initial,
            
            Tailed,
            
            Looped,
            
            Stretched,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use crate::gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const NONE: u32
                    = structs::StyleMathVariant::None as u32;
                // We can't match on enum values if we're matching on a u32
                const NORMAL: u32
                    = structs::StyleMathVariant::Normal as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD: u32
                    = structs::StyleMathVariant::Bold as u32;
                // We can't match on enum values if we're matching on a u32
                const ITALIC: u32
                    = structs::StyleMathVariant::Italic as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_ITALIC: u32
                    = structs::StyleMathVariant::BoldItalic as u32;
                // We can't match on enum values if we're matching on a u32
                const SCRIPT: u32
                    = structs::StyleMathVariant::Script as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_SCRIPT: u32
                    = structs::StyleMathVariant::BoldScript as u32;
                // We can't match on enum values if we're matching on a u32
                const FRAKTUR: u32
                    = structs::StyleMathVariant::Fraktur as u32;
                // We can't match on enum values if we're matching on a u32
                const DOUBLE_STRUCK: u32
                    = structs::StyleMathVariant::DoubleStruck as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_FRAKTUR: u32
                    = structs::StyleMathVariant::BoldFraktur as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF: u32
                    = structs::StyleMathVariant::SansSerif as u32;
                // We can't match on enum values if we're matching on a u32
                const BOLD_SANS_SERIF: u32
                    = structs::StyleMathVariant::BoldSansSerif as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF_ITALIC: u32
                    = structs::StyleMathVariant::SansSerifItalic as u32;
                // We can't match on enum values if we're matching on a u32
                const SANS_SERIF_BOLD_ITALIC: u32
                    = structs::StyleMathVariant::SansSerifBoldItalic as u32;
                // We can't match on enum values if we're matching on a u32
                const MONOSPACE: u32
                    = structs::StyleMathVariant::Monospace as u32;
                // We can't match on enum values if we're matching on a u32
                const INITIAL: u32
                    = structs::StyleMathVariant::Initial as u32;
                // We can't match on enum values if we're matching on a u32
                const TAILED: u32
                    = structs::StyleMathVariant::Tailed as u32;
                // We can't match on enum values if we're matching on a u32
                const LOOPED: u32
                    = structs::StyleMathVariant::Looped as u32;
                // We can't match on enum values if we're matching on a u32
                const STRETCHED: u32
                    = structs::StyleMathVariant::Stretched as u32;
            match kw  {
                    NONE => SpecifiedValue::None,
                    NORMAL => SpecifiedValue::Normal,
                    BOLD => SpecifiedValue::Bold,
                    ITALIC => SpecifiedValue::Italic,
                    BOLD_ITALIC => SpecifiedValue::BoldItalic,
                    SCRIPT => SpecifiedValue::Script,
                    BOLD_SCRIPT => SpecifiedValue::BoldScript,
                    FRAKTUR => SpecifiedValue::Fraktur,
                    DOUBLE_STRUCK => SpecifiedValue::DoubleStruck,
                    BOLD_FRAKTUR => SpecifiedValue::BoldFraktur,
                    SANS_SERIF => SpecifiedValue::SansSerif,
                    BOLD_SANS_SERIF => SpecifiedValue::BoldSansSerif,
                    SANS_SERIF_ITALIC => SpecifiedValue::SansSerifItalic,
                    SANS_SERIF_BOLD_ITALIC => SpecifiedValue::SansSerifBoldItalic,
                    MONOSPACE => SpecifiedValue::Monospace,
                    INITIAL => SpecifiedValue::Initial,
                    TAILED => SpecifiedValue::Tailed,
                    LOOPED => SpecifiedValue::Looped,
                    STRETCHED => SpecifiedValue::Stretched,
                _ => panic!("Found unexpected value in style struct for -moz-math-variant property"),
            }
        }
    }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozMathVariant,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_math_variant();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_math_variant::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_math_variant(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMathVariant)
        }
    }




    
        
    
    /// Internal (not web-exposed)
    pub mod _x_text_scale {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::XTextScale as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::XTextScale as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::XTextScale::All }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::XTextScale as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::XTextScale,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__x_text_scale();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::XTextScale>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__x_text_scale(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XTextScale)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css2/visudet.html#propdef-line-height
    pub mod line_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LineHeight as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LineHeight as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LineHeight::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LineHeight as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::LineHeight,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_line_height();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LineHeight>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_line_height(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LineHeight)
        }
    }



pub mod system_font {
    //! We deal with system fonts here
    //!
    //! System fonts can only be set as a group via the font shorthand.
    //! They resolve at compute time (not parse time -- this lets the
    //! browser respond to changes to the OS font settings).
    //!
    //! While Gecko handles these as a separate property and keyword
    //! values on each property indicating that the font should be picked
    //! from the -x-system-font property, we avoid this. Instead,
    //! each font longhand has a special SystemFont variant which contains
    //! the specified system font. When the cascade function (in helpers)
    //! detects that a value has a system font, it will resolve it, and
    //! cache it on the ComputedValues. After this, it can be just fetched
    //! whenever a font longhand on the same element needs the system font.
    //!
    //! When a longhand property is holding a SystemFont, it's serialized
    //! to an empty string as if its value comes from a shorthand with
    //! variable reference. We may want to improve this behavior at some
    //! point. See also https://github.com/w3c/csswg-drafts/issues/1586.

    use crate::properties::longhands;
    use std::hash::{Hash, Hasher};
    use crate::values::computed::{ToComputedValue, Context};
    use crate::values::specified::font::SystemFont;
    // ComputedValues are compared at times
    // so we need these impls. We don't want to
    // add Eq to Number (which contains a float)
    // so instead we have an eq impl which skips the
    // cached values
    impl PartialEq for ComputedSystemFont {
        fn eq(&self, other: &Self) -> bool {
            self.system_font == other.system_font
        }
    }
    impl Eq for ComputedSystemFont {}

    impl Hash for ComputedSystemFont {
        fn hash<H: Hasher>(&self, hasher: &mut H) {
            self.system_font.hash(hasher)
        }
    }

    impl ToComputedValue for SystemFont {
        type ComputedValue = ComputedSystemFont;

        fn to_computed_value(&self, cx: &Context) -> Self::ComputedValue {
            use crate::gecko_bindings::bindings;
            use crate::gecko_bindings::structs::nsFont;
            use crate::values::computed::font::FontSize;
            use crate::values::specified::font::KeywordInfo;
            use crate::values::generics::NonNegative;
            use std::mem;

            let mut system = mem::MaybeUninit::<nsFont>::uninit();
            let system = unsafe {
                bindings::Gecko_nsFont_InitSystem(
                    system.as_mut_ptr(),
                    *self,
                    &**cx.style().get_font(),
                    cx.device().document()
                );
                &mut *system.as_mut_ptr()
            };
            let size = NonNegative(cx.maybe_zoom_text(system.size.0));
            let ret = ComputedSystemFont {
                font_family: system.family.clone(),
                font_size: FontSize {
                    computed_size: size,
                    used_size: size,
                    keyword_info: KeywordInfo::none()
                },
                font_weight: system.weight,
                font_stretch: system.stretch,
                font_style: system.style,
                system_font: *self,
            };
            unsafe { bindings::Gecko_nsFont_Destroy(system); }
            ret
        }

        fn from_computed_value(_: &ComputedSystemFont) -> Self {
            unreachable!()
        }
    }

    #[inline]
    /// Compute and cache a system font
    ///
    /// Must be called before attempting to compute a system font
    /// specified value
    pub fn resolve_system_font(system: SystemFont, context: &mut Context) {
        // Checking if context.cached_system_font.is_none() isn't enough,
        // if animating from one system font to another the cached system font
        // may change
        if Some(system) != context.cached_system_font.as_ref().map(|x| x.system_font) {
            let computed = system.to_computed_value(context);
            context.cached_system_font = Some(computed);
        }
    }

    #[derive(Clone, Debug)]
    pub struct ComputedSystemFont {
            pub font_family: longhands::font_family::computed_value::T,
            pub font_size: longhands::font_size::computed_value::T,
            pub font_style: longhands::font_style::computed_value::T,
            pub font_stretch: longhands::font_stretch::computed_value::T,
            pub font_weight: longhands::font_weight::computed_value::T,
        pub system_font: SystemFont,
    }

}


    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/font-smooth)
    pub mod _moz_osx_font_smoothing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            #[parse(aliases = "antialiased")]
            Grayscale,
            
            SubpixelAntialiased,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozOsxFontSmoothing,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_osx_font_smoothing();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_osx_font_smoothing::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_osx_font_smoothing(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozOsxFontSmoothing)
        }
    }




    
        
    
    /// Nonstandard (Internal-only)
    pub mod _moz_min_font_size_ratio {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Percentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Percentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Percentage::hundred() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Percentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozMinFontSizeRatio,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_min_font_size_ratio();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Percentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_min_font_size_ratio(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozMinFontSizeRatio)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */



// TODO: collapse. Well, do tables first.

    

    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-visibility
    pub mod visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Visible,
            
            Hidden,
            
            Collapse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Visible
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Visible
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Visibility,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_visibility();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::visibility::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_visibility(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Visibility)
        }
    }



// CSS Writing Modes Level 3
// https://drafts.csswg.org/css-writing-modes-3

    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-writing-mode
    pub mod writing_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            #[parse(aliases = "lr,lr-tb,rl,rl-tb")]
            HorizontalTb,
            
            #[parse(aliases = "tb,tb-rl")]
            VerticalRl,
            
            VerticalLr,
            
            SidewaysRl,
            
            SidewaysLr,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::HorizontalTb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::HorizontalTb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WritingMode,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_writing_mode();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::writing_mode::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_writing_mode(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WritingMode)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-direction
    pub mod direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Ltr,
            
            Rtl,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Ltr
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Ltr
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Direction,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_direction();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::direction::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_direction(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Direction)
        }
    }




    

    
        
    
    /// None (internal)
    pub mod _moz_box_collapse {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Flex,
            
            Legacy,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Flex
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Flex
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozBoxCollapse,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_box_collapse();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_box_collapse::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_box_collapse(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxCollapse)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-text-orientation
    pub mod text_orientation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Mixed,
            
            Upright,
            
            #[parse(aliases = "sideways-right")]
            Sideways,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Mixed
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Mixed
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextOrientation,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_orientation();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_orientation::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_orientation(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextOrientation)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-color-adjust/#print-color-adjust
    pub mod print_color_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PrintColorAdjust as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PrintColorAdjust as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PrintColorAdjust::Economy }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PrintColorAdjust as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PrintColorAdjust,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_print_color_adjust();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::PrintColorAdjust>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_print_color_adjust(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PrintColorAdjust)
        }
    }



// According to to CSS-IMAGES-3, `optimizespeed` and `optimizequality` are synonyms for `auto`
// And, firefox doesn't support `pixelated` yet (https://bugzilla.mozilla.org/show_bug.cgi?id=856337)

    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-image-rendering
    pub mod image_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ImageRendering as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ImageRendering as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ImageRendering::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ImageRendering as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ImageRendering,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_image_rendering();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ImageRendering>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_image_rendering(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImageRendering)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-image-orientation
    pub mod image_orientation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            FromImage,
            
            None,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::FromImage
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::FromImage
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ImageOrientation,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_image_orientation();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::image_orientation::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_image_orientation(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImageOrientation)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */



// Section 10 - Text


    

    
        
    
    /// https://www.w3.org/TR/css-inline-3/#propdef-dominant-baseline
    pub mod dominant_baseline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Ideographic,
            
            Alphabetic,
            
            Hanging,
            
            Mathematical,
            
            Central,
            
            Middle,
            
            TextAfterEdge,
            
            TextBeforeEdge,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::DominantBaseline,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_dominant_baseline();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::dominant_baseline::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_dominant_baseline(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::DominantBaseline)
        }
    }




    

    
        
    
    /// https://svgwg.org/svg2-draft/text.html#TextAnchorProperty
    pub mod text_anchor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Start,
            
            Middle,
            
            End,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Start
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Start
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextAnchor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_anchor();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_anchor::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_anchor(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAnchor)
        }
    }



// Section 11 - Painting: Filling, Stroking and Marker Symbols

    

    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#ColorInterpolationProperty
    pub mod color_interpolation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Srgb,
            
            Auto,
            
            Linearrgb,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Srgb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Srgb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColorInterpolation,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_color_interpolation();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::color_interpolation::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_color_interpolation(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorInterpolation)
        }
    }




    

    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#ColorInterpolationFiltersProperty
    pub mod color_interpolation_filters {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Linearrgb,
            
            Auto,
            
            Srgb,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Linearrgb
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Linearrgb
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColorInterpolationFilters,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_color_interpolation_filters();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::color_interpolation_filters::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_color_interpolation_filters(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorInterpolationFilters)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#SpecifyingFillPaint
    pub mod fill {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGPaint as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGPaint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { crate::values::computed::SVGPaint::BLACK }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGPaint as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Fill,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_fill();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::SVGPaint>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_fill(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Fill)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#FillOpacity
    pub mod fill_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGOpacity as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGOpacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGOpacity as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FillOpacity,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_fill_opacity();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::SVGOpacity>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_fill_opacity(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FillOpacity)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#FillRuleProperty
    pub mod fill_rule {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FillRule as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FillRule as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FillRule as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FillRule,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_fill_rule();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FillRule>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_fill_rule(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FillRule)
        }
    }




    

    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#ShapeRenderingProperty
    pub mod shape_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Optimizespeed,
            
            Crispedges,
            
            Geometricprecision,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ShapeRendering,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_shape_rendering();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::shape_rendering::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_shape_rendering(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ShapeRendering)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#SpecifyingStrokePaint
    pub mod stroke {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGPaint as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGPaint as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGPaint as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Stroke,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::SVGPaint>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_stroke(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Stroke)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#StrokeWidth
    pub mod stroke_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::SVGWidth::one() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StrokeWidth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke_width();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::SVGWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stroke_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeWidth)
        }
    }




    

    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#StrokeLinecapProperty
    pub mod stroke_linecap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Butt,
            
            Round,
            
            Square,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Butt
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Butt
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StrokeLinecap,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke_linecap();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::stroke_linecap::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stroke_linecap(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeLinecap)
        }
    }




    

    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#StrokeLinejoinProperty
    pub mod stroke_linejoin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Miter,
            
            Round,
            
            Bevel,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Miter
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Miter
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StrokeLinejoin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke_linejoin();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::stroke_linejoin::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stroke_linejoin(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeLinejoin)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#StrokeMiterlimitProperty
    pub mod stroke_miterlimit {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(4.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeNumber as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StrokeMiterlimit,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke_miterlimit();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeNumber>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stroke_miterlimit(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeMiterlimit)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#StrokeOpacity
    pub mod stroke_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGOpacity as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGOpacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGOpacity as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StrokeOpacity,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke_opacity();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::SVGOpacity>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stroke_opacity(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeOpacity)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#StrokeDashing
    pub mod stroke_dasharray {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGStrokeDashArray as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGStrokeDashArray as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGStrokeDashArray as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StrokeDasharray,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke_dasharray();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::SVGStrokeDashArray>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stroke_dasharray(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeDasharray)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#StrokeDashing
    pub mod stroke_dashoffset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGLength as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::SVGLength::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGLength as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StrokeDashoffset,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_stroke_dashoffset();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::SVGLength>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stroke_dashoffset(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StrokeDashoffset)
        }
    }



// Section 14 - Clipping, Masking and Compositing

    
        
    
    /// https://svgwg.org/svg2-draft/masking.html#ClipRuleProperty
    pub mod clip_rule {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FillRule as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FillRule as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FillRule as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ClipRule,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_clip_rule();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::FillRule>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_clip_rule(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ClipRule)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#VertexMarkerProperties
    pub mod marker_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::url::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::url::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::url::UrlOrNone::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::url::UrlOrNone as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MarkerStart,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_marker_start();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::url::UrlOrNone>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_marker_start(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarkerStart)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#VertexMarkerProperties
    pub mod marker_mid {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::url::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::url::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::url::UrlOrNone::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::url::UrlOrNone as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MarkerMid,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_marker_mid();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::url::UrlOrNone>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_marker_mid(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarkerMid)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#VertexMarkerProperties
    pub mod marker_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::url::UrlOrNone as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::url::UrlOrNone as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::url::UrlOrNone::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::url::UrlOrNone as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MarkerEnd,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_marker_end();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::url::UrlOrNone>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_marker_end(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarkerEnd)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#PaintOrder
    pub mod paint_order {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SVGPaintOrder as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SVGPaintOrder as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::SVGPaintOrder::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SVGPaintOrder as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PaintOrder,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_paint_order();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::SVGPaintOrder>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_paint_order(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaintOrder)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-context-properties)
    pub mod _moz_context_properties {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::MozContextProperties as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::MozContextProperties as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MozContextProperties::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::MozContextProperties as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozContextProperties,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_context_properties();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::MozContextProperties>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_context_properties(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozContextProperties)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-border-collapse
    pub mod border_collapse {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Separate,
            
            Collapse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Separate
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Separate
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BorderCollapse,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_border_collapse();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::border_collapse::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_border_collapse(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BorderCollapse)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-empty-cells
    pub mod empty_cells {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Show,
            
            Hide,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Show
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Show
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::EmptyCells,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_empty_cells();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::empty_cells::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_empty_cells(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::EmptyCells)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-caption-side
    pub mod caption_side {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::table::CaptionSide as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::table::CaptionSide as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::table::CaptionSide::Top }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::table::CaptionSide as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::CaptionSide,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_caption_side();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::table::CaptionSide>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_caption_side(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CaptionSide)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-border-spacing
    pub mod border_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BorderSpacing::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderSpacing as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BorderSpacing,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_border_spacing();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::BorderSpacing>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_border_spacing(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::BorderSpacing)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-color/#color
    pub mod color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ColorPropertyValue as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ColorPropertyValue as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { crate::color::AbsoluteColor::BLACK }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ColorPropertyValue as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Color,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_color();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ColorPropertyValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Color)
        }
    }



// CSS Text Module Level 3


    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-transform
    pub mod text_transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextTransform as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextTransform as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextTransform::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextTransform as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextTransform,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_transform();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextTransform>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_transform(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextTransform)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-hyphens
    pub mod hyphens {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Manual,
            
            None,
            
            Auto,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Manual
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Manual
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Hyphens,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_hyphens();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::hyphens::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_hyphens(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Hyphens)
        }
    }



// TODO: Support <percentage>

    

    
        
    
    /// https://drafts.csswg.org/css-size-adjust/#adjustment-control
    pub mod _moz_text_size_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            None,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozTextSizeAdjust,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_text_size_adjust();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_text_size_adjust::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_text_size_adjust(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTextSizeAdjust)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-indent
    pub mod text_indent {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextIndent as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextIndent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextIndent::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextIndent as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextIndent,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_indent();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextIndent>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_indent(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextIndent)
        }
    }



// Also known as "word-wrap" (which is more popular because of IE), but this is
// the preferred name per CSS-TEXT 6.2.

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-overflow-wrap
    pub mod overflow_wrap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OverflowWrap as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OverflowWrap as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OverflowWrap::Normal }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OverflowWrap as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OverflowWrap,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_overflow_wrap();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OverflowWrap>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overflow_wrap(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowWrap)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-word-break
    pub mod word_break {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::WordBreak as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::WordBreak as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::WordBreak::Normal }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::WordBreak as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WordBreak,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_word_break();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::WordBreak>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_word_break(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WordBreak)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-justify
    pub mod text_justify {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextJustify as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextJustify as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextJustify::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextJustify as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextJustify,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_justify();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextJustify>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_justify(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextJustify)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-align-last
    pub mod text_align_last {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextAlignLast as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextAlignLast as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::text::TextAlignLast::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextAlignLast as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextAlignLast,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_align_last();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextAlignLast>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_align_last(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAlignLast)
        }
    }



// TODO make this a shorthand and implement text-align-last/text-align-all

    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-text-align
    pub mod text_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextAlign as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextAlign as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextAlign::Start }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextAlign as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextAlign,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_align();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextAlign>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_align(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextAlign)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-letter-spacing
    pub mod letter_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LetterSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LetterSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LetterSpacing::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LetterSpacing as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::LetterSpacing,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_letter_spacing();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LetterSpacing>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_letter_spacing(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LetterSpacing)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text/#propdef-word-spacing
    pub mod word_spacing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::WordSpacing as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::WordSpacing as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::WordSpacing::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::WordSpacing as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WordSpacing,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_word_spacing();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::WordSpacing>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_word_spacing(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WordSpacing)
        }
    }



// TODO: `white-space-collapse: discard` not yet supported

    

    
        
    
    /// https://drafts.csswg.org/css-text-4/#propdef-white-space-collapse
    pub mod white_space_collapse {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Collapse,
            
            Preserve,
            
            PreserveBreaks,
            
            PreserveSpaces,
            
            BreakSpaces,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Collapse
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Collapse
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WhiteSpaceCollapse,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_white_space_collapse();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::white_space_collapse::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_white_space_collapse(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WhiteSpaceCollapse)
        }
    }




    
        
    
    
    /// https://drafts.csswg.org/css-text-decor-3/#text-shadow-property
    pub mod text_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::SimpleShadow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::SimpleShadow as T;
        }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::SimpleShadow as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for text-shadow.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    crate::ArcSlice<T>;

            pub type UnderlyingOwnedList<T> =
                    crate::OwnedSlice<T>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(if_empty = "none", iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub use self::ComputedList as List;

            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToCss)]
            #[css(comma)]
            pub struct ComputedList(
                #[css(if_empty = "none", iterable)]
                #[ignore_malloc_size_of = "Arc"]
                pub UnderlyingList<single_value::T>,
            );

            type ResolvedList = OwnedList<<single_value::T as ToResolvedValue>::ResolvedValue>;
            impl ToResolvedValue for ComputedList {
                type ResolvedValue = ResolvedList;

                fn to_resolved_value(self, context: &crate::values::resolved::Context) -> Self::ResolvedValue {
                    OwnedList(
                        self.0
                            .iter()
                            .cloned()
                            .map(|v| v.to_resolved_value(context))
                            .collect()
                    )
                }

                fn from_resolved_value(resolved: Self::ResolvedValue) -> Self {
                    let iter =
                        resolved.0.into_iter().map(ToResolvedValue::from_resolved_value);
                    ComputedList(UnderlyingList::from_iter(iter))
                }
            }

            impl From<ComputedList> for UnderlyingList<single_value::T> {
                #[inline]
                fn from(l: ComputedList) -> Self {
                    l.0
                }
            }
            impl From<UnderlyingList<single_value::T>> for ComputedList {
                #[inline]
                fn from(l: UnderlyingList<single_value::T>) -> Self {
                    List(l)
                }
            }


            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;

            impl ToAnimatedValue for ComputedList {
                type AnimatedValue = AnimatedList;

                fn to_animated_value(self) -> Self::AnimatedValue {
                    OwnedList(
                        self.0.iter().map(|v| v.clone().to_animated_value()).collect()
                    )
                }

                fn from_animated_value(animated: Self::AnimatedValue) -> Self {
                    let iter =
                        animated.0.into_iter().map(ToAnimatedValue::from_animated_value);
                    ComputedList(UnderlyingList::from_iter(iter))
                }
            }

            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::with_zero::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::with_zero::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of text-shadow.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(if_empty = "none", iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                computed_value::List(Default::default())
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

            if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue(Default::default()))
            }

            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;


        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextShadow,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_shadow();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_shadow::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_shadow(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextShadow)
        }
    }





    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-style
    pub mod text_emphasis_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextEmphasisStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextEmphasisStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextEmphasisStyle::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { SpecifiedValue::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextEmphasisStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextEmphasisStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_emphasis_style();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextEmphasisStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_emphasis_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextEmphasisStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-position
    pub mod text_emphasis_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextEmphasisPosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextEmphasisPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextEmphasisPosition::OVER }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TextEmphasisPosition::OVER }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextEmphasisPosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextEmphasisPosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_emphasis_position();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextEmphasisPosition>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_emphasis_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextEmphasisPosition)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-emphasis-color
    pub mod text_emphasis_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextEmphasisColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_emphasis_color();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_emphasis_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextEmphasisColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-3/#tab-size-property
    pub mod tab_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthOrNumber as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthOrNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::length::LengthOrNumber::Number(From::from(8.0)) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthOrNumber as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TabSize,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_tab_size();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthOrNumber>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_tab_size(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TabSize)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-3/#line-break-property
    pub mod line_break {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LineBreak as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LineBreak as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LineBreak::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LineBreak as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::LineBreak,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_line_break();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LineBreak>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_line_break(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LineBreak)
        }
    }



// CSS Compatibility
// https://compat.spec.whatwg.org

    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-fill-color
    pub mod _webkit_text_fill_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WebkitTextFillColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__webkit_text_fill_color();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__webkit_text_fill_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextFillColor)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke-color
    pub mod _webkit_text_stroke_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WebkitTextStrokeColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__webkit_text_stroke_color();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__webkit_text_stroke_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextStrokeColor)
        }
    }




    
        
    
    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke-width
    pub mod _webkit_text_stroke_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LineWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LineWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au(0) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::LineWidth::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LineWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WebkitTextStrokeWidth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__webkit_text_stroke_width();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LineWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__webkit_text_stroke_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextStrokeWidth)
        }
    }



// CSS Ruby Layout Module Level 1
// https://drafts.csswg.org/css-ruby/

    

    
        
    
    /// https://drafts.csswg.org/css-ruby/#ruby-align-property
    pub mod ruby_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            SpaceAround,
            
            Start,
            
            Center,
            
            SpaceBetween,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::SpaceAround
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::SpaceAround
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::RubyAlign,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_ruby_align();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::ruby_align::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_ruby_align(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::RubyAlign)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ruby/#ruby-position-property
    pub mod ruby_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::RubyPosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::RubyPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::RubyPosition::AlternateOver }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::RubyPosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::RubyPosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_ruby_position();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::RubyPosition>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_ruby_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::RubyPosition)
        }
    }



// CSS Writing Modes Module Level 3
// https://drafts.csswg.org/css-writing-modes-3/


    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes-3/#text-combine-upright
    pub mod text_combine_upright {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            None,
            
            All,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextCombineUpright,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_combine_upright();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_combine_upright::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_combine_upright(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextCombineUpright)
        }
    }



// SVG 2: Section 13 - Painting: Filling, Stroking and Marker Symbols

    

    
        
    
    /// https://svgwg.org/svg2-draft/painting.html#TextRenderingProperty
    pub mod text_rendering {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Optimizespeed,
            
            Optimizelegibility,
            
            Geometricprecision,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextRendering,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_rendering();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_rendering::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_rendering(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextRendering)
        }
    }




    
        
    
    /// Nonstandard
    pub mod _moz_control_character_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::text::MozControlCharacterVisibility as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::text::MozControlCharacterVisibility as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::text::MozControlCharacterVisibility as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozControlCharacterVisibility,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_control_character_visibility();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::text::MozControlCharacterVisibility>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_control_character_visibility(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozControlCharacterVisibility)
        }
    }



// text underline offset

    
        
    
    /// https://drafts.csswg.org/css-text-decor-4/#underline-offset
    pub mod text_underline_offset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextUnderlineOffset,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_underline_offset();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_underline_offset(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextUnderlineOffset)
        }
    }



// text underline position

    
        
    
    /// https://drafts.csswg.org/css-text-decor-3/#text-underline-position-property
    pub mod text_underline_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextUnderlinePosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextUnderlinePosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextUnderlinePosition::AUTO }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextUnderlinePosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextUnderlinePosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_underline_position();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextUnderlinePosition>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_underline_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextUnderlinePosition)
        }
    }



// text decoration skip ink

    
        
    
    /// https://drafts.csswg.org/css-text-decor-4/#text-decoration-skip-ink-property
    pub mod text_decoration_skip_ink {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextDecorationSkipInk as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextDecorationSkipInk as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextDecorationSkipInk::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextDecorationSkipInk as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextDecorationSkipInk,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_decoration_skip_ink();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextDecorationSkipInk>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_decoration_skip_ink(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationSkipInk)
        }
    }



// hyphenation character

    
        
    
    /// https://www.w3.org/TR/css-text-4/#hyphenate-character
    pub mod hyphenate_character {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::HyphenateCharacter as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::HyphenateCharacter as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::HyphenateCharacter::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::HyphenateCharacter as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::HyphenateCharacter,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_hyphenate_character();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::HyphenateCharacter>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_hyphenate_character(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::HyphenateCharacter)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-color-adjust-1/#forced-color-adjust-prop
    pub mod forced_color_adjust {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ForcedColorAdjust as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ForcedColorAdjust as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ForcedColorAdjust::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ForcedColorAdjust as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ForcedColorAdjust,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_forced_color_adjust();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ForcedColorAdjust>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_forced_color_adjust(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ForcedColorAdjust)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text/#MISSING
    pub mod _webkit_text_security {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            None,
            
            Circle,
            
            Disc,
            
            Square,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::WebkitTextSecurity,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__webkit_text_security();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_webkit_text_security::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__webkit_text_security(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::WebkitTextSecurity)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text-4/#propdef-text-wrap-mode
    pub mod text_wrap_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Wrap,
            
            Nowrap,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Wrap
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Wrap
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextWrapMode,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_wrap_mode();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_wrap_mode::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_wrap_mode(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextWrapMode)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text-4/#text-wrap-style
    pub mod text_wrap_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Stable,
            
            Balance,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextWrapStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_text_wrap_style();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_wrap_style::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_wrap_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextWrapStyle)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-ui/#cursor
    pub mod cursor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Cursor as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Cursor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Cursor::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Cursor::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Cursor as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Cursor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_cursor();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Cursor>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_cursor(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Cursor)
        }
    }



// NB: `pointer-events: auto` (and use of `pointer-events` in anything that isn't SVG, in fact)
// is nonstandard, slated for CSS4-UI.
// TODO(pcwalton): SVG-only values.

    

    
        
    
    /// https://svgwg.org/svg2-draft/interact.html#PointerEventsProperty
    pub mod pointer_events {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            None,
            
            Visiblepainted,
            
            Visiblefill,
            
            Visiblestroke,
            
            Visible,
            
            Painted,
            
            Fill,
            
            Stroke,
            
            All,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PointerEvents,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_pointer_events();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::pointer_events::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_pointer_events(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PointerEvents)
        }
    }




    

    
        
    
    /// Nonstandard (https://html.spec.whatwg.org/multipage/#inert-subtrees)
    pub mod _moz_inert {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            None,
            
            Inert,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozInert,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_inert();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_inert::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_inert(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozInert)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-input)
    pub mod _moz_user_input {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            None,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozUserInput,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_user_input();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_user_input::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_user_input(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserInput)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-modify)
    pub mod _moz_user_modify {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            ReadOnly,
            
            ReadWrite,
            
            WriteOnly,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ReadOnly
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ReadOnly
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

            
            
    
    #[cfg(feature = "gecko")]
    impl SpecifiedValue {
        /// Obtain a specified value from a Gecko keyword value
        ///
        /// Intended for use with presentation attributes, not style structs
        pub fn from_gecko_keyword(kw: u32) -> Self {
            use crate::gecko_bindings::structs;
                // We can't match on enum values if we're matching on a u32
                const READ_ONLY: u32
                    = structs::StyleUserModify::ReadOnly as u32;
                // We can't match on enum values if we're matching on a u32
                const READ_WRITE: u32
                    = structs::StyleUserModify::ReadWrite as u32;
                // We can't match on enum values if we're matching on a u32
                const WRITE_ONLY: u32
                    = structs::StyleUserModify::WriteOnly as u32;
            match kw  {
                    READ_ONLY => SpecifiedValue::ReadOnly,
                    READ_WRITE => SpecifiedValue::ReadWrite,
                    WRITE_ONLY => SpecifiedValue::WriteOnly,
                _ => panic!("Found unexpected value in style struct for -moz-user-modify property"),
            }
        }
    }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozUserModify,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_user_modify();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_user_modify::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_user_modify(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserModify)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-user-focus)
    pub mod _moz_user_focus {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            None,
            
            Ignore,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozUserFocus,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_user_focus();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_user_focus::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_user_focus(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozUserFocus)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#caret-color
    pub mod caret_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::color::CaretColor as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::color::CaretColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::color::CaretColor::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::color::CaretColor as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::CaretColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_caret_color();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::color::CaretColor>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_caret_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::CaretColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui-4/#widget-accent
    pub mod accent_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ColorOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ColorOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::color::ColorOrAuto::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ColorOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AccentColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_accent_color();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ColorOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_accent_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AccentColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-color-adjust/#color-scheme-prop
    pub mod color_scheme {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ColorScheme as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ColorScheme as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::color::ColorScheme::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ColorScheme as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColorScheme,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_color_scheme();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ColorScheme>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_color_scheme(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColorScheme)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-scrollbars-1/#scrollbar-color
    pub mod scrollbar_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ui::ScrollbarColor as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ui::ScrollbarColor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ui::ScrollbarColor as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollbarColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_scrollbar_color();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::ui::ScrollbarColor>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_scrollbar_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ScrollbarColor)
        }
    }




    
        
    
    /// Internal
    pub mod _moz_theme {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ui::MozTheme as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ui::MozTheme as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::ui::MozTheme::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ui::MozTheme as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozTheme,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset__moz_theme();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ui::MozTheme>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_theme(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozTheme)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    

    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-position
    pub mod list_style_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Outside,
            
            Inside,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Outside
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Outside
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ListStylePosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_list_style_position();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::list_style_position::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_list_style_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ListStylePosition)
        }
    }



// TODO(pcwalton): Implement the full set of counter styles per CSS-COUNTER-STYLES [1] 6.1:
//
//     decimal-leading-zero, armenian, upper-armenian, lower-armenian, georgian, lower-roman,
//     upper-roman
//
// [1]: http://dev.w3.org/csswg/css-counter-styles/
    
    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-type
    pub mod list_style_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ListStyleType as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ListStyleType as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ListStyleType::disc() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::ListStyleType::disc() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ListStyleType as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ListStyleType,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_list_style_type();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ListStyleType>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_list_style_type(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ListStyleType)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-lists/#propdef-list-style-image
    pub mod list_style_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Image as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Image as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Image::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Image::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Image as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ListStyleImage,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_list_style_image();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Image>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_list_style_image(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ListStyleImage)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-content/#propdef-quotes
    pub mod quotes {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Quotes as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Quotes as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Quotes::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Quotes as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = false;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Quotes,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Initial => {
                                context.builder.reset_quotes();
                        },
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Inherit => {
                                declaration.debug_crash("Unexpected inherit or unset for inherited property");
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Quotes>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_quotes(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Quotes)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-top
    pub mod margin_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MarginTop.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_margin_top();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_margin_top(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginTop)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-right
    pub mod margin_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MarginRight.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_margin_right();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_margin_right(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginRight)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-bottom
    pub mod margin_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MarginBottom.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_margin_bottom();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_margin_bottom(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBottom)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-margin-left
    pub mod margin_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MarginLeft.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_margin_left();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_margin_left(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginLeft)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBlockStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginBlockEnd)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginInlineStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-margin-True
    pub mod margin_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MarginInlineEnd)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-overflow/#propdef-overflow-clip-margin
    pub mod overflow_clip_margin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Length::parse_non_negative(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OverflowClipMargin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_overflow_clip_margin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Length>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_overflow_clip_margin(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OverflowClipMargin)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-top
    pub mod scroll_margin_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollMarginTop.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_margin_top();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Length>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_margin_top(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginTop)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-right
    pub mod scroll_margin_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollMarginRight.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_margin_right();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Length>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_margin_right(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginRight)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-bottom
    pub mod scroll_margin_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollMarginBottom.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_margin_bottom();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Length>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_margin_bottom(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginBottom)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-left
    pub mod scroll_margin_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollMarginLeft.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_margin_left();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Length>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_margin_left(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginLeft)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-block-start
    pub mod scroll_margin_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginBlockStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-block-end
    pub mod scroll_margin_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginBlockEnd)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-inline-start
    pub mod scroll_margin_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginInlineStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-inline-end
    pub mod scroll_margin_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollMarginInlineEnd)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-color
    pub mod outline_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OutlineColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_outline_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_outline_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-style
    pub mod outline_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::OutlineStyle as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::OutlineStyle as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::OutlineStyle::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::OutlineStyle::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::OutlineStyle as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OutlineStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_outline_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::OutlineStyle>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_outline_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-width
    pub mod outline_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BorderSideWidth as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BorderSideWidth as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { app_units::Au::from_px(3) }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BorderSideWidth::medium() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BorderSideWidth as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OutlineWidth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_outline_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BorderSideWidth>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_outline_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineWidth)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-outline-offset
    pub mod outline_offset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { crate::values::computed::Length::new(0.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::OutlineOffset,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_outline_offset();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Length>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_outline_offset(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::OutlineOffset)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-top
    pub mod padding_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::PaddingTop.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_padding_top();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_padding_top(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingTop)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-right
    pub mod padding_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::PaddingRight.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_padding_right();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_padding_right(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingRight)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-bottom
    pub mod padding_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::PaddingBottom.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_padding_bottom();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_padding_bottom(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBottom)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-padding-left
    pub mod padding_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::NonNegativeLengthPercentage::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::PaddingLeft.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_padding_left();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_padding_left(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingLeft)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBlockStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingBlockEnd)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingInlineStart)
        }
    }


    
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-padding-True
    pub mod padding_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PaddingInlineEnd)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-top
    pub mod scroll_padding_top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollPaddingTop.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_padding_top();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_padding_top(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingTop)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-right
    pub mod scroll_padding_right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollPaddingRight.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_padding_right();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_padding_right(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingRight)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-bottom
    pub mod scroll_padding_bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollPaddingBottom.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_padding_bottom();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_padding_bottom(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingBottom)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-left
    pub mod scroll_padding_left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ScrollPaddingLeft.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_padding_left();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scroll_padding_left(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingLeft)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-block-start
    pub mod scroll_padding_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingBlockStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-block-end
    pub mod scroll_padding_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingBlockEnd)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-inline-start
    pub mod scroll_padding_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingInlineStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-inline-end
    pub mod scroll_padding_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollPaddingInlineEnd)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    
        
    
    /// https://drafts.csswg.org/css-page-3/#page-size-prop
    pub mod size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PageSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PageSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PageSize::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PageSize::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PageSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Size,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_size();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::PageSize>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_size(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::Size)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-page-3/#using-named-pages
    pub mod page {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PageName as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PageName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PageName::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PageName as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Page,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_page();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::PageName>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_page(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Page)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-page-3/#page-orientation-prop
    pub mod page_orientation {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PageOrientation as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PageOrientation as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PageOrientation::Upright }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PageOrientation::Upright }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PageOrientation as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PageOrientation,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_page_orientation();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::PageOrientation>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_page_orientation(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PageOrientation)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




// "top" / "left" / "bottom" / "right"
    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-top
    pub mod top {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::Top.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_top();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_top(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Top)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-right
    pub mod right {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::Right.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_right();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_right(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Right)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-bottom
    pub mod bottom {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::Bottom.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_bottom();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_bottom(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Bottom)
        }
    }


    
    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#propdef-left
    pub mod left {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::LengthPercentageOrAuto::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::Left.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_left();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_left(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Left)
        }
    }


// inset-* logical properties, map to "top" / "left" / "bottom" / "right"
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inset-block-start
    pub mod inset_block_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InsetBlockStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inset-block-end
    pub mod inset_block_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InsetBlockEnd)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inset-inline-start
    pub mod inset_inline_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InsetInlineStart)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inset-inline-end
    pub mod inset_inline_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InsetInlineEnd)
        }
    }




    
        
    
    /// https://www.w3.org/TR/CSS2/visuren.html#z-index
    pub mod z_index {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ZIndex as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ZIndex as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ZIndex::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ZIndex as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ZIndex,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_z_index();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ZIndex>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_z_index(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ZIndex)
        }
    }



// CSS Flexible Box Layout Module Level 1
// http://www.w3.org/TR/css3-flexbox/

// Flex container properties

    

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-direction-property
    pub mod flex_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Row,
            
            RowReverse,
            
            Column,
            
            ColumnReverse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Row
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Row
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FlexDirection,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_flex_direction();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::flex_direction::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_flex_direction(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexDirection)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-wrap-property
    pub mod flex_wrap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Nowrap,
            
            Wrap,
            
            WrapReverse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Nowrap
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Nowrap
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FlexWrap,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_flex_wrap();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::flex_wrap::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_flex_wrap(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexWrap)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-justify-content
    pub mod justify_content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::JustifyContent as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::JustifyContent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::JustifyContent(specified::ContentDistribution::normal()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::JustifyContent as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::JustifyContent,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_justify_content();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::JustifyContent>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_justify_content(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifyContent)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-align-content
    pub mod align_content {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AlignContent as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AlignContent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignContent(specified::ContentDistribution::normal()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AlignContent as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AlignContent,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_align_content();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::AlignContent>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_align_content(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignContent)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-align-items
    pub mod align_items {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AlignItems as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AlignItems as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignItems::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AlignItems as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AlignItems,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_align_items();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::AlignItems>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_align_items(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignItems)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#propdef-justify-items
    pub mod justify_items {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::JustifyItems as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::JustifyItems as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::JustifyItems::legacy() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::JustifyItems as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::JustifyItems,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_justify_items();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::JustifyItems>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_justify_items(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifyItems)
        }
    }



// Flex item properties

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-grow-property
    pub mod flex_grow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(0.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeNumber as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FlexGrow,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_flex_grow();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeNumber>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_flex_grow(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexGrow)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-shrink-property
    pub mod flex_shrink {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(1.0) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeNumber as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FlexShrink,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_flex_shrink();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeNumber>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_flex_shrink(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FlexShrink)
        }
    }



// https://drafts.csswg.org/css-align/#align-self-property
    
    
        
    
    /// https://drafts.csswg.org/css-align/#align-self-property
    pub mod align_self {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AlignSelf as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AlignSelf as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::AlignSelf(specified::SelfAlignment::auto()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AlignSelf as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AlignSelf,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_align_self();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::AlignSelf>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_align_self(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AlignSelf)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-align/#justify-self-property
    pub mod justify_self {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::JustifySelf as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::JustifySelf as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::JustifySelf(specified::SelfAlignment::auto()) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::JustifySelf as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::JustifySelf,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_justify_self();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::JustifySelf>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_justify_self(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::JustifySelf)
        }
    }



// https://drafts.csswg.org/css-flexbox/#propdef-order

    
        
    
    /// https://drafts.csswg.org/css-flexbox/#order-property
    pub mod order {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Integer as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Integer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Integer as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Order,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_order();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Integer>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_order(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Order)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-flexbox/#flex-basis-property
    pub mod flex_basis {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::FlexBasis as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::FlexBasis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::FlexBasis::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::FlexBasis as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FlexBasis,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_flex_basis();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::FlexBasis>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_flex_basis(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::FlexBasis)
        }
    }



    
    // width, height, block-size, inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Size::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::Height.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_height();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Size>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_height(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Height)
        }
    }


    // min-width, min-height, min-block-size, min-inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod min_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Size::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MinHeight.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_min_height();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Size>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_min_height(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinHeight)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-height
    pub mod max_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::MaxSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::MaxSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxSize::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MaxSize::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MaxHeight.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_max_height();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::MaxSize>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_max_height(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxHeight)
        }
    }


    
    // width, height, block-size, inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Size::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::Width.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Size>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Width)
        }
    }


    // min-width, min-height, min-block-size, min-inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod min_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Size::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MinWidth.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_min_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Size>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_min_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinWidth)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-box/#propdef-width
    pub mod max_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::MaxSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::MaxSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxSize::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::MaxSize::parse_quirky(context, input, AllowQuirks::Yes)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::MaxWidth.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_max_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::MaxSize>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_max_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxWidth)
        }
    }


    
    // width, height, block-size, inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Size as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BlockSize)
        }
    }


    // min-width, min-height, min-block-size, min-inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod min_block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Size as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinBlockSize)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-block-size
    pub mod max_block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::MaxSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::MaxSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxSize::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::MaxSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxBlockSize)
        }
    }


    
    // width, height, block-size, inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Size as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InlineSize)
        }
    }


    // min-width, min-height, min-block-size, min-inline-size
    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod min_inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Size as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Size as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Size::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Size as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MinInlineSize)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-logical-props/#propdef-inline-size
    pub mod max_inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::MaxSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::MaxSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MaxSize::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::MaxSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaxInlineSize)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-anchor-position-1/#propdef-position-anchor
    pub mod position_anchor {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PositionAnchor as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PositionAnchor as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PositionAnchor::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PositionAnchor as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PositionAnchor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_position_anchor();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::PositionAnchor>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_position_anchor(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PositionAnchor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-anchor-position-1/#propdef-position-visibility
    pub mod position_visibility {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PositionVisibility as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PositionVisibility as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PositionVisibility::ALWAYS }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionVisibility::ALWAYS }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PositionVisibility as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PositionVisibility,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_position_visibility();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::PositionVisibility>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_position_visibility(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PositionVisibility)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-anchor-position-1/#typedef-inset-area
    pub mod inset_area {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::InsetArea as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::InsetArea as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::InsetArea::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::InsetArea::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::InsetArea as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::InsetArea,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_inset_area();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::InsetArea>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_inset_area(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InsetArea)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-anchor-position-1/#position-try-options
    pub mod position_try_options {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PositionTryOptions as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PositionTryOptions as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PositionTryOptions::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionTryOptions::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PositionTryOptions as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PositionTryOptions,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_position_try_options();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::PositionTryOptions>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_position_try_options(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PositionTryOptions)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-anchor-position-1/#position-try-order-property
    pub mod position_try_order {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::PositionTryOrder as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::PositionTryOrder as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::PositionTryOrder::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionTryOrder::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::PositionTryOrder as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::PositionTryOrder,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_position_try_order();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::PositionTryOrder>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_position_try_order(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::PositionTryOrder)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-box-sizing
    pub mod box_sizing {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            ContentBox,
            
            BorderBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::ContentBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::ContentBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::BoxSizing,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_box_sizing();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::box_sizing::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_box_sizing(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::BoxSizing)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-images/#propdef-object-fit
    pub mod object_fit {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Fill,
            
            Contain,
            
            Cover,
            
            None,
            
            ScaleDown,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Fill
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Fill
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ObjectFit,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_object_fit();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::object_fit::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_object_fit(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ObjectFit)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-images-3/#the-object-position
    pub mod object_position {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Position as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Position as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Position::center() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Position as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ObjectPosition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_object_position();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::Position>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_object_position(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::ObjectPosition)
        }
    }



        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-start
    pub mod grid_row_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridLine as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridRowStart,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_row_start();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridLine>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_row_start(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridRowStart)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-row-end
    pub mod grid_row_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridLine as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridRowEnd,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_row_end();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridLine>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_row_end(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridRowEnd)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-rows
    pub mod grid_auto_rows {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ImplicitGridTracks as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ImplicitGridTracks as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ImplicitGridTracks as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridAutoRows,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_auto_rows();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ImplicitGridTracks>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_auto_rows(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridAutoRows)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-rows
    pub mod grid_template_rows {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridTemplateComponent as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridTemplateComponent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::GenericGridTemplateComponent::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridTemplateComponent as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridTemplateRows,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_template_rows();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridTemplateComponent>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_template_rows(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridTemplateRows)
        }
    }



        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-start
    pub mod grid_column_start {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridLine as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridColumnStart,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_column_start();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridLine>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_column_start(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridColumnStart)
        }
    }


        
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-column-end
    pub mod grid_column_end {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridLine as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridLine as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridColumnEnd,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_column_end();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridLine>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_column_end(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridColumnEnd)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-columns
    pub mod grid_auto_columns {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ImplicitGridTracks as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ImplicitGridTracks as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { Default::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ImplicitGridTracks as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridAutoColumns,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_auto_columns();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ImplicitGridTracks>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_auto_columns(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridAutoColumns)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-columns
    pub mod grid_template_columns {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridTemplateComponent as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridTemplateComponent as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::GenericGridTemplateComponent::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridTemplateComponent as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridTemplateColumns,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_template_columns();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridTemplateComponent>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_template_columns(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridTemplateColumns)
        }
    }





    
        
    
    /// https://github.com/w3c/csswg-drafts/issues/4650
    pub mod masonry_auto_flow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::MasonryAutoFlow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::MasonryAutoFlow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::MasonryAutoFlow::initial() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::MasonryAutoFlow as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MasonryAutoFlow,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_masonry_auto_flow();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::MasonryAutoFlow>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_masonry_auto_flow(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MasonryAutoFlow)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-auto-flow
    pub mod grid_auto_flow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridAutoFlow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridAutoFlow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::GridAutoFlow::ROW }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridAutoFlow as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridAutoFlow,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_auto_flow();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridAutoFlow>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_auto_flow(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridAutoFlow)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-grid/#propdef-grid-template-areas
    pub mod grid_template_areas {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::GridTemplateAreas as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::GridTemplateAreas as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::GridTemplateAreas::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::GridTemplateAreas as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::GridTemplateAreas,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_grid_template_areas();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::GridTemplateAreas>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_grid_template_areas(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::GridTemplateAreas)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-align-3/#propdef-column-gap
    pub mod column_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::length::NonNegativeLengthPercentageOrNormal as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::length::NonNegativeLengthPercentageOrNormal as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::length::NonNegativeLengthPercentageOrNormal::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::length::NonNegativeLengthPercentageOrNormal as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ColumnGap,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_column_gap();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_column_gap(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ColumnGap)
        }
    }



// no need for -moz- prefixed alias for this property

    
        
    
    /// https://drafts.csswg.org/css-align-3/#propdef-row-gap
    pub mod row_gap {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::length::NonNegativeLengthPercentageOrNormal as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::length::NonNegativeLengthPercentageOrNormal as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::length::NonNegativeLengthPercentageOrNormal::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::length::NonNegativeLengthPercentageOrNormal as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::RowGap,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_row_gap();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_row_gap(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::RowGap)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-sizing-4/#aspect-ratio
    pub mod aspect_ratio {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AspectRatio as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AspectRatio as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AspectRatio::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AspectRatio as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AspectRatio,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_aspect_ratio();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::AspectRatio>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_aspect_ratio(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AspectRatio)
        }
    }



    
    
        
    
    /// https://drafts.csswg.org/css-sizing-4/#intrinsic-size-override
    pub mod contain_intrinsic_height {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ContainIntrinsicSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ContainIntrinsicSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ContainIntrinsicSize::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ContainIntrinsicSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ContainIntrinsicHeight.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_contain_intrinsic_height();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ContainIntrinsicSize>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_contain_intrinsic_height(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ContainIntrinsicHeight)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-sizing-4/#intrinsic-size-override
    pub mod contain_intrinsic_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ContainIntrinsicSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ContainIntrinsicSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ContainIntrinsicSize::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ContainIntrinsicSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap().logical_group(),
                LonghandId::ContainIntrinsicWidth.logical_group(),
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_contain_intrinsic_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::ContainIntrinsicSize>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_contain_intrinsic_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ContainIntrinsicWidth)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-sizing-4/#intrinsic-size-override
    pub mod contain_intrinsic_block_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ContainIntrinsicSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ContainIntrinsicSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ContainIntrinsicSize::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ContainIntrinsicSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ContainIntrinsicBlockSize)
        }
    }


    
    
        
    
    /// https://drafts.csswg.org/css-sizing-4/#intrinsic-size-override
    pub mod contain_intrinsic_inline_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ContainIntrinsicSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ContainIntrinsicSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ContainIntrinsicSize::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ContainIntrinsicSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            declaration.debug_crash("Should physicalize before entering here");
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ContainIntrinsicInlineSize)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    

    
        
    
    /// https://svgwg.org/svg2-draft/coords.html#VectorEffects
    pub mod vector_effect {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            None,
            
            NonScalingStroke,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::None
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::None
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::VectorEffect,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_vector_effect();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::vector_effect::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_vector_effect(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::VectorEffect)
        }
    }



// Section 14 - Gradients and Patterns


    
        
    
    /// https://svgwg.org/svg2-draft/pservers.html#StopColorProperties
    pub mod stop_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Color::BLACK }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StopColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_stop_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stop_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StopColor)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/pservers.html#StopOpacityProperty
    pub mod stop_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Opacity as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::StopOpacity,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_stop_opacity();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Opacity>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_stop_opacity(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::StopOpacity)
        }
    }



// Filter Effects Module


    
        
    
    /// https://drafts.fxtf.org/filter-effects-1/#FloodColorProperty
    pub mod flood_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Color::BLACK }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FloodColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_flood_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_flood_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FloodColor)
        }
    }




    
        
    
    /// https://drafts.fxtf.org/filter-effects-1/#FloodOpacityProperty
    pub mod flood_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Opacity as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::FloodOpacity,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_flood_opacity();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Opacity>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_flood_opacity(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::FloodOpacity)
        }
    }




    
        
    
    /// https://drafts.fxtf.org/filter-effects-1#LightingColorProperty
    pub mod lighting_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Color::WHITE }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::LightingColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_lighting_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_lighting_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::LightingColor)
        }
    }



// CSS Masking Module Level 1
// https://drafts.fxtf.org/css-masking-1

    

    
        
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-type
    pub mod mask_type {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Luminance,
            
            Alpha,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Luminance
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Luminance
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskType,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_type();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_type::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_mask_type(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskType)
        }
    }




    
        
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-clip-path
    pub mod clip_path {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::basic_shape::ClipPath as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::basic_shape::ClipPath as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::basic_shape::ClipPath::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::basic_shape::ClipPath as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ClipPath,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_clip_path();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::basic_shape::ClipPath>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_clip_path(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ClipPath)
        }
    }




    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-mode
    pub mod mask_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            MatchSource,
            
            Alpha,
            
            Luminance,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::MatchSource
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::MatchSource
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-mode.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-mode.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskMode,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_mode();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_mode::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_mode(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskMode)
        }
    }





    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-repeat
    pub mod mask_repeat {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BackgroundRepeat as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BackgroundRepeat as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundRepeat::repeat() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundRepeat::repeat() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BackgroundRepeat as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-repeat.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-repeat.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskRepeat,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_repeat();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_repeat::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_repeat(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskRepeat)
        }
    }




    
    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-position
    pub mod mask_position_x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::position::HorizontalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::position::HorizontalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero_percent() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionComponent::Center }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::position::HorizontalPosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-position-x.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::repeatable_list::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::repeatable_list::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-position-x.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskPositionX,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_position_x();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_position_x::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_position_x(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskPositionX)
        }
    }



    
    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-position
    pub mod mask_position_y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::position::VerticalPosition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::position::VerticalPosition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero_percent() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::PositionComponent::Center }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::position::VerticalPosition as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-position-y.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::repeatable_list::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::repeatable_list::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-position-y.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskPositionY,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_position_y();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_position_y::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_position_y(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskPositionY)
        }
    }





    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-clip
    pub mod mask_clip {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            BorderBox,
            
            ContentBox,
            
            PaddingBox,
            
            FillBox,
            
            StrokeBox,
            
            ViewBox,
            
            NoClip,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-clip.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-clip.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskClip,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_clip();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_clip::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_clip(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskClip)
        }
    }





    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-origin
    pub mod mask_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            BorderBox,
            
            ContentBox,
            
            PaddingBox,
            
            FillBox,
            
            StrokeBox,
            
            ViewBox,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::BorderBox
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::BorderBox
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-origin.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-origin.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskOrigin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_origin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_origin::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_origin(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskOrigin)
        }
    }





    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-size
    pub mod mask_size {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::background::BackgroundSize as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::background::BackgroundSize as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BackgroundSize::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::BackgroundSize::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::background::BackgroundSize as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-size.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            use crate::values::animated::{Animate, ToAnimatedZero, Procedure, lists};
            use crate::values::distance::{SquaredDistance, ComputeSquaredDistance};

            // FIXME(emilio): For some reason rust thinks that this alias is
            // unused, even though it's clearly used below?
            #[allow(unused)]
            type AnimatedList = OwnedList<<single_value::T as ToAnimatedValue>::AnimatedValue>;


            impl ToAnimatedZero for AnimatedList {
                fn to_animated_zero(&self) -> Result<Self, ()> { Err(()) }
            }

            impl Animate for AnimatedList {
                fn animate(
                    &self,
                    other: &Self,
                    procedure: Procedure,
                ) -> Result<Self, ()> {
                    Ok(OwnedList(
                        lists::repeatable_list::animate(&self.0, &other.0, procedure)?
                    ))
                }
            }
            impl ComputeSquaredDistance for AnimatedList {
                fn compute_squared_distance(
                    &self,
                    other: &Self,
                ) -> Result<SquaredDistance, ()> {
                    lists::repeatable_list::squared_distance(&self.0, &other.0)
                }
            }

            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-size.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskSize,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_size();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_size::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_size(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskSize)
        }
    }





    

    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-composite
    pub mod mask_composite {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Add,
            
            Subtract,
            
            Intersect,
            
            Exclude,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Add
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Add
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        }

        /// The definition of the computed value for mask-composite.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-composite.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskComposite,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_composite();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_composite::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_composite(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskComposite)
        }
    }





    
        
    
    
    /// https://drafts.fxtf.org/css-masking-1/#propdef-mask-image
    pub mod mask_image {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Image as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Image as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Image::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Image::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Image::parse_with_cors_anonymous(context, input)
        }
    
        
        }

        /// The definition of the computed value for mask-image.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of mask-image.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MaskImage,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_mask_image();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::mask_image::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_svg();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_mask_image(iter);
                }
                context.builder.put_svg(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MaskImage)
        }
    }





    
        
    
    /// https://svgwg.org/svg2-draft/geometry.html#X
    pub mod x {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::X,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_x();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_x(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::X)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/geometry.html#Y
    pub mod y {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Y,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_y();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_y(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Y)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/geometry.html#CX
    pub mod cx {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Cx,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_cx();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_cx(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Cx)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/geometry.html#CY
    pub mod cy {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::LengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::LengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::LengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::LengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Cy,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_cy();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::LengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_cy(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Cy)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/geometry.html#RX
    pub mod rx {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Rx,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_rx();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_rx(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Rx)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/geometry.html#RY
    pub mod ry {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentageOrAuto as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentageOrAuto::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentageOrAuto as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::Ry,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_ry();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentageOrAuto>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_ry(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::Ry)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/geometry.html#R
    pub mod r {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeLengthPercentage as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeLengthPercentage as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::NonNegativeLengthPercentage::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeLengthPercentage as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::R,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_r();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeLengthPercentage>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_r(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::R)
        }
    }




    
        
    
    /// https://svgwg.org/svg2-draft/paths.html#TheDProperty
    pub mod d {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::DProperty as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::DProperty as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::DProperty::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::DProperty as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::D,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_d();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::DProperty>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_d(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::D)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    

    
        
    
    /// https://drafts.csswg.org/css-tables/#propdef-table-layout
    pub mod table_layout {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Fixed,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TableLayout,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_table_layout();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::table_layout::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_table_layout(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TableLayout)
        }
    }




    
        
    
    /// Internal-only (for `<col span>` pres attr)
    pub mod _x_span {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Integer as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Integer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Integer as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::XSpan,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__x_span();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Integer>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__x_span(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::XSpan)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
        
    
    /// https://drafts.csswg.org/css-ui/#propdef-text-overflow
    pub mod text_overflow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextOverflow as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextOverflow as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TextOverflow::get_initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextOverflow as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextOverflow,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_text_overflow();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::TextOverflow>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set_text_overflow(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::TextOverflow)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-writing-modes/#propdef-unicode-bidi
    pub mod unicode_bidi {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            Embed,
            
            Isolate,
            
            BidiOverride,
            
            IsolateOverride,
            
            Plaintext,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::UnicodeBidi,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_unicode_bidi();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::unicode_bidi::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_unicode_bidi(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::UnicodeBidi)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-line
    pub mod text_decoration_line {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextDecorationLine as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextDecorationLine as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { specified::TextDecorationLine::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TextDecorationLine::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextDecorationLine as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextDecorationLine,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_text_decoration_line();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextDecorationLine>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_decoration_line(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationLine)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-style
    pub mod text_decoration_style {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Solid,
            
            Double,
            
            Dotted,
            
            Dashed,
            
            Wavy,
            
            MozNone,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Solid
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Solid
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextDecorationStyle,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_text_decoration_style();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::text_decoration_style::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_decoration_style(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationStyle)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration-color
    pub mod text_decoration_color {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Color as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Color as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed_value::T::currentcolor() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Color::currentcolor() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Color as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextDecorationColor,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_text_decoration_color();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Color>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_decoration_color(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationColor)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-inline/#sizing-drop-initials
    pub mod initial_letter {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::InitialLetter as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::InitialLetter as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::InitialLetter::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::InitialLetter::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::InitialLetter as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::InitialLetter,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_initial_letter();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::InitialLetter>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_initial_letter(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::InitialLetter)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-text-decor-4/#text-decoration-width-property
    pub mod text_decoration_thickness {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TextDecorationLength as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TextDecorationLength as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::text::GenericTextDecorationLength::Auto }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { generics::text::GenericTextDecorationLength::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TextDecorationLength as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TextDecorationThickness,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_text_decoration_thickness();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::TextDecorationLength>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_text_decoration_thickness(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TextDecorationThickness)
        }
    }



    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




// TODO spec says that UAs should not support this
// we should probably remove from gecko (https://bugzilla.mozilla.org/show_bug.cgi?id=1328331)

    

    
        
    
    /// https://drafts.csswg.org/css-ui/#input-method-editor
    pub mod ime_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Normal,
            
            Active,
            
            Disabled,
            
            Inactive,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ImeMode,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_ime_mode();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::ime_mode::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_ime_mode(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ImeMode)
        }
    }




    

    
        
    
    /// https://drafts.csswg.org/css-scrollbars-1/#scrollbar-width
    pub mod scrollbar_width {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            Thin,
            
            None,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollbarWidth,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scrollbar_width();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::scrollbar_width::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_scrollbar_width(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollbarWidth)
        }
    }




    
        
    
    /// https://drafts.csswg.org/css-ui-4/#propdef-user-select
    pub mod user_select {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::UserSelect as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::UserSelect as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::UserSelect::Auto }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::UserSelect as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::UserSelect,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_user_select();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::UserSelect>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set_user_select(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::UserSelect)
        }
    }



// TODO(emilio): This probably should be hidden from content.

    

    
        
    
    /// None (Nonstandard Firefox-only property)
    pub mod _moz_window_dragging {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Default,
            
            Drag,
            
            NoDrag,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Default
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Default
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozWindowDragging,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_window_dragging();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_window_dragging::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_window_dragging(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowDragging)
        }
    }



// TODO(emilio): Maybe make shadow behavior on macOS match Linux / Windows, and remove this? But
// that requires making -moz-window-input-region-margin work there...

    

    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_shadow {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Auto,
            
            None,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Auto
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Auto
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozWindowShadow,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_window_shadow();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_window_shadow::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_window_shadow(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowShadow)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_opacity {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Opacity as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Opacity as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1.0 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Opacity as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozWindowOpacity,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_window_opacity();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Opacity>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_window_opacity(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowOpacity)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_transform {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Transform as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Transform as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { generics::transform::Transform::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Transform as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozWindowTransform,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_window_transform();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Transform>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_window_transform(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowTransform)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_transform_origin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TransformOrigin as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TransformOrigin as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransformOrigin::initial_value() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TransformOrigin as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozWindowTransformOrigin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_window_transform_origin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<Box<crate::values::specified::TransformOrigin>>()
                },
            };


                let computed = (**specified_value).to_computed_value(context);
                context.builder.set__moz_window_transform_origin(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(Box::new)
                .map(PropertyDeclaration::MozWindowTransformOrigin)
        }
    }




    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_window_input_region_margin {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Length as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Length as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Length::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Length as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozWindowInputRegionMargin,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_window_input_region_margin();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Length>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_window_input_region_margin(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozWindowInputRegionMargin)
        }
    }



// Hack to allow chrome to hide stuff only visually (without hiding it from a11y).

    
        
    
    /// None (Nonstandard internal property)
    pub mod _moz_subtree_hidden_only_visually {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BoolInteger as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BoolInteger as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BoolInteger::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BoolInteger as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozSubtreeHiddenOnlyVisually,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_subtree_hidden_only_visually();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BoolInteger>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_subtree_hidden_only_visually(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozSubtreeHiddenOnlyVisually)
        }
    }



// TODO(emilio): Probably also should be hidden from content.

    
        
    
    /// None (Nonstandard Firefox-only property)
    pub mod _moz_force_broken_image_icon {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::BoolInteger as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::BoolInteger as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::BoolInteger::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::BoolInteger as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozForceBrokenImageIcon,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_force_broken_image_icon();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::BoolInteger>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_force_broken_image_icon(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozForceBrokenImageIcon)
        }
    }






    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-duration
    pub mod transition_duration {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse_non_negative(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-duration.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of transition-duration.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransitionDuration,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transition_duration();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::transition_duration::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_transition_duration(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionDuration)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-timing-function
    pub mod transition_timing_function {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TimingFunction as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TimingFunction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TimingFunction::ease() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TimingFunction::ease() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TimingFunction as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-timing-function.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of transition-timing-function.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransitionTimingFunction,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transition_timing_function();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::transition_timing_function::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_transition_timing_function(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionTimingFunction)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-property
    pub mod transition_property {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TransitionProperty as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TransitionProperty as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransitionProperty::all() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TransitionProperty::all() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TransitionProperty as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-property.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of transition-property.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[value_info(other_values = "none")]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;

            if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
                return Ok(SpecifiedValue(crate::OwnedSlice::from(vec![computed::TransitionProperty::none()])))
            }

            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransitionProperty,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transition_property();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::transition_property::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_transition_property(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionProperty)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-delay
    pub mod transition_delay {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Time as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-delay.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of transition-delay.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransitionDelay,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transition_delay();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::transition_delay::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_transition_delay(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionDelay)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions-2/#transition-behavior-property
    pub mod transition_behavior {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TransitionBehavior as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TransitionBehavior as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TransitionBehavior::normal() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TransitionBehavior::normal() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TransitionBehavior as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for transition-behavior.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of transition-behavior.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::TransitionBehavior,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_transition_behavior();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::transition_behavior::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_transition_behavior(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::TransitionBehavior)
        }
    }







    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-name
    pub mod animation_name {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnimationName as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnimationName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationName::none() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationName::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnimationName as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-name.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-name.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationName,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_name();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_name::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_name(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationName)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-transition-duration
    pub mod animation_duration {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Time::parse_non_negative(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-duration.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-duration.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationDuration,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_duration();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_duration::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_duration(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDuration)
        }
    }




// animation-timing-function is the exception to the rule for allowed_in_keyframe_block:
// https://drafts.csswg.org/css-animations/#keyframes

    
        
    
    
    /// https://drafts.csswg.org/css-transitions/#propdef-animation-timing-function
    pub mod animation_timing_function {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::TimingFunction as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::TimingFunction as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::TimingFunction::ease() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::TimingFunction::ease() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::TimingFunction as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-timing-function.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-timing-function.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationTimingFunction,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_timing_function();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_timing_function::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_timing_function(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationTimingFunction)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-iteration-count
    pub mod animation_iteration_count {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnimationIterationCount as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnimationIterationCount as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationIterationCount::one() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationIterationCount::one() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnimationIterationCount as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-iteration-count.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-iteration-count.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationIterationCount,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_iteration_count();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_iteration_count::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_iteration_count(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationIterationCount)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-direction
    pub mod animation_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnimationDirection as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnimationDirection as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationDirection::Normal }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationDirection::Normal }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnimationDirection as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-direction.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-direction.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationDirection,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_direction();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_direction::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_direction(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDirection)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-play-state
    pub mod animation_play_state {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnimationPlayState as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnimationPlayState as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationPlayState::Running }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { computed::AnimationPlayState::Running }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnimationPlayState as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-play-state.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-play-state.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationPlayState,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_play_state();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_play_state::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_play_state(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationPlayState)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-fill-mode
    pub mod animation_fill_mode {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnimationFillMode as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnimationFillMode as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationFillMode::None }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { computed::AnimationFillMode::None }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnimationFillMode as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-fill-mode.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-fill-mode.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationFillMode,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_fill_mode();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_fill_mode::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_fill_mode(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationFillMode)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations-2/#animation-composition
    pub mod animation_composition {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnimationComposition as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnimationComposition as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationComposition::Replace }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { computed::AnimationComposition::Replace }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnimationComposition as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-composition.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-composition.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationComposition,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_composition();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_composition::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_composition(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationComposition)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations/#propdef-animation-delay
    pub mod animation_delay {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Time as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Time as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::Time::zero() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::Time::zero() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::Time as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-delay.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-delay.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationDelay,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_delay();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_delay::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_delay(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationDelay)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/css-animations-2/#propdef-animation-timeline
    pub mod animation_timeline {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::AnimationTimeline as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::AnimationTimeline as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::AnimationTimeline::auto() }
        #[inline] pub fn get_initial_specified_value() -> SpecifiedValue { specified::AnimationTimeline::auto() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::AnimationTimeline as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for animation-timeline.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of animation-timeline.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::AnimationTimeline,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_animation_timeline();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::animation_timeline::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_animation_timeline(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::AnimationTimeline)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/scroll-animations-1/#scroll-timeline-name
    pub mod scroll_timeline_name {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollTimelineName as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollTimelineName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollTimelineName::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollTimelineName as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for scroll-timeline-name.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of scroll-timeline-name.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollTimelineName,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_timeline_name();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::scroll_timeline_name::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_scroll_timeline_name(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollTimelineName)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/scroll-animations-1/#scroll-timeline-axis
    pub mod scroll_timeline_axis {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollAxis as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollAxis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollAxis::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollAxis as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for scroll-timeline-axis.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of scroll-timeline-axis.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ScrollTimelineAxis,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_scroll_timeline_axis();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::scroll_timeline_axis::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_scroll_timeline_axis(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ScrollTimelineAxis)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/scroll-animations-1/#view-timeline-name
    pub mod view_timeline_name {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollTimelineName as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollTimelineName as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollTimelineName::none() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollTimelineName as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for view-timeline-name.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of view-timeline-name.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ViewTimelineName,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_view_timeline_name();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::view_timeline_name::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_view_timeline_name(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ViewTimelineName)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/scroll-animations-1/#view-timeline-axis
    pub mod view_timeline_axis {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ScrollAxis as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ScrollAxis as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ScrollAxis::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ScrollAxis as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for view-timeline-axis.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of view-timeline-axis.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ViewTimelineAxis,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_view_timeline_axis();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::view_timeline_axis::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_view_timeline_axis(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ViewTimelineAxis)
        }
    }





    
        
    
    
    /// https://drafts.csswg.org/scroll-animations-1/#view-timeline-axis
    pub mod view_timeline_inset {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
        #[allow(unused_imports)]
        use smallvec::SmallVec;

        pub mod single_value {
            #[allow(unused_imports)]
            use cssparser::{Parser, BasicParseError};
            #[allow(unused_imports)]
            use crate::parser::{Parse, ParserContext};
            #[allow(unused_imports)]
            use crate::properties::ShorthandId;
            #[allow(unused_imports)]
            use selectors::parser::SelectorParseErrorKind;
            #[allow(unused_imports)]
            use style_traits::{ParseError, StyleParseErrorKind};
            #[allow(unused_imports)]
            use crate::values::computed::{Context, ToComputedValue};
            #[allow(unused_imports)]
            use crate::values::{computed, specified};
            
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::ViewTimelineInset as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::ViewTimelineInset as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { computed::ViewTimelineInset::default() }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::ViewTimelineInset as crate::parser::Parse>::parse(context, input)
        }
    
        
        }

        /// The definition of the computed value for view-timeline-inset.
        pub mod computed_value {
            #[allow(unused_imports)]
            use crate::values::animated::ToAnimatedValue;
            #[allow(unused_imports)]
            use crate::values::resolved::ToResolvedValue;
            pub use super::single_value::computed_value as single_value;
            pub use self::single_value::T as SingleComputedValue;
            use smallvec::SmallVec;
            use crate::values::computed::ComputedVecIter;

            

            // FIXME(emilio): Add an OwnedNonEmptySlice type, and figure out
            // something for transition-name, which is the only remaining user
            // of NotInitial.
            pub type UnderlyingList<T> =
                    SmallVec<[T; 1]>;

            pub type UnderlyingOwnedList<T> =
                    SmallVec<[T; 1]>;


            /// The generic type defining the animated and resolved values for
            /// this property.
            ///
            /// Making this type generic allows the compiler to figure out the
            /// animated value for us, instead of having to implement it
            /// manually for every type we care about.
            #[derive(Clone, Debug, MallocSizeOf, PartialEq, ToAnimatedValue, ToResolvedValue, ToCss)]
            #[css(comma)]
            pub struct OwnedList<T>(
                #[css(iterable)]
                pub UnderlyingOwnedList<T>,
            );

            /// The computed value for this property.
            pub type ComputedList = OwnedList<single_value::T>;
            pub use self::OwnedList as List;



            /// The computed value, effectively a list of single values.
            pub use self::ComputedList as T;

            pub type Iter<'a, 'cx, 'cx_a> = ComputedVecIter<'a, 'cx, 'cx_a, super::single_value::SpecifiedValue>;
        }

        /// The specified value of view-timeline-inset.
        #[derive(Clone, Debug, MallocSizeOf, PartialEq, SpecifiedValueInfo, ToCss, ToShmem)]
        #[css(comma)]
        pub struct SpecifiedValue(
            #[css(iterable)]
            pub crate::OwnedSlice<single_value::SpecifiedValue>,
        );

        pub fn get_initial_value() -> computed_value::T {
                let mut v = SmallVec::new();
                v.push(single_value::get_initial_value());
                computed_value::List(v)
        }

        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            use style_traits::Separator;


            let v = style_traits::Comma::parse(input, |parser| {
                single_value::parse(context, parser)
            })?;
            Ok(SpecifiedValue(v.into()))
        }

        pub use self::single_value::SpecifiedValue as SingleSpecifiedValue;

        impl SpecifiedValue {
            fn compute_iter<'a, 'cx, 'cx_a>(
                &'a self,
                context: &'cx Context<'cx_a>,
            ) -> computed_value::Iter<'a, 'cx, 'cx_a> {
                computed_value::Iter::new(context, &self.0)
            }
        }

        impl ToComputedValue for SpecifiedValue {
            type ComputedValue = computed_value::T;

            #[inline]
            fn to_computed_value(&self, context: &Context) -> computed_value::T {
                use std::iter::FromIterator;
                computed_value::List(computed_value::UnderlyingList::from_iter(
                    self.0.iter().map(|i| i.to_computed_value(context))
                ))
            }

            #[inline]
            fn from_computed_value(computed: &computed_value::T) -> Self {
                let iter = computed.0.iter().map(ToComputedValue::from_computed_value);
                SpecifiedValue(iter.collect())
            }
        }
    
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::ViewTimelineInset,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit_view_timeline_inset();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::view_timeline_inset::SpecifiedValue>()
                },
            };


                // In the case of a vector property we want to pass down an
                // iterator so that this can be computed without allocation.
                //
                // However, computing requires a context, but the style struct
                // being mutated is on the context. We temporarily remove it,
                // mutate it, and then put it back. Vector longhands cannot
                // touch their own style struct whilst computing, else this will
                // panic.
                let mut s =
                    context.builder.take_ui();
                {
                    let iter = specified_value.compute_iter(context);
                    s.set_view_timeline_inset(iter);
                }
                context.builder.put_ui(s);
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::ViewTimelineInset)
        }
    }




    
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-align)
    pub mod _moz_box_align {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Stretch,
            
            Start,
            
            Center,
            
            Baseline,
            
            End,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Stretch
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Stretch
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozBoxAlign,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_box_align();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_box_align::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_box_align(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxAlign)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-direction)
    pub mod _moz_box_direction {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Normal,
            
            Reverse,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Normal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Normal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozBoxDirection,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_box_direction();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_box_direction::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_box_direction(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxDirection)
        }
    }




    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-flex)
    pub mod _moz_box_flex {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::NonNegativeNumber as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::NonNegativeNumber as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { From::from(0.) }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            <specified::NonNegativeNumber as crate::parser::Parse>::parse(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozBoxFlex,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_box_flex();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::NonNegativeNumber>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_box_flex(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxFlex)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-orient)
    pub mod _moz_box_orient {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            #[parse(aliases = "inline-axis")]
            Horizontal,
            
            #[parse(aliases = "block-axis")]
            Vertical,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Horizontal
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Horizontal
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozBoxOrient,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_box_orient();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_box_orient::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_box_orient(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxOrient)
        }
    }




    

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/box-pack)
    pub mod _moz_box_pack {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        pub use self::computed_value::T as SpecifiedValue;
        pub mod computed_value {
            #[cfg_attr(feature = "servo", derive(Deserialize, Serialize))]
            #[derive(Clone, Copy, Debug, Eq, FromPrimitive, MallocSizeOf, Parse, PartialEq, SpecifiedValueInfo, ToComputedValue, ToCss, ToResolvedValue, ToShmem)]
            pub enum T {
            
            Start,
            
            Center,
            
            End,
            
            Justify,
            }
        }
        #[inline]
        pub fn get_initial_value() -> computed_value::T {
            computed_value::T::Start
        }
        #[inline]
        pub fn get_initial_specified_value() -> SpecifiedValue {
            SpecifiedValue::Start
        }
        #[inline]
        pub fn parse<'i, 't>(_context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<SpecifiedValue, ParseError<'i>> {
            SpecifiedValue::parse(input)
        }

    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozBoxPack,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_box_pack();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<longhands::_moz_box_pack::SpecifiedValue>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_box_pack(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxPack)
        }
    }



// NOTE(heycam): Odd that the initial value is 1 yet 0 is a valid value. There
// are uses of `-moz-box-ordinal-group: 0` in the tree, too.

    
        
    
    /// Nonstandard (https://developer.mozilla.org/en-US/docs/Web/CSS/-moz-box-ordinal-group)
    pub mod _moz_box_ordinal_group {
        #[allow(unused_imports)]
        use cssparser::{Parser, BasicParseError, Token};
        #[allow(unused_imports)]
        use crate::parser::{Parse, ParserContext};
        #[allow(unused_imports)]
        use crate::properties::{UnparsedValue, ShorthandId};
        #[allow(unused_imports)]
        use crate::error_reporting::ParseErrorReporter;
        #[allow(unused_imports)]
        use crate::properties::longhands;
        #[allow(unused_imports)]
        use crate::properties::{LonghandId, LonghandIdSet};
        #[allow(unused_imports)]
        use crate::properties::{CSSWideKeyword, ComputedValues, PropertyDeclaration};
        #[allow(unused_imports)]
        use crate::properties::style_structs;
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use servo_arc::Arc;
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use crate::values::computed::{Context, ToComputedValue};
        #[allow(unused_imports)]
        use crate::values::{computed, generics, specified};
        #[allow(unused_imports)]
        use crate::Atom;
        
            
        #[allow(unused_imports)]
        use app_units::Au;
        #[allow(unused_imports)]
        use crate::values::specified::AllowQuirks;
        #[allow(unused_imports)]
        use crate::Zero;
        #[allow(unused_imports)]
        use smallvec::SmallVec;
        pub use crate::values::specified::Integer as SpecifiedValue;
        pub mod computed_value {
            pub use crate::values::computed::Integer as T;
        }
        #[inline] pub fn get_initial_value() -> computed_value::T { 1 }
        #[allow(unused_variables)]
        #[inline]
        pub fn parse<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SpecifiedValue, ParseError<'i>> {
            specified::Integer::parse_non_negative(context, input)
        }
    
        
        #[allow(unused_variables)]
        pub unsafe fn cascade_property(
            declaration: &PropertyDeclaration,
            context: &mut computed::Context,
        ) {
            context.for_non_inherited_property = true;
            debug_assert_eq!(
                declaration.id().as_longhand().unwrap(),
                LonghandId::MozBoxOrdinalGroup,
            );
            let specified_value = match *declaration {
                PropertyDeclaration::CSSWideKeyword(ref wk) => {
                    match wk.keyword {
                        CSSWideKeyword::Unset |
                        CSSWideKeyword::Initial => {
                                declaration.debug_crash("Unexpected initial or unset for non-inherited property");
                        },
                        CSSWideKeyword::Inherit => {
                                context.rule_cache_conditions.borrow_mut().set_uncacheable();
                                context.builder.inherit__moz_box_ordinal_group();
                        }
                        CSSWideKeyword::RevertLayer |
                        CSSWideKeyword::Revert => {
                            declaration.debug_crash("Found revert/revert-layer not deal with");
                        },
                    }
                    return;
                },
                #[cfg(debug_assertions)]
                PropertyDeclaration::WithVariables(..) => {
                    declaration.debug_crash("Found variables not substituted");
                    return;
                },
                _ => unsafe {
                    declaration.unchecked_value_as::<crate::values::specified::Integer>()
                },
            };


                let computed = specified_value.to_computed_value(context);
                context.builder.set__moz_box_ordinal_group(computed)
        }

        pub fn parse_declared<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>> {
                parse(context, input)
                .map(PropertyDeclaration::MozBoxOrdinalGroup)
        }
    }



}


#[cfg(feature = "gecko")]
#[allow(unsafe_code, missing_docs)]
pub mod gecko {
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

// `data` comes from components/style/properties.mako.rs; see build.rs for more details.




use crate::Atom;
use app_units::Au;
use crate::computed_value_flags::*;
use crate::custom_properties::ComputedCustomProperties;
use crate::gecko_bindings::bindings;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleBackground;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleBackground;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleBackground;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleBorder;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleBorder;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleBorder;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleDisplay;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleDisplay;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleDisplay;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleColumn;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleColumn;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleColumn;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleContent;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleContent;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleContent;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleEffects;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleEffects;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleEffects;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleFont;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleFont;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleFont;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleVisibility;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleVisibility;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleVisibility;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleSVG;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleSVG;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleSVG;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleTableBorder;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleTableBorder;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleTableBorder;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleText;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleText;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleText;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleUI;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleUI;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleUI;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleList;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleList;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleList;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleMargin;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleMargin;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleMargin;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleOutline;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleOutline;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleOutline;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStylePadding;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStylePadding;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStylePadding;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStylePage;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStylePage;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStylePage;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStylePosition;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStylePosition;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStylePosition;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleSVGReset;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleSVGReset;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleSVGReset;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleTable;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleTable;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleTable;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleTextReset;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleTextReset;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleTextReset;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleUIReset;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleUIReset;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleUIReset;
use crate::gecko_bindings::bindings::Gecko_Construct_Default_nsStyleXUL;
use crate::gecko_bindings::bindings::Gecko_CopyConstruct_nsStyleXUL;
use crate::gecko_bindings::bindings::Gecko_Destroy_nsStyleXUL;
use crate::gecko_bindings::bindings::Gecko_EnsureImageLayersLength;
use crate::gecko_bindings::bindings::Gecko_nsStyleFont_SetLang;
use crate::gecko_bindings::bindings::Gecko_nsStyleFont_CopyLangFrom;
use crate::gecko_bindings::structs;
use crate::gecko_bindings::structs::mozilla::PseudoStyleType;
use crate::gecko::data::PerDocumentStyleData;
use crate::logical_geometry::WritingMode;
use crate::media_queries::Device;
use crate::properties::longhands;
use crate::rule_tree::StrongRuleNode;
use crate::selector_parser::PseudoElement;
use servo_arc::{Arc, UniqueArc};
use std::mem::{forget, MaybeUninit, ManuallyDrop};
use std::{ops, ptr};
use crate::values;
use crate::values::computed::{BorderStyle, Time, Zoom};
use crate::values::computed::font::FontSize;


pub mod style_structs {
    pub use super::GeckoBackground as Background;

    unsafe impl Send for Background {}
    unsafe impl Sync for Background {}
    pub use super::GeckoBorder as Border;

    unsafe impl Send for Border {}
    unsafe impl Sync for Border {}
    pub use super::GeckoBox as Box;

    unsafe impl Send for Box {}
    unsafe impl Sync for Box {}
    pub use super::GeckoColumn as Column;

    unsafe impl Send for Column {}
    unsafe impl Sync for Column {}
    pub use super::GeckoCounters as Counters;

    unsafe impl Send for Counters {}
    unsafe impl Sync for Counters {}
    pub use super::GeckoEffects as Effects;

    unsafe impl Send for Effects {}
    unsafe impl Sync for Effects {}
    pub use super::GeckoFont as Font;

    unsafe impl Send for Font {}
    unsafe impl Sync for Font {}
    pub use super::GeckoInheritedBox as InheritedBox;

    unsafe impl Send for InheritedBox {}
    unsafe impl Sync for InheritedBox {}
    pub use super::GeckoInheritedSVG as InheritedSVG;

    unsafe impl Send for InheritedSVG {}
    unsafe impl Sync for InheritedSVG {}
    pub use super::GeckoInheritedTable as InheritedTable;

    unsafe impl Send for InheritedTable {}
    unsafe impl Sync for InheritedTable {}
    pub use super::GeckoInheritedText as InheritedText;

    unsafe impl Send for InheritedText {}
    unsafe impl Sync for InheritedText {}
    pub use super::GeckoInheritedUI as InheritedUI;

    unsafe impl Send for InheritedUI {}
    unsafe impl Sync for InheritedUI {}
    pub use super::GeckoList as List;

    unsafe impl Send for List {}
    unsafe impl Sync for List {}
    pub use super::GeckoMargin as Margin;

    unsafe impl Send for Margin {}
    unsafe impl Sync for Margin {}
    pub use super::GeckoOutline as Outline;

    unsafe impl Send for Outline {}
    unsafe impl Sync for Outline {}
    pub use super::GeckoPadding as Padding;

    unsafe impl Send for Padding {}
    unsafe impl Sync for Padding {}
    pub use super::GeckoPage as Page;

    unsafe impl Send for Page {}
    unsafe impl Sync for Page {}
    pub use super::GeckoPosition as Position;

    unsafe impl Send for Position {}
    unsafe impl Sync for Position {}
    pub use super::GeckoSVG as SVG;

    unsafe impl Send for SVG {}
    unsafe impl Sync for SVG {}
    pub use super::GeckoTable as Table;

    unsafe impl Send for Table {}
    unsafe impl Sync for Table {}
    pub use super::GeckoText as Text;

    unsafe impl Send for Text {}
    unsafe impl Sync for Text {}
    pub use super::GeckoUI as UI;

    unsafe impl Send for UI {}
    unsafe impl Sync for UI {}
    pub use super::GeckoXUL as XUL;

    unsafe impl Send for XUL {}
    unsafe impl Sync for XUL {}
}

/// FIXME(emilio): This is completely duplicated with the other properties code.
pub type ComputedValuesInner = structs::ServoComputedData;

#[repr(C)]
pub struct ComputedValues(structs::mozilla::ComputedStyle);

impl ComputedValues {
    #[inline]
    pub (crate) fn as_gecko_computed_style(&self) -> &structs::ComputedStyle {
        &self.0
    }

    pub fn new(
        pseudo: Option<&PseudoElement>,
        custom_properties: ComputedCustomProperties,
        writing_mode: WritingMode,
        effective_zoom: Zoom,
        flags: ComputedValueFlags,
        rules: Option<StrongRuleNode>,
        visited_style: Option<Arc<ComputedValues>>,
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inherited_box: Arc<style_structs::InheritedBox>,
        inherited_svg: Arc<style_structs::InheritedSVG>,
        inherited_table: Arc<style_structs::InheritedTable>,
        inherited_text: Arc<style_structs::InheritedText>,
        inherited_ui: Arc<style_structs::InheritedUI>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        page: Arc<style_structs::Page>,
        position: Arc<style_structs::Position>,
        svg: Arc<style_structs::SVG>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        xul: Arc<style_structs::XUL>,
    ) -> Arc<Self> {
        ComputedValuesInner::new(
            custom_properties,
            writing_mode,
            effective_zoom,
            flags,
            rules,
            visited_style,
            background,
            border,
            box_,
            column,
            counters,
            effects,
            font,
            inherited_box,
            inherited_svg,
            inherited_table,
            inherited_text,
            inherited_ui,
            list,
            margin,
            outline,
            padding,
            page,
            position,
            svg,
            table,
            text,
            ui,
            xul,
        ).to_outer(pseudo)
    }

    pub fn default_values(doc: &structs::Document) -> Arc<Self> {
        ComputedValuesInner::new(
            ComputedCustomProperties::default(),
            WritingMode::empty(), // FIXME(bz): This seems dubious
            Zoom::ONE,
            ComputedValueFlags::empty(),
            /* rules = */ None,
            /* visited_style = */ None,
            style_structs::Background::default(doc),
            style_structs::Border::default(doc),
            style_structs::Box::default(doc),
            style_structs::Column::default(doc),
            style_structs::Counters::default(doc),
            style_structs::Effects::default(doc),
            style_structs::Font::default(doc),
            style_structs::InheritedBox::default(doc),
            style_structs::InheritedSVG::default(doc),
            style_structs::InheritedTable::default(doc),
            style_structs::InheritedText::default(doc),
            style_structs::InheritedUI::default(doc),
            style_structs::List::default(doc),
            style_structs::Margin::default(doc),
            style_structs::Outline::default(doc),
            style_structs::Padding::default(doc),
            style_structs::Page::default(doc),
            style_structs::Position::default(doc),
            style_structs::SVG::default(doc),
            style_structs::Table::default(doc),
            style_structs::Text::default(doc),
            style_structs::UI::default(doc),
            style_structs::XUL::default(doc),
        ).to_outer(None)
    }

    /// Converts the computed values to an Arc<> from a reference.
    pub fn to_arc(&self) -> Arc<Self> {
        // SAFETY: We're guaranteed to be allocated as an Arc<> since the
        // functions above are the only ones that create ComputedValues
        // instances in Gecko (and that must be the case since ComputedValues'
        // member is private).
        unsafe { Arc::from_raw_addrefed(self) }
    }

    #[inline]
    pub fn is_pseudo_style(&self) -> bool {
        self.0.mPseudoType != PseudoStyleType::NotPseudo
    }

    #[inline]
    pub fn pseudo(&self) -> Option<PseudoElement> {
        if !self.is_pseudo_style() {
            return None;
        }
        PseudoElement::from_pseudo_type(self.0.mPseudoType, None)
    }

    #[inline]
    pub fn is_first_line_style(&self) -> bool {
        self.pseudo() == Some(PseudoElement::FirstLine)
    }

    /// Returns true if the display property is changed from 'none' to others.
    pub fn is_display_property_changed_from_none(
        &self,
        old_values: Option<&ComputedValues>
    ) -> bool {
        use crate::properties::longhands::display::computed_value::T as Display;

        old_values.map_or(false, |old| {
            let old_display_style = old.get_box().clone_display();
            let new_display_style = self.get_box().clone_display();
            old_display_style == Display::None &&
            new_display_style != Display::None
        })
    }

}

impl Drop for ComputedValues {
    fn drop(&mut self) {
        // XXX this still relies on the destructor of ComputedValuesInner to run on the rust side,
        // that's pretty wild.
        unsafe {
            bindings::Gecko_ComputedStyle_Destroy(&mut self.0);
        }
    }
}

unsafe impl Sync for ComputedValues {}
unsafe impl Send for ComputedValues {}

impl Clone for ComputedValues {
    fn clone(&self) -> Self {
        unreachable!()
    }
}

impl Clone for ComputedValuesInner {
    fn clone(&self) -> Self {
        ComputedValuesInner {
            Background: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.background_ptr()) }) as *const _,
            Border: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.border_ptr()) }) as *const _,
            Display: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.box_ptr()) }) as *const _,
            Column: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.column_ptr()) }) as *const _,
            Content: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.counters_ptr()) }) as *const _,
            Effects: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.effects_ptr()) }) as *const _,
            Font: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.font_ptr()) }) as *const _,
            Visibility: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.inherited_box_ptr()) }) as *const _,
            SVG: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.inherited_svg_ptr()) }) as *const _,
            TableBorder: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.inherited_table_ptr()) }) as *const _,
            Text: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.inherited_text_ptr()) }) as *const _,
            UI: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.inherited_ui_ptr()) }) as *const _,
            List: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.list_ptr()) }) as *const _,
            Margin: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.margin_ptr()) }) as *const _,
            Outline: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.outline_ptr()) }) as *const _,
            Padding: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.padding_ptr()) }) as *const _,
            Page: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.page_ptr()) }) as *const _,
            Position: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.position_ptr()) }) as *const _,
            SVGReset: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.svg_ptr()) }) as *const _,
            Table: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.table_ptr()) }) as *const _,
            TextReset: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.text_ptr()) }) as *const _,
            UIReset: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.ui_ptr()) }) as *const _,
            XUL: Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.xul_ptr()) }) as *const _,
            custom_properties: self.custom_properties.clone(),
            writing_mode: self.writing_mode.clone(),
            flags: self.flags.clone(),
            effective_zoom: self.effective_zoom,
            rules: self.rules.clone(),
            visited_style: if self.visited_style.is_null() {
                ptr::null()
            } else {
                Arc::into_raw(unsafe { Arc::from_raw_addrefed(self.visited_style_ptr()) }) as *const _
            },
        }
    }
}


impl Drop for ComputedValuesInner {
    fn drop(&mut self) {
        let _ = unsafe { Arc::from_raw(self.background_ptr()) };
        let _ = unsafe { Arc::from_raw(self.border_ptr()) };
        let _ = unsafe { Arc::from_raw(self.box_ptr()) };
        let _ = unsafe { Arc::from_raw(self.column_ptr()) };
        let _ = unsafe { Arc::from_raw(self.counters_ptr()) };
        let _ = unsafe { Arc::from_raw(self.effects_ptr()) };
        let _ = unsafe { Arc::from_raw(self.font_ptr()) };
        let _ = unsafe { Arc::from_raw(self.inherited_box_ptr()) };
        let _ = unsafe { Arc::from_raw(self.inherited_svg_ptr()) };
        let _ = unsafe { Arc::from_raw(self.inherited_table_ptr()) };
        let _ = unsafe { Arc::from_raw(self.inherited_text_ptr()) };
        let _ = unsafe { Arc::from_raw(self.inherited_ui_ptr()) };
        let _ = unsafe { Arc::from_raw(self.list_ptr()) };
        let _ = unsafe { Arc::from_raw(self.margin_ptr()) };
        let _ = unsafe { Arc::from_raw(self.outline_ptr()) };
        let _ = unsafe { Arc::from_raw(self.padding_ptr()) };
        let _ = unsafe { Arc::from_raw(self.page_ptr()) };
        let _ = unsafe { Arc::from_raw(self.position_ptr()) };
        let _ = unsafe { Arc::from_raw(self.svg_ptr()) };
        let _ = unsafe { Arc::from_raw(self.table_ptr()) };
        let _ = unsafe { Arc::from_raw(self.text_ptr()) };
        let _ = unsafe { Arc::from_raw(self.ui_ptr()) };
        let _ = unsafe { Arc::from_raw(self.xul_ptr()) };
        if !self.visited_style.is_null() {
            let _ = unsafe { Arc::from_raw(self.visited_style_ptr()) };
        }
    }
}

impl ComputedValuesInner {
    pub fn new(
        custom_properties: ComputedCustomProperties,
        writing_mode: WritingMode,
        effective_zoom: Zoom,
        flags: ComputedValueFlags,
        rules: Option<StrongRuleNode>,
        visited_style: Option<Arc<ComputedValues>>,
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inherited_box: Arc<style_structs::InheritedBox>,
        inherited_svg: Arc<style_structs::InheritedSVG>,
        inherited_table: Arc<style_structs::InheritedTable>,
        inherited_text: Arc<style_structs::InheritedText>,
        inherited_ui: Arc<style_structs::InheritedUI>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        page: Arc<style_structs::Page>,
        position: Arc<style_structs::Position>,
        svg: Arc<style_structs::SVG>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        xul: Arc<style_structs::XUL>,
    ) -> Self {
        Self {
            custom_properties,
            writing_mode,
            rules,
            visited_style: visited_style.map_or(ptr::null(), |p| Arc::into_raw(p)) as *const _,
            flags,
            effective_zoom,
            Background: Arc::into_raw(background) as *const _,
            Border: Arc::into_raw(border) as *const _,
            Display: Arc::into_raw(box_) as *const _,
            Column: Arc::into_raw(column) as *const _,
            Content: Arc::into_raw(counters) as *const _,
            Effects: Arc::into_raw(effects) as *const _,
            Font: Arc::into_raw(font) as *const _,
            Visibility: Arc::into_raw(inherited_box) as *const _,
            SVG: Arc::into_raw(inherited_svg) as *const _,
            TableBorder: Arc::into_raw(inherited_table) as *const _,
            Text: Arc::into_raw(inherited_text) as *const _,
            UI: Arc::into_raw(inherited_ui) as *const _,
            List: Arc::into_raw(list) as *const _,
            Margin: Arc::into_raw(margin) as *const _,
            Outline: Arc::into_raw(outline) as *const _,
            Padding: Arc::into_raw(padding) as *const _,
            Page: Arc::into_raw(page) as *const _,
            Position: Arc::into_raw(position) as *const _,
            SVGReset: Arc::into_raw(svg) as *const _,
            Table: Arc::into_raw(table) as *const _,
            TextReset: Arc::into_raw(text) as *const _,
            UIReset: Arc::into_raw(ui) as *const _,
            XUL: Arc::into_raw(xul) as *const _,
        }
    }

    fn to_outer(self, pseudo: Option<&PseudoElement>) -> Arc<ComputedValues> {
        let pseudo_ty = match pseudo {
            Some(p) => p.pseudo_type(),
            None => structs::PseudoStyleType::NotPseudo,
        };
        unsafe {
            let mut arc = UniqueArc::<ComputedValues>::new_uninit();
            bindings::Gecko_ComputedStyle_Init(
                arc.as_mut_ptr() as *mut _,
                &self,
                pseudo_ty,
            );
            // We're simulating move semantics by having C++ do a memcpy and
            // then forgetting it on this end.
            forget(self);
            UniqueArc::assume_init(arc).shareable()
        }
    }
}

impl ops::Deref for ComputedValues {
    type Target = ComputedValuesInner;
    #[inline]
    fn deref(&self) -> &ComputedValuesInner {
        &self.0.mSource
    }
}

impl ops::DerefMut for ComputedValues {
    #[inline]
    fn deref_mut(&mut self) -> &mut ComputedValuesInner {
        &mut self.0.mSource
    }
}

impl ComputedValuesInner {
    /// Returns true if the value of the `content` property would make a
    /// pseudo-element not rendered.
    #[inline]
    pub fn ineffective_content_property(&self) -> bool {
        self.get_counters().ineffective_content_property()
    }

    #[inline]
    fn visited_style_ptr(&self) -> *const ComputedValues {
        self.visited_style as *const _
    }

    /// Returns the visited style, if any.
    pub fn visited_style(&self) -> Option<&ComputedValues> {
        unsafe { self.visited_style_ptr().as_ref() }
    }

    #[inline]
    fn background_ptr(&self) -> *const style_structs::Background {
        // This is sound because the wrapper we create is repr(transparent).
        self.Background as *const _
    }

    #[inline]
    pub fn clone_background(&self) -> Arc<style_structs::Background> {
        unsafe { Arc::from_raw_addrefed(self.background_ptr()) }
    }
    #[inline]
    pub fn get_background(&self) -> &style_structs::Background {
        unsafe { &*self.background_ptr() }
    }

    #[inline]
    pub fn mutate_background(&mut self) -> &mut style_structs::Background {
        unsafe {
            let mut arc = Arc::from_raw(self.background_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Background = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn border_ptr(&self) -> *const style_structs::Border {
        // This is sound because the wrapper we create is repr(transparent).
        self.Border as *const _
    }

    #[inline]
    pub fn clone_border(&self) -> Arc<style_structs::Border> {
        unsafe { Arc::from_raw_addrefed(self.border_ptr()) }
    }
    #[inline]
    pub fn get_border(&self) -> &style_structs::Border {
        unsafe { &*self.border_ptr() }
    }

    #[inline]
    pub fn mutate_border(&mut self) -> &mut style_structs::Border {
        unsafe {
            let mut arc = Arc::from_raw(self.border_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Border = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn box_ptr(&self) -> *const style_structs::Box {
        // This is sound because the wrapper we create is repr(transparent).
        self.Display as *const _
    }

    #[inline]
    pub fn clone_box(&self) -> Arc<style_structs::Box> {
        unsafe { Arc::from_raw_addrefed(self.box_ptr()) }
    }
    #[inline]
    pub fn get_box(&self) -> &style_structs::Box {
        unsafe { &*self.box_ptr() }
    }

    #[inline]
    pub fn mutate_box(&mut self) -> &mut style_structs::Box {
        unsafe {
            let mut arc = Arc::from_raw(self.box_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Display = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn column_ptr(&self) -> *const style_structs::Column {
        // This is sound because the wrapper we create is repr(transparent).
        self.Column as *const _
    }

    #[inline]
    pub fn clone_column(&self) -> Arc<style_structs::Column> {
        unsafe { Arc::from_raw_addrefed(self.column_ptr()) }
    }
    #[inline]
    pub fn get_column(&self) -> &style_structs::Column {
        unsafe { &*self.column_ptr() }
    }

    #[inline]
    pub fn mutate_column(&mut self) -> &mut style_structs::Column {
        unsafe {
            let mut arc = Arc::from_raw(self.column_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Column = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn counters_ptr(&self) -> *const style_structs::Counters {
        // This is sound because the wrapper we create is repr(transparent).
        self.Content as *const _
    }

    #[inline]
    pub fn clone_counters(&self) -> Arc<style_structs::Counters> {
        unsafe { Arc::from_raw_addrefed(self.counters_ptr()) }
    }
    #[inline]
    pub fn get_counters(&self) -> &style_structs::Counters {
        unsafe { &*self.counters_ptr() }
    }

    #[inline]
    pub fn mutate_counters(&mut self) -> &mut style_structs::Counters {
        unsafe {
            let mut arc = Arc::from_raw(self.counters_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Content = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn effects_ptr(&self) -> *const style_structs::Effects {
        // This is sound because the wrapper we create is repr(transparent).
        self.Effects as *const _
    }

    #[inline]
    pub fn clone_effects(&self) -> Arc<style_structs::Effects> {
        unsafe { Arc::from_raw_addrefed(self.effects_ptr()) }
    }
    #[inline]
    pub fn get_effects(&self) -> &style_structs::Effects {
        unsafe { &*self.effects_ptr() }
    }

    #[inline]
    pub fn mutate_effects(&mut self) -> &mut style_structs::Effects {
        unsafe {
            let mut arc = Arc::from_raw(self.effects_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Effects = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn font_ptr(&self) -> *const style_structs::Font {
        // This is sound because the wrapper we create is repr(transparent).
        self.Font as *const _
    }

    #[inline]
    pub fn clone_font(&self) -> Arc<style_structs::Font> {
        unsafe { Arc::from_raw_addrefed(self.font_ptr()) }
    }
    #[inline]
    pub fn get_font(&self) -> &style_structs::Font {
        unsafe { &*self.font_ptr() }
    }

    #[inline]
    pub fn mutate_font(&mut self) -> &mut style_structs::Font {
        unsafe {
            let mut arc = Arc::from_raw(self.font_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Font = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn inherited_box_ptr(&self) -> *const style_structs::InheritedBox {
        // This is sound because the wrapper we create is repr(transparent).
        self.Visibility as *const _
    }

    #[inline]
    pub fn clone_inherited_box(&self) -> Arc<style_structs::InheritedBox> {
        unsafe { Arc::from_raw_addrefed(self.inherited_box_ptr()) }
    }
    #[inline]
    pub fn get_inherited_box(&self) -> &style_structs::InheritedBox {
        unsafe { &*self.inherited_box_ptr() }
    }

    #[inline]
    pub fn mutate_inherited_box(&mut self) -> &mut style_structs::InheritedBox {
        unsafe {
            let mut arc = Arc::from_raw(self.inherited_box_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Visibility = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn inherited_svg_ptr(&self) -> *const style_structs::InheritedSVG {
        // This is sound because the wrapper we create is repr(transparent).
        self.SVG as *const _
    }

    #[inline]
    pub fn clone_inherited_svg(&self) -> Arc<style_structs::InheritedSVG> {
        unsafe { Arc::from_raw_addrefed(self.inherited_svg_ptr()) }
    }
    #[inline]
    pub fn get_inherited_svg(&self) -> &style_structs::InheritedSVG {
        unsafe { &*self.inherited_svg_ptr() }
    }

    #[inline]
    pub fn mutate_inherited_svg(&mut self) -> &mut style_structs::InheritedSVG {
        unsafe {
            let mut arc = Arc::from_raw(self.inherited_svg_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.SVG = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn inherited_table_ptr(&self) -> *const style_structs::InheritedTable {
        // This is sound because the wrapper we create is repr(transparent).
        self.TableBorder as *const _
    }

    #[inline]
    pub fn clone_inherited_table(&self) -> Arc<style_structs::InheritedTable> {
        unsafe { Arc::from_raw_addrefed(self.inherited_table_ptr()) }
    }
    #[inline]
    pub fn get_inherited_table(&self) -> &style_structs::InheritedTable {
        unsafe { &*self.inherited_table_ptr() }
    }

    #[inline]
    pub fn mutate_inherited_table(&mut self) -> &mut style_structs::InheritedTable {
        unsafe {
            let mut arc = Arc::from_raw(self.inherited_table_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.TableBorder = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn inherited_text_ptr(&self) -> *const style_structs::InheritedText {
        // This is sound because the wrapper we create is repr(transparent).
        self.Text as *const _
    }

    #[inline]
    pub fn clone_inherited_text(&self) -> Arc<style_structs::InheritedText> {
        unsafe { Arc::from_raw_addrefed(self.inherited_text_ptr()) }
    }
    #[inline]
    pub fn get_inherited_text(&self) -> &style_structs::InheritedText {
        unsafe { &*self.inherited_text_ptr() }
    }

    #[inline]
    pub fn mutate_inherited_text(&mut self) -> &mut style_structs::InheritedText {
        unsafe {
            let mut arc = Arc::from_raw(self.inherited_text_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Text = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn inherited_ui_ptr(&self) -> *const style_structs::InheritedUI {
        // This is sound because the wrapper we create is repr(transparent).
        self.UI as *const _
    }

    #[inline]
    pub fn clone_inherited_ui(&self) -> Arc<style_structs::InheritedUI> {
        unsafe { Arc::from_raw_addrefed(self.inherited_ui_ptr()) }
    }
    #[inline]
    pub fn get_inherited_ui(&self) -> &style_structs::InheritedUI {
        unsafe { &*self.inherited_ui_ptr() }
    }

    #[inline]
    pub fn mutate_inherited_ui(&mut self) -> &mut style_structs::InheritedUI {
        unsafe {
            let mut arc = Arc::from_raw(self.inherited_ui_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.UI = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn list_ptr(&self) -> *const style_structs::List {
        // This is sound because the wrapper we create is repr(transparent).
        self.List as *const _
    }

    #[inline]
    pub fn clone_list(&self) -> Arc<style_structs::List> {
        unsafe { Arc::from_raw_addrefed(self.list_ptr()) }
    }
    #[inline]
    pub fn get_list(&self) -> &style_structs::List {
        unsafe { &*self.list_ptr() }
    }

    #[inline]
    pub fn mutate_list(&mut self) -> &mut style_structs::List {
        unsafe {
            let mut arc = Arc::from_raw(self.list_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.List = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn margin_ptr(&self) -> *const style_structs::Margin {
        // This is sound because the wrapper we create is repr(transparent).
        self.Margin as *const _
    }

    #[inline]
    pub fn clone_margin(&self) -> Arc<style_structs::Margin> {
        unsafe { Arc::from_raw_addrefed(self.margin_ptr()) }
    }
    #[inline]
    pub fn get_margin(&self) -> &style_structs::Margin {
        unsafe { &*self.margin_ptr() }
    }

    #[inline]
    pub fn mutate_margin(&mut self) -> &mut style_structs::Margin {
        unsafe {
            let mut arc = Arc::from_raw(self.margin_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Margin = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn outline_ptr(&self) -> *const style_structs::Outline {
        // This is sound because the wrapper we create is repr(transparent).
        self.Outline as *const _
    }

    #[inline]
    pub fn clone_outline(&self) -> Arc<style_structs::Outline> {
        unsafe { Arc::from_raw_addrefed(self.outline_ptr()) }
    }
    #[inline]
    pub fn get_outline(&self) -> &style_structs::Outline {
        unsafe { &*self.outline_ptr() }
    }

    #[inline]
    pub fn mutate_outline(&mut self) -> &mut style_structs::Outline {
        unsafe {
            let mut arc = Arc::from_raw(self.outline_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Outline = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn padding_ptr(&self) -> *const style_structs::Padding {
        // This is sound because the wrapper we create is repr(transparent).
        self.Padding as *const _
    }

    #[inline]
    pub fn clone_padding(&self) -> Arc<style_structs::Padding> {
        unsafe { Arc::from_raw_addrefed(self.padding_ptr()) }
    }
    #[inline]
    pub fn get_padding(&self) -> &style_structs::Padding {
        unsafe { &*self.padding_ptr() }
    }

    #[inline]
    pub fn mutate_padding(&mut self) -> &mut style_structs::Padding {
        unsafe {
            let mut arc = Arc::from_raw(self.padding_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Padding = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn page_ptr(&self) -> *const style_structs::Page {
        // This is sound because the wrapper we create is repr(transparent).
        self.Page as *const _
    }

    #[inline]
    pub fn clone_page(&self) -> Arc<style_structs::Page> {
        unsafe { Arc::from_raw_addrefed(self.page_ptr()) }
    }
    #[inline]
    pub fn get_page(&self) -> &style_structs::Page {
        unsafe { &*self.page_ptr() }
    }

    #[inline]
    pub fn mutate_page(&mut self) -> &mut style_structs::Page {
        unsafe {
            let mut arc = Arc::from_raw(self.page_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Page = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn position_ptr(&self) -> *const style_structs::Position {
        // This is sound because the wrapper we create is repr(transparent).
        self.Position as *const _
    }

    #[inline]
    pub fn clone_position(&self) -> Arc<style_structs::Position> {
        unsafe { Arc::from_raw_addrefed(self.position_ptr()) }
    }
    #[inline]
    pub fn get_position(&self) -> &style_structs::Position {
        unsafe { &*self.position_ptr() }
    }

    #[inline]
    pub fn mutate_position(&mut self) -> &mut style_structs::Position {
        unsafe {
            let mut arc = Arc::from_raw(self.position_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Position = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn svg_ptr(&self) -> *const style_structs::SVG {
        // This is sound because the wrapper we create is repr(transparent).
        self.SVGReset as *const _
    }

    #[inline]
    pub fn clone_svg(&self) -> Arc<style_structs::SVG> {
        unsafe { Arc::from_raw_addrefed(self.svg_ptr()) }
    }
    #[inline]
    pub fn get_svg(&self) -> &style_structs::SVG {
        unsafe { &*self.svg_ptr() }
    }

    #[inline]
    pub fn mutate_svg(&mut self) -> &mut style_structs::SVG {
        unsafe {
            let mut arc = Arc::from_raw(self.svg_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.SVGReset = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn table_ptr(&self) -> *const style_structs::Table {
        // This is sound because the wrapper we create is repr(transparent).
        self.Table as *const _
    }

    #[inline]
    pub fn clone_table(&self) -> Arc<style_structs::Table> {
        unsafe { Arc::from_raw_addrefed(self.table_ptr()) }
    }
    #[inline]
    pub fn get_table(&self) -> &style_structs::Table {
        unsafe { &*self.table_ptr() }
    }

    #[inline]
    pub fn mutate_table(&mut self) -> &mut style_structs::Table {
        unsafe {
            let mut arc = Arc::from_raw(self.table_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.Table = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn text_ptr(&self) -> *const style_structs::Text {
        // This is sound because the wrapper we create is repr(transparent).
        self.TextReset as *const _
    }

    #[inline]
    pub fn clone_text(&self) -> Arc<style_structs::Text> {
        unsafe { Arc::from_raw_addrefed(self.text_ptr()) }
    }
    #[inline]
    pub fn get_text(&self) -> &style_structs::Text {
        unsafe { &*self.text_ptr() }
    }

    #[inline]
    pub fn mutate_text(&mut self) -> &mut style_structs::Text {
        unsafe {
            let mut arc = Arc::from_raw(self.text_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.TextReset = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn ui_ptr(&self) -> *const style_structs::UI {
        // This is sound because the wrapper we create is repr(transparent).
        self.UIReset as *const _
    }

    #[inline]
    pub fn clone_ui(&self) -> Arc<style_structs::UI> {
        unsafe { Arc::from_raw_addrefed(self.ui_ptr()) }
    }
    #[inline]
    pub fn get_ui(&self) -> &style_structs::UI {
        unsafe { &*self.ui_ptr() }
    }

    #[inline]
    pub fn mutate_ui(&mut self) -> &mut style_structs::UI {
        unsafe {
            let mut arc = Arc::from_raw(self.ui_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.UIReset = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
    #[inline]
    fn xul_ptr(&self) -> *const style_structs::XUL {
        // This is sound because the wrapper we create is repr(transparent).
        self.XUL as *const _
    }

    #[inline]
    pub fn clone_xul(&self) -> Arc<style_structs::XUL> {
        unsafe { Arc::from_raw_addrefed(self.xul_ptr()) }
    }
    #[inline]
    pub fn get_xul(&self) -> &style_structs::XUL {
        unsafe { &*self.xul_ptr() }
    }

    #[inline]
    pub fn mutate_xul(&mut self) -> &mut style_structs::XUL {
        unsafe {
            let mut arc = Arc::from_raw(self.xul_ptr());
            let ptr = Arc::make_mut(&mut arc) as *mut _;
            // Sound for the same reason _ptr() is sound.
            self.XUL = Arc::into_raw(arc) as *const _;
            &mut *ptr
        }
    }
}



























#[allow(dead_code)]
fn static_assert() {
    // Note: using the above technique with an enum hits a rust bug when |structs| is in a different crate.
    { const DETAIL: u32 = [0][(structs::Side::eSideTop as usize != 0) as usize]; let _ = DETAIL; }
    { const DETAIL: u32 = [0][(structs::Side::eSideRight as usize != 1) as usize]; let _ = DETAIL; }
    { const DETAIL: u32 = [0][(structs::Side::eSideBottom as usize != 2) as usize]; let _ = DETAIL; }
    { const DETAIL: u32 = [0][(structs::Side::eSideLeft as usize != 3) as usize]; let _ = DETAIL; }
}






impl GeckoBorder {
    /*
     * Manually-Implemented Methods.
     */
    
    pub fn set_border_top_style(&mut self, v: BorderStyle) {
        self.mBorderStyle[0] = v;

        // This is needed because the initial mComputedBorder value is set to
        // zero.
        //
        // In order to compute stuff, we start from the initial struct, and keep
        // going down the tree applying properties.
        //
        // That means, effectively, that when we set border-style to something
        // non-hidden, we should use the initial border instead.
        //
        // Servo stores the initial border-width in the initial struct, and then
        // adjusts as needed in the fixup phase. This means that the initial
        // struct is technically not valid without fixups, and that you lose
        // pretty much any sharing of the initial struct, which is kind of
        // unfortunate.
        //
        // Gecko has two fields for this, one that stores the "specified"
        // border, and other that stores the actual computed one. That means
        // that when we set border-style, border-width may change and we need to
        // sync back to the specified one. This is what this function does.
        //
        // Note that this doesn't impose any dependency in the order of
        // computation of the properties. This is only relevant if border-style
        // is specified, but border-width isn't. If border-width is specified at
        // some point, the two mBorder and mComputedBorder fields would be the
        // same already.
        //
        // Once we're here, we know that we'll run style fixups, so it's fine to
        // just copy the specified border here, we'll adjust it if it's
        // incorrect later.
        self.mComputedBorder.top = self.mBorder.top;
    }

    pub fn copy_border_top_style_from(&mut self, other: &Self) {
        self.set_border_top_style(other.mBorderStyle[0]);
    }

    pub fn reset_border_top_style(&mut self, other: &Self) {
        self.copy_border_top_style_from(other);
    }

    #[inline]
    pub fn clone_border_top_style(&self) -> BorderStyle {
        self.mBorderStyle[0]
    }

    
    #[allow(non_snake_case)]
    pub fn set_border_top_width(&mut self, v: Au) {
        let value = v.0;
        self.mBorder.top = value;
        self.mComputedBorder.top = value;
    }

    #[allow(non_snake_case)]
    pub fn copy_border_top_width_from(&mut self, other: &Self) {
        self.mBorder.top = other.mBorder.top;
        // NOTE: This is needed to easily handle the `unset` and `initial`
        // keywords, which are implemented calling this function.
        //
        // In practice, this means that we may have an incorrect value here, but
        // we'll adjust that properly in the style fixup phase.
        //
        // FIXME(emilio): We could clean this up a bit special-casing the reset_
        // function below.
        self.mComputedBorder.top = other.mBorder.top;
    }

    #[allow(non_snake_case)]
    pub fn reset_border_top_width(&mut self, other: &Self) {
        self.copy_border_top_width_from(other)
    }

    #[allow(non_snake_case)]
    pub fn clone_border_top_width(&self) -> Au {
        Au(self.mComputedBorder.top)
    }


    pub fn border_top_has_nonzero_width(&self) -> bool {
        self.mComputedBorder.top != 0
    }
    pub fn set_border_right_style(&mut self, v: BorderStyle) {
        self.mBorderStyle[1] = v;

        // This is needed because the initial mComputedBorder value is set to
        // zero.
        //
        // In order to compute stuff, we start from the initial struct, and keep
        // going down the tree applying properties.
        //
        // That means, effectively, that when we set border-style to something
        // non-hidden, we should use the initial border instead.
        //
        // Servo stores the initial border-width in the initial struct, and then
        // adjusts as needed in the fixup phase. This means that the initial
        // struct is technically not valid without fixups, and that you lose
        // pretty much any sharing of the initial struct, which is kind of
        // unfortunate.
        //
        // Gecko has two fields for this, one that stores the "specified"
        // border, and other that stores the actual computed one. That means
        // that when we set border-style, border-width may change and we need to
        // sync back to the specified one. This is what this function does.
        //
        // Note that this doesn't impose any dependency in the order of
        // computation of the properties. This is only relevant if border-style
        // is specified, but border-width isn't. If border-width is specified at
        // some point, the two mBorder and mComputedBorder fields would be the
        // same already.
        //
        // Once we're here, we know that we'll run style fixups, so it's fine to
        // just copy the specified border here, we'll adjust it if it's
        // incorrect later.
        self.mComputedBorder.right = self.mBorder.right;
    }

    pub fn copy_border_right_style_from(&mut self, other: &Self) {
        self.set_border_right_style(other.mBorderStyle[1]);
    }

    pub fn reset_border_right_style(&mut self, other: &Self) {
        self.copy_border_right_style_from(other);
    }

    #[inline]
    pub fn clone_border_right_style(&self) -> BorderStyle {
        self.mBorderStyle[1]
    }

    
    #[allow(non_snake_case)]
    pub fn set_border_right_width(&mut self, v: Au) {
        let value = v.0;
        self.mBorder.right = value;
        self.mComputedBorder.right = value;
    }

    #[allow(non_snake_case)]
    pub fn copy_border_right_width_from(&mut self, other: &Self) {
        self.mBorder.right = other.mBorder.right;
        // NOTE: This is needed to easily handle the `unset` and `initial`
        // keywords, which are implemented calling this function.
        //
        // In practice, this means that we may have an incorrect value here, but
        // we'll adjust that properly in the style fixup phase.
        //
        // FIXME(emilio): We could clean this up a bit special-casing the reset_
        // function below.
        self.mComputedBorder.right = other.mBorder.right;
    }

    #[allow(non_snake_case)]
    pub fn reset_border_right_width(&mut self, other: &Self) {
        self.copy_border_right_width_from(other)
    }

    #[allow(non_snake_case)]
    pub fn clone_border_right_width(&self) -> Au {
        Au(self.mComputedBorder.right)
    }


    pub fn border_right_has_nonzero_width(&self) -> bool {
        self.mComputedBorder.right != 0
    }
    pub fn set_border_bottom_style(&mut self, v: BorderStyle) {
        self.mBorderStyle[2] = v;

        // This is needed because the initial mComputedBorder value is set to
        // zero.
        //
        // In order to compute stuff, we start from the initial struct, and keep
        // going down the tree applying properties.
        //
        // That means, effectively, that when we set border-style to something
        // non-hidden, we should use the initial border instead.
        //
        // Servo stores the initial border-width in the initial struct, and then
        // adjusts as needed in the fixup phase. This means that the initial
        // struct is technically not valid without fixups, and that you lose
        // pretty much any sharing of the initial struct, which is kind of
        // unfortunate.
        //
        // Gecko has two fields for this, one that stores the "specified"
        // border, and other that stores the actual computed one. That means
        // that when we set border-style, border-width may change and we need to
        // sync back to the specified one. This is what this function does.
        //
        // Note that this doesn't impose any dependency in the order of
        // computation of the properties. This is only relevant if border-style
        // is specified, but border-width isn't. If border-width is specified at
        // some point, the two mBorder and mComputedBorder fields would be the
        // same already.
        //
        // Once we're here, we know that we'll run style fixups, so it's fine to
        // just copy the specified border here, we'll adjust it if it's
        // incorrect later.
        self.mComputedBorder.bottom = self.mBorder.bottom;
    }

    pub fn copy_border_bottom_style_from(&mut self, other: &Self) {
        self.set_border_bottom_style(other.mBorderStyle[2]);
    }

    pub fn reset_border_bottom_style(&mut self, other: &Self) {
        self.copy_border_bottom_style_from(other);
    }

    #[inline]
    pub fn clone_border_bottom_style(&self) -> BorderStyle {
        self.mBorderStyle[2]
    }

    
    #[allow(non_snake_case)]
    pub fn set_border_bottom_width(&mut self, v: Au) {
        let value = v.0;
        self.mBorder.bottom = value;
        self.mComputedBorder.bottom = value;
    }

    #[allow(non_snake_case)]
    pub fn copy_border_bottom_width_from(&mut self, other: &Self) {
        self.mBorder.bottom = other.mBorder.bottom;
        // NOTE: This is needed to easily handle the `unset` and `initial`
        // keywords, which are implemented calling this function.
        //
        // In practice, this means that we may have an incorrect value here, but
        // we'll adjust that properly in the style fixup phase.
        //
        // FIXME(emilio): We could clean this up a bit special-casing the reset_
        // function below.
        self.mComputedBorder.bottom = other.mBorder.bottom;
    }

    #[allow(non_snake_case)]
    pub fn reset_border_bottom_width(&mut self, other: &Self) {
        self.copy_border_bottom_width_from(other)
    }

    #[allow(non_snake_case)]
    pub fn clone_border_bottom_width(&self) -> Au {
        Au(self.mComputedBorder.bottom)
    }


    pub fn border_bottom_has_nonzero_width(&self) -> bool {
        self.mComputedBorder.bottom != 0
    }
    pub fn set_border_left_style(&mut self, v: BorderStyle) {
        self.mBorderStyle[3] = v;

        // This is needed because the initial mComputedBorder value is set to
        // zero.
        //
        // In order to compute stuff, we start from the initial struct, and keep
        // going down the tree applying properties.
        //
        // That means, effectively, that when we set border-style to something
        // non-hidden, we should use the initial border instead.
        //
        // Servo stores the initial border-width in the initial struct, and then
        // adjusts as needed in the fixup phase. This means that the initial
        // struct is technically not valid without fixups, and that you lose
        // pretty much any sharing of the initial struct, which is kind of
        // unfortunate.
        //
        // Gecko has two fields for this, one that stores the "specified"
        // border, and other that stores the actual computed one. That means
        // that when we set border-style, border-width may change and we need to
        // sync back to the specified one. This is what this function does.
        //
        // Note that this doesn't impose any dependency in the order of
        // computation of the properties. This is only relevant if border-style
        // is specified, but border-width isn't. If border-width is specified at
        // some point, the two mBorder and mComputedBorder fields would be the
        // same already.
        //
        // Once we're here, we know that we'll run style fixups, so it's fine to
        // just copy the specified border here, we'll adjust it if it's
        // incorrect later.
        self.mComputedBorder.left = self.mBorder.left;
    }

    pub fn copy_border_left_style_from(&mut self, other: &Self) {
        self.set_border_left_style(other.mBorderStyle[3]);
    }

    pub fn reset_border_left_style(&mut self, other: &Self) {
        self.copy_border_left_style_from(other);
    }

    #[inline]
    pub fn clone_border_left_style(&self) -> BorderStyle {
        self.mBorderStyle[3]
    }

    
    #[allow(non_snake_case)]
    pub fn set_border_left_width(&mut self, v: Au) {
        let value = v.0;
        self.mBorder.left = value;
        self.mComputedBorder.left = value;
    }

    #[allow(non_snake_case)]
    pub fn copy_border_left_width_from(&mut self, other: &Self) {
        self.mBorder.left = other.mBorder.left;
        // NOTE: This is needed to easily handle the `unset` and `initial`
        // keywords, which are implemented calling this function.
        //
        // In practice, this means that we may have an incorrect value here, but
        // we'll adjust that properly in the style fixup phase.
        //
        // FIXME(emilio): We could clean this up a bit special-casing the reset_
        // function below.
        self.mComputedBorder.left = other.mBorder.left;
    }

    #[allow(non_snake_case)]
    pub fn reset_border_left_width(&mut self, other: &Self) {
        self.copy_border_left_width_from(other)
    }

    #[allow(non_snake_case)]
    pub fn clone_border_left_width(&self) -> Au {
        Au(self.mComputedBorder.left)
    }


    pub fn border_left_has_nonzero_width(&self) -> bool {
        self.mComputedBorder.left != 0
    }

    

    #[allow(non_snake_case)]
    pub fn set_border_top_left_radius(&mut self, v: longhands::border_top_left_radius::computed_value::T) {
        self.mBorderRadius.top_left = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_top_left_radius_from(&mut self, other: &Self) {
        self.mBorderRadius.top_left = other.mBorderRadius.top_left.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_top_left_radius(&mut self, other: &Self) {
        self.copy_border_top_left_radius_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_top_left_radius(&self) -> longhands::border_top_left_radius::computed_value::T {
        From::from(self.mBorderRadius.top_left.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_border_top_right_radius(&mut self, v: longhands::border_top_right_radius::computed_value::T) {
        self.mBorderRadius.top_right = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_top_right_radius_from(&mut self, other: &Self) {
        self.mBorderRadius.top_right = other.mBorderRadius.top_right.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_top_right_radius(&mut self, other: &Self) {
        self.copy_border_top_right_radius_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_top_right_radius(&self) -> longhands::border_top_right_radius::computed_value::T {
        From::from(self.mBorderRadius.top_right.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_border_bottom_right_radius(&mut self, v: longhands::border_bottom_right_radius::computed_value::T) {
        self.mBorderRadius.bottom_right = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_bottom_right_radius_from(&mut self, other: &Self) {
        self.mBorderRadius.bottom_right = other.mBorderRadius.bottom_right.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_bottom_right_radius(&mut self, other: &Self) {
        self.copy_border_bottom_right_radius_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_bottom_right_radius(&self) -> longhands::border_bottom_right_radius::computed_value::T {
        From::from(self.mBorderRadius.bottom_right.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_border_bottom_left_radius(&mut self, v: longhands::border_bottom_left_radius::computed_value::T) {
        self.mBorderRadius.bottom_left = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_bottom_left_radius_from(&mut self, other: &Self) {
        self.mBorderRadius.bottom_left = other.mBorderRadius.bottom_left.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_bottom_left_radius(&mut self, other: &Self) {
        self.copy_border_bottom_left_radius_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_bottom_left_radius(&self) -> longhands::border_bottom_left_radius::computed_value::T {
        From::from(self.mBorderRadius.bottom_left.clone())
    }



    

    pub fn set_border_image_repeat(&mut self, v: longhands::border_image_repeat::computed_value::T) {
        use crate::values::specified::border::BorderImageRepeatKeyword;
        use crate::gecko_bindings::structs::StyleBorderImageRepeat;

            self.mBorderImageRepeatH = match v.0 {
                BorderImageRepeatKeyword::Stretch => StyleBorderImageRepeat::Stretch,
                BorderImageRepeatKeyword::Repeat => StyleBorderImageRepeat::Repeat,
                BorderImageRepeatKeyword::Round => StyleBorderImageRepeat::Round,
                BorderImageRepeatKeyword::Space => StyleBorderImageRepeat::Space,
            };
            self.mBorderImageRepeatV = match v.1 {
                BorderImageRepeatKeyword::Stretch => StyleBorderImageRepeat::Stretch,
                BorderImageRepeatKeyword::Repeat => StyleBorderImageRepeat::Repeat,
                BorderImageRepeatKeyword::Round => StyleBorderImageRepeat::Round,
                BorderImageRepeatKeyword::Space => StyleBorderImageRepeat::Space,
            };
    }

    pub fn copy_border_image_repeat_from(&mut self, other: &Self) {
        self.mBorderImageRepeatH = other.mBorderImageRepeatH;
        self.mBorderImageRepeatV = other.mBorderImageRepeatV;
    }

    pub fn reset_border_image_repeat(&mut self, other: &Self) {
        self.copy_border_image_repeat_from(other)
    }

    pub fn clone_border_image_repeat(&self) -> longhands::border_image_repeat::computed_value::T {
        use crate::values::specified::border::BorderImageRepeatKeyword;
        use crate::gecko_bindings::structs::StyleBorderImageRepeat;

        let servo_h = match self.mBorderImageRepeatH {
            StyleBorderImageRepeat::Stretch => BorderImageRepeatKeyword::Stretch,
            StyleBorderImageRepeat::Repeat => BorderImageRepeatKeyword::Repeat,
            StyleBorderImageRepeat::Round => BorderImageRepeatKeyword::Round,
            StyleBorderImageRepeat::Space => BorderImageRepeatKeyword::Space,
        };
        let servo_v = match self.mBorderImageRepeatV {
            StyleBorderImageRepeat::Stretch => BorderImageRepeatKeyword::Stretch,
            StyleBorderImageRepeat::Repeat => BorderImageRepeatKeyword::Repeat,
            StyleBorderImageRepeat::Round => BorderImageRepeatKeyword::Round,
            StyleBorderImageRepeat::Space => BorderImageRepeatKeyword::Space,
        };
        longhands::border_image_repeat::computed_value::T(servo_h, servo_v)
    }


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_border_top_color(&mut self, v: longhands::border_top_color::computed_value::T) {
        self.mBorderTopColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_top_color_from(&mut self, other: &Self) {
        self.mBorderTopColor = other.mBorderTopColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_top_color(&mut self, other: &Self) {
        self.copy_border_top_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_top_color(&self) -> longhands::border_top_color::computed_value::T {
        From::from(self.mBorderTopColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_border_right_color(&mut self, v: longhands::border_right_color::computed_value::T) {
        self.mBorderRightColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_right_color_from(&mut self, other: &Self) {
        self.mBorderRightColor = other.mBorderRightColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_right_color(&mut self, other: &Self) {
        self.copy_border_right_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_right_color(&self) -> longhands::border_right_color::computed_value::T {
        From::from(self.mBorderRightColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_border_bottom_color(&mut self, v: longhands::border_bottom_color::computed_value::T) {
        self.mBorderBottomColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_bottom_color_from(&mut self, other: &Self) {
        self.mBorderBottomColor = other.mBorderBottomColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_bottom_color(&mut self, other: &Self) {
        self.copy_border_bottom_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_bottom_color(&self) -> longhands::border_bottom_color::computed_value::T {
        From::from(self.mBorderBottomColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_border_left_color(&mut self, v: longhands::border_left_color::computed_value::T) {
        self.mBorderLeftColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_left_color_from(&mut self, other: &Self) {
        self.mBorderLeftColor = other.mBorderLeftColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_left_color(&mut self, other: &Self) {
        self.copy_border_left_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_left_color(&self) -> longhands::border_left_color::computed_value::T {
        From::from(self.mBorderLeftColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_box_decoration_break(&mut self, v: longhands::box_decoration_break::computed_value::T) {
        use crate::properties::longhands::box_decoration_break::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Slice =>
                    structs::StyleBoxDecorationBreak::Slice ,
                Keyword::Clone =>
                    structs::StyleBoxDecorationBreak::Clone ,
        };
        self.mBoxDecorationBreak = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_box_decoration_break_from(&mut self, other: &Self) {
        self.mBoxDecorationBreak = other.mBoxDecorationBreak.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_box_decoration_break(&mut self, other: &Self) {
        self.copy_box_decoration_break_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_box_decoration_break(&self) -> longhands::box_decoration_break::computed_value::T {
        use crate::properties::longhands::box_decoration_break::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBoxDecorationBreak {
            structs::StyleBoxDecorationBreak::Slice => Keyword::Slice,
            structs::StyleBoxDecorationBreak::Clone => Keyword::Clone,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_float_edge(&mut self, v: longhands::_moz_float_edge::computed_value::T) {
        use crate::properties::longhands::_moz_float_edge::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::ContentBox =>
                    structs::StyleFloatEdge::ContentBox ,
                Keyword::MarginBox =>
                    structs::StyleFloatEdge::MarginBox ,
        };
        self.mFloatEdge = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_float_edge_from(&mut self, other: &Self) {
        self.mFloatEdge = other.mFloatEdge.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_float_edge(&mut self, other: &Self) {
        self.copy__moz_float_edge_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_float_edge(&self) -> longhands::_moz_float_edge::computed_value::T {
        use crate::properties::longhands::_moz_float_edge::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mFloatEdge {
            structs::StyleFloatEdge::ContentBox => Keyword::ContentBox,
            structs::StyleFloatEdge::MarginBox => Keyword::MarginBox,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_border_image_source(&mut self, v: longhands::border_image_source::computed_value::T) {
        self.mBorderImageSource = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_image_source_from(&mut self, other: &Self) {
        self.mBorderImageSource = other.mBorderImageSource.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_image_source(&mut self, other: &Self) {
        self.copy_border_image_source_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_image_source(&self) -> longhands::border_image_source::computed_value::T {
        From::from(self.mBorderImageSource.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_border_image_outset(&mut self, v: longhands::border_image_outset::computed_value::T) {
        self.mBorderImageOutset = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_image_outset_from(&mut self, other: &Self) {
        self.mBorderImageOutset = other.mBorderImageOutset.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_image_outset(&mut self, other: &Self) {
        self.copy_border_image_outset_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_image_outset(&self) -> longhands::border_image_outset::computed_value::T {
        From::from(self.mBorderImageOutset.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_border_image_width(&mut self, v: longhands::border_image_width::computed_value::T) {
        self.mBorderImageWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_image_width_from(&mut self, other: &Self) {
        self.mBorderImageWidth = other.mBorderImageWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_image_width(&mut self, other: &Self) {
        self.copy_border_image_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_image_width(&self) -> longhands::border_image_width::computed_value::T {
        From::from(self.mBorderImageWidth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_border_image_slice(&mut self, v: longhands::border_image_slice::computed_value::T) {
        self.mBorderImageSlice = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_image_slice_from(&mut self, other: &Self) {
        self.mBorderImageSlice = other.mBorderImageSlice.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_image_slice(&mut self, other: &Self) {
        self.copy_border_image_slice_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_image_slice(&self) -> longhands::border_image_slice::computed_value::T {
        From::from(self.mBorderImageSlice.clone())
    }


}






impl GeckoMargin {
    /*
     * Manually-Implemented Methods.
     */
    
    

    #[allow(non_snake_case)]
    pub fn set_margin_top(&mut self, v: longhands::margin_top::computed_value::T) {
        self.mMargin.0 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_margin_top_from(&mut self, other: &Self) {
        self.mMargin.0 = other.mMargin.0.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_margin_top(&mut self, other: &Self) {
        self.copy_margin_top_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_margin_top(&self) -> longhands::margin_top::computed_value::T {
        From::from(self.mMargin.0.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_margin_top(&mut self, v: longhands::scroll_margin_top::computed_value::T) {
        self.mScrollMargin.0 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_margin_top_from(&mut self, other: &Self) {
        self.mScrollMargin.0 = other.mScrollMargin.0.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_margin_top(&mut self, other: &Self) {
        self.copy_scroll_margin_top_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_top(&self) -> longhands::scroll_margin_top::computed_value::T {
        From::from(self.mScrollMargin.0.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_margin_right(&mut self, v: longhands::margin_right::computed_value::T) {
        self.mMargin.1 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_margin_right_from(&mut self, other: &Self) {
        self.mMargin.1 = other.mMargin.1.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_margin_right(&mut self, other: &Self) {
        self.copy_margin_right_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_margin_right(&self) -> longhands::margin_right::computed_value::T {
        From::from(self.mMargin.1.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_margin_right(&mut self, v: longhands::scroll_margin_right::computed_value::T) {
        self.mScrollMargin.1 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_margin_right_from(&mut self, other: &Self) {
        self.mScrollMargin.1 = other.mScrollMargin.1.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_margin_right(&mut self, other: &Self) {
        self.copy_scroll_margin_right_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_right(&self) -> longhands::scroll_margin_right::computed_value::T {
        From::from(self.mScrollMargin.1.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_margin_bottom(&mut self, v: longhands::margin_bottom::computed_value::T) {
        self.mMargin.2 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_margin_bottom_from(&mut self, other: &Self) {
        self.mMargin.2 = other.mMargin.2.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_margin_bottom(&mut self, other: &Self) {
        self.copy_margin_bottom_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_margin_bottom(&self) -> longhands::margin_bottom::computed_value::T {
        From::from(self.mMargin.2.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_margin_bottom(&mut self, v: longhands::scroll_margin_bottom::computed_value::T) {
        self.mScrollMargin.2 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_margin_bottom_from(&mut self, other: &Self) {
        self.mScrollMargin.2 = other.mScrollMargin.2.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_margin_bottom(&mut self, other: &Self) {
        self.copy_scroll_margin_bottom_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_bottom(&self) -> longhands::scroll_margin_bottom::computed_value::T {
        From::from(self.mScrollMargin.2.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_margin_left(&mut self, v: longhands::margin_left::computed_value::T) {
        self.mMargin.3 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_margin_left_from(&mut self, other: &Self) {
        self.mMargin.3 = other.mMargin.3.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_margin_left(&mut self, other: &Self) {
        self.copy_margin_left_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_margin_left(&self) -> longhands::margin_left::computed_value::T {
        From::from(self.mMargin.3.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_margin_left(&mut self, v: longhands::scroll_margin_left::computed_value::T) {
        self.mScrollMargin.3 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_margin_left_from(&mut self, other: &Self) {
        self.mScrollMargin.3 = other.mScrollMargin.3.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_margin_left(&mut self, other: &Self) {
        self.copy_scroll_margin_left_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_left(&self) -> longhands::scroll_margin_left::computed_value::T {
        From::from(self.mScrollMargin.3.clone())
    }




    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_overflow_clip_margin(&mut self, v: longhands::overflow_clip_margin::computed_value::T) {
        self.mOverflowClipMargin = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overflow_clip_margin_from(&mut self, other: &Self) {
        self.mOverflowClipMargin = other.mOverflowClipMargin.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overflow_clip_margin(&mut self, other: &Self) {
        self.copy_overflow_clip_margin_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overflow_clip_margin(&self) -> longhands::overflow_clip_margin::computed_value::T {
        From::from(self.mOverflowClipMargin.clone())
    }


}






impl GeckoPadding {
    /*
     * Manually-Implemented Methods.
     */
    

    

    #[allow(non_snake_case)]
    pub fn set_padding_top(&mut self, v: longhands::padding_top::computed_value::T) {
        self.mPadding.0 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_padding_top_from(&mut self, other: &Self) {
        self.mPadding.0 = other.mPadding.0.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_padding_top(&mut self, other: &Self) {
        self.copy_padding_top_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_padding_top(&self) -> longhands::padding_top::computed_value::T {
        From::from(self.mPadding.0.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_padding_top(&mut self, v: longhands::scroll_padding_top::computed_value::T) {
        self.mScrollPadding.0 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_padding_top_from(&mut self, other: &Self) {
        self.mScrollPadding.0 = other.mScrollPadding.0.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_padding_top(&mut self, other: &Self) {
        self.copy_scroll_padding_top_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_top(&self) -> longhands::scroll_padding_top::computed_value::T {
        From::from(self.mScrollPadding.0.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_padding_right(&mut self, v: longhands::padding_right::computed_value::T) {
        self.mPadding.1 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_padding_right_from(&mut self, other: &Self) {
        self.mPadding.1 = other.mPadding.1.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_padding_right(&mut self, other: &Self) {
        self.copy_padding_right_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_padding_right(&self) -> longhands::padding_right::computed_value::T {
        From::from(self.mPadding.1.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_padding_right(&mut self, v: longhands::scroll_padding_right::computed_value::T) {
        self.mScrollPadding.1 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_padding_right_from(&mut self, other: &Self) {
        self.mScrollPadding.1 = other.mScrollPadding.1.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_padding_right(&mut self, other: &Self) {
        self.copy_scroll_padding_right_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_right(&self) -> longhands::scroll_padding_right::computed_value::T {
        From::from(self.mScrollPadding.1.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_padding_bottom(&mut self, v: longhands::padding_bottom::computed_value::T) {
        self.mPadding.2 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_padding_bottom_from(&mut self, other: &Self) {
        self.mPadding.2 = other.mPadding.2.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_padding_bottom(&mut self, other: &Self) {
        self.copy_padding_bottom_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_padding_bottom(&self) -> longhands::padding_bottom::computed_value::T {
        From::from(self.mPadding.2.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_padding_bottom(&mut self, v: longhands::scroll_padding_bottom::computed_value::T) {
        self.mScrollPadding.2 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_padding_bottom_from(&mut self, other: &Self) {
        self.mScrollPadding.2 = other.mScrollPadding.2.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_padding_bottom(&mut self, other: &Self) {
        self.copy_scroll_padding_bottom_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_bottom(&self) -> longhands::scroll_padding_bottom::computed_value::T {
        From::from(self.mScrollPadding.2.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_padding_left(&mut self, v: longhands::padding_left::computed_value::T) {
        self.mPadding.3 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_padding_left_from(&mut self, other: &Self) {
        self.mPadding.3 = other.mPadding.3.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_padding_left(&mut self, other: &Self) {
        self.copy_padding_left_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_padding_left(&self) -> longhands::padding_left::computed_value::T {
        From::from(self.mPadding.3.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_scroll_padding_left(&mut self, v: longhands::scroll_padding_left::computed_value::T) {
        self.mScrollPadding.3 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_padding_left_from(&mut self, other: &Self) {
        self.mScrollPadding.3 = other.mScrollPadding.3.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_padding_left(&mut self, other: &Self) {
        self.copy_scroll_padding_left_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_left(&self) -> longhands::scroll_padding_left::computed_value::T {
        From::from(self.mScrollPadding.3.clone())
    }




    /*
     * Auto-Generated Methods.
     */
    
}




impl GeckoPage {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_size(&mut self, v: longhands::size::computed_value::T) {
        self.mSize = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_size_from(&mut self, other: &Self) {
        self.mSize = other.mSize.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_size(&mut self, other: &Self) {
        self.copy_size_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_size(&self) -> longhands::size::computed_value::T {
        From::from(self.mSize.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_page(&mut self, v: longhands::page::computed_value::T) {
        self.mPage = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_page_from(&mut self, other: &Self) {
        self.mPage = other.mPage.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_page(&mut self, other: &Self) {
        self.copy_page_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_page(&self) -> longhands::page::computed_value::T {
        From::from(self.mPage.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_page_orientation(&mut self, v: longhands::page_orientation::computed_value::T) {
        self.mPageOrientation = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_page_orientation_from(&mut self, other: &Self) {
        self.mPageOrientation = other.mPageOrientation.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_page_orientation(&mut self, other: &Self) {
        self.copy_page_orientation_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_page_orientation(&self) -> longhands::page_orientation::computed_value::T {
        From::from(self.mPageOrientation.clone())
    }


}





impl GeckoPosition {
    /*
     * Manually-Implemented Methods.
     */
    
    

    #[allow(non_snake_case)]
    pub fn set_top(&mut self, v: longhands::top::computed_value::T) {
        self.mOffset.0 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_top_from(&mut self, other: &Self) {
        self.mOffset.0 = other.mOffset.0.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_top(&mut self, other: &Self) {
        self.copy_top_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_top(&self) -> longhands::top::computed_value::T {
        From::from(self.mOffset.0.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_right(&mut self, v: longhands::right::computed_value::T) {
        self.mOffset.1 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_right_from(&mut self, other: &Self) {
        self.mOffset.1 = other.mOffset.1.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_right(&mut self, other: &Self) {
        self.copy_right_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_right(&self) -> longhands::right::computed_value::T {
        From::from(self.mOffset.1.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_bottom(&mut self, v: longhands::bottom::computed_value::T) {
        self.mOffset.2 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_bottom_from(&mut self, other: &Self) {
        self.mOffset.2 = other.mOffset.2.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_bottom(&mut self, other: &Self) {
        self.copy_bottom_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_bottom(&self) -> longhands::bottom::computed_value::T {
        From::from(self.mOffset.2.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_left(&mut self, v: longhands::left::computed_value::T) {
        self.mOffset.3 = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_left_from(&mut self, other: &Self) {
        self.mOffset.3 = other.mOffset.3.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_left(&mut self, other: &Self) {
        self.copy_left_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_left(&self) -> longhands::left::computed_value::T {
        From::from(self.mOffset.3.clone())
    }


    pub fn set_computed_justify_items(&mut self, v: values::specified::JustifyItems) {
        debug_assert_ne!(v.0, crate::values::specified::align::AlignFlags::LEGACY);
        self.mJustifyItems.computed = v;
    }


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_z_index(&mut self, v: longhands::z_index::computed_value::T) {
        self.mZIndex = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_z_index_from(&mut self, other: &Self) {
        self.mZIndex = other.mZIndex.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_z_index(&mut self, other: &Self) {
        self.copy_z_index_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_z_index(&self) -> longhands::z_index::computed_value::T {
        From::from(self.mZIndex.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_flex_direction(&mut self, v: longhands::flex_direction::computed_value::T) {
        use crate::properties::longhands::flex_direction::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Row =>
                    structs::StyleFlexDirection::Row ,
                Keyword::RowReverse =>
                    structs::StyleFlexDirection::RowReverse ,
                Keyword::Column =>
                    structs::StyleFlexDirection::Column ,
                Keyword::ColumnReverse =>
                    structs::StyleFlexDirection::ColumnReverse ,
        };
        self.mFlexDirection = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_flex_direction_from(&mut self, other: &Self) {
        self.mFlexDirection = other.mFlexDirection.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_flex_direction(&mut self, other: &Self) {
        self.copy_flex_direction_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_flex_direction(&self) -> longhands::flex_direction::computed_value::T {
        use crate::properties::longhands::flex_direction::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mFlexDirection {
            structs::StyleFlexDirection::Row => Keyword::Row,
            structs::StyleFlexDirection::RowReverse => Keyword::RowReverse,
            structs::StyleFlexDirection::Column => Keyword::Column,
            structs::StyleFlexDirection::ColumnReverse => Keyword::ColumnReverse,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_flex_wrap(&mut self, v: longhands::flex_wrap::computed_value::T) {
        use crate::properties::longhands::flex_wrap::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Nowrap =>
                    structs::StyleFlexWrap::Nowrap ,
                Keyword::Wrap =>
                    structs::StyleFlexWrap::Wrap ,
                Keyword::WrapReverse =>
                    structs::StyleFlexWrap::WrapReverse ,
        };
        self.mFlexWrap = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_flex_wrap_from(&mut self, other: &Self) {
        self.mFlexWrap = other.mFlexWrap.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_flex_wrap(&mut self, other: &Self) {
        self.copy_flex_wrap_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_flex_wrap(&self) -> longhands::flex_wrap::computed_value::T {
        use crate::properties::longhands::flex_wrap::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mFlexWrap {
            structs::StyleFlexWrap::Nowrap => Keyword::Nowrap,
            structs::StyleFlexWrap::Wrap => Keyword::Wrap,
            structs::StyleFlexWrap::WrapReverse => Keyword::WrapReverse,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_justify_content(&mut self, v: longhands::justify_content::computed_value::T) {
        self.mJustifyContent = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_justify_content_from(&mut self, other: &Self) {
        self.mJustifyContent = other.mJustifyContent.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_justify_content(&mut self, other: &Self) {
        self.copy_justify_content_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_justify_content(&self) -> longhands::justify_content::computed_value::T {
        From::from(self.mJustifyContent.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_align_content(&mut self, v: longhands::align_content::computed_value::T) {
        self.mAlignContent = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_align_content_from(&mut self, other: &Self) {
        self.mAlignContent = other.mAlignContent.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_align_content(&mut self, other: &Self) {
        self.copy_align_content_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_align_content(&self) -> longhands::align_content::computed_value::T {
        From::from(self.mAlignContent.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_align_items(&mut self, v: longhands::align_items::computed_value::T) {
        self.mAlignItems = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_align_items_from(&mut self, other: &Self) {
        self.mAlignItems = other.mAlignItems.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_align_items(&mut self, other: &Self) {
        self.copy_align_items_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_align_items(&self) -> longhands::align_items::computed_value::T {
        From::from(self.mAlignItems.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_justify_items(&mut self, v: longhands::justify_items::computed_value::T) {
        self.mJustifyItems = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_justify_items_from(&mut self, other: &Self) {
        self.mJustifyItems = other.mJustifyItems.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_justify_items(&mut self, other: &Self) {
        self.copy_justify_items_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_justify_items(&self) -> longhands::justify_items::computed_value::T {
        From::from(self.mJustifyItems.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_flex_grow(&mut self, v: longhands::flex_grow::computed_value::T) {
        self.mFlexGrow = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_flex_grow_from(&mut self, other: &Self) {
        self.mFlexGrow = other.mFlexGrow.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_flex_grow(&mut self, other: &Self) {
        self.copy_flex_grow_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_flex_grow(&self) -> longhands::flex_grow::computed_value::T {
        From::from(self.mFlexGrow.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_flex_shrink(&mut self, v: longhands::flex_shrink::computed_value::T) {
        self.mFlexShrink = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_flex_shrink_from(&mut self, other: &Self) {
        self.mFlexShrink = other.mFlexShrink.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_flex_shrink(&mut self, other: &Self) {
        self.copy_flex_shrink_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_flex_shrink(&self) -> longhands::flex_shrink::computed_value::T {
        From::from(self.mFlexShrink.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_align_self(&mut self, v: longhands::align_self::computed_value::T) {
        self.mAlignSelf = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_align_self_from(&mut self, other: &Self) {
        self.mAlignSelf = other.mAlignSelf.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_align_self(&mut self, other: &Self) {
        self.copy_align_self_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_align_self(&self) -> longhands::align_self::computed_value::T {
        From::from(self.mAlignSelf.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_justify_self(&mut self, v: longhands::justify_self::computed_value::T) {
        self.mJustifySelf = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_justify_self_from(&mut self, other: &Self) {
        self.mJustifySelf = other.mJustifySelf.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_justify_self(&mut self, other: &Self) {
        self.copy_justify_self_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_justify_self(&self) -> longhands::justify_self::computed_value::T {
        From::from(self.mJustifySelf.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_order(&mut self, v: longhands::order::computed_value::T) {
        self.mOrder = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_order_from(&mut self, other: &Self) {
        self.mOrder = other.mOrder.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_order(&mut self, other: &Self) {
        self.copy_order_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_order(&self) -> longhands::order::computed_value::T {
        From::from(self.mOrder.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_flex_basis(&mut self, v: longhands::flex_basis::computed_value::T) {
        self.mFlexBasis = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_flex_basis_from(&mut self, other: &Self) {
        self.mFlexBasis = other.mFlexBasis.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_flex_basis(&mut self, other: &Self) {
        self.copy_flex_basis_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_flex_basis(&self) -> longhands::flex_basis::computed_value::T {
        From::from(self.mFlexBasis.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_height(&mut self, v: longhands::height::computed_value::T) {
        self.mHeight = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_height_from(&mut self, other: &Self) {
        self.mHeight = other.mHeight.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_height(&mut self, other: &Self) {
        self.copy_height_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_height(&self) -> longhands::height::computed_value::T {
        From::from(self.mHeight.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_min_height(&mut self, v: longhands::min_height::computed_value::T) {
        self.mMinHeight = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_min_height_from(&mut self, other: &Self) {
        self.mMinHeight = other.mMinHeight.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_min_height(&mut self, other: &Self) {
        self.copy_min_height_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_min_height(&self) -> longhands::min_height::computed_value::T {
        From::from(self.mMinHeight.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_max_height(&mut self, v: longhands::max_height::computed_value::T) {
        self.mMaxHeight = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_max_height_from(&mut self, other: &Self) {
        self.mMaxHeight = other.mMaxHeight.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_max_height(&mut self, other: &Self) {
        self.copy_max_height_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_max_height(&self) -> longhands::max_height::computed_value::T {
        From::from(self.mMaxHeight.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_width(&mut self, v: longhands::width::computed_value::T) {
        self.mWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_width_from(&mut self, other: &Self) {
        self.mWidth = other.mWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_width(&mut self, other: &Self) {
        self.copy_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_width(&self) -> longhands::width::computed_value::T {
        From::from(self.mWidth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_min_width(&mut self, v: longhands::min_width::computed_value::T) {
        self.mMinWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_min_width_from(&mut self, other: &Self) {
        self.mMinWidth = other.mMinWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_min_width(&mut self, other: &Self) {
        self.copy_min_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_min_width(&self) -> longhands::min_width::computed_value::T {
        From::from(self.mMinWidth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_max_width(&mut self, v: longhands::max_width::computed_value::T) {
        self.mMaxWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_max_width_from(&mut self, other: &Self) {
        self.mMaxWidth = other.mMaxWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_max_width(&mut self, other: &Self) {
        self.copy_max_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_max_width(&self) -> longhands::max_width::computed_value::T {
        From::from(self.mMaxWidth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_position_anchor(&mut self, v: longhands::position_anchor::computed_value::T) {
        self.mPositionAnchor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_position_anchor_from(&mut self, other: &Self) {
        self.mPositionAnchor = other.mPositionAnchor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_position_anchor(&mut self, other: &Self) {
        self.copy_position_anchor_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_position_anchor(&self) -> longhands::position_anchor::computed_value::T {
        From::from(self.mPositionAnchor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_position_visibility(&mut self, v: longhands::position_visibility::computed_value::T) {
        self.mPositionVisibility = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_position_visibility_from(&mut self, other: &Self) {
        self.mPositionVisibility = other.mPositionVisibility.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_position_visibility(&mut self, other: &Self) {
        self.copy_position_visibility_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_position_visibility(&self) -> longhands::position_visibility::computed_value::T {
        From::from(self.mPositionVisibility.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_inset_area(&mut self, v: longhands::inset_area::computed_value::T) {
        self.mInsetArea = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_inset_area_from(&mut self, other: &Self) {
        self.mInsetArea = other.mInsetArea.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_inset_area(&mut self, other: &Self) {
        self.copy_inset_area_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_inset_area(&self) -> longhands::inset_area::computed_value::T {
        From::from(self.mInsetArea.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_position_try_options(&mut self, v: longhands::position_try_options::computed_value::T) {
        self.mPositionTryOptions = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_position_try_options_from(&mut self, other: &Self) {
        self.mPositionTryOptions = other.mPositionTryOptions.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_position_try_options(&mut self, other: &Self) {
        self.copy_position_try_options_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_position_try_options(&self) -> longhands::position_try_options::computed_value::T {
        From::from(self.mPositionTryOptions.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_position_try_order(&mut self, v: longhands::position_try_order::computed_value::T) {
        self.mPositionTryOrder = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_position_try_order_from(&mut self, other: &Self) {
        self.mPositionTryOrder = other.mPositionTryOrder.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_position_try_order(&mut self, other: &Self) {
        self.copy_position_try_order_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_position_try_order(&self) -> longhands::position_try_order::computed_value::T {
        From::from(self.mPositionTryOrder.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_box_sizing(&mut self, v: longhands::box_sizing::computed_value::T) {
        use crate::properties::longhands::box_sizing::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::ContentBox =>
                    structs::StyleBoxSizing::Content ,
                Keyword::BorderBox =>
                    structs::StyleBoxSizing::Border ,
        };
        self.mBoxSizing = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_box_sizing_from(&mut self, other: &Self) {
        self.mBoxSizing = other.mBoxSizing.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_box_sizing(&mut self, other: &Self) {
        self.copy_box_sizing_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_box_sizing(&self) -> longhands::box_sizing::computed_value::T {
        use crate::properties::longhands::box_sizing::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBoxSizing {
            structs::StyleBoxSizing::Content => Keyword::ContentBox,
            structs::StyleBoxSizing::Border => Keyword::BorderBox,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_object_fit(&mut self, v: longhands::object_fit::computed_value::T) {
        use crate::properties::longhands::object_fit::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Fill =>
                    structs::StyleObjectFit::Fill ,
                Keyword::Contain =>
                    structs::StyleObjectFit::Contain ,
                Keyword::Cover =>
                    structs::StyleObjectFit::Cover ,
                Keyword::None =>
                    structs::StyleObjectFit::None ,
                Keyword::ScaleDown =>
                    structs::StyleObjectFit::ScaleDown ,
        };
        self.mObjectFit = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_object_fit_from(&mut self, other: &Self) {
        self.mObjectFit = other.mObjectFit.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_object_fit(&mut self, other: &Self) {
        self.copy_object_fit_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_object_fit(&self) -> longhands::object_fit::computed_value::T {
        use crate::properties::longhands::object_fit::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mObjectFit {
            structs::StyleObjectFit::Fill => Keyword::Fill,
            structs::StyleObjectFit::Contain => Keyword::Contain,
            structs::StyleObjectFit::Cover => Keyword::Cover,
            structs::StyleObjectFit::None => Keyword::None,
            structs::StyleObjectFit::ScaleDown => Keyword::ScaleDown,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_object_position(&mut self, v: longhands::object_position::computed_value::T) {
        self.mObjectPosition = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_object_position_from(&mut self, other: &Self) {
        self.mObjectPosition = other.mObjectPosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_object_position(&mut self, other: &Self) {
        self.copy_object_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_object_position(&self) -> longhands::object_position::computed_value::T {
        From::from(self.mObjectPosition.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_row_start(&mut self, v: longhands::grid_row_start::computed_value::T) {
        self.mGridRowStart = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_row_start_from(&mut self, other: &Self) {
        self.mGridRowStart = other.mGridRowStart.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_row_start(&mut self, other: &Self) {
        self.copy_grid_row_start_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_row_start(&self) -> longhands::grid_row_start::computed_value::T {
        From::from(self.mGridRowStart.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_row_end(&mut self, v: longhands::grid_row_end::computed_value::T) {
        self.mGridRowEnd = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_row_end_from(&mut self, other: &Self) {
        self.mGridRowEnd = other.mGridRowEnd.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_row_end(&mut self, other: &Self) {
        self.copy_grid_row_end_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_row_end(&self) -> longhands::grid_row_end::computed_value::T {
        From::from(self.mGridRowEnd.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_auto_rows(&mut self, v: longhands::grid_auto_rows::computed_value::T) {
        self.mGridAutoRows = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_auto_rows_from(&mut self, other: &Self) {
        self.mGridAutoRows = other.mGridAutoRows.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_auto_rows(&mut self, other: &Self) {
        self.copy_grid_auto_rows_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_auto_rows(&self) -> longhands::grid_auto_rows::computed_value::T {
        From::from(self.mGridAutoRows.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_template_rows(&mut self, v: longhands::grid_template_rows::computed_value::T) {
        self.mGridTemplateRows = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_template_rows_from(&mut self, other: &Self) {
        self.mGridTemplateRows = other.mGridTemplateRows.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_template_rows(&mut self, other: &Self) {
        self.copy_grid_template_rows_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_template_rows(&self) -> longhands::grid_template_rows::computed_value::T {
        From::from(self.mGridTemplateRows.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_column_start(&mut self, v: longhands::grid_column_start::computed_value::T) {
        self.mGridColumnStart = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_column_start_from(&mut self, other: &Self) {
        self.mGridColumnStart = other.mGridColumnStart.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_column_start(&mut self, other: &Self) {
        self.copy_grid_column_start_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_column_start(&self) -> longhands::grid_column_start::computed_value::T {
        From::from(self.mGridColumnStart.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_column_end(&mut self, v: longhands::grid_column_end::computed_value::T) {
        self.mGridColumnEnd = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_column_end_from(&mut self, other: &Self) {
        self.mGridColumnEnd = other.mGridColumnEnd.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_column_end(&mut self, other: &Self) {
        self.copy_grid_column_end_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_column_end(&self) -> longhands::grid_column_end::computed_value::T {
        From::from(self.mGridColumnEnd.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_auto_columns(&mut self, v: longhands::grid_auto_columns::computed_value::T) {
        self.mGridAutoColumns = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_auto_columns_from(&mut self, other: &Self) {
        self.mGridAutoColumns = other.mGridAutoColumns.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_auto_columns(&mut self, other: &Self) {
        self.copy_grid_auto_columns_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_auto_columns(&self) -> longhands::grid_auto_columns::computed_value::T {
        From::from(self.mGridAutoColumns.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_template_columns(&mut self, v: longhands::grid_template_columns::computed_value::T) {
        self.mGridTemplateColumns = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_template_columns_from(&mut self, other: &Self) {
        self.mGridTemplateColumns = other.mGridTemplateColumns.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_template_columns(&mut self, other: &Self) {
        self.copy_grid_template_columns_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_template_columns(&self) -> longhands::grid_template_columns::computed_value::T {
        From::from(self.mGridTemplateColumns.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_masonry_auto_flow(&mut self, v: longhands::masonry_auto_flow::computed_value::T) {
        self.mMasonryAutoFlow = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_masonry_auto_flow_from(&mut self, other: &Self) {
        self.mMasonryAutoFlow = other.mMasonryAutoFlow.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_masonry_auto_flow(&mut self, other: &Self) {
        self.copy_masonry_auto_flow_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_masonry_auto_flow(&self) -> longhands::masonry_auto_flow::computed_value::T {
        From::from(self.mMasonryAutoFlow.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_auto_flow(&mut self, v: longhands::grid_auto_flow::computed_value::T) {
        self.mGridAutoFlow = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_auto_flow_from(&mut self, other: &Self) {
        self.mGridAutoFlow = other.mGridAutoFlow.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_auto_flow(&mut self, other: &Self) {
        self.copy_grid_auto_flow_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_auto_flow(&self) -> longhands::grid_auto_flow::computed_value::T {
        From::from(self.mGridAutoFlow.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_grid_template_areas(&mut self, v: longhands::grid_template_areas::computed_value::T) {
        self.mGridTemplateAreas = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_grid_template_areas_from(&mut self, other: &Self) {
        self.mGridTemplateAreas = other.mGridTemplateAreas.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_grid_template_areas(&mut self, other: &Self) {
        self.copy_grid_template_areas_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_grid_template_areas(&self) -> longhands::grid_template_areas::computed_value::T {
        From::from(self.mGridTemplateAreas.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_column_gap(&mut self, v: longhands::column_gap::computed_value::T) {
        self.mColumnGap = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_column_gap_from(&mut self, other: &Self) {
        self.mColumnGap = other.mColumnGap.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_column_gap(&mut self, other: &Self) {
        self.copy_column_gap_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_column_gap(&self) -> longhands::column_gap::computed_value::T {
        From::from(self.mColumnGap.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_row_gap(&mut self, v: longhands::row_gap::computed_value::T) {
        self.mRowGap = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_row_gap_from(&mut self, other: &Self) {
        self.mRowGap = other.mRowGap.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_row_gap(&mut self, other: &Self) {
        self.copy_row_gap_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_row_gap(&self) -> longhands::row_gap::computed_value::T {
        From::from(self.mRowGap.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_aspect_ratio(&mut self, v: longhands::aspect_ratio::computed_value::T) {
        self.mAspectRatio = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_aspect_ratio_from(&mut self, other: &Self) {
        self.mAspectRatio = other.mAspectRatio.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_aspect_ratio(&mut self, other: &Self) {
        self.copy_aspect_ratio_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_aspect_ratio(&self) -> longhands::aspect_ratio::computed_value::T {
        From::from(self.mAspectRatio.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_contain_intrinsic_height(&mut self, v: longhands::contain_intrinsic_height::computed_value::T) {
        self.mContainIntrinsicHeight = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_contain_intrinsic_height_from(&mut self, other: &Self) {
        self.mContainIntrinsicHeight = other.mContainIntrinsicHeight.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_contain_intrinsic_height(&mut self, other: &Self) {
        self.copy_contain_intrinsic_height_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_contain_intrinsic_height(&self) -> longhands::contain_intrinsic_height::computed_value::T {
        From::from(self.mContainIntrinsicHeight.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_contain_intrinsic_width(&mut self, v: longhands::contain_intrinsic_width::computed_value::T) {
        self.mContainIntrinsicWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_contain_intrinsic_width_from(&mut self, other: &Self) {
        self.mContainIntrinsicWidth = other.mContainIntrinsicWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_contain_intrinsic_width(&mut self, other: &Self) {
        self.copy_contain_intrinsic_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_contain_intrinsic_width(&self) -> longhands::contain_intrinsic_width::computed_value::T {
        From::from(self.mContainIntrinsicWidth.clone())
    }


}




impl GeckoOutline {
    /*
     * Manually-Implemented Methods.
     */
    

    pub fn set_outline_style(&mut self, v: longhands::outline_style::computed_value::T) {
        self.mOutlineStyle = v;
        // NB: This is needed to correctly handling the initial value of
        // outline-width when outline-style changes, see the
        // update_border_left comment for more details.
        self.mActualOutlineWidth = self.mOutlineWidth;
    }

    pub fn copy_outline_style_from(&mut self, other: &Self) {
        self.set_outline_style(other.mOutlineStyle);
    }

    pub fn reset_outline_style(&mut self, other: &Self) {
        self.copy_outline_style_from(other)
    }

    pub fn clone_outline_style(&self) -> longhands::outline_style::computed_value::T {
        self.mOutlineStyle.clone()
    }

    
    #[allow(non_snake_case)]
    pub fn set_outline_width(&mut self, v: Au) {
        let value = v.0;
        self.mOutlineWidth = value;
        self.mActualOutlineWidth = value;
    }

    #[allow(non_snake_case)]
    pub fn copy_outline_width_from(&mut self, other: &Self) {
        self.mOutlineWidth = other.mOutlineWidth;
        // NOTE: This is needed to easily handle the `unset` and `initial`
        // keywords, which are implemented calling this function.
        //
        // In practice, this means that we may have an incorrect value here, but
        // we'll adjust that properly in the style fixup phase.
        //
        // FIXME(emilio): We could clean this up a bit special-casing the reset_
        // function below.
        self.mActualOutlineWidth = other.mOutlineWidth;
    }

    #[allow(non_snake_case)]
    pub fn reset_outline_width(&mut self, other: &Self) {
        self.copy_outline_width_from(other)
    }

    #[allow(non_snake_case)]
    pub fn clone_outline_width(&self) -> Au {
        Au(self.mActualOutlineWidth)
    }


    pub fn outline_has_nonzero_width(&self) -> bool {
        self.mActualOutlineWidth != 0
    }


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_outline_color(&mut self, v: longhands::outline_color::computed_value::T) {
        self.mOutlineColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_outline_color_from(&mut self, other: &Self) {
        self.mOutlineColor = other.mOutlineColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_outline_color(&mut self, other: &Self) {
        self.copy_outline_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_outline_color(&self) -> longhands::outline_color::computed_value::T {
        From::from(self.mOutlineColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_outline_offset(&mut self, v: longhands::outline_offset::computed_value::T) {
        self.mOutlineOffset = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_outline_offset_from(&mut self, other: &Self) {
        self.mOutlineOffset = other.mOutlineOffset.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_outline_offset(&mut self, other: &Self) {
        self.copy_outline_offset_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_outline_offset(&self) -> longhands::outline_offset::computed_value::T {
        From::from(self.mOutlineOffset.clone())
    }


}





impl GeckoFont {
    /*
     * Manually-Implemented Methods.
     */
    

    // Negative numbers are invalid at parse time, but <integer> is still an
    // i32.
    
    

    pub fn set_font_feature_settings(&mut self, v: longhands::font_feature_settings::computed_value::T) {
        let iter = v.0.iter().map(|other| structs::gfxFontFeature {
            mTag: other.tag.0,
            mValue: other.value as u32,
        });
        self.mFont.fontFeatureSettings.clear();
        self.mFont.fontFeatureSettings.extend(iter);
    }

    
    #[allow(non_snake_case)]
    pub fn copy_font_feature_settings_from(&mut self, other: &Self) {
        self.mFont.fontFeatureSettings = other.mFont.fontFeatureSettings.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_feature_settings(&mut self, other: &Self) {
        self.copy_font_feature_settings_from(other)
    }


    pub fn clone_font_feature_settings(&self) -> longhands::font_feature_settings::computed_value::T {
        use crate::values::generics::font::{FontSettings, FontTag, FeatureTagValue};

        FontSettings(
            self.mFont.fontFeatureSettings.iter().map(|gecko_font_setting| {
                FeatureTagValue {
                    tag: FontTag(gecko_font_setting.mTag),
                    value: gecko_font_setting.mValue as i32,
                }
            }).collect::<Vec<_>>().into_boxed_slice()
        )
    }

    
    

    pub fn set_font_variation_settings(&mut self, v: longhands::font_variation_settings::computed_value::T) {
        let iter = v.0.iter().map(|other| structs::gfxFontVariation {
            mTag: other.tag.0,
            mValue: other.value as f32,
        });
        self.mFont.fontVariationSettings.clear();
        self.mFont.fontVariationSettings.extend(iter);
    }

    
    #[allow(non_snake_case)]
    pub fn copy_font_variation_settings_from(&mut self, other: &Self) {
        self.mFont.fontVariationSettings = other.mFont.fontVariationSettings.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variation_settings(&mut self, other: &Self) {
        self.copy_font_variation_settings_from(other)
    }


    pub fn clone_font_variation_settings(&self) -> longhands::font_variation_settings::computed_value::T {
        use crate::values::generics::font::{FontSettings, FontTag, VariationValue};

        FontSettings(
            self.mFont.fontVariationSettings.iter().map(|gecko_font_setting| {
                VariationValue {
                    tag: FontTag(gecko_font_setting.mTag),
                    value: gecko_font_setting.mValue as f32,
                }
            }).collect::<Vec<_>>().into_boxed_slice()
        )
    }


    pub fn unzoom_fonts(&mut self, device: &Device) {
        use crate::values::generics::NonNegative;
        self.mSize = NonNegative(device.unzoom_text(self.mSize.0));
        self.mScriptUnconstrainedSize = NonNegative(device.unzoom_text(self.mScriptUnconstrainedSize.0));
        self.mFont.size = NonNegative(device.unzoom_text(self.mFont.size.0));
    }

    pub fn copy_font_size_from(&mut self, other: &Self) {
        self.mScriptUnconstrainedSize = other.mScriptUnconstrainedSize;

        self.mSize = other.mScriptUnconstrainedSize;
        // NOTE: Intentionally not copying from mFont.size. The cascade process
        // recomputes the used size as needed.
        self.mFont.size = other.mSize;
        self.mFontSizeKeyword = other.mFontSizeKeyword;

        // TODO(emilio): Should we really copy over these two?
        self.mFontSizeFactor = other.mFontSizeFactor;
        self.mFontSizeOffset = other.mFontSizeOffset;
    }

    pub fn reset_font_size(&mut self, other: &Self) {
        self.copy_font_size_from(other)
    }

    pub fn set_font_size(&mut self, v: FontSize) {
        let computed_size = v.computed_size;
        self.mScriptUnconstrainedSize = computed_size;

        // These two may be changed from Cascade::fixup_font_stuff.
        self.mSize = computed_size;
        // NOTE: Intentionally not copying from used_size. The cascade process
        // recomputes the used size as needed.
        self.mFont.size = computed_size;

        self.mFontSizeKeyword = v.keyword_info.kw;
        self.mFontSizeFactor = v.keyword_info.factor;
        self.mFontSizeOffset = v.keyword_info.offset;
    }

    pub fn clone_font_size(&self) -> FontSize {
        use crate::values::specified::font::KeywordInfo;

        FontSize {
            computed_size: self.mSize,
            used_size: self.mFont.size,
            keyword_info: KeywordInfo {
                kw: self.mFontSizeKeyword,
                factor: self.mFontSizeFactor,
                offset: self.mFontSizeOffset,
            }
        }
    }

    

    #[allow(non_snake_case)]
    pub fn set_font_weight(&mut self, v: longhands::font_weight::computed_value::T) {
        self.mFont.weight = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_weight_from(&mut self, other: &Self) {
        self.mFont.weight = other.mFont.weight.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_weight(&mut self, other: &Self) {
        self.copy_font_weight_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_weight(&self) -> longhands::font_weight::computed_value::T {
        From::from(self.mFont.weight.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_font_stretch(&mut self, v: longhands::font_stretch::computed_value::T) {
        self.mFont.stretch = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_stretch_from(&mut self, other: &Self) {
        self.mFont.stretch = other.mFont.stretch.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_stretch(&mut self, other: &Self) {
        self.copy_font_stretch_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_stretch(&self) -> longhands::font_stretch::computed_value::T {
        From::from(self.mFont.stretch.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_font_style(&mut self, v: longhands::font_style::computed_value::T) {
        self.mFont.style = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_style_from(&mut self, other: &Self) {
        self.mFont.style = other.mFont.style.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_style(&mut self, other: &Self) {
        self.copy_font_style_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_style(&self) -> longhands::font_style::computed_value::T {
        From::from(self.mFont.style.clone())
    }



    

    #[allow(non_snake_case)]
    pub fn set_font_variant_alternates(&mut self, v: longhands::font_variant_alternates::computed_value::T) {
        self.mFont.variantAlternates = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_variant_alternates_from(&mut self, other: &Self) {
        self.mFont.variantAlternates = other.mFont.variantAlternates.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variant_alternates(&mut self, other: &Self) {
        self.copy_font_variant_alternates_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_variant_alternates(&self) -> longhands::font_variant_alternates::computed_value::T {
        From::from(self.mFont.variantAlternates.clone())
    }



    

    #[allow(non_snake_case)]
    pub fn set_font_size_adjust(&mut self, v: longhands::font_size_adjust::computed_value::T) {
        self.mFont.sizeAdjust = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_size_adjust_from(&mut self, other: &Self) {
        self.mFont.sizeAdjust = other.mFont.sizeAdjust.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_size_adjust(&mut self, other: &Self) {
        self.copy_font_size_adjust_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_size_adjust(&self) -> longhands::font_size_adjust::computed_value::T {
        From::from(self.mFont.sizeAdjust.clone())
    }



    

    #[allow(non_snake_case)]
    pub fn set_font_family(&mut self, v: longhands::font_family::computed_value::T) {
        self.mFont.family = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_family_from(&mut self, other: &Self) {
        self.mFont.family = other.mFont.family.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_family(&mut self, other: &Self) {
        self.copy_font_family_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_family(&self) -> longhands::font_family::computed_value::T {
        From::from(self.mFont.family.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__x_lang(&mut self, v: longhands::_x_lang::computed_value::T) {
        let ptr = v.0.as_ptr();
        forget(v);
        unsafe {
            Gecko_nsStyleFont_SetLang(&mut **self, ptr);
        }
    }

    #[allow(non_snake_case)]
    pub fn copy__x_lang_from(&mut self, other: &Self) {
        unsafe {
            Gecko_nsStyleFont_CopyLangFrom(&mut **self, &**other);
        }
    }

    #[allow(non_snake_case)]
    pub fn reset__x_lang(&mut self, other: &Self) {
        self.copy__x_lang_from(other)
    }

    #[allow(non_snake_case)]
    pub fn clone__x_lang(&self) -> longhands::_x_lang::computed_value::T {
        longhands::_x_lang::computed_value::T(unsafe {
            Atom::from_raw(self.mLanguage.mRawPtr)
        })
    }


    

    #[allow(non_snake_case)]
    pub fn set__moz_min_font_size_ratio(&mut self, v: longhands::_moz_min_font_size_ratio::computed_value::T) {
        self.mMinFontSizeRatio = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_min_font_size_ratio_from(&mut self, other: &Self) {
        self.mMinFontSizeRatio = other.mMinFontSizeRatio.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_min_font_size_ratio(&mut self, other: &Self) {
        self.copy__moz_min_font_size_ratio_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_min_font_size_ratio(&self) -> longhands::_moz_min_font_size_ratio::computed_value::T {
        From::from(self.mMinFontSizeRatio.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_font_language_override(&mut self, v: longhands::font_language_override::computed_value::T) {
        self.mFont.languageOverride = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_language_override_from(&mut self, other: &Self) {
        self.mFont.languageOverride = other.mFont.languageOverride.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_language_override(&mut self, other: &Self) {
        self.copy_font_language_override_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_language_override(&self) -> longhands::font_language_override::computed_value::T {
        From::from(self.mFont.languageOverride.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_font_variant_ligatures(&mut self, v: longhands::font_variant_ligatures::computed_value::T) {
        self.mFont.variantLigatures = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_variant_ligatures_from(&mut self, other: &Self) {
        self.mFont.variantLigatures = other.mFont.variantLigatures.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variant_ligatures(&mut self, other: &Self) {
        self.copy_font_variant_ligatures_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_variant_ligatures(&self) -> longhands::font_variant_ligatures::computed_value::T {
        From::from(self.mFont.variantLigatures.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_font_variant_east_asian(&mut self, v: longhands::font_variant_east_asian::computed_value::T) {
        self.mFont.variantEastAsian = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_variant_east_asian_from(&mut self, other: &Self) {
        self.mFont.variantEastAsian = other.mFont.variantEastAsian.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variant_east_asian(&mut self, other: &Self) {
        self.copy_font_variant_east_asian_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_variant_east_asian(&self) -> longhands::font_variant_east_asian::computed_value::T {
        From::from(self.mFont.variantEastAsian.clone())
    }


    

    #[allow(non_snake_case)]
    pub fn set_font_variant_numeric(&mut self, v: longhands::font_variant_numeric::computed_value::T) {
        self.mFont.variantNumeric = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_variant_numeric_from(&mut self, other: &Self) {
        self.mFont.variantNumeric = other.mFont.variantNumeric.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variant_numeric(&mut self, other: &Self) {
        self.copy_font_variant_numeric_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_variant_numeric(&self) -> longhands::font_variant_numeric::computed_value::T {
        From::from(self.mFont.variantNumeric.clone())
    }




    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_font_variant_caps(&mut self, v: longhands::font_variant_caps::computed_value::T) {
        use crate::properties::longhands::font_variant_caps::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::NS_FONT_VARIANT_CAPS_NORMAL as u8,
                Keyword::SmallCaps =>
                    structs::NS_FONT_VARIANT_CAPS_SMALLCAPS as u8,
                Keyword::AllSmallCaps =>
                    structs::NS_FONT_VARIANT_CAPS_ALLSMALL as u8,
                Keyword::PetiteCaps =>
                    structs::NS_FONT_VARIANT_CAPS_PETITECAPS as u8,
                Keyword::AllPetiteCaps =>
                    structs::NS_FONT_VARIANT_CAPS_ALLPETITE as u8,
                Keyword::Unicase =>
                    structs::NS_FONT_VARIANT_CAPS_UNICASE as u8,
                Keyword::TitlingCaps =>
                    structs::NS_FONT_VARIANT_CAPS_TITLING as u8,
        };
        self.mFont.variantCaps = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_font_variant_caps_from(&mut self, other: &Self) {
        self.mFont.variantCaps = other.mFont.variantCaps.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variant_caps(&mut self, other: &Self) {
        self.copy_font_variant_caps_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_variant_caps(&self) -> longhands::font_variant_caps::computed_value::T {
        use crate::properties::longhands::font_variant_caps::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        const U8_NS_FONT_VARIANT_CAPS_NORMAL : u8 =
            structs::NS_FONT_VARIANT_CAPS_NORMAL as u8;
        const U8_NS_FONT_VARIANT_CAPS_SMALLCAPS : u8 =
            structs::NS_FONT_VARIANT_CAPS_SMALLCAPS as u8;
        const U8_NS_FONT_VARIANT_CAPS_ALLSMALL : u8 =
            structs::NS_FONT_VARIANT_CAPS_ALLSMALL as u8;
        const U8_NS_FONT_VARIANT_CAPS_PETITECAPS : u8 =
            structs::NS_FONT_VARIANT_CAPS_PETITECAPS as u8;
        const U8_NS_FONT_VARIANT_CAPS_ALLPETITE : u8 =
            structs::NS_FONT_VARIANT_CAPS_ALLPETITE as u8;
        const U8_NS_FONT_VARIANT_CAPS_UNICASE : u8 =
            structs::NS_FONT_VARIANT_CAPS_UNICASE as u8;
        const U8_NS_FONT_VARIANT_CAPS_TITLING : u8 =
            structs::NS_FONT_VARIANT_CAPS_TITLING as u8;

        match self.mFont.variantCaps as u8 {
            U8_NS_FONT_VARIANT_CAPS_NORMAL => Keyword::Normal,
            U8_NS_FONT_VARIANT_CAPS_SMALLCAPS => Keyword::SmallCaps,
            U8_NS_FONT_VARIANT_CAPS_ALLSMALL => Keyword::AllSmallCaps,
            U8_NS_FONT_VARIANT_CAPS_PETITECAPS => Keyword::PetiteCaps,
            U8_NS_FONT_VARIANT_CAPS_ALLPETITE => Keyword::AllPetiteCaps,
            U8_NS_FONT_VARIANT_CAPS_UNICASE => Keyword::Unicase,
            U8_NS_FONT_VARIANT_CAPS_TITLING => Keyword::TitlingCaps,
            _ => panic!("Found unexpected value in style struct for font_variant_caps property"),
        }
    }



    #[allow(non_snake_case)]
    pub fn set_font_synthesis_weight(&mut self, v: longhands::font_synthesis_weight::computed_value::T) {
        self.mFont.synthesisWeight = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_synthesis_weight_from(&mut self, other: &Self) {
        self.mFont.synthesisWeight = other.mFont.synthesisWeight.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_weight(&mut self, other: &Self) {
        self.copy_font_synthesis_weight_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_weight(&self) -> longhands::font_synthesis_weight::computed_value::T {
        From::from(self.mFont.synthesisWeight.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_font_synthesis_style(&mut self, v: longhands::font_synthesis_style::computed_value::T) {
        self.mFont.synthesisStyle = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_synthesis_style_from(&mut self, other: &Self) {
        self.mFont.synthesisStyle = other.mFont.synthesisStyle.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_style(&mut self, other: &Self) {
        self.copy_font_synthesis_style_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_style(&self) -> longhands::font_synthesis_style::computed_value::T {
        From::from(self.mFont.synthesisStyle.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_font_synthesis_small_caps(&mut self, v: longhands::font_synthesis_small_caps::computed_value::T) {
        self.mFont.synthesisSmallCaps = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_synthesis_small_caps_from(&mut self, other: &Self) {
        self.mFont.synthesisSmallCaps = other.mFont.synthesisSmallCaps.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_small_caps(&mut self, other: &Self) {
        self.copy_font_synthesis_small_caps_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_small_caps(&self) -> longhands::font_synthesis_small_caps::computed_value::T {
        From::from(self.mFont.synthesisSmallCaps.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_font_synthesis_position(&mut self, v: longhands::font_synthesis_position::computed_value::T) {
        self.mFont.synthesisPosition = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_synthesis_position_from(&mut self, other: &Self) {
        self.mFont.synthesisPosition = other.mFont.synthesisPosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_position(&mut self, other: &Self) {
        self.copy_font_synthesis_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_position(&self) -> longhands::font_synthesis_position::computed_value::T {
        From::from(self.mFont.synthesisPosition.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_font_kerning(&mut self, v: longhands::font_kerning::computed_value::T) {
        use crate::properties::longhands::font_kerning::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::NS_FONT_KERNING_AUTO as u8,
                Keyword::None =>
                    structs::NS_FONT_KERNING_NONE as u8,
                Keyword::Normal =>
                    structs::NS_FONT_KERNING_NORMAL as u8,
        };
        self.mFont.kerning = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_font_kerning_from(&mut self, other: &Self) {
        self.mFont.kerning = other.mFont.kerning.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_kerning(&mut self, other: &Self) {
        self.copy_font_kerning_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_kerning(&self) -> longhands::font_kerning::computed_value::T {
        use crate::properties::longhands::font_kerning::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        const U8_NS_FONT_KERNING_AUTO : u8 =
            structs::NS_FONT_KERNING_AUTO as u8;
        const U8_NS_FONT_KERNING_NONE : u8 =
            structs::NS_FONT_KERNING_NONE as u8;
        const U8_NS_FONT_KERNING_NORMAL : u8 =
            structs::NS_FONT_KERNING_NORMAL as u8;

        match self.mFont.kerning as u8 {
            U8_NS_FONT_KERNING_AUTO => Keyword::Auto,
            U8_NS_FONT_KERNING_NONE => Keyword::None,
            U8_NS_FONT_KERNING_NORMAL => Keyword::Normal,
            _ => panic!("Found unexpected value in style struct for font_kerning property"),
        }
    }



    #[allow(non_snake_case)]
    pub fn set_font_variant_emoji(&mut self, v: longhands::font_variant_emoji::computed_value::T) {
        use crate::properties::longhands::font_variant_emoji::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::StyleFontVariantEmoji::Normal ,
                Keyword::Text =>
                    structs::StyleFontVariantEmoji::Text ,
                Keyword::Emoji =>
                    structs::StyleFontVariantEmoji::Emoji ,
                Keyword::Unicode =>
                    structs::StyleFontVariantEmoji::Unicode ,
        };
        self.mFont.variantEmoji = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_font_variant_emoji_from(&mut self, other: &Self) {
        self.mFont.variantEmoji = other.mFont.variantEmoji.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variant_emoji(&mut self, other: &Self) {
        self.copy_font_variant_emoji_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_variant_emoji(&self) -> longhands::font_variant_emoji::computed_value::T {
        use crate::properties::longhands::font_variant_emoji::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mFont.variantEmoji {
            structs::StyleFontVariantEmoji::Normal => Keyword::Normal,
            structs::StyleFontVariantEmoji::Text => Keyword::Text,
            structs::StyleFontVariantEmoji::Emoji => Keyword::Emoji,
            structs::StyleFontVariantEmoji::Unicode => Keyword::Unicode,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_font_variant_position(&mut self, v: longhands::font_variant_position::computed_value::T) {
        use crate::properties::longhands::font_variant_position::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::NS_FONT_VARIANT_POSITION_NORMAL as u8,
                Keyword::Sub =>
                    structs::NS_FONT_VARIANT_POSITION_SUB as u8,
                Keyword::Super =>
                    structs::NS_FONT_VARIANT_POSITION_SUPER as u8,
        };
        self.mFont.variantPosition = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_font_variant_position_from(&mut self, other: &Self) {
        self.mFont.variantPosition = other.mFont.variantPosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_variant_position(&mut self, other: &Self) {
        self.copy_font_variant_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_variant_position(&self) -> longhands::font_variant_position::computed_value::T {
        use crate::properties::longhands::font_variant_position::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        const U8_NS_FONT_VARIANT_POSITION_NORMAL : u8 =
            structs::NS_FONT_VARIANT_POSITION_NORMAL as u8;
        const U8_NS_FONT_VARIANT_POSITION_SUB : u8 =
            structs::NS_FONT_VARIANT_POSITION_SUB as u8;
        const U8_NS_FONT_VARIANT_POSITION_SUPER : u8 =
            structs::NS_FONT_VARIANT_POSITION_SUPER as u8;

        match self.mFont.variantPosition as u8 {
            U8_NS_FONT_VARIANT_POSITION_NORMAL => Keyword::Normal,
            U8_NS_FONT_VARIANT_POSITION_SUB => Keyword::Sub,
            U8_NS_FONT_VARIANT_POSITION_SUPER => Keyword::Super,
            _ => panic!("Found unexpected value in style struct for font_variant_position property"),
        }
    }



    #[allow(non_snake_case)]
    pub fn set_font_optical_sizing(&mut self, v: longhands::font_optical_sizing::computed_value::T) {
        use crate::properties::longhands::font_optical_sizing::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::NS_FONT_OPTICAL_SIZING_AUTO as u8,
                Keyword::None =>
                    structs::NS_FONT_OPTICAL_SIZING_NONE as u8,
        };
        self.mFont.opticalSizing = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_font_optical_sizing_from(&mut self, other: &Self) {
        self.mFont.opticalSizing = other.mFont.opticalSizing.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_optical_sizing(&mut self, other: &Self) {
        self.copy_font_optical_sizing_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_optical_sizing(&self) -> longhands::font_optical_sizing::computed_value::T {
        use crate::properties::longhands::font_optical_sizing::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        const U8_NS_FONT_OPTICAL_SIZING_AUTO : u8 =
            structs::NS_FONT_OPTICAL_SIZING_AUTO as u8;
        const U8_NS_FONT_OPTICAL_SIZING_NONE : u8 =
            structs::NS_FONT_OPTICAL_SIZING_NONE as u8;

        match self.mFont.opticalSizing as u8 {
            U8_NS_FONT_OPTICAL_SIZING_AUTO => Keyword::Auto,
            U8_NS_FONT_OPTICAL_SIZING_NONE => Keyword::None,
            _ => panic!("Found unexpected value in style struct for font_optical_sizing property"),
        }
    }



    #[allow(non_snake_case)]
    pub fn set_font_palette(&mut self, v: longhands::font_palette::computed_value::T) {
        self.mFontPalette = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_font_palette_from(&mut self, other: &Self) {
        self.mFontPalette = other.mFontPalette.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_font_palette(&mut self, other: &Self) {
        self.copy_font_palette_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_font_palette(&self) -> longhands::font_palette::computed_value::T {
        From::from(self.mFontPalette.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_math_depth(&mut self, v: longhands::math_depth::computed_value::T) {
        self.mMathDepth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_math_depth_from(&mut self, other: &Self) {
        self.mMathDepth = other.mMathDepth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_math_depth(&mut self, other: &Self) {
        self.copy_math_depth_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_math_depth(&self) -> longhands::math_depth::computed_value::T {
        From::from(self.mMathDepth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_math_style(&mut self, v: longhands::math_style::computed_value::T) {
        use crate::properties::longhands::math_style::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::StyleMathStyle::Normal ,
                Keyword::Compact =>
                    structs::StyleMathStyle::Compact ,
        };
        self.mMathStyle = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_math_style_from(&mut self, other: &Self) {
        self.mMathStyle = other.mMathStyle.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_math_style(&mut self, other: &Self) {
        self.copy_math_style_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_math_style(&self) -> longhands::math_style::computed_value::T {
        use crate::properties::longhands::math_style::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mMathStyle {
            structs::StyleMathStyle::Normal => Keyword::Normal,
            structs::StyleMathStyle::Compact => Keyword::Compact,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_math_variant(&mut self, v: longhands::_moz_math_variant::computed_value::T) {
        use crate::properties::longhands::_moz_math_variant::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::None =>
                    structs::StyleMathVariant::None ,
                Keyword::Normal =>
                    structs::StyleMathVariant::Normal ,
                Keyword::Bold =>
                    structs::StyleMathVariant::Bold ,
                Keyword::Italic =>
                    structs::StyleMathVariant::Italic ,
                Keyword::BoldItalic =>
                    structs::StyleMathVariant::BoldItalic ,
                Keyword::Script =>
                    structs::StyleMathVariant::Script ,
                Keyword::BoldScript =>
                    structs::StyleMathVariant::BoldScript ,
                Keyword::Fraktur =>
                    structs::StyleMathVariant::Fraktur ,
                Keyword::DoubleStruck =>
                    structs::StyleMathVariant::DoubleStruck ,
                Keyword::BoldFraktur =>
                    structs::StyleMathVariant::BoldFraktur ,
                Keyword::SansSerif =>
                    structs::StyleMathVariant::SansSerif ,
                Keyword::BoldSansSerif =>
                    structs::StyleMathVariant::BoldSansSerif ,
                Keyword::SansSerifItalic =>
                    structs::StyleMathVariant::SansSerifItalic ,
                Keyword::SansSerifBoldItalic =>
                    structs::StyleMathVariant::SansSerifBoldItalic ,
                Keyword::Monospace =>
                    structs::StyleMathVariant::Monospace ,
                Keyword::Initial =>
                    structs::StyleMathVariant::Initial ,
                Keyword::Tailed =>
                    structs::StyleMathVariant::Tailed ,
                Keyword::Looped =>
                    structs::StyleMathVariant::Looped ,
                Keyword::Stretched =>
                    structs::StyleMathVariant::Stretched ,
        };
        self.mMathVariant = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_math_variant_from(&mut self, other: &Self) {
        self.mMathVariant = other.mMathVariant.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_math_variant(&mut self, other: &Self) {
        self.copy__moz_math_variant_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_math_variant(&self) -> longhands::_moz_math_variant::computed_value::T {
        use crate::properties::longhands::_moz_math_variant::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mMathVariant {
            structs::StyleMathVariant::None => Keyword::None,
            structs::StyleMathVariant::Normal => Keyword::Normal,
            structs::StyleMathVariant::Bold => Keyword::Bold,
            structs::StyleMathVariant::Italic => Keyword::Italic,
            structs::StyleMathVariant::BoldItalic => Keyword::BoldItalic,
            structs::StyleMathVariant::Script => Keyword::Script,
            structs::StyleMathVariant::BoldScript => Keyword::BoldScript,
            structs::StyleMathVariant::Fraktur => Keyword::Fraktur,
            structs::StyleMathVariant::DoubleStruck => Keyword::DoubleStruck,
            structs::StyleMathVariant::BoldFraktur => Keyword::BoldFraktur,
            structs::StyleMathVariant::SansSerif => Keyword::SansSerif,
            structs::StyleMathVariant::BoldSansSerif => Keyword::BoldSansSerif,
            structs::StyleMathVariant::SansSerifItalic => Keyword::SansSerifItalic,
            structs::StyleMathVariant::SansSerifBoldItalic => Keyword::SansSerifBoldItalic,
            structs::StyleMathVariant::Monospace => Keyword::Monospace,
            structs::StyleMathVariant::Initial => Keyword::Initial,
            structs::StyleMathVariant::Tailed => Keyword::Tailed,
            structs::StyleMathVariant::Looped => Keyword::Looped,
            structs::StyleMathVariant::Stretched => Keyword::Stretched,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__x_text_scale(&mut self, v: longhands::_x_text_scale::computed_value::T) {
        self.mXTextScale = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__x_text_scale_from(&mut self, other: &Self) {
        self.mXTextScale = other.mXTextScale.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__x_text_scale(&mut self, other: &Self) {
        self.copy__x_text_scale_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__x_text_scale(&self) -> longhands::_x_text_scale::computed_value::T {
        From::from(self.mXTextScale.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_line_height(&mut self, v: longhands::line_height::computed_value::T) {
        self.mLineHeight = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_line_height_from(&mut self, other: &Self) {
        self.mLineHeight = other.mLineHeight.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_line_height(&mut self, other: &Self) {
        self.copy_line_height_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_line_height(&self) -> longhands::line_height::computed_value::T {
        From::from(self.mLineHeight.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_osx_font_smoothing(&mut self, v: longhands::_moz_osx_font_smoothing::computed_value::T) {
        use crate::properties::longhands::_moz_osx_font_smoothing::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::NS_FONT_SMOOTHING_AUTO as u8,
                Keyword::Grayscale =>
                    structs::NS_FONT_SMOOTHING_GRAYSCALE as u8,
                Keyword::SubpixelAntialiased =>
                    structs::NS_FONT_SMOOTHING_SUBPIXEL_ANTIALIASED as u8,
        };
        self.mFont.smoothing = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_osx_font_smoothing_from(&mut self, other: &Self) {
        self.mFont.smoothing = other.mFont.smoothing.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_osx_font_smoothing(&mut self, other: &Self) {
        self.copy__moz_osx_font_smoothing_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_osx_font_smoothing(&self) -> longhands::_moz_osx_font_smoothing::computed_value::T {
        use crate::properties::longhands::_moz_osx_font_smoothing::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        const U8_NS_FONT_SMOOTHING_AUTO : u8 =
            structs::NS_FONT_SMOOTHING_AUTO as u8;
        const U8_NS_FONT_SMOOTHING_GRAYSCALE : u8 =
            structs::NS_FONT_SMOOTHING_GRAYSCALE as u8;
        const U8_NS_FONT_SMOOTHING_SUBPIXEL_ANTIALIASED : u8 =
            structs::NS_FONT_SMOOTHING_SUBPIXEL_ANTIALIASED as u8;

        match self.mFont.smoothing as u8 {
            U8_NS_FONT_SMOOTHING_AUTO => Keyword::Auto,
            U8_NS_FONT_SMOOTHING_GRAYSCALE => Keyword::Grayscale,
            U8_NS_FONT_SMOOTHING_SUBPIXEL_ANTIALIASED => Keyword::SubpixelAntialiased,
            _ => panic!("Found unexpected value in style struct for _moz_osx_font_smoothing property"),
        }
    }


}











impl GeckoBox {
    /*
     * Manually-Implemented Methods.
     */
    
    #[inline]
    pub fn set_display(&mut self, v: longhands::display::computed_value::T) {
        self.mDisplay = v;
        self.mOriginalDisplay = v;
    }

    #[inline]
    pub fn copy_display_from(&mut self, other: &Self) {
        self.set_display(other.mDisplay);
    }

    #[inline]
    pub fn reset_display(&mut self, other: &Self) {
        self.copy_display_from(other)
    }

    #[inline]
    pub fn set_adjusted_display(
        &mut self,
        v: longhands::display::computed_value::T,
        _is_item_or_root: bool
    ) {
        self.mDisplay = v;
    }

    #[inline]
    pub fn clone_display(&self) -> longhands::display::computed_value::T {
        self.mDisplay
    }

    #[inline]
    pub fn set_contain(&mut self, v: longhands::contain::computed_value::T) {
        self.mContain = v;
        self.mEffectiveContainment = v;
    }

    #[inline]
    pub fn copy_contain_from(&mut self, other: &Self) {
        self.set_contain(other.mContain);
    }

    #[inline]
    pub fn reset_contain(&mut self, other: &Self) {
        self.copy_contain_from(other)
    }

    #[inline]
    pub fn clone_contain(&self) -> longhands::contain::computed_value::T {
        self.mContain
    }

    #[inline]
    pub fn set_effective_containment(
        &mut self,
        v: longhands::contain::computed_value::T
    ) {
        self.mEffectiveContainment = v;
    }

    #[inline]
    pub fn clone_effective_containment(&self) -> longhands::contain::computed_value::T {
        self.mEffectiveContainment
    }


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set__moz_top_layer(&mut self, v: longhands::_moz_top_layer::computed_value::T) {
        use crate::properties::longhands::_moz_top_layer::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::None =>
                    structs::StyleTopLayer::None ,
                Keyword::Top =>
                    structs::StyleTopLayer::Top ,
        };
        self.mTopLayer = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_top_layer_from(&mut self, other: &Self) {
        self.mTopLayer = other.mTopLayer.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_top_layer(&mut self, other: &Self) {
        self.copy__moz_top_layer_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_top_layer(&self) -> longhands::_moz_top_layer::computed_value::T {
        use crate::properties::longhands::_moz_top_layer::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTopLayer {
            structs::StyleTopLayer::None => Keyword::None,
            structs::StyleTopLayer::Top => Keyword::Top,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_position(&mut self, v: longhands::position::computed_value::T) {
        use crate::properties::longhands::position::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Static =>
                    structs::StylePositionProperty::Static ,
                Keyword::Absolute =>
                    structs::StylePositionProperty::Absolute ,
                Keyword::Relative =>
                    structs::StylePositionProperty::Relative ,
                Keyword::Fixed =>
                    structs::StylePositionProperty::Fixed ,
                Keyword::Sticky =>
                    structs::StylePositionProperty::Sticky ,
        };
        self.mPosition = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_position_from(&mut self, other: &Self) {
        self.mPosition = other.mPosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_position(&mut self, other: &Self) {
        self.copy_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_position(&self) -> longhands::position::computed_value::T {
        use crate::properties::longhands::position::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mPosition {
            structs::StylePositionProperty::Static => Keyword::Static,
            structs::StylePositionProperty::Absolute => Keyword::Absolute,
            structs::StylePositionProperty::Relative => Keyword::Relative,
            structs::StylePositionProperty::Fixed => Keyword::Fixed,
            structs::StylePositionProperty::Sticky => Keyword::Sticky,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_anchor_name(&mut self, v: longhands::anchor_name::computed_value::T) {
        self.mAnchorName = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_anchor_name_from(&mut self, other: &Self) {
        self.mAnchorName = other.mAnchorName.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_anchor_name(&mut self, other: &Self) {
        self.copy_anchor_name_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_anchor_name(&self) -> longhands::anchor_name::computed_value::T {
        From::from(self.mAnchorName.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_anchor_scope(&mut self, v: longhands::anchor_scope::computed_value::T) {
        self.mAnchorScope = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_anchor_scope_from(&mut self, other: &Self) {
        self.mAnchorScope = other.mAnchorScope.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_anchor_scope(&mut self, other: &Self) {
        self.copy_anchor_scope_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_anchor_scope(&self) -> longhands::anchor_scope::computed_value::T {
        From::from(self.mAnchorScope.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_float(&mut self, v: longhands::float::computed_value::T) {
        self.mFloat = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_float_from(&mut self, other: &Self) {
        self.mFloat = other.mFloat.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_float(&mut self, other: &Self) {
        self.copy_float_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_float(&self) -> longhands::float::computed_value::T {
        From::from(self.mFloat.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_clear(&mut self, v: longhands::clear::computed_value::T) {
        self.mClear = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_clear_from(&mut self, other: &Self) {
        self.mClear = other.mClear.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_clear(&mut self, other: &Self) {
        self.copy_clear_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_clear(&self) -> longhands::clear::computed_value::T {
        From::from(self.mClear.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_vertical_align(&mut self, v: longhands::vertical_align::computed_value::T) {
        self.mVerticalAlign = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_vertical_align_from(&mut self, other: &Self) {
        self.mVerticalAlign = other.mVerticalAlign.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_vertical_align(&mut self, other: &Self) {
        self.copy_vertical_align_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_vertical_align(&self) -> longhands::vertical_align::computed_value::T {
        From::from(self.mVerticalAlign.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_baseline_source(&mut self, v: longhands::baseline_source::computed_value::T) {
        self.mBaselineSource = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_baseline_source_from(&mut self, other: &Self) {
        self.mBaselineSource = other.mBaselineSource.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_baseline_source(&mut self, other: &Self) {
        self.copy_baseline_source_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_baseline_source(&self) -> longhands::baseline_source::computed_value::T {
        From::from(self.mBaselineSource.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_inline(&mut self, v: longhands::overflow_clip_box_inline::computed_value::T) {
        self.mOverflowClipBoxInline = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overflow_clip_box_inline_from(&mut self, other: &Self) {
        self.mOverflowClipBoxInline = other.mOverflowClipBoxInline.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overflow_clip_box_inline(&mut self, other: &Self) {
        self.copy_overflow_clip_box_inline_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overflow_clip_box_inline(&self) -> longhands::overflow_clip_box_inline::computed_value::T {
        From::from(self.mOverflowClipBoxInline.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_block(&mut self, v: longhands::overflow_clip_box_block::computed_value::T) {
        self.mOverflowClipBoxBlock = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overflow_clip_box_block_from(&mut self, other: &Self) {
        self.mOverflowClipBoxBlock = other.mOverflowClipBoxBlock.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overflow_clip_box_block(&mut self, other: &Self) {
        self.copy_overflow_clip_box_block_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overflow_clip_box_block(&self) -> longhands::overflow_clip_box_block::computed_value::T {
        From::from(self.mOverflowClipBoxBlock.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overflow_y(&mut self, v: longhands::overflow_y::computed_value::T) {
        self.mOverflowY = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overflow_y_from(&mut self, other: &Self) {
        self.mOverflowY = other.mOverflowY.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overflow_y(&mut self, other: &Self) {
        self.copy_overflow_y_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overflow_y(&self) -> longhands::overflow_y::computed_value::T {
        From::from(self.mOverflowY.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overflow_x(&mut self, v: longhands::overflow_x::computed_value::T) {
        self.mOverflowX = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overflow_x_from(&mut self, other: &Self) {
        self.mOverflowX = other.mOverflowX.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overflow_x(&mut self, other: &Self) {
        self.copy_overflow_x_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overflow_x(&self) -> longhands::overflow_x::computed_value::T {
        From::from(self.mOverflowX.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overflow_anchor(&mut self, v: longhands::overflow_anchor::computed_value::T) {
        self.mOverflowAnchor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overflow_anchor_from(&mut self, other: &Self) {
        self.mOverflowAnchor = other.mOverflowAnchor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overflow_anchor(&mut self, other: &Self) {
        self.copy_overflow_anchor_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overflow_anchor(&self) -> longhands::overflow_anchor::computed_value::T {
        From::from(self.mOverflowAnchor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_transform(&mut self, v: longhands::transform::computed_value::T) {
        self.mTransform = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_transform_from(&mut self, other: &Self) {
        self.mTransform = other.mTransform.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_transform(&mut self, other: &Self) {
        self.copy_transform_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_transform(&self) -> longhands::transform::computed_value::T {
        From::from(self.mTransform.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_rotate(&mut self, v: longhands::rotate::computed_value::T) {
        self.mRotate = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_rotate_from(&mut self, other: &Self) {
        self.mRotate = other.mRotate.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_rotate(&mut self, other: &Self) {
        self.copy_rotate_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_rotate(&self) -> longhands::rotate::computed_value::T {
        From::from(self.mRotate.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_scale(&mut self, v: longhands::scale::computed_value::T) {
        self.mScale = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scale_from(&mut self, other: &Self) {
        self.mScale = other.mScale.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scale(&mut self, other: &Self) {
        self.copy_scale_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scale(&self) -> longhands::scale::computed_value::T {
        From::from(self.mScale.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_translate(&mut self, v: longhands::translate::computed_value::T) {
        self.mTranslate = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_translate_from(&mut self, other: &Self) {
        self.mTranslate = other.mTranslate.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_translate(&mut self, other: &Self) {
        self.copy_translate_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_translate(&self) -> longhands::translate::computed_value::T {
        From::from(self.mTranslate.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_offset_path(&mut self, v: longhands::offset_path::computed_value::T) {
        self.mOffsetPath = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_offset_path_from(&mut self, other: &Self) {
        self.mOffsetPath = other.mOffsetPath.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_offset_path(&mut self, other: &Self) {
        self.copy_offset_path_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_offset_path(&self) -> longhands::offset_path::computed_value::T {
        From::from(self.mOffsetPath.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_offset_distance(&mut self, v: longhands::offset_distance::computed_value::T) {
        self.mOffsetDistance = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_offset_distance_from(&mut self, other: &Self) {
        self.mOffsetDistance = other.mOffsetDistance.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_offset_distance(&mut self, other: &Self) {
        self.copy_offset_distance_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_offset_distance(&self) -> longhands::offset_distance::computed_value::T {
        From::from(self.mOffsetDistance.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_offset_rotate(&mut self, v: longhands::offset_rotate::computed_value::T) {
        self.mOffsetRotate = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_offset_rotate_from(&mut self, other: &Self) {
        self.mOffsetRotate = other.mOffsetRotate.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_offset_rotate(&mut self, other: &Self) {
        self.copy_offset_rotate_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_offset_rotate(&self) -> longhands::offset_rotate::computed_value::T {
        From::from(self.mOffsetRotate.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_offset_anchor(&mut self, v: longhands::offset_anchor::computed_value::T) {
        self.mOffsetAnchor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_offset_anchor_from(&mut self, other: &Self) {
        self.mOffsetAnchor = other.mOffsetAnchor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_offset_anchor(&mut self, other: &Self) {
        self.copy_offset_anchor_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_offset_anchor(&self) -> longhands::offset_anchor::computed_value::T {
        From::from(self.mOffsetAnchor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_offset_position(&mut self, v: longhands::offset_position::computed_value::T) {
        self.mOffsetPosition = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_offset_position_from(&mut self, other: &Self) {
        self.mOffsetPosition = other.mOffsetPosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_offset_position(&mut self, other: &Self) {
        self.copy_offset_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_offset_position(&self) -> longhands::offset_position::computed_value::T {
        From::from(self.mOffsetPosition.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_scroll_behavior(&mut self, v: longhands::scroll_behavior::computed_value::T) {
        use crate::properties::longhands::scroll_behavior::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleScrollBehavior::Auto ,
                Keyword::Smooth =>
                    structs::StyleScrollBehavior::Smooth ,
        };
        self.mScrollBehavior = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_behavior_from(&mut self, other: &Self) {
        self.mScrollBehavior = other.mScrollBehavior.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_behavior(&mut self, other: &Self) {
        self.copy_scroll_behavior_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_behavior(&self) -> longhands::scroll_behavior::computed_value::T {
        use crate::properties::longhands::scroll_behavior::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mScrollBehavior {
            structs::StyleScrollBehavior::Auto => Keyword::Auto,
            structs::StyleScrollBehavior::Smooth => Keyword::Smooth,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_scroll_snap_align(&mut self, v: longhands::scroll_snap_align::computed_value::T) {
        self.mScrollSnapAlign = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_snap_align_from(&mut self, other: &Self) {
        self.mScrollSnapAlign = other.mScrollSnapAlign.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_align(&mut self, other: &Self) {
        self.copy_scroll_snap_align_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_snap_align(&self) -> longhands::scroll_snap_align::computed_value::T {
        From::from(self.mScrollSnapAlign.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_scroll_snap_type(&mut self, v: longhands::scroll_snap_type::computed_value::T) {
        self.mScrollSnapType = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_snap_type_from(&mut self, other: &Self) {
        self.mScrollSnapType = other.mScrollSnapType.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_type(&mut self, other: &Self) {
        self.copy_scroll_snap_type_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_snap_type(&self) -> longhands::scroll_snap_type::computed_value::T {
        From::from(self.mScrollSnapType.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_scroll_snap_stop(&mut self, v: longhands::scroll_snap_stop::computed_value::T) {
        self.mScrollSnapStop = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scroll_snap_stop_from(&mut self, other: &Self) {
        self.mScrollSnapStop = other.mScrollSnapStop.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scroll_snap_stop(&mut self, other: &Self) {
        self.copy_scroll_snap_stop_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scroll_snap_stop(&self) -> longhands::scroll_snap_stop::computed_value::T {
        From::from(self.mScrollSnapStop.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_y(&mut self, v: longhands::overscroll_behavior_y::computed_value::T) {
        self.mOverscrollBehaviorY = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overscroll_behavior_y_from(&mut self, other: &Self) {
        self.mOverscrollBehaviorY = other.mOverscrollBehaviorY.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overscroll_behavior_y(&mut self, other: &Self) {
        self.copy_overscroll_behavior_y_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overscroll_behavior_y(&self) -> longhands::overscroll_behavior_y::computed_value::T {
        From::from(self.mOverscrollBehaviorY.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_x(&mut self, v: longhands::overscroll_behavior_x::computed_value::T) {
        self.mOverscrollBehaviorX = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overscroll_behavior_x_from(&mut self, other: &Self) {
        self.mOverscrollBehaviorX = other.mOverscrollBehaviorX.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overscroll_behavior_x(&mut self, other: &Self) {
        self.copy_overscroll_behavior_x_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overscroll_behavior_x(&self) -> longhands::overscroll_behavior_x::computed_value::T {
        From::from(self.mOverscrollBehaviorX.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_isolation(&mut self, v: longhands::isolation::computed_value::T) {
        use crate::properties::longhands::isolation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleIsolation::Auto ,
                Keyword::Isolate =>
                    structs::StyleIsolation::Isolate ,
        };
        self.mIsolation = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_isolation_from(&mut self, other: &Self) {
        self.mIsolation = other.mIsolation.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_isolation(&mut self, other: &Self) {
        self.copy_isolation_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_isolation(&self) -> longhands::isolation::computed_value::T {
        use crate::properties::longhands::isolation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mIsolation {
            structs::StyleIsolation::Auto => Keyword::Auto,
            structs::StyleIsolation::Isolate => Keyword::Isolate,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_break_after(&mut self, v: longhands::break_after::computed_value::T) {
        self.mBreakAfter = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_break_after_from(&mut self, other: &Self) {
        self.mBreakAfter = other.mBreakAfter.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_break_after(&mut self, other: &Self) {
        self.copy_break_after_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_break_after(&self) -> longhands::break_after::computed_value::T {
        From::from(self.mBreakAfter.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_break_before(&mut self, v: longhands::break_before::computed_value::T) {
        self.mBreakBefore = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_break_before_from(&mut self, other: &Self) {
        self.mBreakBefore = other.mBreakBefore.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_break_before(&mut self, other: &Self) {
        self.copy_break_before_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_break_before(&self) -> longhands::break_before::computed_value::T {
        From::from(self.mBreakBefore.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_break_inside(&mut self, v: longhands::break_inside::computed_value::T) {
        self.mBreakInside = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_break_inside_from(&mut self, other: &Self) {
        self.mBreakInside = other.mBreakInside.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_break_inside(&mut self, other: &Self) {
        self.copy_break_inside_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_break_inside(&self) -> longhands::break_inside::computed_value::T {
        From::from(self.mBreakInside.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_resize(&mut self, v: longhands::resize::computed_value::T) {
        self.mResize = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_resize_from(&mut self, other: &Self) {
        self.mResize = other.mResize.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_resize(&mut self, other: &Self) {
        self.copy_resize_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_resize(&self) -> longhands::resize::computed_value::T {
        From::from(self.mResize.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_perspective(&mut self, v: longhands::perspective::computed_value::T) {
        self.mChildPerspective = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_perspective_from(&mut self, other: &Self) {
        self.mChildPerspective = other.mChildPerspective.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_perspective(&mut self, other: &Self) {
        self.copy_perspective_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_perspective(&self) -> longhands::perspective::computed_value::T {
        From::from(self.mChildPerspective.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_perspective_origin(&mut self, v: longhands::perspective_origin::computed_value::T) {
        self.mPerspectiveOrigin = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_perspective_origin_from(&mut self, other: &Self) {
        self.mPerspectiveOrigin = other.mPerspectiveOrigin.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_perspective_origin(&mut self, other: &Self) {
        self.copy_perspective_origin_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_perspective_origin(&self) -> longhands::perspective_origin::computed_value::T {
        From::from(self.mPerspectiveOrigin.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_backface_visibility(&mut self, v: longhands::backface_visibility::computed_value::T) {
        use crate::properties::longhands::backface_visibility::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Visible =>
                    structs::StyleBackfaceVisibility::Visible ,
                Keyword::Hidden =>
                    structs::StyleBackfaceVisibility::Hidden ,
        };
        self.mBackfaceVisibility = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_backface_visibility_from(&mut self, other: &Self) {
        self.mBackfaceVisibility = other.mBackfaceVisibility.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_backface_visibility(&mut self, other: &Self) {
        self.copy_backface_visibility_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_backface_visibility(&self) -> longhands::backface_visibility::computed_value::T {
        use crate::properties::longhands::backface_visibility::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBackfaceVisibility {
            structs::StyleBackfaceVisibility::Visible => Keyword::Visible,
            structs::StyleBackfaceVisibility::Hidden => Keyword::Hidden,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_transform_box(&mut self, v: longhands::transform_box::computed_value::T) {
        self.mTransformBox = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_transform_box_from(&mut self, other: &Self) {
        self.mTransformBox = other.mTransformBox.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_transform_box(&mut self, other: &Self) {
        self.copy_transform_box_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_transform_box(&self) -> longhands::transform_box::computed_value::T {
        From::from(self.mTransformBox.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_transform_style(&mut self, v: longhands::transform_style::computed_value::T) {
        self.mTransformStyle = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_transform_style_from(&mut self, other: &Self) {
        self.mTransformStyle = other.mTransformStyle.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_transform_style(&mut self, other: &Self) {
        self.copy_transform_style_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_transform_style(&self) -> longhands::transform_style::computed_value::T {
        From::from(self.mTransformStyle.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_transform_origin(&mut self, v: longhands::transform_origin::computed_value::T) {
        self.mTransformOrigin = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_transform_origin_from(&mut self, other: &Self) {
        self.mTransformOrigin = other.mTransformOrigin.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_transform_origin(&mut self, other: &Self) {
        self.copy_transform_origin_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_transform_origin(&self) -> longhands::transform_origin::computed_value::T {
        From::from(self.mTransformOrigin.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_content_visibility(&mut self, v: longhands::content_visibility::computed_value::T) {
        self.mContentVisibility = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_content_visibility_from(&mut self, other: &Self) {
        self.mContentVisibility = other.mContentVisibility.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_content_visibility(&mut self, other: &Self) {
        self.copy_content_visibility_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_content_visibility(&self) -> longhands::content_visibility::computed_value::T {
        From::from(self.mContentVisibility.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_container_type(&mut self, v: longhands::container_type::computed_value::T) {
        self.mContainerType = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_container_type_from(&mut self, other: &Self) {
        self.mContainerType = other.mContainerType.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_container_type(&mut self, other: &Self) {
        self.copy_container_type_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_container_type(&self) -> longhands::container_type::computed_value::T {
        From::from(self.mContainerType.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_container_name(&mut self, v: longhands::container_name::computed_value::T) {
        self.mContainerName = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_container_name_from(&mut self, other: &Self) {
        self.mContainerName = other.mContainerName.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_container_name(&mut self, other: &Self) {
        self.copy_container_name_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_container_name(&self) -> longhands::container_name::computed_value::T {
        From::from(self.mContainerName.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_appearance(&mut self, v: longhands::appearance::computed_value::T) {
        self.mAppearance = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_appearance_from(&mut self, other: &Self) {
        self.mAppearance = other.mAppearance.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_appearance(&mut self, other: &Self) {
        self.copy_appearance_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_appearance(&self) -> longhands::appearance::computed_value::T {
        From::from(self.mAppearance.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_default_appearance(&mut self, v: longhands::_moz_default_appearance::computed_value::T) {
        self.mDefaultAppearance = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_default_appearance_from(&mut self, other: &Self) {
        self.mDefaultAppearance = other.mDefaultAppearance.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_default_appearance(&mut self, other: &Self) {
        self.copy__moz_default_appearance_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_default_appearance(&self) -> longhands::_moz_default_appearance::computed_value::T {
        From::from(self.mDefaultAppearance.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_orient(&mut self, v: longhands::_moz_orient::computed_value::T) {
        use crate::properties::longhands::_moz_orient::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Inline =>
                    structs::StyleOrient::Inline ,
                Keyword::Block =>
                    structs::StyleOrient::Block ,
                Keyword::Horizontal =>
                    structs::StyleOrient::Horizontal ,
                Keyword::Vertical =>
                    structs::StyleOrient::Vertical ,
        };
        self.mOrient = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_orient_from(&mut self, other: &Self) {
        self.mOrient = other.mOrient.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_orient(&mut self, other: &Self) {
        self.copy__moz_orient_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_orient(&self) -> longhands::_moz_orient::computed_value::T {
        use crate::properties::longhands::_moz_orient::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mOrient {
            structs::StyleOrient::Inline => Keyword::Inline,
            structs::StyleOrient::Block => Keyword::Block,
            structs::StyleOrient::Horizontal => Keyword::Horizontal,
            structs::StyleOrient::Vertical => Keyword::Vertical,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_will_change(&mut self, v: longhands::will_change::computed_value::T) {
        self.mWillChange = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_will_change_from(&mut self, other: &Self) {
        self.mWillChange = other.mWillChange.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_will_change(&mut self, other: &Self) {
        self.copy_will_change_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_will_change(&self) -> longhands::will_change::computed_value::T {
        From::from(self.mWillChange.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_shape_image_threshold(&mut self, v: longhands::shape_image_threshold::computed_value::T) {
        self.mShapeImageThreshold = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_shape_image_threshold_from(&mut self, other: &Self) {
        self.mShapeImageThreshold = other.mShapeImageThreshold.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_shape_image_threshold(&mut self, other: &Self) {
        self.copy_shape_image_threshold_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_shape_image_threshold(&self) -> longhands::shape_image_threshold::computed_value::T {
        From::from(self.mShapeImageThreshold.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_shape_margin(&mut self, v: longhands::shape_margin::computed_value::T) {
        self.mShapeMargin = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_shape_margin_from(&mut self, other: &Self) {
        self.mShapeMargin = other.mShapeMargin.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_shape_margin(&mut self, other: &Self) {
        self.copy_shape_margin_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_shape_margin(&self) -> longhands::shape_margin::computed_value::T {
        From::from(self.mShapeMargin.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_shape_outside(&mut self, v: longhands::shape_outside::computed_value::T) {
        self.mShapeOutside = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_shape_outside_from(&mut self, other: &Self) {
        self.mShapeOutside = other.mShapeOutside.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_shape_outside(&mut self, other: &Self) {
        self.copy_shape_outside_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_shape_outside(&self) -> longhands::shape_outside::computed_value::T {
        From::from(self.mShapeOutside.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_touch_action(&mut self, v: longhands::touch_action::computed_value::T) {
        self.mTouchAction = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_touch_action_from(&mut self, other: &Self) {
        self.mTouchAction = other.mTouchAction.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_touch_action(&mut self, other: &Self) {
        self.copy_touch_action_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_touch_action(&self) -> longhands::touch_action::computed_value::T {
        From::from(self.mTouchAction.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__webkit_line_clamp(&mut self, v: longhands::_webkit_line_clamp::computed_value::T) {
        self.mWebkitLineClamp = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__webkit_line_clamp_from(&mut self, other: &Self) {
        self.mWebkitLineClamp = other.mWebkitLineClamp.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__webkit_line_clamp(&mut self, other: &Self) {
        self.copy__webkit_line_clamp_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__webkit_line_clamp(&self) -> longhands::_webkit_line_clamp::computed_value::T {
        From::from(self.mWebkitLineClamp.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_scrollbar_gutter(&mut self, v: longhands::scrollbar_gutter::computed_value::T) {
        self.mScrollbarGutter = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scrollbar_gutter_from(&mut self, other: &Self) {
        self.mScrollbarGutter = other.mScrollbarGutter.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scrollbar_gutter(&mut self, other: &Self) {
        self.copy_scrollbar_gutter_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scrollbar_gutter(&self) -> longhands::scrollbar_gutter::computed_value::T {
        From::from(self.mScrollbarGutter.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_zoom(&mut self, v: longhands::zoom::computed_value::T) {
        self.mZoom = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_zoom_from(&mut self, other: &Self) {
        self.mZoom = other.mZoom.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_zoom(&mut self, other: &Self) {
        self.copy_zoom_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_zoom(&self) -> longhands::zoom::computed_value::T {
        From::from(self.mZoom.clone())
    }


}










// TODO: Gecko accepts lists in most background-related properties. We just use
// the first element (which is the common case), but at some point we want to
// add support for parsing these lists in servo and pushing to nsTArray's.



impl GeckoBackground {
    /*
     * Manually-Implemented Methods.
     */
    

    
    

    
    
    pub fn copy_background_repeat_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mRepeatCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mRepeat = other.mRepeat.clone();
        }
        self.mImage.mRepeatCount = count;
    }

    pub fn reset_background_repeat(&mut self, other: &Self) {
        self.copy_background_repeat_from(other)
    }


    pub fn set_background_repeat<I>(&mut self, v: I)
        where I: IntoIterator<Item=longhands::background_repeat::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;
        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mRepeatCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage.mLayers.iter_mut()) {
            geckolayer.mRepeat = {
                
        use crate::values::specified::background::BackgroundRepeatKeyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_Repeat;
        use crate::gecko_bindings::structs::StyleImageLayerRepeat;

        fn to_ns(repeat: BackgroundRepeatKeyword) -> StyleImageLayerRepeat {
            match repeat {
                BackgroundRepeatKeyword::Repeat => StyleImageLayerRepeat::Repeat,
                BackgroundRepeatKeyword::Space => StyleImageLayerRepeat::Space,
                BackgroundRepeatKeyword::Round => StyleImageLayerRepeat::Round,
                BackgroundRepeatKeyword::NoRepeat => StyleImageLayerRepeat::NoRepeat,
            }
        }

        let repeat_x = to_ns(servo.0);
        let repeat_y = to_ns(servo.1);
        nsStyleImageLayers_Repeat {
              mXRepeat: repeat_x,
              mYRepeat: repeat_y,
        }
    
            };
        }
    }


    pub fn clone_background_repeat(&self) -> longhands::background_repeat::computed_value::T {
        use crate::properties::longhands::background_repeat::single_value::computed_value::T;
        use crate::values::specified::background::BackgroundRepeatKeyword;
        use crate::gecko_bindings::structs::StyleImageLayerRepeat;

        fn to_servo(repeat: StyleImageLayerRepeat) -> BackgroundRepeatKeyword {
            match repeat {
                StyleImageLayerRepeat::Repeat => BackgroundRepeatKeyword::Repeat,
                StyleImageLayerRepeat::Space => BackgroundRepeatKeyword::Space,
                StyleImageLayerRepeat::Round => BackgroundRepeatKeyword::Round,
                StyleImageLayerRepeat::NoRepeat => BackgroundRepeatKeyword::NoRepeat,
                _ => panic!("Found unexpected value in style struct for background_repeat property"),
            }
        }

        longhands::background_repeat::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mRepeatCount as usize)
                .map(|ref layer| {
                    T(to_servo(layer.mRepeat.mXRepeat), to_servo(layer.mRepeat.mYRepeat))
                }).collect()
        )
    }

    
    

    
    pub fn copy_background_clip_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mClipCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mClip = other.mClip.clone();
        }
        self.mImage.mClipCount = count;
    }

    pub fn reset_background_clip(&mut self, other: &Self) {
        self.copy_background_clip_from(other)
    }


    pub fn set_background_clip<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::background_clip::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::background_clip::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mClipCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage.mLayers.iter_mut()) {
            geckolayer.mClip = {
                match servo {
                    Keyword::BorderBox =>
                        structs::StyleGeometryBox::BorderBox ,
                    Keyword::PaddingBox =>
                        structs::StyleGeometryBox::PaddingBox ,
                    Keyword::ContentBox =>
                        structs::StyleGeometryBox::ContentBox ,
                    Keyword::Text =>
                        structs::StyleGeometryBox::Text ,
                }
            };
        }
    }

    pub fn clone_background_clip(&self) -> longhands::background_clip::computed_value::T {
        use crate::properties::longhands::background_clip::single_value::computed_value::T as Keyword;


        longhands::background_clip::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mClipCount as usize)
                .map(|ref layer| {
                    match layer.mClip {
                        structs::StyleGeometryBox::BorderBox
                            => Keyword::BorderBox,
                        structs::StyleGeometryBox::PaddingBox
                            => Keyword::PaddingBox,
                        structs::StyleGeometryBox::ContentBox
                            => Keyword::ContentBox,
                        structs::StyleGeometryBox::Text
                            => Keyword::Text,
                        _ => panic!("Found unexpected value in style struct for background_clip property"),
                    }
                }).collect()
        )
    }

    
    

    
    pub fn copy_background_origin_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mOriginCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mOrigin = other.mOrigin.clone();
        }
        self.mImage.mOriginCount = count;
    }

    pub fn reset_background_origin(&mut self, other: &Self) {
        self.copy_background_origin_from(other)
    }


    pub fn set_background_origin<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::background_origin::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::background_origin::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mOriginCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage.mLayers.iter_mut()) {
            geckolayer.mOrigin = {
                match servo {
                    Keyword::PaddingBox =>
                        structs::StyleGeometryBox::PaddingBox ,
                    Keyword::BorderBox =>
                        structs::StyleGeometryBox::BorderBox ,
                    Keyword::ContentBox =>
                        structs::StyleGeometryBox::ContentBox ,
                }
            };
        }
    }

    pub fn clone_background_origin(&self) -> longhands::background_origin::computed_value::T {
        use crate::properties::longhands::background_origin::single_value::computed_value::T as Keyword;


        longhands::background_origin::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mOriginCount as usize)
                .map(|ref layer| {
                    match layer.mOrigin {
                        structs::StyleGeometryBox::PaddingBox
                            => Keyword::PaddingBox,
                        structs::StyleGeometryBox::BorderBox
                            => Keyword::BorderBox,
                        structs::StyleGeometryBox::ContentBox
                            => Keyword::ContentBox,
                        _ => panic!("Found unexpected value in style struct for background_origin property"),
                    }
                }).collect()
        )
    }


    pub fn copy_background_position_x_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mPositionXCount;

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }

        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mPosition.horizontal = other.mPosition.horizontal.clone();
        }
        self.mImage.mPositionXCount = count;
    }

    pub fn reset_background_position_x(&mut self, other: &Self) {
        self.copy_background_position_x_from(other)
    }

    pub fn clone_background_position_x(&self)
        -> longhands::background_position_x::computed_value::T {
        longhands::background_position_x::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mPositionXCount as usize)
                .map(|position| position.mPosition.horizontal.clone())
                .collect()
        )
    }

    pub fn set_background_position_x<I>(&mut self,
                                     v: I)
        where I: IntoIterator<Item = longhands::background_position_x
                                              ::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mPositionXCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage
                                                           .mLayers.iter_mut()) {
            geckolayer.mPosition.horizontal = servo;
        }
    }
    pub fn copy_background_position_y_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mPositionYCount;

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }

        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mPosition.vertical = other.mPosition.vertical.clone();
        }
        self.mImage.mPositionYCount = count;
    }

    pub fn reset_background_position_y(&mut self, other: &Self) {
        self.copy_background_position_y_from(other)
    }

    pub fn clone_background_position_y(&self)
        -> longhands::background_position_y::computed_value::T {
        longhands::background_position_y::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mPositionYCount as usize)
                .map(|position| position.mPosition.vertical.clone())
                .collect()
        )
    }

    pub fn set_background_position_y<I>(&mut self,
                                     v: I)
        where I: IntoIterator<Item = longhands::background_position_y
                                              ::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mPositionYCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage
                                                           .mLayers.iter_mut()) {
            geckolayer.mPosition.vertical = servo;
        }
    }

    
    
    pub fn copy_background_size_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mSizeCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mSize = other.mSize.clone();
        }
        self.mImage.mSizeCount = count;
    }

    pub fn reset_background_size(&mut self, other: &Self) {
        self.copy_background_size_from(other)
    }


    pub fn set_background_size<I>(&mut self, v: I)
        where I: IntoIterator<Item=longhands::background_size::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;
        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mSizeCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage.mLayers.iter_mut()) {
            geckolayer.mSize = {
                
        servo
    
            };
        }
    }


    pub fn clone_background_size(&self) -> longhands::background_size::computed_value::T {
        longhands::background_size::computed_value::List(
            self.mImage.mLayers.iter().map(|layer| layer.mSize.clone()).collect()
        )
    }

    pub fn copy_background_image_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;
        unsafe {
            let count = other.mImage.mImageCount;
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);

            for (layer, other) in self.mImage.mLayers.iter_mut()
                                      .zip(other.mImage.mLayers.iter())
                                      .take(count as usize) {
                layer.mImage = other.mImage.clone();
            }
            self.mImage.mImageCount = count;
        }
    }

    pub fn reset_background_image(&mut self, other: &Self) {
        self.copy_background_image_from(other)
    }

    #[allow(unused_variables)]
    pub fn set_background_image<I>(&mut self, images: I)
        where I: IntoIterator<Item = longhands::background_image::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let images = images.into_iter();

        unsafe {
            Gecko_EnsureImageLayersLength(
                &mut self.mImage,
                images.len(),
                LayerType::Background,
            );
        }

        self.mImage.mImageCount = images.len() as u32;
        for (image, geckoimage) in images.zip(self.mImage
                                                  .mLayers.iter_mut()) {
            geckoimage.mImage = image;
        }
    }

    pub fn clone_background_image(&self) -> longhands::background_image::computed_value::T {
        longhands::background_image::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mImageCount as usize)
                .map(|layer| layer.mImage.clone())
                .collect()
        )
    }

    
    pub fn fill_arrays(&mut self) {
        use crate::gecko_bindings::bindings::Gecko_FillAllImageLayers;
        use std::cmp;
        let mut max_len = 1;
            max_len = cmp::max(max_len, self.mImage.mRepeatCount);
            max_len = cmp::max(max_len, self.mImage.mClipCount);
            max_len = cmp::max(max_len, self.mImage.mOriginCount);
            max_len = cmp::max(max_len, self.mImage.mPositionXCount);
            max_len = cmp::max(max_len, self.mImage.mPositionYCount);
            max_len = cmp::max(max_len, self.mImage.mImageCount);
            max_len = cmp::max(max_len, self.mImage.mSizeCount);
            max_len = cmp::max(max_len, self.mImage.mAttachmentCount);
            max_len = cmp::max(max_len, self.mImage.mBlendModeCount);
        unsafe {
            // While we could do this manually, we'd need to also manually
            // run all the copy constructors, so we just delegate to gecko
            Gecko_FillAllImageLayers(&mut self.mImage, max_len);
        }
    }

    
    

    
    pub fn copy_background_attachment_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mAttachmentCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mAttachment = other.mAttachment.clone();
        }
        self.mImage.mAttachmentCount = count;
    }

    pub fn reset_background_attachment(&mut self, other: &Self) {
        self.copy_background_attachment_from(other)
    }


    pub fn set_background_attachment<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::background_attachment::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::background_attachment::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mAttachmentCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage.mLayers.iter_mut()) {
            geckolayer.mAttachment = {
                match servo {
                    Keyword::Scroll =>
                        structs::StyleImageLayerAttachment::Scroll ,
                    Keyword::Fixed =>
                        structs::StyleImageLayerAttachment::Fixed ,
                    Keyword::Local =>
                        structs::StyleImageLayerAttachment::Local ,
                }
            };
        }
    }

    pub fn clone_background_attachment(&self) -> longhands::background_attachment::computed_value::T {
        use crate::properties::longhands::background_attachment::single_value::computed_value::T as Keyword;


        longhands::background_attachment::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mAttachmentCount as usize)
                .map(|ref layer| {
                    match layer.mAttachment {
                        structs::StyleImageLayerAttachment::Scroll
                            => Keyword::Scroll,
                        structs::StyleImageLayerAttachment::Fixed
                            => Keyword::Fixed,
                        structs::StyleImageLayerAttachment::Local
                            => Keyword::Local,
                    }
                }).collect()
        )
    }

    
    

    
    pub fn copy_background_blend_mode_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mImage.mBlendModeCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mImage,
                                          count as usize,
                                          LayerType::Background);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mImage.mLayers.iter_mut()
                                  .zip(other.mImage.mLayers.iter())
                                  .take(count as usize) {
            layer.mBlendMode = other.mBlendMode.clone();
        }
        self.mImage.mBlendModeCount = count;
    }

    pub fn reset_background_blend_mode(&mut self, other: &Self) {
        self.copy_background_blend_mode_from(other)
    }


    pub fn set_background_blend_mode<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::background_blend_mode::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::background_blend_mode::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mImage, v.len(),
                                        LayerType::Background);
        }

        self.mImage.mBlendModeCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mImage.mLayers.iter_mut()) {
            geckolayer.mBlendMode = {
                match servo {
                    Keyword::Normal =>
                        structs::StyleBlend::Normal ,
                    Keyword::Multiply =>
                        structs::StyleBlend::Multiply ,
                    Keyword::Screen =>
                        structs::StyleBlend::Screen ,
                    Keyword::Overlay =>
                        structs::StyleBlend::Overlay ,
                    Keyword::Darken =>
                        structs::StyleBlend::Darken ,
                    Keyword::Lighten =>
                        structs::StyleBlend::Lighten ,
                    Keyword::ColorDodge =>
                        structs::StyleBlend::ColorDodge ,
                    Keyword::ColorBurn =>
                        structs::StyleBlend::ColorBurn ,
                    Keyword::HardLight =>
                        structs::StyleBlend::HardLight ,
                    Keyword::SoftLight =>
                        structs::StyleBlend::SoftLight ,
                    Keyword::Difference =>
                        structs::StyleBlend::Difference ,
                    Keyword::Exclusion =>
                        structs::StyleBlend::Exclusion ,
                    Keyword::Hue =>
                        structs::StyleBlend::Hue ,
                    Keyword::Saturation =>
                        structs::StyleBlend::Saturation ,
                    Keyword::Color =>
                        structs::StyleBlend::Color ,
                    Keyword::Luminosity =>
                        structs::StyleBlend::Luminosity ,
                }
            };
        }
    }

    pub fn clone_background_blend_mode(&self) -> longhands::background_blend_mode::computed_value::T {
        use crate::properties::longhands::background_blend_mode::single_value::computed_value::T as Keyword;


        longhands::background_blend_mode::computed_value::List(
            self.mImage.mLayers.iter()
                .take(self.mImage.mBlendModeCount as usize)
                .map(|ref layer| {
                    match layer.mBlendMode {
                        structs::StyleBlend::Normal
                            => Keyword::Normal,
                        structs::StyleBlend::Multiply
                            => Keyword::Multiply,
                        structs::StyleBlend::Screen
                            => Keyword::Screen,
                        structs::StyleBlend::Overlay
                            => Keyword::Overlay,
                        structs::StyleBlend::Darken
                            => Keyword::Darken,
                        structs::StyleBlend::Lighten
                            => Keyword::Lighten,
                        structs::StyleBlend::ColorDodge
                            => Keyword::ColorDodge,
                        structs::StyleBlend::ColorBurn
                            => Keyword::ColorBurn,
                        structs::StyleBlend::HardLight
                            => Keyword::HardLight,
                        structs::StyleBlend::SoftLight
                            => Keyword::SoftLight,
                        structs::StyleBlend::Difference
                            => Keyword::Difference,
                        structs::StyleBlend::Exclusion
                            => Keyword::Exclusion,
                        structs::StyleBlend::Hue
                            => Keyword::Hue,
                        structs::StyleBlend::Saturation
                            => Keyword::Saturation,
                        structs::StyleBlend::Color
                            => Keyword::Color,
                        structs::StyleBlend::Luminosity
                            => Keyword::Luminosity,
                        _ => panic!("Found unexpected value in style struct for background_blend_mode property"),
                    }
                }).collect()
        )
    }



    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_background_color(&mut self, v: longhands::background_color::computed_value::T) {
        self.mBackgroundColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_background_color_from(&mut self, other: &Self) {
        self.mBackgroundColor = other.mBackgroundColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_background_color(&mut self, other: &Self) {
        self.copy_background_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_background_color(&self) -> longhands::background_color::computed_value::T {
        From::from(self.mBackgroundColor.clone())
    }


}




impl GeckoList {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_list_style_position(&mut self, v: longhands::list_style_position::computed_value::T) {
        use crate::properties::longhands::list_style_position::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Outside =>
                    structs::StyleListStylePosition::Outside ,
                Keyword::Inside =>
                    structs::StyleListStylePosition::Inside ,
        };
        self.mListStylePosition = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_list_style_position_from(&mut self, other: &Self) {
        self.mListStylePosition = other.mListStylePosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_list_style_position(&mut self, other: &Self) {
        self.copy_list_style_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_list_style_position(&self) -> longhands::list_style_position::computed_value::T {
        use crate::properties::longhands::list_style_position::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mListStylePosition {
            structs::StyleListStylePosition::Outside => Keyword::Outside,
            structs::StyleListStylePosition::Inside => Keyword::Inside,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_list_style_type(&mut self, v: longhands::list_style_type::computed_value::T) {
        self.mListStyleType = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_list_style_type_from(&mut self, other: &Self) {
        self.mListStyleType = other.mListStyleType.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_list_style_type(&mut self, other: &Self) {
        self.copy_list_style_type_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_list_style_type(&self) -> longhands::list_style_type::computed_value::T {
        From::from(self.mListStyleType.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_list_style_image(&mut self, v: longhands::list_style_image::computed_value::T) {
        self.mListStyleImage = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_list_style_image_from(&mut self, other: &Self) {
        self.mListStyleImage = other.mListStyleImage.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_list_style_image(&mut self, other: &Self) {
        self.copy_list_style_image_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_list_style_image(&self) -> longhands::list_style_image::computed_value::T {
        From::from(self.mListStyleImage.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_quotes(&mut self, v: longhands::quotes::computed_value::T) {
        self.mQuotes = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_quotes_from(&mut self, other: &Self) {
        self.mQuotes = other.mQuotes.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_quotes(&mut self, other: &Self) {
        self.copy_quotes_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_quotes(&self) -> longhands::quotes::computed_value::T {
        From::from(self.mQuotes.clone())
    }


}




impl GeckoTable {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_table_layout(&mut self, v: longhands::table_layout::computed_value::T) {
        use crate::properties::longhands::table_layout::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleTableLayout::Auto ,
                Keyword::Fixed =>
                    structs::StyleTableLayout::Fixed ,
        };
        self.mLayoutStrategy = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_table_layout_from(&mut self, other: &Self) {
        self.mLayoutStrategy = other.mLayoutStrategy.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_table_layout(&mut self, other: &Self) {
        self.copy_table_layout_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_table_layout(&self) -> longhands::table_layout::computed_value::T {
        use crate::properties::longhands::table_layout::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mLayoutStrategy {
            structs::StyleTableLayout::Auto => Keyword::Auto,
            structs::StyleTableLayout::Fixed => Keyword::Fixed,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__x_span(&mut self, v: longhands::_x_span::computed_value::T) {
        self.mXSpan = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__x_span_from(&mut self, other: &Self) {
        self.mXSpan = other.mXSpan.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__x_span(&mut self, other: &Self) {
        self.copy__x_span_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__x_span(&self) -> longhands::_x_span::computed_value::T {
        From::from(self.mXSpan.clone())
    }


}




impl GeckoEffects {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_opacity(&mut self, v: longhands::opacity::computed_value::T) {
        self.mOpacity = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_opacity_from(&mut self, other: &Self) {
        self.mOpacity = other.mOpacity.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_opacity(&mut self, other: &Self) {
        self.copy_opacity_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_opacity(&self) -> longhands::opacity::computed_value::T {
        From::from(self.mOpacity.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_box_shadow(&mut self, v: longhands::box_shadow::computed_value::T) {
        self.mBoxShadow = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_box_shadow_from(&mut self, other: &Self) {
        self.mBoxShadow = other.mBoxShadow.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_box_shadow(&mut self, other: &Self) {
        self.copy_box_shadow_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_box_shadow(&self) -> longhands::box_shadow::computed_value::T {
        From::from(self.mBoxShadow.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_clip(&mut self, v: longhands::clip::computed_value::T) {
        self.mClip = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_clip_from(&mut self, other: &Self) {
        self.mClip = other.mClip.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_clip(&mut self, other: &Self) {
        self.copy_clip_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_clip(&self) -> longhands::clip::computed_value::T {
        From::from(self.mClip.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_filter(&mut self, v: longhands::filter::computed_value::T) {
        self.mFilters = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_filter_from(&mut self, other: &Self) {
        self.mFilters = other.mFilters.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_filter(&mut self, other: &Self) {
        self.copy_filter_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_filter(&self) -> longhands::filter::computed_value::T {
        From::from(self.mFilters.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_backdrop_filter(&mut self, v: longhands::backdrop_filter::computed_value::T) {
        self.mBackdropFilters = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_backdrop_filter_from(&mut self, other: &Self) {
        self.mBackdropFilters = other.mBackdropFilters.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_backdrop_filter(&mut self, other: &Self) {
        self.copy_backdrop_filter_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_backdrop_filter(&self) -> longhands::backdrop_filter::computed_value::T {
        From::from(self.mBackdropFilters.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_mix_blend_mode(&mut self, v: longhands::mix_blend_mode::computed_value::T) {
        use crate::properties::longhands::mix_blend_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::StyleBlend::Normal ,
                Keyword::Multiply =>
                    structs::StyleBlend::Multiply ,
                Keyword::Screen =>
                    structs::StyleBlend::Screen ,
                Keyword::Overlay =>
                    structs::StyleBlend::Overlay ,
                Keyword::Darken =>
                    structs::StyleBlend::Darken ,
                Keyword::Lighten =>
                    structs::StyleBlend::Lighten ,
                Keyword::ColorDodge =>
                    structs::StyleBlend::ColorDodge ,
                Keyword::ColorBurn =>
                    structs::StyleBlend::ColorBurn ,
                Keyword::HardLight =>
                    structs::StyleBlend::HardLight ,
                Keyword::SoftLight =>
                    structs::StyleBlend::SoftLight ,
                Keyword::Difference =>
                    structs::StyleBlend::Difference ,
                Keyword::Exclusion =>
                    structs::StyleBlend::Exclusion ,
                Keyword::Hue =>
                    structs::StyleBlend::Hue ,
                Keyword::Saturation =>
                    structs::StyleBlend::Saturation ,
                Keyword::Color =>
                    structs::StyleBlend::Color ,
                Keyword::Luminosity =>
                    structs::StyleBlend::Luminosity ,
                Keyword::PlusLighter =>
                    structs::StyleBlend::PlusLighter ,
        };
        self.mMixBlendMode = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_mix_blend_mode_from(&mut self, other: &Self) {
        self.mMixBlendMode = other.mMixBlendMode.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_mix_blend_mode(&mut self, other: &Self) {
        self.copy_mix_blend_mode_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_mix_blend_mode(&self) -> longhands::mix_blend_mode::computed_value::T {
        use crate::properties::longhands::mix_blend_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mMixBlendMode {
            structs::StyleBlend::Normal => Keyword::Normal,
            structs::StyleBlend::Multiply => Keyword::Multiply,
            structs::StyleBlend::Screen => Keyword::Screen,
            structs::StyleBlend::Overlay => Keyword::Overlay,
            structs::StyleBlend::Darken => Keyword::Darken,
            structs::StyleBlend::Lighten => Keyword::Lighten,
            structs::StyleBlend::ColorDodge => Keyword::ColorDodge,
            structs::StyleBlend::ColorBurn => Keyword::ColorBurn,
            structs::StyleBlend::HardLight => Keyword::HardLight,
            structs::StyleBlend::SoftLight => Keyword::SoftLight,
            structs::StyleBlend::Difference => Keyword::Difference,
            structs::StyleBlend::Exclusion => Keyword::Exclusion,
            structs::StyleBlend::Hue => Keyword::Hue,
            structs::StyleBlend::Saturation => Keyword::Saturation,
            structs::StyleBlend::Color => Keyword::Color,
            structs::StyleBlend::Luminosity => Keyword::Luminosity,
            structs::StyleBlend::PlusLighter => Keyword::PlusLighter,
        }
    }


}




impl GeckoInheritedBox {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_visibility(&mut self, v: longhands::visibility::computed_value::T) {
        use crate::properties::longhands::visibility::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Visible =>
                    structs::StyleVisibility::Visible ,
                Keyword::Hidden =>
                    structs::StyleVisibility::Hidden ,
                Keyword::Collapse =>
                    structs::StyleVisibility::Collapse ,
        };
        self.mVisible = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_visibility_from(&mut self, other: &Self) {
        self.mVisible = other.mVisible.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_visibility(&mut self, other: &Self) {
        self.copy_visibility_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_visibility(&self) -> longhands::visibility::computed_value::T {
        use crate::properties::longhands::visibility::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mVisible {
            structs::StyleVisibility::Visible => Keyword::Visible,
            structs::StyleVisibility::Hidden => Keyword::Hidden,
            structs::StyleVisibility::Collapse => Keyword::Collapse,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_writing_mode(&mut self, v: longhands::writing_mode::computed_value::T) {
        use crate::properties::longhands::writing_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::HorizontalTb =>
                    structs::StyleWritingModeProperty::HorizontalTb ,
                Keyword::VerticalRl =>
                    structs::StyleWritingModeProperty::VerticalRl ,
                Keyword::VerticalLr =>
                    structs::StyleWritingModeProperty::VerticalLr ,
                Keyword::SidewaysRl =>
                    structs::StyleWritingModeProperty::SidewaysRl ,
                Keyword::SidewaysLr =>
                    structs::StyleWritingModeProperty::SidewaysLr ,
        };
        self.mWritingMode = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_writing_mode_from(&mut self, other: &Self) {
        self.mWritingMode = other.mWritingMode.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_writing_mode(&mut self, other: &Self) {
        self.copy_writing_mode_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_writing_mode(&self) -> longhands::writing_mode::computed_value::T {
        use crate::properties::longhands::writing_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mWritingMode {
            structs::StyleWritingModeProperty::HorizontalTb => Keyword::HorizontalTb,
            structs::StyleWritingModeProperty::VerticalRl => Keyword::VerticalRl,
            structs::StyleWritingModeProperty::VerticalLr => Keyword::VerticalLr,
            structs::StyleWritingModeProperty::SidewaysRl => Keyword::SidewaysRl,
            structs::StyleWritingModeProperty::SidewaysLr => Keyword::SidewaysLr,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_direction(&mut self, v: longhands::direction::computed_value::T) {
        use crate::properties::longhands::direction::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Ltr =>
                    structs::StyleDirection::Ltr ,
                Keyword::Rtl =>
                    structs::StyleDirection::Rtl ,
        };
        self.mDirection = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_direction_from(&mut self, other: &Self) {
        self.mDirection = other.mDirection.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_direction(&mut self, other: &Self) {
        self.copy_direction_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_direction(&self) -> longhands::direction::computed_value::T {
        use crate::properties::longhands::direction::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mDirection {
            structs::StyleDirection::Ltr => Keyword::Ltr,
            structs::StyleDirection::Rtl => Keyword::Rtl,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_box_collapse(&mut self, v: longhands::_moz_box_collapse::computed_value::T) {
        use crate::properties::longhands::_moz_box_collapse::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Flex =>
                    structs::StyleMozBoxCollapse::Flex ,
                Keyword::Legacy =>
                    structs::StyleMozBoxCollapse::Legacy ,
        };
        self.mMozBoxCollapse = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_box_collapse_from(&mut self, other: &Self) {
        self.mMozBoxCollapse = other.mMozBoxCollapse.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_box_collapse(&mut self, other: &Self) {
        self.copy__moz_box_collapse_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_box_collapse(&self) -> longhands::_moz_box_collapse::computed_value::T {
        use crate::properties::longhands::_moz_box_collapse::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mMozBoxCollapse {
            structs::StyleMozBoxCollapse::Flex => Keyword::Flex,
            structs::StyleMozBoxCollapse::Legacy => Keyword::Legacy,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_orientation(&mut self, v: longhands::text_orientation::computed_value::T) {
        use crate::properties::longhands::text_orientation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Mixed =>
                    structs::StyleTextOrientation::Mixed ,
                Keyword::Upright =>
                    structs::StyleTextOrientation::Upright ,
                Keyword::Sideways =>
                    structs::StyleTextOrientation::Sideways ,
        };
        self.mTextOrientation = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_text_orientation_from(&mut self, other: &Self) {
        self.mTextOrientation = other.mTextOrientation.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_orientation(&mut self, other: &Self) {
        self.copy_text_orientation_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_orientation(&self) -> longhands::text_orientation::computed_value::T {
        use crate::properties::longhands::text_orientation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextOrientation {
            structs::StyleTextOrientation::Mixed => Keyword::Mixed,
            structs::StyleTextOrientation::Upright => Keyword::Upright,
            structs::StyleTextOrientation::Sideways => Keyword::Sideways,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_print_color_adjust(&mut self, v: longhands::print_color_adjust::computed_value::T) {
        self.mPrintColorAdjust = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_print_color_adjust_from(&mut self, other: &Self) {
        self.mPrintColorAdjust = other.mPrintColorAdjust.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_print_color_adjust(&mut self, other: &Self) {
        self.copy_print_color_adjust_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_print_color_adjust(&self) -> longhands::print_color_adjust::computed_value::T {
        From::from(self.mPrintColorAdjust.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_image_rendering(&mut self, v: longhands::image_rendering::computed_value::T) {
        self.mImageRendering = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_image_rendering_from(&mut self, other: &Self) {
        self.mImageRendering = other.mImageRendering.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_image_rendering(&mut self, other: &Self) {
        self.copy_image_rendering_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_image_rendering(&self) -> longhands::image_rendering::computed_value::T {
        From::from(self.mImageRendering.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_image_orientation(&mut self, v: longhands::image_orientation::computed_value::T) {
        use crate::properties::longhands::image_orientation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::FromImage =>
                    structs::StyleImageOrientation::FromImage ,
                Keyword::None =>
                    structs::StyleImageOrientation::None ,
        };
        self.mImageOrientation = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_image_orientation_from(&mut self, other: &Self) {
        self.mImageOrientation = other.mImageOrientation.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_image_orientation(&mut self, other: &Self) {
        self.copy_image_orientation_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_image_orientation(&self) -> longhands::image_orientation::computed_value::T {
        use crate::properties::longhands::image_orientation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mImageOrientation {
            structs::StyleImageOrientation::FromImage => Keyword::FromImage,
            structs::StyleImageOrientation::None => Keyword::None,
        }
    }


}




impl GeckoInheritedTable {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_border_collapse(&mut self, v: longhands::border_collapse::computed_value::T) {
        use crate::properties::longhands::border_collapse::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Separate =>
                    structs::StyleBorderCollapse::Separate ,
                Keyword::Collapse =>
                    structs::StyleBorderCollapse::Collapse ,
        };
        self.mBorderCollapse = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_border_collapse_from(&mut self, other: &Self) {
        self.mBorderCollapse = other.mBorderCollapse.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_collapse(&mut self, other: &Self) {
        self.copy_border_collapse_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_collapse(&self) -> longhands::border_collapse::computed_value::T {
        use crate::properties::longhands::border_collapse::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBorderCollapse {
            structs::StyleBorderCollapse::Separate => Keyword::Separate,
            structs::StyleBorderCollapse::Collapse => Keyword::Collapse,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_empty_cells(&mut self, v: longhands::empty_cells::computed_value::T) {
        use crate::properties::longhands::empty_cells::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Show =>
                    structs::StyleEmptyCells::Show ,
                Keyword::Hide =>
                    structs::StyleEmptyCells::Hide ,
        };
        self.mEmptyCells = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_empty_cells_from(&mut self, other: &Self) {
        self.mEmptyCells = other.mEmptyCells.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_empty_cells(&mut self, other: &Self) {
        self.copy_empty_cells_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_empty_cells(&self) -> longhands::empty_cells::computed_value::T {
        use crate::properties::longhands::empty_cells::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mEmptyCells {
            structs::StyleEmptyCells::Show => Keyword::Show,
            structs::StyleEmptyCells::Hide => Keyword::Hide,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_caption_side(&mut self, v: longhands::caption_side::computed_value::T) {
        self.mCaptionSide = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_caption_side_from(&mut self, other: &Self) {
        self.mCaptionSide = other.mCaptionSide.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_caption_side(&mut self, other: &Self) {
        self.copy_caption_side_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_caption_side(&self) -> longhands::caption_side::computed_value::T {
        From::from(self.mCaptionSide.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_border_spacing(&mut self, v: longhands::border_spacing::computed_value::T) {
        self.mBorderSpacing = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_border_spacing_from(&mut self, other: &Self) {
        self.mBorderSpacing = other.mBorderSpacing.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_border_spacing(&mut self, other: &Self) {
        self.copy_border_spacing_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_border_spacing(&self) -> longhands::border_spacing::computed_value::T {
        From::from(self.mBorderSpacing.clone())
    }


}




impl GeckoInheritedText {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_color(&mut self, v: longhands::color::computed_value::T) {
        self.mColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_color_from(&mut self, other: &Self) {
        self.mColor = other.mColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_color(&mut self, other: &Self) {
        self.copy_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_color(&self) -> longhands::color::computed_value::T {
        From::from(self.mColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_transform(&mut self, v: longhands::text_transform::computed_value::T) {
        self.mTextTransform = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_transform_from(&mut self, other: &Self) {
        self.mTextTransform = other.mTextTransform.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_transform(&mut self, other: &Self) {
        self.copy_text_transform_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_transform(&self) -> longhands::text_transform::computed_value::T {
        From::from(self.mTextTransform.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_hyphens(&mut self, v: longhands::hyphens::computed_value::T) {
        use crate::properties::longhands::hyphens::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Manual =>
                    structs::StyleHyphens::Manual ,
                Keyword::None =>
                    structs::StyleHyphens::None ,
                Keyword::Auto =>
                    structs::StyleHyphens::Auto ,
        };
        self.mHyphens = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_hyphens_from(&mut self, other: &Self) {
        self.mHyphens = other.mHyphens.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_hyphens(&mut self, other: &Self) {
        self.copy_hyphens_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_hyphens(&self) -> longhands::hyphens::computed_value::T {
        use crate::properties::longhands::hyphens::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mHyphens {
            structs::StyleHyphens::Manual => Keyword::Manual,
            structs::StyleHyphens::None => Keyword::None,
            structs::StyleHyphens::Auto => Keyword::Auto,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_text_size_adjust(&mut self, v: longhands::_moz_text_size_adjust::computed_value::T) {
        use crate::properties::longhands::_moz_text_size_adjust::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleTextSizeAdjust::Auto ,
                Keyword::None =>
                    structs::StyleTextSizeAdjust::None ,
        };
        self.mTextSizeAdjust = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_text_size_adjust_from(&mut self, other: &Self) {
        self.mTextSizeAdjust = other.mTextSizeAdjust.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_text_size_adjust(&mut self, other: &Self) {
        self.copy__moz_text_size_adjust_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_text_size_adjust(&self) -> longhands::_moz_text_size_adjust::computed_value::T {
        use crate::properties::longhands::_moz_text_size_adjust::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextSizeAdjust {
            structs::StyleTextSizeAdjust::Auto => Keyword::Auto,
            structs::StyleTextSizeAdjust::None => Keyword::None,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_indent(&mut self, v: longhands::text_indent::computed_value::T) {
        self.mTextIndent = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_indent_from(&mut self, other: &Self) {
        self.mTextIndent = other.mTextIndent.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_indent(&mut self, other: &Self) {
        self.copy_text_indent_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_indent(&self) -> longhands::text_indent::computed_value::T {
        From::from(self.mTextIndent.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_overflow_wrap(&mut self, v: longhands::overflow_wrap::computed_value::T) {
        self.mOverflowWrap = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_overflow_wrap_from(&mut self, other: &Self) {
        self.mOverflowWrap = other.mOverflowWrap.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_overflow_wrap(&mut self, other: &Self) {
        self.copy_overflow_wrap_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_overflow_wrap(&self) -> longhands::overflow_wrap::computed_value::T {
        From::from(self.mOverflowWrap.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_word_break(&mut self, v: longhands::word_break::computed_value::T) {
        self.mWordBreak = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_word_break_from(&mut self, other: &Self) {
        self.mWordBreak = other.mWordBreak.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_word_break(&mut self, other: &Self) {
        self.copy_word_break_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_word_break(&self) -> longhands::word_break::computed_value::T {
        From::from(self.mWordBreak.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_justify(&mut self, v: longhands::text_justify::computed_value::T) {
        self.mTextJustify = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_justify_from(&mut self, other: &Self) {
        self.mTextJustify = other.mTextJustify.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_justify(&mut self, other: &Self) {
        self.copy_text_justify_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_justify(&self) -> longhands::text_justify::computed_value::T {
        From::from(self.mTextJustify.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_align_last(&mut self, v: longhands::text_align_last::computed_value::T) {
        self.mTextAlignLast = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_align_last_from(&mut self, other: &Self) {
        self.mTextAlignLast = other.mTextAlignLast.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_align_last(&mut self, other: &Self) {
        self.copy_text_align_last_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_align_last(&self) -> longhands::text_align_last::computed_value::T {
        From::from(self.mTextAlignLast.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_align(&mut self, v: longhands::text_align::computed_value::T) {
        self.mTextAlign = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_align_from(&mut self, other: &Self) {
        self.mTextAlign = other.mTextAlign.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_align(&mut self, other: &Self) {
        self.copy_text_align_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_align(&self) -> longhands::text_align::computed_value::T {
        From::from(self.mTextAlign.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_letter_spacing(&mut self, v: longhands::letter_spacing::computed_value::T) {
        self.mLetterSpacing = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_letter_spacing_from(&mut self, other: &Self) {
        self.mLetterSpacing = other.mLetterSpacing.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_letter_spacing(&mut self, other: &Self) {
        self.copy_letter_spacing_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_letter_spacing(&self) -> longhands::letter_spacing::computed_value::T {
        From::from(self.mLetterSpacing.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_word_spacing(&mut self, v: longhands::word_spacing::computed_value::T) {
        self.mWordSpacing = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_word_spacing_from(&mut self, other: &Self) {
        self.mWordSpacing = other.mWordSpacing.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_word_spacing(&mut self, other: &Self) {
        self.copy_word_spacing_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_word_spacing(&self) -> longhands::word_spacing::computed_value::T {
        From::from(self.mWordSpacing.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_white_space_collapse(&mut self, v: longhands::white_space_collapse::computed_value::T) {
        use crate::properties::longhands::white_space_collapse::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Collapse =>
                    structs::StyleWhiteSpaceCollapse::Collapse ,
                Keyword::Preserve =>
                    structs::StyleWhiteSpaceCollapse::Preserve ,
                Keyword::PreserveBreaks =>
                    structs::StyleWhiteSpaceCollapse::PreserveBreaks ,
                Keyword::PreserveSpaces =>
                    structs::StyleWhiteSpaceCollapse::PreserveSpaces ,
                Keyword::BreakSpaces =>
                    structs::StyleWhiteSpaceCollapse::BreakSpaces ,
        };
        self.mWhiteSpaceCollapse = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_white_space_collapse_from(&mut self, other: &Self) {
        self.mWhiteSpaceCollapse = other.mWhiteSpaceCollapse.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_white_space_collapse(&mut self, other: &Self) {
        self.copy_white_space_collapse_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_white_space_collapse(&self) -> longhands::white_space_collapse::computed_value::T {
        use crate::properties::longhands::white_space_collapse::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mWhiteSpaceCollapse {
            structs::StyleWhiteSpaceCollapse::Collapse => Keyword::Collapse,
            structs::StyleWhiteSpaceCollapse::Preserve => Keyword::Preserve,
            structs::StyleWhiteSpaceCollapse::PreserveBreaks => Keyword::PreserveBreaks,
            structs::StyleWhiteSpaceCollapse::PreserveSpaces => Keyword::PreserveSpaces,
            structs::StyleWhiteSpaceCollapse::BreakSpaces => Keyword::BreakSpaces,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_shadow(&mut self, v: longhands::text_shadow::computed_value::T) {
        self.mTextShadow = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_shadow_from(&mut self, other: &Self) {
        self.mTextShadow = other.mTextShadow.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_shadow(&mut self, other: &Self) {
        self.copy_text_shadow_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_shadow(&self) -> longhands::text_shadow::computed_value::T {
        From::from(self.mTextShadow.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_emphasis_style(&mut self, v: longhands::text_emphasis_style::computed_value::T) {
        self.mTextEmphasisStyle = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_emphasis_style_from(&mut self, other: &Self) {
        self.mTextEmphasisStyle = other.mTextEmphasisStyle.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_style(&mut self, other: &Self) {
        self.copy_text_emphasis_style_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_emphasis_style(&self) -> longhands::text_emphasis_style::computed_value::T {
        From::from(self.mTextEmphasisStyle.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_emphasis_position(&mut self, v: longhands::text_emphasis_position::computed_value::T) {
        self.mTextEmphasisPosition = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_emphasis_position_from(&mut self, other: &Self) {
        self.mTextEmphasisPosition = other.mTextEmphasisPosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_position(&mut self, other: &Self) {
        self.copy_text_emphasis_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_emphasis_position(&self) -> longhands::text_emphasis_position::computed_value::T {
        From::from(self.mTextEmphasisPosition.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_emphasis_color(&mut self, v: longhands::text_emphasis_color::computed_value::T) {
        self.mTextEmphasisColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_emphasis_color_from(&mut self, other: &Self) {
        self.mTextEmphasisColor = other.mTextEmphasisColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_color(&mut self, other: &Self) {
        self.copy_text_emphasis_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_emphasis_color(&self) -> longhands::text_emphasis_color::computed_value::T {
        From::from(self.mTextEmphasisColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_tab_size(&mut self, v: longhands::tab_size::computed_value::T) {
        self.mTabSize = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_tab_size_from(&mut self, other: &Self) {
        self.mTabSize = other.mTabSize.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_tab_size(&mut self, other: &Self) {
        self.copy_tab_size_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_tab_size(&self) -> longhands::tab_size::computed_value::T {
        From::from(self.mTabSize.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_line_break(&mut self, v: longhands::line_break::computed_value::T) {
        self.mLineBreak = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_line_break_from(&mut self, other: &Self) {
        self.mLineBreak = other.mLineBreak.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_line_break(&mut self, other: &Self) {
        self.copy_line_break_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_line_break(&self) -> longhands::line_break::computed_value::T {
        From::from(self.mLineBreak.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__webkit_text_fill_color(&mut self, v: longhands::_webkit_text_fill_color::computed_value::T) {
        self.mWebkitTextFillColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__webkit_text_fill_color_from(&mut self, other: &Self) {
        self.mWebkitTextFillColor = other.mWebkitTextFillColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__webkit_text_fill_color(&mut self, other: &Self) {
        self.copy__webkit_text_fill_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__webkit_text_fill_color(&self) -> longhands::_webkit_text_fill_color::computed_value::T {
        From::from(self.mWebkitTextFillColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_color(&mut self, v: longhands::_webkit_text_stroke_color::computed_value::T) {
        self.mWebkitTextStrokeColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__webkit_text_stroke_color_from(&mut self, other: &Self) {
        self.mWebkitTextStrokeColor = other.mWebkitTextStrokeColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_color(&mut self, other: &Self) {
        self.copy__webkit_text_stroke_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__webkit_text_stroke_color(&self) -> longhands::_webkit_text_stroke_color::computed_value::T {
        From::from(self.mWebkitTextStrokeColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_width(&mut self, v: longhands::_webkit_text_stroke_width::computed_value::T) {
        self.mWebkitTextStrokeWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__webkit_text_stroke_width_from(&mut self, other: &Self) {
        self.mWebkitTextStrokeWidth = other.mWebkitTextStrokeWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_width(&mut self, other: &Self) {
        self.copy__webkit_text_stroke_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__webkit_text_stroke_width(&self) -> longhands::_webkit_text_stroke_width::computed_value::T {
        From::from(self.mWebkitTextStrokeWidth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_ruby_align(&mut self, v: longhands::ruby_align::computed_value::T) {
        use crate::properties::longhands::ruby_align::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::SpaceAround =>
                    structs::StyleRubyAlign::SpaceAround ,
                Keyword::Start =>
                    structs::StyleRubyAlign::Start ,
                Keyword::Center =>
                    structs::StyleRubyAlign::Center ,
                Keyword::SpaceBetween =>
                    structs::StyleRubyAlign::SpaceBetween ,
        };
        self.mRubyAlign = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_ruby_align_from(&mut self, other: &Self) {
        self.mRubyAlign = other.mRubyAlign.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_ruby_align(&mut self, other: &Self) {
        self.copy_ruby_align_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_ruby_align(&self) -> longhands::ruby_align::computed_value::T {
        use crate::properties::longhands::ruby_align::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mRubyAlign {
            structs::StyleRubyAlign::SpaceAround => Keyword::SpaceAround,
            structs::StyleRubyAlign::Start => Keyword::Start,
            structs::StyleRubyAlign::Center => Keyword::Center,
            structs::StyleRubyAlign::SpaceBetween => Keyword::SpaceBetween,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_ruby_position(&mut self, v: longhands::ruby_position::computed_value::T) {
        self.mRubyPosition = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_ruby_position_from(&mut self, other: &Self) {
        self.mRubyPosition = other.mRubyPosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_ruby_position(&mut self, other: &Self) {
        self.copy_ruby_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_ruby_position(&self) -> longhands::ruby_position::computed_value::T {
        From::from(self.mRubyPosition.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_combine_upright(&mut self, v: longhands::text_combine_upright::computed_value::T) {
        use crate::properties::longhands::text_combine_upright::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::None =>
                    structs::StyleTextCombineUpright::None ,
                Keyword::All =>
                    structs::StyleTextCombineUpright::All ,
        };
        self.mTextCombineUpright = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_text_combine_upright_from(&mut self, other: &Self) {
        self.mTextCombineUpright = other.mTextCombineUpright.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_combine_upright(&mut self, other: &Self) {
        self.copy_text_combine_upright_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_combine_upright(&self) -> longhands::text_combine_upright::computed_value::T {
        use crate::properties::longhands::text_combine_upright::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextCombineUpright {
            structs::StyleTextCombineUpright::None => Keyword::None,
            structs::StyleTextCombineUpright::All => Keyword::All,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_rendering(&mut self, v: longhands::text_rendering::computed_value::T) {
        use crate::properties::longhands::text_rendering::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleTextRendering::Auto ,
                Keyword::Optimizespeed =>
                    structs::StyleTextRendering::Optimizespeed ,
                Keyword::Optimizelegibility =>
                    structs::StyleTextRendering::Optimizelegibility ,
                Keyword::Geometricprecision =>
                    structs::StyleTextRendering::Geometricprecision ,
        };
        self.mTextRendering = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_text_rendering_from(&mut self, other: &Self) {
        self.mTextRendering = other.mTextRendering.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_rendering(&mut self, other: &Self) {
        self.copy_text_rendering_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_rendering(&self) -> longhands::text_rendering::computed_value::T {
        use crate::properties::longhands::text_rendering::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextRendering {
            structs::StyleTextRendering::Auto => Keyword::Auto,
            structs::StyleTextRendering::Optimizespeed => Keyword::Optimizespeed,
            structs::StyleTextRendering::Optimizelegibility => Keyword::Optimizelegibility,
            structs::StyleTextRendering::Geometricprecision => Keyword::Geometricprecision,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_control_character_visibility(&mut self, v: longhands::_moz_control_character_visibility::computed_value::T) {
        self.mMozControlCharacterVisibility = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_control_character_visibility_from(&mut self, other: &Self) {
        self.mMozControlCharacterVisibility = other.mMozControlCharacterVisibility.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_control_character_visibility(&mut self, other: &Self) {
        self.copy__moz_control_character_visibility_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_control_character_visibility(&self) -> longhands::_moz_control_character_visibility::computed_value::T {
        From::from(self.mMozControlCharacterVisibility.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_underline_offset(&mut self, v: longhands::text_underline_offset::computed_value::T) {
        self.mTextUnderlineOffset = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_underline_offset_from(&mut self, other: &Self) {
        self.mTextUnderlineOffset = other.mTextUnderlineOffset.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_underline_offset(&mut self, other: &Self) {
        self.copy_text_underline_offset_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_underline_offset(&self) -> longhands::text_underline_offset::computed_value::T {
        From::from(self.mTextUnderlineOffset.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_underline_position(&mut self, v: longhands::text_underline_position::computed_value::T) {
        self.mTextUnderlinePosition = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_underline_position_from(&mut self, other: &Self) {
        self.mTextUnderlinePosition = other.mTextUnderlinePosition.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_underline_position(&mut self, other: &Self) {
        self.copy_text_underline_position_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_underline_position(&self) -> longhands::text_underline_position::computed_value::T {
        From::from(self.mTextUnderlinePosition.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_decoration_skip_ink(&mut self, v: longhands::text_decoration_skip_ink::computed_value::T) {
        self.mTextDecorationSkipInk = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_decoration_skip_ink_from(&mut self, other: &Self) {
        self.mTextDecorationSkipInk = other.mTextDecorationSkipInk.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_decoration_skip_ink(&mut self, other: &Self) {
        self.copy_text_decoration_skip_ink_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_decoration_skip_ink(&self) -> longhands::text_decoration_skip_ink::computed_value::T {
        From::from(self.mTextDecorationSkipInk.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_hyphenate_character(&mut self, v: longhands::hyphenate_character::computed_value::T) {
        self.mHyphenateCharacter = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_hyphenate_character_from(&mut self, other: &Self) {
        self.mHyphenateCharacter = other.mHyphenateCharacter.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_hyphenate_character(&mut self, other: &Self) {
        self.copy_hyphenate_character_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_hyphenate_character(&self) -> longhands::hyphenate_character::computed_value::T {
        From::from(self.mHyphenateCharacter.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_forced_color_adjust(&mut self, v: longhands::forced_color_adjust::computed_value::T) {
        self.mForcedColorAdjust = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_forced_color_adjust_from(&mut self, other: &Self) {
        self.mForcedColorAdjust = other.mForcedColorAdjust.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_forced_color_adjust(&mut self, other: &Self) {
        self.copy_forced_color_adjust_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_forced_color_adjust(&self) -> longhands::forced_color_adjust::computed_value::T {
        From::from(self.mForcedColorAdjust.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__webkit_text_security(&mut self, v: longhands::_webkit_text_security::computed_value::T) {
        use crate::properties::longhands::_webkit_text_security::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::None =>
                    structs::StyleTextSecurity::None ,
                Keyword::Circle =>
                    structs::StyleTextSecurity::Circle ,
                Keyword::Disc =>
                    structs::StyleTextSecurity::Disc ,
                Keyword::Square =>
                    structs::StyleTextSecurity::Square ,
        };
        self.mWebkitTextSecurity = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__webkit_text_security_from(&mut self, other: &Self) {
        self.mWebkitTextSecurity = other.mWebkitTextSecurity.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__webkit_text_security(&mut self, other: &Self) {
        self.copy__webkit_text_security_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__webkit_text_security(&self) -> longhands::_webkit_text_security::computed_value::T {
        use crate::properties::longhands::_webkit_text_security::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mWebkitTextSecurity {
            structs::StyleTextSecurity::None => Keyword::None,
            structs::StyleTextSecurity::Circle => Keyword::Circle,
            structs::StyleTextSecurity::Disc => Keyword::Disc,
            structs::StyleTextSecurity::Square => Keyword::Square,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_wrap_mode(&mut self, v: longhands::text_wrap_mode::computed_value::T) {
        use crate::properties::longhands::text_wrap_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Wrap =>
                    structs::StyleTextWrapMode::Wrap ,
                Keyword::Nowrap =>
                    structs::StyleTextWrapMode::Nowrap ,
        };
        self.mTextWrapMode = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_text_wrap_mode_from(&mut self, other: &Self) {
        self.mTextWrapMode = other.mTextWrapMode.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_wrap_mode(&mut self, other: &Self) {
        self.copy_text_wrap_mode_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_wrap_mode(&self) -> longhands::text_wrap_mode::computed_value::T {
        use crate::properties::longhands::text_wrap_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextWrapMode {
            structs::StyleTextWrapMode::Wrap => Keyword::Wrap,
            structs::StyleTextWrapMode::Nowrap => Keyword::Nowrap,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_wrap_style(&mut self, v: longhands::text_wrap_style::computed_value::T) {
        use crate::properties::longhands::text_wrap_style::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleTextWrapStyle::Auto ,
                Keyword::Stable =>
                    structs::StyleTextWrapStyle::Stable ,
                Keyword::Balance =>
                    structs::StyleTextWrapStyle::Balance ,
        };
        self.mTextWrapStyle = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_text_wrap_style_from(&mut self, other: &Self) {
        self.mTextWrapStyle = other.mTextWrapStyle.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_wrap_style(&mut self, other: &Self) {
        self.copy_text_wrap_style_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_wrap_style(&self) -> longhands::text_wrap_style::computed_value::T {
        use crate::properties::longhands::text_wrap_style::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextWrapStyle {
            structs::StyleTextWrapStyle::Auto => Keyword::Auto,
            structs::StyleTextWrapStyle::Stable => Keyword::Stable,
            structs::StyleTextWrapStyle::Balance => Keyword::Balance,
        }
    }


}




impl GeckoText {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_text_overflow(&mut self, v: longhands::text_overflow::computed_value::T) {
        self.mTextOverflow = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_overflow_from(&mut self, other: &Self) {
        self.mTextOverflow = other.mTextOverflow.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_overflow(&mut self, other: &Self) {
        self.copy_text_overflow_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_overflow(&self) -> longhands::text_overflow::computed_value::T {
        From::from(self.mTextOverflow.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_unicode_bidi(&mut self, v: longhands::unicode_bidi::computed_value::T) {
        use crate::properties::longhands::unicode_bidi::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::StyleUnicodeBidi::Normal ,
                Keyword::Embed =>
                    structs::StyleUnicodeBidi::Embed ,
                Keyword::Isolate =>
                    structs::StyleUnicodeBidi::Isolate ,
                Keyword::BidiOverride =>
                    structs::StyleUnicodeBidi::BidiOverride ,
                Keyword::IsolateOverride =>
                    structs::StyleUnicodeBidi::IsolateOverride ,
                Keyword::Plaintext =>
                    structs::StyleUnicodeBidi::Plaintext ,
        };
        self.mUnicodeBidi = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_unicode_bidi_from(&mut self, other: &Self) {
        self.mUnicodeBidi = other.mUnicodeBidi.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_unicode_bidi(&mut self, other: &Self) {
        self.copy_unicode_bidi_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_unicode_bidi(&self) -> longhands::unicode_bidi::computed_value::T {
        use crate::properties::longhands::unicode_bidi::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mUnicodeBidi {
            structs::StyleUnicodeBidi::Normal => Keyword::Normal,
            structs::StyleUnicodeBidi::Embed => Keyword::Embed,
            structs::StyleUnicodeBidi::Isolate => Keyword::Isolate,
            structs::StyleUnicodeBidi::BidiOverride => Keyword::BidiOverride,
            structs::StyleUnicodeBidi::IsolateOverride => Keyword::IsolateOverride,
            structs::StyleUnicodeBidi::Plaintext => Keyword::Plaintext,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_decoration_line(&mut self, v: longhands::text_decoration_line::computed_value::T) {
        self.mTextDecorationLine = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_decoration_line_from(&mut self, other: &Self) {
        self.mTextDecorationLine = other.mTextDecorationLine.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_decoration_line(&mut self, other: &Self) {
        self.copy_text_decoration_line_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_decoration_line(&self) -> longhands::text_decoration_line::computed_value::T {
        From::from(self.mTextDecorationLine.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_decoration_style(&mut self, v: longhands::text_decoration_style::computed_value::T) {
        use crate::properties::longhands::text_decoration_style::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Solid =>
                    structs::StyleTextDecorationStyle::Solid ,
                Keyword::Double =>
                    structs::StyleTextDecorationStyle::Double ,
                Keyword::Dotted =>
                    structs::StyleTextDecorationStyle::Dotted ,
                Keyword::Dashed =>
                    structs::StyleTextDecorationStyle::Dashed ,
                Keyword::Wavy =>
                    structs::StyleTextDecorationStyle::Wavy ,
                Keyword::MozNone =>
                    structs::StyleTextDecorationStyle::None ,
        };
        self.mTextDecorationStyle = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_text_decoration_style_from(&mut self, other: &Self) {
        self.mTextDecorationStyle = other.mTextDecorationStyle.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_decoration_style(&mut self, other: &Self) {
        self.copy_text_decoration_style_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_decoration_style(&self) -> longhands::text_decoration_style::computed_value::T {
        use crate::properties::longhands::text_decoration_style::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextDecorationStyle {
            structs::StyleTextDecorationStyle::Solid => Keyword::Solid,
            structs::StyleTextDecorationStyle::Double => Keyword::Double,
            structs::StyleTextDecorationStyle::Dotted => Keyword::Dotted,
            structs::StyleTextDecorationStyle::Dashed => Keyword::Dashed,
            structs::StyleTextDecorationStyle::Wavy => Keyword::Wavy,
            structs::StyleTextDecorationStyle::None => Keyword::MozNone,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_decoration_color(&mut self, v: longhands::text_decoration_color::computed_value::T) {
        self.mTextDecorationColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_decoration_color_from(&mut self, other: &Self) {
        self.mTextDecorationColor = other.mTextDecorationColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_decoration_color(&mut self, other: &Self) {
        self.copy_text_decoration_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_decoration_color(&self) -> longhands::text_decoration_color::computed_value::T {
        From::from(self.mTextDecorationColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_initial_letter(&mut self, v: longhands::initial_letter::computed_value::T) {
        self.mInitialLetter = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_initial_letter_from(&mut self, other: &Self) {
        self.mInitialLetter = other.mInitialLetter.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_initial_letter(&mut self, other: &Self) {
        self.copy_initial_letter_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_initial_letter(&self) -> longhands::initial_letter::computed_value::T {
        From::from(self.mInitialLetter.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_text_decoration_thickness(&mut self, v: longhands::text_decoration_thickness::computed_value::T) {
        self.mTextDecorationThickness = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_text_decoration_thickness_from(&mut self, other: &Self) {
        self.mTextDecorationThickness = other.mTextDecorationThickness.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_decoration_thickness(&mut self, other: &Self) {
        self.copy_text_decoration_thickness_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_decoration_thickness(&self) -> longhands::text_decoration_thickness::computed_value::T {
        From::from(self.mTextDecorationThickness.clone())
    }


}





impl GeckoSVG {
    /*
     * Manually-Implemented Methods.
     */
    
    
    

    
    
    pub fn copy_mask_repeat_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mRepeatCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mRepeat = other.mRepeat.clone();
        }
        self.mMask.mRepeatCount = count;
    }

    pub fn reset_mask_repeat(&mut self, other: &Self) {
        self.copy_mask_repeat_from(other)
    }


    pub fn set_mask_repeat<I>(&mut self, v: I)
        where I: IntoIterator<Item=longhands::mask_repeat::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;
        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mRepeatCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask.mLayers.iter_mut()) {
            geckolayer.mRepeat = {
                
        use crate::values::specified::background::BackgroundRepeatKeyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_Repeat;
        use crate::gecko_bindings::structs::StyleImageLayerRepeat;

        fn to_ns(repeat: BackgroundRepeatKeyword) -> StyleImageLayerRepeat {
            match repeat {
                BackgroundRepeatKeyword::Repeat => StyleImageLayerRepeat::Repeat,
                BackgroundRepeatKeyword::Space => StyleImageLayerRepeat::Space,
                BackgroundRepeatKeyword::Round => StyleImageLayerRepeat::Round,
                BackgroundRepeatKeyword::NoRepeat => StyleImageLayerRepeat::NoRepeat,
            }
        }

        let repeat_x = to_ns(servo.0);
        let repeat_y = to_ns(servo.1);
        nsStyleImageLayers_Repeat {
              mXRepeat: repeat_x,
              mYRepeat: repeat_y,
        }
    
            };
        }
    }


    pub fn clone_mask_repeat(&self) -> longhands::mask_repeat::computed_value::T {
        use crate::properties::longhands::mask_repeat::single_value::computed_value::T;
        use crate::values::specified::background::BackgroundRepeatKeyword;
        use crate::gecko_bindings::structs::StyleImageLayerRepeat;

        fn to_servo(repeat: StyleImageLayerRepeat) -> BackgroundRepeatKeyword {
            match repeat {
                StyleImageLayerRepeat::Repeat => BackgroundRepeatKeyword::Repeat,
                StyleImageLayerRepeat::Space => BackgroundRepeatKeyword::Space,
                StyleImageLayerRepeat::Round => BackgroundRepeatKeyword::Round,
                StyleImageLayerRepeat::NoRepeat => BackgroundRepeatKeyword::NoRepeat,
                _ => panic!("Found unexpected value in style struct for mask_repeat property"),
            }
        }

        longhands::mask_repeat::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mRepeatCount as usize)
                .map(|ref layer| {
                    T(to_servo(layer.mRepeat.mXRepeat), to_servo(layer.mRepeat.mYRepeat))
                }).collect()
        )
    }

    
    

    
    pub fn copy_mask_clip_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mClipCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mClip = other.mClip.clone();
        }
        self.mMask.mClipCount = count;
    }

    pub fn reset_mask_clip(&mut self, other: &Self) {
        self.copy_mask_clip_from(other)
    }


    pub fn set_mask_clip<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::mask_clip::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::mask_clip::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mClipCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask.mLayers.iter_mut()) {
            geckolayer.mClip = {
                match servo {
                    Keyword::BorderBox =>
                        structs::StyleGeometryBox::BorderBox ,
                    Keyword::ContentBox =>
                        structs::StyleGeometryBox::ContentBox ,
                    Keyword::PaddingBox =>
                        structs::StyleGeometryBox::PaddingBox ,
                    Keyword::FillBox =>
                        structs::StyleGeometryBox::FillBox ,
                    Keyword::StrokeBox =>
                        structs::StyleGeometryBox::StrokeBox ,
                    Keyword::ViewBox =>
                        structs::StyleGeometryBox::ViewBox ,
                    Keyword::NoClip =>
                        structs::StyleGeometryBox::NoClip ,
                }
            };
        }
    }

    pub fn clone_mask_clip(&self) -> longhands::mask_clip::computed_value::T {
        use crate::properties::longhands::mask_clip::single_value::computed_value::T as Keyword;


        longhands::mask_clip::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mClipCount as usize)
                .map(|ref layer| {
                    match layer.mClip {
                        structs::StyleGeometryBox::BorderBox
                            => Keyword::BorderBox,
                        structs::StyleGeometryBox::ContentBox
                            => Keyword::ContentBox,
                        structs::StyleGeometryBox::PaddingBox
                            => Keyword::PaddingBox,
                        structs::StyleGeometryBox::FillBox
                            => Keyword::FillBox,
                        structs::StyleGeometryBox::StrokeBox
                            => Keyword::StrokeBox,
                        structs::StyleGeometryBox::ViewBox
                            => Keyword::ViewBox,
                        structs::StyleGeometryBox::NoClip
                            => Keyword::NoClip,
                        _ => panic!("Found unexpected value in style struct for mask_clip property"),
                    }
                }).collect()
        )
    }

    
    

    
    pub fn copy_mask_origin_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mOriginCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mOrigin = other.mOrigin.clone();
        }
        self.mMask.mOriginCount = count;
    }

    pub fn reset_mask_origin(&mut self, other: &Self) {
        self.copy_mask_origin_from(other)
    }


    pub fn set_mask_origin<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::mask_origin::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::mask_origin::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mOriginCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask.mLayers.iter_mut()) {
            geckolayer.mOrigin = {
                match servo {
                    Keyword::BorderBox =>
                        structs::StyleGeometryBox::BorderBox ,
                    Keyword::ContentBox =>
                        structs::StyleGeometryBox::ContentBox ,
                    Keyword::PaddingBox =>
                        structs::StyleGeometryBox::PaddingBox ,
                    Keyword::FillBox =>
                        structs::StyleGeometryBox::FillBox ,
                    Keyword::StrokeBox =>
                        structs::StyleGeometryBox::StrokeBox ,
                    Keyword::ViewBox =>
                        structs::StyleGeometryBox::ViewBox ,
                }
            };
        }
    }

    pub fn clone_mask_origin(&self) -> longhands::mask_origin::computed_value::T {
        use crate::properties::longhands::mask_origin::single_value::computed_value::T as Keyword;


        longhands::mask_origin::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mOriginCount as usize)
                .map(|ref layer| {
                    match layer.mOrigin {
                        structs::StyleGeometryBox::BorderBox
                            => Keyword::BorderBox,
                        structs::StyleGeometryBox::ContentBox
                            => Keyword::ContentBox,
                        structs::StyleGeometryBox::PaddingBox
                            => Keyword::PaddingBox,
                        structs::StyleGeometryBox::FillBox
                            => Keyword::FillBox,
                        structs::StyleGeometryBox::StrokeBox
                            => Keyword::StrokeBox,
                        structs::StyleGeometryBox::ViewBox
                            => Keyword::ViewBox,
                        _ => panic!("Found unexpected value in style struct for mask_origin property"),
                    }
                }).collect()
        )
    }


    pub fn copy_mask_position_x_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mPositionXCount;

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }

        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mPosition.horizontal = other.mPosition.horizontal.clone();
        }
        self.mMask.mPositionXCount = count;
    }

    pub fn reset_mask_position_x(&mut self, other: &Self) {
        self.copy_mask_position_x_from(other)
    }

    pub fn clone_mask_position_x(&self)
        -> longhands::mask_position_x::computed_value::T {
        longhands::mask_position_x::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mPositionXCount as usize)
                .map(|position| position.mPosition.horizontal.clone())
                .collect()
        )
    }

    pub fn set_mask_position_x<I>(&mut self,
                                     v: I)
        where I: IntoIterator<Item = longhands::mask_position_x
                                              ::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mPositionXCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask
                                                           .mLayers.iter_mut()) {
            geckolayer.mPosition.horizontal = servo;
        }
    }
    pub fn copy_mask_position_y_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mPositionYCount;

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }

        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mPosition.vertical = other.mPosition.vertical.clone();
        }
        self.mMask.mPositionYCount = count;
    }

    pub fn reset_mask_position_y(&mut self, other: &Self) {
        self.copy_mask_position_y_from(other)
    }

    pub fn clone_mask_position_y(&self)
        -> longhands::mask_position_y::computed_value::T {
        longhands::mask_position_y::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mPositionYCount as usize)
                .map(|position| position.mPosition.vertical.clone())
                .collect()
        )
    }

    pub fn set_mask_position_y<I>(&mut self,
                                     v: I)
        where I: IntoIterator<Item = longhands::mask_position_y
                                              ::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mPositionYCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask
                                                           .mLayers.iter_mut()) {
            geckolayer.mPosition.vertical = servo;
        }
    }

    
    
    pub fn copy_mask_size_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mSizeCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mSize = other.mSize.clone();
        }
        self.mMask.mSizeCount = count;
    }

    pub fn reset_mask_size(&mut self, other: &Self) {
        self.copy_mask_size_from(other)
    }


    pub fn set_mask_size<I>(&mut self, v: I)
        where I: IntoIterator<Item=longhands::mask_size::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;
        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mSizeCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask.mLayers.iter_mut()) {
            geckolayer.mSize = {
                
        servo
    
            };
        }
    }


    pub fn clone_mask_size(&self) -> longhands::mask_size::computed_value::T {
        longhands::mask_size::computed_value::List(
            self.mMask.mLayers.iter().map(|layer| layer.mSize.clone()).collect()
        )
    }

    pub fn copy_mask_image_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;
        unsafe {
            let count = other.mMask.mImageCount;
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);

            for (layer, other) in self.mMask.mLayers.iter_mut()
                                      .zip(other.mMask.mLayers.iter())
                                      .take(count as usize) {
                layer.mImage = other.mImage.clone();
            }
            self.mMask.mImageCount = count;
        }
    }

    pub fn reset_mask_image(&mut self, other: &Self) {
        self.copy_mask_image_from(other)
    }

    #[allow(unused_variables)]
    pub fn set_mask_image<I>(&mut self, images: I)
        where I: IntoIterator<Item = longhands::mask_image::computed_value::single_value::T>,
              I::IntoIter: ExactSizeIterator
    {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let images = images.into_iter();

        unsafe {
            Gecko_EnsureImageLayersLength(
                &mut self.mMask,
                images.len(),
                LayerType::Mask,
            );
        }

        self.mMask.mImageCount = images.len() as u32;
        for (image, geckoimage) in images.zip(self.mMask
                                                  .mLayers.iter_mut()) {
            geckoimage.mImage = image;
        }
    }

    pub fn clone_mask_image(&self) -> longhands::mask_image::computed_value::T {
        longhands::mask_image::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mImageCount as usize)
                .map(|layer| layer.mImage.clone())
                .collect()
        )
    }

    
    pub fn fill_arrays(&mut self) {
        use crate::gecko_bindings::bindings::Gecko_FillAllImageLayers;
        use std::cmp;
        let mut max_len = 1;
            max_len = cmp::max(max_len, self.mMask.mRepeatCount);
            max_len = cmp::max(max_len, self.mMask.mClipCount);
            max_len = cmp::max(max_len, self.mMask.mOriginCount);
            max_len = cmp::max(max_len, self.mMask.mPositionXCount);
            max_len = cmp::max(max_len, self.mMask.mPositionYCount);
            max_len = cmp::max(max_len, self.mMask.mImageCount);
            max_len = cmp::max(max_len, self.mMask.mSizeCount);
            max_len = cmp::max(max_len, self.mMask.mMaskModeCount);
            max_len = cmp::max(max_len, self.mMask.mCompositeCount);
        unsafe {
            // While we could do this manually, we'd need to also manually
            // run all the copy constructors, so we just delegate to gecko
            Gecko_FillAllImageLayers(&mut self.mMask, max_len);
        }
    }

    
    

    
    pub fn copy_mask_mode_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mMaskModeCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mMaskMode = other.mMaskMode.clone();
        }
        self.mMask.mMaskModeCount = count;
    }

    pub fn reset_mask_mode(&mut self, other: &Self) {
        self.copy_mask_mode_from(other)
    }


    pub fn set_mask_mode<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::mask_mode::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::mask_mode::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mMaskModeCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask.mLayers.iter_mut()) {
            geckolayer.mMaskMode = {
                match servo {
                    Keyword::MatchSource =>
                        structs::StyleMaskMode::MatchSource ,
                    Keyword::Alpha =>
                        structs::StyleMaskMode::Alpha ,
                    Keyword::Luminance =>
                        structs::StyleMaskMode::Luminance ,
                }
            };
        }
    }

    pub fn clone_mask_mode(&self) -> longhands::mask_mode::computed_value::T {
        use crate::properties::longhands::mask_mode::single_value::computed_value::T as Keyword;


        longhands::mask_mode::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mMaskModeCount as usize)
                .map(|ref layer| {
                    match layer.mMaskMode {
                        structs::StyleMaskMode::MatchSource
                            => Keyword::MatchSource,
                        structs::StyleMaskMode::Alpha
                            => Keyword::Alpha,
                        structs::StyleMaskMode::Luminance
                            => Keyword::Luminance,
                    }
                }).collect()
        )
    }

    
    

    
    pub fn copy_mask_composite_from(&mut self, other: &Self) {
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let count = other.mMask.mCompositeCount;
        unsafe {
            Gecko_EnsureImageLayersLength(&mut self.mMask,
                                          count as usize,
                                          LayerType::Mask);
        }
        // FIXME(emilio): This may be bogus in the same way as bug 1426246.
        for (layer, other) in self.mMask.mLayers.iter_mut()
                                  .zip(other.mMask.mLayers.iter())
                                  .take(count as usize) {
            layer.mComposite = other.mComposite.clone();
        }
        self.mMask.mCompositeCount = count;
    }

    pub fn reset_mask_composite(&mut self, other: &Self) {
        self.copy_mask_composite_from(other)
    }


    pub fn set_mask_composite<I>(&mut self, v: I)
    where
        I: IntoIterator<Item=longhands::mask_composite::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator,
    {
        use crate::properties::longhands::mask_composite::single_value::computed_value::T as Keyword;
        use crate::gecko_bindings::structs::nsStyleImageLayers_LayerType as LayerType;

        let v = v.into_iter();

        unsafe {
          Gecko_EnsureImageLayersLength(&mut self.mMask, v.len(),
                                        LayerType::Mask);
        }

        self.mMask.mCompositeCount = v.len() as u32;
        for (servo, geckolayer) in v.zip(self.mMask.mLayers.iter_mut()) {
            geckolayer.mComposite = {
                match servo {
                    Keyword::Add =>
                        structs::StyleMaskComposite::Add ,
                    Keyword::Subtract =>
                        structs::StyleMaskComposite::Subtract ,
                    Keyword::Intersect =>
                        structs::StyleMaskComposite::Intersect ,
                    Keyword::Exclude =>
                        structs::StyleMaskComposite::Exclude ,
                }
            };
        }
    }

    pub fn clone_mask_composite(&self) -> longhands::mask_composite::computed_value::T {
        use crate::properties::longhands::mask_composite::single_value::computed_value::T as Keyword;


        longhands::mask_composite::computed_value::List(
            self.mMask.mLayers.iter()
                .take(self.mMask.mCompositeCount as usize)
                .map(|ref layer| {
                    match layer.mComposite {
                        structs::StyleMaskComposite::Add
                            => Keyword::Add,
                        structs::StyleMaskComposite::Subtract
                            => Keyword::Subtract,
                        structs::StyleMaskComposite::Intersect
                            => Keyword::Intersect,
                        structs::StyleMaskComposite::Exclude
                            => Keyword::Exclude,
                    }
                }).collect()
        )
    }



    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_vector_effect(&mut self, v: longhands::vector_effect::computed_value::T) {
        use crate::properties::longhands::vector_effect::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::None =>
                    structs::StyleVectorEffect::None ,
                Keyword::NonScalingStroke =>
                    structs::StyleVectorEffect::NonScalingStroke ,
        };
        self.mVectorEffect = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_vector_effect_from(&mut self, other: &Self) {
        self.mVectorEffect = other.mVectorEffect.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_vector_effect(&mut self, other: &Self) {
        self.copy_vector_effect_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_vector_effect(&self) -> longhands::vector_effect::computed_value::T {
        use crate::properties::longhands::vector_effect::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mVectorEffect {
            structs::StyleVectorEffect::None => Keyword::None,
            structs::StyleVectorEffect::NonScalingStroke => Keyword::NonScalingStroke,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_stop_color(&mut self, v: longhands::stop_color::computed_value::T) {
        self.mStopColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stop_color_from(&mut self, other: &Self) {
        self.mStopColor = other.mStopColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stop_color(&mut self, other: &Self) {
        self.copy_stop_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stop_color(&self) -> longhands::stop_color::computed_value::T {
        From::from(self.mStopColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_stop_opacity(&mut self, v: longhands::stop_opacity::computed_value::T) {
        self.mStopOpacity = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stop_opacity_from(&mut self, other: &Self) {
        self.mStopOpacity = other.mStopOpacity.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stop_opacity(&mut self, other: &Self) {
        self.copy_stop_opacity_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stop_opacity(&self) -> longhands::stop_opacity::computed_value::T {
        From::from(self.mStopOpacity.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_flood_color(&mut self, v: longhands::flood_color::computed_value::T) {
        self.mFloodColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_flood_color_from(&mut self, other: &Self) {
        self.mFloodColor = other.mFloodColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_flood_color(&mut self, other: &Self) {
        self.copy_flood_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_flood_color(&self) -> longhands::flood_color::computed_value::T {
        From::from(self.mFloodColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_flood_opacity(&mut self, v: longhands::flood_opacity::computed_value::T) {
        self.mFloodOpacity = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_flood_opacity_from(&mut self, other: &Self) {
        self.mFloodOpacity = other.mFloodOpacity.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_flood_opacity(&mut self, other: &Self) {
        self.copy_flood_opacity_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_flood_opacity(&self) -> longhands::flood_opacity::computed_value::T {
        From::from(self.mFloodOpacity.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_lighting_color(&mut self, v: longhands::lighting_color::computed_value::T) {
        self.mLightingColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_lighting_color_from(&mut self, other: &Self) {
        self.mLightingColor = other.mLightingColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_lighting_color(&mut self, other: &Self) {
        self.copy_lighting_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_lighting_color(&self) -> longhands::lighting_color::computed_value::T {
        From::from(self.mLightingColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_mask_type(&mut self, v: longhands::mask_type::computed_value::T) {
        use crate::properties::longhands::mask_type::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Luminance =>
                    structs::StyleMaskType::Luminance ,
                Keyword::Alpha =>
                    structs::StyleMaskType::Alpha ,
        };
        self.mMaskType = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_mask_type_from(&mut self, other: &Self) {
        self.mMaskType = other.mMaskType.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_mask_type(&mut self, other: &Self) {
        self.copy_mask_type_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_mask_type(&self) -> longhands::mask_type::computed_value::T {
        use crate::properties::longhands::mask_type::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mMaskType {
            structs::StyleMaskType::Luminance => Keyword::Luminance,
            structs::StyleMaskType::Alpha => Keyword::Alpha,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_clip_path(&mut self, v: longhands::clip_path::computed_value::T) {
        self.mClipPath = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_clip_path_from(&mut self, other: &Self) {
        self.mClipPath = other.mClipPath.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_clip_path(&mut self, other: &Self) {
        self.copy_clip_path_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_clip_path(&self) -> longhands::clip_path::computed_value::T {
        From::from(self.mClipPath.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_x(&mut self, v: longhands::x::computed_value::T) {
        self.mX = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_x_from(&mut self, other: &Self) {
        self.mX = other.mX.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_x(&mut self, other: &Self) {
        self.copy_x_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_x(&self) -> longhands::x::computed_value::T {
        From::from(self.mX.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_y(&mut self, v: longhands::y::computed_value::T) {
        self.mY = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_y_from(&mut self, other: &Self) {
        self.mY = other.mY.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_y(&mut self, other: &Self) {
        self.copy_y_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_y(&self) -> longhands::y::computed_value::T {
        From::from(self.mY.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_cx(&mut self, v: longhands::cx::computed_value::T) {
        self.mCx = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_cx_from(&mut self, other: &Self) {
        self.mCx = other.mCx.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_cx(&mut self, other: &Self) {
        self.copy_cx_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_cx(&self) -> longhands::cx::computed_value::T {
        From::from(self.mCx.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_cy(&mut self, v: longhands::cy::computed_value::T) {
        self.mCy = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_cy_from(&mut self, other: &Self) {
        self.mCy = other.mCy.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_cy(&mut self, other: &Self) {
        self.copy_cy_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_cy(&self) -> longhands::cy::computed_value::T {
        From::from(self.mCy.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_rx(&mut self, v: longhands::rx::computed_value::T) {
        self.mRx = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_rx_from(&mut self, other: &Self) {
        self.mRx = other.mRx.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_rx(&mut self, other: &Self) {
        self.copy_rx_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_rx(&self) -> longhands::rx::computed_value::T {
        From::from(self.mRx.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_ry(&mut self, v: longhands::ry::computed_value::T) {
        self.mRy = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_ry_from(&mut self, other: &Self) {
        self.mRy = other.mRy.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_ry(&mut self, other: &Self) {
        self.copy_ry_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_ry(&self) -> longhands::ry::computed_value::T {
        From::from(self.mRy.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_r(&mut self, v: longhands::r::computed_value::T) {
        self.mR = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_r_from(&mut self, other: &Self) {
        self.mR = other.mR.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_r(&mut self, other: &Self) {
        self.copy_r_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_r(&self) -> longhands::r::computed_value::T {
        From::from(self.mR.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_d(&mut self, v: longhands::d::computed_value::T) {
        self.mD = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_d_from(&mut self, other: &Self) {
        self.mD = other.mD.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_d(&mut self, other: &Self) {
        self.copy_d_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_d(&self) -> longhands::d::computed_value::T {
        From::from(self.mD.clone())
    }


}




impl GeckoInheritedSVG {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_dominant_baseline(&mut self, v: longhands::dominant_baseline::computed_value::T) {
        use crate::properties::longhands::dominant_baseline::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleDominantBaseline::Auto ,
                Keyword::Ideographic =>
                    structs::StyleDominantBaseline::Ideographic ,
                Keyword::Alphabetic =>
                    structs::StyleDominantBaseline::Alphabetic ,
                Keyword::Hanging =>
                    structs::StyleDominantBaseline::Hanging ,
                Keyword::Mathematical =>
                    structs::StyleDominantBaseline::Mathematical ,
                Keyword::Central =>
                    structs::StyleDominantBaseline::Central ,
                Keyword::Middle =>
                    structs::StyleDominantBaseline::Middle ,
                Keyword::TextAfterEdge =>
                    structs::StyleDominantBaseline::TextAfterEdge ,
                Keyword::TextBeforeEdge =>
                    structs::StyleDominantBaseline::TextBeforeEdge ,
        };
        self.mDominantBaseline = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_dominant_baseline_from(&mut self, other: &Self) {
        self.mDominantBaseline = other.mDominantBaseline.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_dominant_baseline(&mut self, other: &Self) {
        self.copy_dominant_baseline_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_dominant_baseline(&self) -> longhands::dominant_baseline::computed_value::T {
        use crate::properties::longhands::dominant_baseline::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mDominantBaseline {
            structs::StyleDominantBaseline::Auto => Keyword::Auto,
            structs::StyleDominantBaseline::Ideographic => Keyword::Ideographic,
            structs::StyleDominantBaseline::Alphabetic => Keyword::Alphabetic,
            structs::StyleDominantBaseline::Hanging => Keyword::Hanging,
            structs::StyleDominantBaseline::Mathematical => Keyword::Mathematical,
            structs::StyleDominantBaseline::Central => Keyword::Central,
            structs::StyleDominantBaseline::Middle => Keyword::Middle,
            structs::StyleDominantBaseline::TextAfterEdge => Keyword::TextAfterEdge,
            structs::StyleDominantBaseline::TextBeforeEdge => Keyword::TextBeforeEdge,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_text_anchor(&mut self, v: longhands::text_anchor::computed_value::T) {
        use crate::properties::longhands::text_anchor::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Start =>
                    structs::StyleTextAnchor::Start ,
                Keyword::Middle =>
                    structs::StyleTextAnchor::Middle ,
                Keyword::End =>
                    structs::StyleTextAnchor::End ,
        };
        self.mTextAnchor = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_text_anchor_from(&mut self, other: &Self) {
        self.mTextAnchor = other.mTextAnchor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_text_anchor(&mut self, other: &Self) {
        self.copy_text_anchor_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_text_anchor(&self) -> longhands::text_anchor::computed_value::T {
        use crate::properties::longhands::text_anchor::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mTextAnchor {
            structs::StyleTextAnchor::Start => Keyword::Start,
            structs::StyleTextAnchor::Middle => Keyword::Middle,
            structs::StyleTextAnchor::End => Keyword::End,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_color_interpolation(&mut self, v: longhands::color_interpolation::computed_value::T) {
        use crate::properties::longhands::color_interpolation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Srgb =>
                    structs::StyleColorInterpolation::Srgb ,
                Keyword::Auto =>
                    structs::StyleColorInterpolation::Auto ,
                Keyword::Linearrgb =>
                    structs::StyleColorInterpolation::Linearrgb ,
        };
        self.mColorInterpolation = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_color_interpolation_from(&mut self, other: &Self) {
        self.mColorInterpolation = other.mColorInterpolation.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_color_interpolation(&mut self, other: &Self) {
        self.copy_color_interpolation_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_color_interpolation(&self) -> longhands::color_interpolation::computed_value::T {
        use crate::properties::longhands::color_interpolation::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mColorInterpolation {
            structs::StyleColorInterpolation::Srgb => Keyword::Srgb,
            structs::StyleColorInterpolation::Auto => Keyword::Auto,
            structs::StyleColorInterpolation::Linearrgb => Keyword::Linearrgb,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_color_interpolation_filters(&mut self, v: longhands::color_interpolation_filters::computed_value::T) {
        use crate::properties::longhands::color_interpolation_filters::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Linearrgb =>
                    structs::StyleColorInterpolation::Linearrgb ,
                Keyword::Auto =>
                    structs::StyleColorInterpolation::Auto ,
                Keyword::Srgb =>
                    structs::StyleColorInterpolation::Srgb ,
        };
        self.mColorInterpolationFilters = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_color_interpolation_filters_from(&mut self, other: &Self) {
        self.mColorInterpolationFilters = other.mColorInterpolationFilters.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_color_interpolation_filters(&mut self, other: &Self) {
        self.copy_color_interpolation_filters_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_color_interpolation_filters(&self) -> longhands::color_interpolation_filters::computed_value::T {
        use crate::properties::longhands::color_interpolation_filters::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mColorInterpolationFilters {
            structs::StyleColorInterpolation::Linearrgb => Keyword::Linearrgb,
            structs::StyleColorInterpolation::Auto => Keyword::Auto,
            structs::StyleColorInterpolation::Srgb => Keyword::Srgb,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_fill(&mut self, v: longhands::fill::computed_value::T) {
        self.mFill = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_fill_from(&mut self, other: &Self) {
        self.mFill = other.mFill.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_fill(&mut self, other: &Self) {
        self.copy_fill_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_fill(&self) -> longhands::fill::computed_value::T {
        From::from(self.mFill.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_fill_opacity(&mut self, v: longhands::fill_opacity::computed_value::T) {
        self.mFillOpacity = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_fill_opacity_from(&mut self, other: &Self) {
        self.mFillOpacity = other.mFillOpacity.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_fill_opacity(&mut self, other: &Self) {
        self.copy_fill_opacity_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_fill_opacity(&self) -> longhands::fill_opacity::computed_value::T {
        From::from(self.mFillOpacity.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_fill_rule(&mut self, v: longhands::fill_rule::computed_value::T) {
        self.mFillRule = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_fill_rule_from(&mut self, other: &Self) {
        self.mFillRule = other.mFillRule.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_fill_rule(&mut self, other: &Self) {
        self.copy_fill_rule_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_fill_rule(&self) -> longhands::fill_rule::computed_value::T {
        From::from(self.mFillRule.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_shape_rendering(&mut self, v: longhands::shape_rendering::computed_value::T) {
        use crate::properties::longhands::shape_rendering::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleShapeRendering::Auto ,
                Keyword::Optimizespeed =>
                    structs::StyleShapeRendering::Optimizespeed ,
                Keyword::Crispedges =>
                    structs::StyleShapeRendering::Crispedges ,
                Keyword::Geometricprecision =>
                    structs::StyleShapeRendering::Geometricprecision ,
        };
        self.mShapeRendering = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_shape_rendering_from(&mut self, other: &Self) {
        self.mShapeRendering = other.mShapeRendering.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_shape_rendering(&mut self, other: &Self) {
        self.copy_shape_rendering_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_shape_rendering(&self) -> longhands::shape_rendering::computed_value::T {
        use crate::properties::longhands::shape_rendering::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mShapeRendering {
            structs::StyleShapeRendering::Auto => Keyword::Auto,
            structs::StyleShapeRendering::Optimizespeed => Keyword::Optimizespeed,
            structs::StyleShapeRendering::Crispedges => Keyword::Crispedges,
            structs::StyleShapeRendering::Geometricprecision => Keyword::Geometricprecision,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_stroke(&mut self, v: longhands::stroke::computed_value::T) {
        self.mStroke = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_from(&mut self, other: &Self) {
        self.mStroke = other.mStroke.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke(&mut self, other: &Self) {
        self.copy_stroke_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke(&self) -> longhands::stroke::computed_value::T {
        From::from(self.mStroke.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_stroke_width(&mut self, v: longhands::stroke_width::computed_value::T) {
        self.mStrokeWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_width_from(&mut self, other: &Self) {
        self.mStrokeWidth = other.mStrokeWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke_width(&mut self, other: &Self) {
        self.copy_stroke_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke_width(&self) -> longhands::stroke_width::computed_value::T {
        From::from(self.mStrokeWidth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_stroke_linecap(&mut self, v: longhands::stroke_linecap::computed_value::T) {
        use crate::properties::longhands::stroke_linecap::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Butt =>
                    structs::StyleStrokeLinecap::Butt ,
                Keyword::Round =>
                    structs::StyleStrokeLinecap::Round ,
                Keyword::Square =>
                    structs::StyleStrokeLinecap::Square ,
        };
        self.mStrokeLinecap = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_linecap_from(&mut self, other: &Self) {
        self.mStrokeLinecap = other.mStrokeLinecap.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke_linecap(&mut self, other: &Self) {
        self.copy_stroke_linecap_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke_linecap(&self) -> longhands::stroke_linecap::computed_value::T {
        use crate::properties::longhands::stroke_linecap::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mStrokeLinecap {
            structs::StyleStrokeLinecap::Butt => Keyword::Butt,
            structs::StyleStrokeLinecap::Round => Keyword::Round,
            structs::StyleStrokeLinecap::Square => Keyword::Square,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_stroke_linejoin(&mut self, v: longhands::stroke_linejoin::computed_value::T) {
        use crate::properties::longhands::stroke_linejoin::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Miter =>
                    structs::StyleStrokeLinejoin::Miter ,
                Keyword::Round =>
                    structs::StyleStrokeLinejoin::Round ,
                Keyword::Bevel =>
                    structs::StyleStrokeLinejoin::Bevel ,
        };
        self.mStrokeLinejoin = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_linejoin_from(&mut self, other: &Self) {
        self.mStrokeLinejoin = other.mStrokeLinejoin.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke_linejoin(&mut self, other: &Self) {
        self.copy_stroke_linejoin_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke_linejoin(&self) -> longhands::stroke_linejoin::computed_value::T {
        use crate::properties::longhands::stroke_linejoin::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mStrokeLinejoin {
            structs::StyleStrokeLinejoin::Miter => Keyword::Miter,
            structs::StyleStrokeLinejoin::Round => Keyword::Round,
            structs::StyleStrokeLinejoin::Bevel => Keyword::Bevel,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_stroke_miterlimit(&mut self, v: longhands::stroke_miterlimit::computed_value::T) {
        self.mStrokeMiterlimit = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_miterlimit_from(&mut self, other: &Self) {
        self.mStrokeMiterlimit = other.mStrokeMiterlimit.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke_miterlimit(&mut self, other: &Self) {
        self.copy_stroke_miterlimit_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke_miterlimit(&self) -> longhands::stroke_miterlimit::computed_value::T {
        From::from(self.mStrokeMiterlimit.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_stroke_opacity(&mut self, v: longhands::stroke_opacity::computed_value::T) {
        self.mStrokeOpacity = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_opacity_from(&mut self, other: &Self) {
        self.mStrokeOpacity = other.mStrokeOpacity.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke_opacity(&mut self, other: &Self) {
        self.copy_stroke_opacity_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke_opacity(&self) -> longhands::stroke_opacity::computed_value::T {
        From::from(self.mStrokeOpacity.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_stroke_dasharray(&mut self, v: longhands::stroke_dasharray::computed_value::T) {
        self.mStrokeDasharray = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_dasharray_from(&mut self, other: &Self) {
        self.mStrokeDasharray = other.mStrokeDasharray.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke_dasharray(&mut self, other: &Self) {
        self.copy_stroke_dasharray_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke_dasharray(&self) -> longhands::stroke_dasharray::computed_value::T {
        From::from(self.mStrokeDasharray.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_stroke_dashoffset(&mut self, v: longhands::stroke_dashoffset::computed_value::T) {
        self.mStrokeDashoffset = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_stroke_dashoffset_from(&mut self, other: &Self) {
        self.mStrokeDashoffset = other.mStrokeDashoffset.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_stroke_dashoffset(&mut self, other: &Self) {
        self.copy_stroke_dashoffset_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_stroke_dashoffset(&self) -> longhands::stroke_dashoffset::computed_value::T {
        From::from(self.mStrokeDashoffset.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_clip_rule(&mut self, v: longhands::clip_rule::computed_value::T) {
        self.mClipRule = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_clip_rule_from(&mut self, other: &Self) {
        self.mClipRule = other.mClipRule.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_clip_rule(&mut self, other: &Self) {
        self.copy_clip_rule_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_clip_rule(&self) -> longhands::clip_rule::computed_value::T {
        From::from(self.mClipRule.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_marker_start(&mut self, v: longhands::marker_start::computed_value::T) {
        self.mMarkerStart = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_marker_start_from(&mut self, other: &Self) {
        self.mMarkerStart = other.mMarkerStart.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_marker_start(&mut self, other: &Self) {
        self.copy_marker_start_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_marker_start(&self) -> longhands::marker_start::computed_value::T {
        From::from(self.mMarkerStart.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_marker_mid(&mut self, v: longhands::marker_mid::computed_value::T) {
        self.mMarkerMid = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_marker_mid_from(&mut self, other: &Self) {
        self.mMarkerMid = other.mMarkerMid.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_marker_mid(&mut self, other: &Self) {
        self.copy_marker_mid_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_marker_mid(&self) -> longhands::marker_mid::computed_value::T {
        From::from(self.mMarkerMid.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_marker_end(&mut self, v: longhands::marker_end::computed_value::T) {
        self.mMarkerEnd = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_marker_end_from(&mut self, other: &Self) {
        self.mMarkerEnd = other.mMarkerEnd.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_marker_end(&mut self, other: &Self) {
        self.copy_marker_end_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_marker_end(&self) -> longhands::marker_end::computed_value::T {
        From::from(self.mMarkerEnd.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_paint_order(&mut self, v: longhands::paint_order::computed_value::T) {
        self.mPaintOrder = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_paint_order_from(&mut self, other: &Self) {
        self.mPaintOrder = other.mPaintOrder.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_paint_order(&mut self, other: &Self) {
        self.copy_paint_order_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_paint_order(&self) -> longhands::paint_order::computed_value::T {
        From::from(self.mPaintOrder.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_context_properties(&mut self, v: longhands::_moz_context_properties::computed_value::T) {
        self.mMozContextProperties = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_context_properties_from(&mut self, other: &Self) {
        self.mMozContextProperties = other.mMozContextProperties.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_context_properties(&mut self, other: &Self) {
        self.copy__moz_context_properties_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_context_properties(&self) -> longhands::_moz_context_properties::computed_value::T {
        From::from(self.mMozContextProperties.clone())
    }


}




impl GeckoInheritedUI {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_cursor(&mut self, v: longhands::cursor::computed_value::T) {
        self.mCursor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_cursor_from(&mut self, other: &Self) {
        self.mCursor = other.mCursor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_cursor(&mut self, other: &Self) {
        self.copy_cursor_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_cursor(&self) -> longhands::cursor::computed_value::T {
        From::from(self.mCursor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_pointer_events(&mut self, v: longhands::pointer_events::computed_value::T) {
        use crate::properties::longhands::pointer_events::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StylePointerEvents::Auto ,
                Keyword::None =>
                    structs::StylePointerEvents::None ,
                Keyword::Visiblepainted =>
                    structs::StylePointerEvents::Visiblepainted ,
                Keyword::Visiblefill =>
                    structs::StylePointerEvents::Visiblefill ,
                Keyword::Visiblestroke =>
                    structs::StylePointerEvents::Visiblestroke ,
                Keyword::Visible =>
                    structs::StylePointerEvents::Visible ,
                Keyword::Painted =>
                    structs::StylePointerEvents::Painted ,
                Keyword::Fill =>
                    structs::StylePointerEvents::Fill ,
                Keyword::Stroke =>
                    structs::StylePointerEvents::Stroke ,
                Keyword::All =>
                    structs::StylePointerEvents::All ,
        };
        self.mPointerEvents = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_pointer_events_from(&mut self, other: &Self) {
        self.mPointerEvents = other.mPointerEvents.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_pointer_events(&mut self, other: &Self) {
        self.copy_pointer_events_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_pointer_events(&self) -> longhands::pointer_events::computed_value::T {
        use crate::properties::longhands::pointer_events::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mPointerEvents {
            structs::StylePointerEvents::Auto => Keyword::Auto,
            structs::StylePointerEvents::None => Keyword::None,
            structs::StylePointerEvents::Visiblepainted => Keyword::Visiblepainted,
            structs::StylePointerEvents::Visiblefill => Keyword::Visiblefill,
            structs::StylePointerEvents::Visiblestroke => Keyword::Visiblestroke,
            structs::StylePointerEvents::Visible => Keyword::Visible,
            structs::StylePointerEvents::Painted => Keyword::Painted,
            structs::StylePointerEvents::Fill => Keyword::Fill,
            structs::StylePointerEvents::Stroke => Keyword::Stroke,
            structs::StylePointerEvents::All => Keyword::All,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_inert(&mut self, v: longhands::_moz_inert::computed_value::T) {
        use crate::properties::longhands::_moz_inert::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::None =>
                    structs::StyleInert::None ,
                Keyword::Inert =>
                    structs::StyleInert::Inert ,
        };
        self.mInert = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_inert_from(&mut self, other: &Self) {
        self.mInert = other.mInert.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_inert(&mut self, other: &Self) {
        self.copy__moz_inert_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_inert(&self) -> longhands::_moz_inert::computed_value::T {
        use crate::properties::longhands::_moz_inert::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mInert {
            structs::StyleInert::None => Keyword::None,
            structs::StyleInert::Inert => Keyword::Inert,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_user_input(&mut self, v: longhands::_moz_user_input::computed_value::T) {
        use crate::properties::longhands::_moz_user_input::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleUserInput::Auto ,
                Keyword::None =>
                    structs::StyleUserInput::None ,
        };
        self.mUserInput = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_user_input_from(&mut self, other: &Self) {
        self.mUserInput = other.mUserInput.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_user_input(&mut self, other: &Self) {
        self.copy__moz_user_input_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_user_input(&self) -> longhands::_moz_user_input::computed_value::T {
        use crate::properties::longhands::_moz_user_input::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mUserInput {
            structs::StyleUserInput::Auto => Keyword::Auto,
            structs::StyleUserInput::None => Keyword::None,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_user_modify(&mut self, v: longhands::_moz_user_modify::computed_value::T) {
        use crate::properties::longhands::_moz_user_modify::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::ReadOnly =>
                    structs::StyleUserModify::ReadOnly ,
                Keyword::ReadWrite =>
                    structs::StyleUserModify::ReadWrite ,
                Keyword::WriteOnly =>
                    structs::StyleUserModify::WriteOnly ,
        };
        self.mUserModify = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_user_modify_from(&mut self, other: &Self) {
        self.mUserModify = other.mUserModify.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_user_modify(&mut self, other: &Self) {
        self.copy__moz_user_modify_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_user_modify(&self) -> longhands::_moz_user_modify::computed_value::T {
        use crate::properties::longhands::_moz_user_modify::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mUserModify {
            structs::StyleUserModify::ReadOnly => Keyword::ReadOnly,
            structs::StyleUserModify::ReadWrite => Keyword::ReadWrite,
            structs::StyleUserModify::WriteOnly => Keyword::WriteOnly,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_user_focus(&mut self, v: longhands::_moz_user_focus::computed_value::T) {
        use crate::properties::longhands::_moz_user_focus::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::StyleUserFocus::Normal ,
                Keyword::None =>
                    structs::StyleUserFocus::None ,
                Keyword::Ignore =>
                    structs::StyleUserFocus::Ignore ,
        };
        self.mUserFocus = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_user_focus_from(&mut self, other: &Self) {
        self.mUserFocus = other.mUserFocus.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_user_focus(&mut self, other: &Self) {
        self.copy__moz_user_focus_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_user_focus(&self) -> longhands::_moz_user_focus::computed_value::T {
        use crate::properties::longhands::_moz_user_focus::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mUserFocus {
            structs::StyleUserFocus::Normal => Keyword::Normal,
            structs::StyleUserFocus::None => Keyword::None,
            structs::StyleUserFocus::Ignore => Keyword::Ignore,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_caret_color(&mut self, v: longhands::caret_color::computed_value::T) {
        self.mCaretColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_caret_color_from(&mut self, other: &Self) {
        self.mCaretColor = other.mCaretColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_caret_color(&mut self, other: &Self) {
        self.copy_caret_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_caret_color(&self) -> longhands::caret_color::computed_value::T {
        From::from(self.mCaretColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_accent_color(&mut self, v: longhands::accent_color::computed_value::T) {
        self.mAccentColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_accent_color_from(&mut self, other: &Self) {
        self.mAccentColor = other.mAccentColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_accent_color(&mut self, other: &Self) {
        self.copy_accent_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_accent_color(&self) -> longhands::accent_color::computed_value::T {
        From::from(self.mAccentColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_color_scheme(&mut self, v: longhands::color_scheme::computed_value::T) {
        self.mColorScheme = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_color_scheme_from(&mut self, other: &Self) {
        self.mColorScheme = other.mColorScheme.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_color_scheme(&mut self, other: &Self) {
        self.copy_color_scheme_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_color_scheme(&self) -> longhands::color_scheme::computed_value::T {
        From::from(self.mColorScheme.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_scrollbar_color(&mut self, v: longhands::scrollbar_color::computed_value::T) {
        self.mScrollbarColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_scrollbar_color_from(&mut self, other: &Self) {
        self.mScrollbarColor = other.mScrollbarColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scrollbar_color(&mut self, other: &Self) {
        self.copy_scrollbar_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scrollbar_color(&self) -> longhands::scrollbar_color::computed_value::T {
        From::from(self.mScrollbarColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_theme(&mut self, v: longhands::_moz_theme::computed_value::T) {
        self.mMozTheme = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_theme_from(&mut self, other: &Self) {
        self.mMozTheme = other.mMozTheme.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_theme(&mut self, other: &Self) {
        self.copy__moz_theme_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_theme(&self) -> longhands::_moz_theme::computed_value::T {
        From::from(self.mMozTheme.clone())
    }


}




impl GeckoColumn {
    /*
     * Manually-Implemented Methods.
     */
    
    pub fn set_column_rule_style(&mut self, v: longhands::column_rule_style::computed_value::T) {
        self.mColumnRuleStyle = v;
        // NB: This is needed to correctly handling the initial value of
        // column-rule-width when colun-rule-style changes, see the
        // update_border_left comment for more details.
        self.mActualColumnRuleWidth = self.mColumnRuleWidth;
    }

    pub fn copy_column_rule_style_from(&mut self, other: &Self) {
        self.set_column_rule_style(other.mColumnRuleStyle);
    }

    pub fn reset_column_rule_style(&mut self, other: &Self) {
        self.copy_column_rule_style_from(other)
    }

    pub fn clone_column_rule_style(&self) -> longhands::column_rule_style::computed_value::T {
        self.mColumnRuleStyle.clone()
    }

    
    #[allow(non_snake_case)]
    pub fn set_column_rule_width(&mut self, v: Au) {
        let value = v.0;
        self.mColumnRuleWidth = value;
        self.mActualColumnRuleWidth = value;
    }

    #[allow(non_snake_case)]
    pub fn copy_column_rule_width_from(&mut self, other: &Self) {
        self.mColumnRuleWidth = other.mColumnRuleWidth;
        // NOTE: This is needed to easily handle the `unset` and `initial`
        // keywords, which are implemented calling this function.
        //
        // In practice, this means that we may have an incorrect value here, but
        // we'll adjust that properly in the style fixup phase.
        //
        // FIXME(emilio): We could clean this up a bit special-casing the reset_
        // function below.
        self.mActualColumnRuleWidth = other.mColumnRuleWidth;
    }

    #[allow(non_snake_case)]
    pub fn reset_column_rule_width(&mut self, other: &Self) {
        self.copy_column_rule_width_from(other)
    }

    #[allow(non_snake_case)]
    pub fn clone_column_rule_width(&self) -> Au {
        Au(self.mActualColumnRuleWidth)
    }


    pub fn column_rule_has_nonzero_width(&self) -> bool {
        self.mActualColumnRuleWidth != 0
    }


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_column_width(&mut self, v: longhands::column_width::computed_value::T) {
        self.mColumnWidth = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_column_width_from(&mut self, other: &Self) {
        self.mColumnWidth = other.mColumnWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_column_width(&mut self, other: &Self) {
        self.copy_column_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_column_width(&self) -> longhands::column_width::computed_value::T {
        From::from(self.mColumnWidth.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_column_count(&mut self, v: longhands::column_count::computed_value::T) {
        self.mColumnCount = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_column_count_from(&mut self, other: &Self) {
        self.mColumnCount = other.mColumnCount.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_column_count(&mut self, other: &Self) {
        self.copy_column_count_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_column_count(&self) -> longhands::column_count::computed_value::T {
        From::from(self.mColumnCount.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_column_fill(&mut self, v: longhands::column_fill::computed_value::T) {
        use crate::properties::longhands::column_fill::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Balance =>
                    structs::StyleColumnFill::Balance ,
                Keyword::Auto =>
                    structs::StyleColumnFill::Auto ,
        };
        self.mColumnFill = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_column_fill_from(&mut self, other: &Self) {
        self.mColumnFill = other.mColumnFill.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_column_fill(&mut self, other: &Self) {
        self.copy_column_fill_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_column_fill(&self) -> longhands::column_fill::computed_value::T {
        use crate::properties::longhands::column_fill::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mColumnFill {
            structs::StyleColumnFill::Balance => Keyword::Balance,
            structs::StyleColumnFill::Auto => Keyword::Auto,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_column_rule_color(&mut self, v: longhands::column_rule_color::computed_value::T) {
        self.mColumnRuleColor = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_column_rule_color_from(&mut self, other: &Self) {
        self.mColumnRuleColor = other.mColumnRuleColor.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_column_rule_color(&mut self, other: &Self) {
        self.copy_column_rule_color_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_column_rule_color(&self) -> longhands::column_rule_color::computed_value::T {
        From::from(self.mColumnRuleColor.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_column_span(&mut self, v: longhands::column_span::computed_value::T) {
        use crate::properties::longhands::column_span::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::None =>
                    structs::StyleColumnSpan::None ,
                Keyword::All =>
                    structs::StyleColumnSpan::All ,
        };
        self.mColumnSpan = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_column_span_from(&mut self, other: &Self) {
        self.mColumnSpan = other.mColumnSpan.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_column_span(&mut self, other: &Self) {
        self.copy_column_span_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_column_span(&self) -> longhands::column_span::computed_value::T {
        use crate::properties::longhands::column_span::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mColumnSpan {
            structs::StyleColumnSpan::None => Keyword::None,
            structs::StyleColumnSpan::All => Keyword::All,
        }
    }


}




impl GeckoCounters {
    /*
     * Manually-Implemented Methods.
     */
    
    pub fn ineffective_content_property(&self) -> bool {
        !self.mContent.is_items()
    }


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_content(&mut self, v: longhands::content::computed_value::T) {
        self.mContent = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_content_from(&mut self, other: &Self) {
        self.mContent = other.mContent.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_content(&mut self, other: &Self) {
        self.copy_content_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_content(&self) -> longhands::content::computed_value::T {
        From::from(self.mContent.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_counter_increment(&mut self, v: longhands::counter_increment::computed_value::T) {
        self.mCounterIncrement = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_counter_increment_from(&mut self, other: &Self) {
        self.mCounterIncrement = other.mCounterIncrement.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_counter_increment(&mut self, other: &Self) {
        self.copy_counter_increment_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_counter_increment(&self) -> longhands::counter_increment::computed_value::T {
        From::from(self.mCounterIncrement.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_counter_reset(&mut self, v: longhands::counter_reset::computed_value::T) {
        self.mCounterReset = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_counter_reset_from(&mut self, other: &Self) {
        self.mCounterReset = other.mCounterReset.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_counter_reset(&mut self, other: &Self) {
        self.copy_counter_reset_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_counter_reset(&self) -> longhands::counter_reset::computed_value::T {
        From::from(self.mCounterReset.clone())
    }



    #[allow(non_snake_case)]
    pub fn set_counter_set(&mut self, v: longhands::counter_set::computed_value::T) {
        self.mCounterSet = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_counter_set_from(&mut self, other: &Self) {
        self.mCounterSet = other.mCounterSet.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_counter_set(&mut self, other: &Self) {
        self.copy_counter_set_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_counter_set(&self) -> longhands::counter_set::computed_value::T {
        From::from(self.mCounterSet.clone())
    }


}






impl GeckoUI {
    /*
     * Manually-Implemented Methods.
     */
    
    
    #[allow(non_snake_case)]
    pub fn set_transition_behavior<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::transition_behavior::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mTransitions.ensure_len(input_len);

        self.mTransitionBehaviorCount = input_len as u32;
        for (gecko, servo) in self.mTransitions.iter_mut().take(input_len as usize).zip(v) {
            gecko.mBehavior = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn transition_behavior_at(&self, index: usize)
        -> longhands::transition_behavior::computed_value::SingleComputedValue {
        self.mTransitions[index % self.transition_behavior_count()].mBehavior.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_transition_behavior_from(&mut self, other: &Self) {
        self.mTransitions.ensure_len(other.mTransitions.len());

        let count = other.mTransitionBehaviorCount;
        self.mTransitionBehaviorCount = count;

        let iter = self.mTransitions.iter_mut().take(count as usize).zip(
            other.mTransitions.iter()
        );

        for (ours, others) in iter {
            ours.mBehavior = others.mBehavior.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_transition_behavior(&mut self, other: &Self) {
        self.copy_transition_behavior_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn transition_behavior_count(&self) -> usize {
        self.mTransitionBehaviorCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_transition_delay<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::transition_delay::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mTransitions.ensure_len(input_len);

        self.mTransitionDelayCount = input_len as u32;
        for (gecko, servo) in self.mTransitions.iter_mut().take(input_len as usize).zip(v) {
            gecko.mDelay = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn transition_delay_at(&self, index: usize)
        -> longhands::transition_delay::computed_value::SingleComputedValue {
        self.mTransitions[index % self.transition_delay_count()].mDelay.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_transition_delay_from(&mut self, other: &Self) {
        self.mTransitions.ensure_len(other.mTransitions.len());

        let count = other.mTransitionDelayCount;
        self.mTransitionDelayCount = count;

        let iter = self.mTransitions.iter_mut().take(count as usize).zip(
            other.mTransitions.iter()
        );

        for (ours, others) in iter {
            ours.mDelay = others.mDelay.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_transition_delay(&mut self, other: &Self) {
        self.copy_transition_delay_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn transition_delay_count(&self) -> usize {
        self.mTransitionDelayCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_transition_duration<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::transition_duration::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mTransitions.ensure_len(input_len);

        self.mTransitionDurationCount = input_len as u32;
        for (gecko, servo) in self.mTransitions.iter_mut().take(input_len as usize).zip(v) {
            gecko.mDuration = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn transition_duration_at(&self, index: usize)
        -> longhands::transition_duration::computed_value::SingleComputedValue {
        self.mTransitions[index % self.transition_duration_count()].mDuration.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_transition_duration_from(&mut self, other: &Self) {
        self.mTransitions.ensure_len(other.mTransitions.len());

        let count = other.mTransitionDurationCount;
        self.mTransitionDurationCount = count;

        let iter = self.mTransitions.iter_mut().take(count as usize).zip(
            other.mTransitions.iter()
        );

        for (ours, others) in iter {
            ours.mDuration = others.mDuration.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_transition_duration(&mut self, other: &Self) {
        self.copy_transition_duration_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn transition_duration_count(&self) -> usize {
        self.mTransitionDurationCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_transition_timing_function<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::transition_timing_function::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mTransitions.ensure_len(input_len);

        self.mTransitionTimingFunctionCount = input_len as u32;
        for (gecko, servo) in self.mTransitions.iter_mut().take(input_len as usize).zip(v) {
            gecko.mTimingFunction = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn transition_timing_function_at(&self, index: usize)
        -> longhands::transition_timing_function::computed_value::SingleComputedValue {
        self.mTransitions[index % self.transition_timing_function_count()].mTimingFunction.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_transition_timing_function_from(&mut self, other: &Self) {
        self.mTransitions.ensure_len(other.mTransitions.len());

        let count = other.mTransitionTimingFunctionCount;
        self.mTransitionTimingFunctionCount = count;

        let iter = self.mTransitions.iter_mut().take(count as usize).zip(
            other.mTransitions.iter()
        );

        for (ours, others) in iter {
            ours.mTimingFunction = others.mTimingFunction.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_transition_timing_function(&mut self, other: &Self) {
        self.copy_transition_timing_function_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn transition_timing_function_count(&self) -> usize {
        self.mTransitionTimingFunctionCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_transition_property<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::transition_property::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mTransitions.ensure_len(input_len);

        self.mTransitionPropertyCount = input_len as u32;
        for (gecko, servo) in self.mTransitions.iter_mut().take(input_len as usize).zip(v) {
            gecko.mProperty = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn transition_property_at(&self, index: usize)
        -> longhands::transition_property::computed_value::SingleComputedValue {
        self.mTransitions[index % self.transition_property_count()].mProperty.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_transition_property_from(&mut self, other: &Self) {
        self.mTransitions.ensure_len(other.mTransitions.len());

        let count = other.mTransitionPropertyCount;
        self.mTransitionPropertyCount = count;

        let iter = self.mTransitions.iter_mut().take(count as usize).zip(
            other.mTransitions.iter()
        );

        for (ours, others) in iter {
            ours.mProperty = others.mProperty.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_transition_property(&mut self, other: &Self) {
        self.copy_transition_property_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn transition_property_count(&self) -> usize {
        self.mTransitionPropertyCount as usize
    }



    pub fn transition_combined_duration_at(&self, index: usize) -> Time {
        // https://drafts.csswg.org/css-transitions/#transition-combined-duration
        Time::from_seconds(
            self.transition_duration_at(index).seconds().max(0.0) +
            self.transition_delay_at(index).seconds()
        )
    }

    /// Returns whether there are any transitions specified.
    pub fn specifies_transitions(&self) -> bool {
        if self.mTransitionPropertyCount == 1 &&
            self.transition_combined_duration_at(0).seconds() <= 0.0f32 {
            return false;
        }
        self.mTransitionPropertyCount > 0
    }

    pub fn animations_equals(&self, other: &Self) -> bool {
        return self.mAnimationNameCount == other.mAnimationNameCount
            && self.mAnimationDelayCount == other.mAnimationDelayCount
            && self.mAnimationDirectionCount == other.mAnimationDirectionCount
            && self.mAnimationDurationCount == other.mAnimationDurationCount
            && self.mAnimationFillModeCount == other.mAnimationFillModeCount
            && self.mAnimationIterationCountCount == other.mAnimationIterationCountCount
            && self.mAnimationPlayStateCount == other.mAnimationPlayStateCount
            && self.mAnimationTimingFunctionCount == other.mAnimationTimingFunctionCount
            && self.mAnimationCompositionCount == other.mAnimationCompositionCount
            && self.mAnimationTimelineCount == other.mAnimationTimelineCount
            && unsafe { bindings::Gecko_StyleAnimationsEquals(&self.mAnimations, &other.mAnimations) }
    }

    
    #[allow(non_snake_case)]
    pub fn set_animation_name<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_name::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationNameCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mName = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_name_at(&self, index: usize)
        -> longhands::animation_name::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_name_count()].mName.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_name_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationNameCount;
        self.mAnimationNameCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mName = others.mName.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_name(&mut self, other: &Self) {
        self.copy_animation_name_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_name_count(&self) -> usize {
        self.mAnimationNameCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_delay<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_delay::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationDelayCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mDelay = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_delay_at(&self, index: usize)
        -> longhands::animation_delay::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_delay_count()].mDelay.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_delay_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationDelayCount;
        self.mAnimationDelayCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mDelay = others.mDelay.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_delay(&mut self, other: &Self) {
        self.copy_animation_delay_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_delay_count(&self) -> usize {
        self.mAnimationDelayCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_duration<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_duration::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationDurationCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mDuration = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_duration_at(&self, index: usize)
        -> longhands::animation_duration::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_duration_count()].mDuration.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_duration_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationDurationCount;
        self.mAnimationDurationCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mDuration = others.mDuration.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_duration(&mut self, other: &Self) {
        self.copy_animation_duration_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_duration_count(&self) -> usize {
        self.mAnimationDurationCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_direction<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_direction::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationDirectionCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mDirection = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_direction_at(&self, index: usize)
        -> longhands::animation_direction::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_direction_count()].mDirection.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_direction_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationDirectionCount;
        self.mAnimationDirectionCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mDirection = others.mDirection.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_direction(&mut self, other: &Self) {
        self.copy_animation_direction_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_direction_count(&self) -> usize {
        self.mAnimationDirectionCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_fill_mode<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_fill_mode::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationFillModeCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mFillMode = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_fill_mode_at(&self, index: usize)
        -> longhands::animation_fill_mode::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_fill_mode_count()].mFillMode.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_fill_mode_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationFillModeCount;
        self.mAnimationFillModeCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mFillMode = others.mFillMode.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_fill_mode(&mut self, other: &Self) {
        self.copy_animation_fill_mode_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_fill_mode_count(&self) -> usize {
        self.mAnimationFillModeCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_play_state<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_play_state::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationPlayStateCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mPlayState = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_play_state_at(&self, index: usize)
        -> longhands::animation_play_state::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_play_state_count()].mPlayState.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_play_state_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationPlayStateCount;
        self.mAnimationPlayStateCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mPlayState = others.mPlayState.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_play_state(&mut self, other: &Self) {
        self.copy_animation_play_state_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_play_state_count(&self) -> usize {
        self.mAnimationPlayStateCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_composition<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_composition::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationCompositionCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mComposition = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_composition_at(&self, index: usize)
        -> longhands::animation_composition::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_composition_count()].mComposition.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_composition_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationCompositionCount;
        self.mAnimationCompositionCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mComposition = others.mComposition.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_composition(&mut self, other: &Self) {
        self.copy_animation_composition_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_composition_count(&self) -> usize {
        self.mAnimationCompositionCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_iteration_count<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_iteration_count::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationIterationCountCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mIterationCount = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_iteration_count_at(&self, index: usize)
        -> longhands::animation_iteration_count::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_iteration_count_count()].mIterationCount.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_iteration_count_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationIterationCountCount;
        self.mAnimationIterationCountCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mIterationCount = others.mIterationCount.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_iteration_count(&mut self, other: &Self) {
        self.copy_animation_iteration_count_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_iteration_count_count(&self) -> usize {
        self.mAnimationIterationCountCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_timeline<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_timeline::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationTimelineCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mTimeline = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_timeline_at(&self, index: usize)
        -> longhands::animation_timeline::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_timeline_count()].mTimeline.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_timeline_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationTimelineCount;
        self.mAnimationTimelineCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mTimeline = others.mTimeline.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_timeline(&mut self, other: &Self) {
        self.copy_animation_timeline_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_timeline_count(&self) -> usize {
        self.mAnimationTimelineCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_animation_timing_function<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::animation_timing_function::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mAnimations.ensure_len(input_len);

        self.mAnimationTimingFunctionCount = input_len as u32;
        for (gecko, servo) in self.mAnimations.iter_mut().take(input_len as usize).zip(v) {
            gecko.mTimingFunction = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn animation_timing_function_at(&self, index: usize)
        -> longhands::animation_timing_function::computed_value::SingleComputedValue {
        self.mAnimations[index % self.animation_timing_function_count()].mTimingFunction.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_animation_timing_function_from(&mut self, other: &Self) {
        self.mAnimations.ensure_len(other.mAnimations.len());

        let count = other.mAnimationTimingFunctionCount;
        self.mAnimationTimingFunctionCount = count;

        let iter = self.mAnimations.iter_mut().take(count as usize).zip(
            other.mAnimations.iter()
        );

        for (ours, others) in iter {
            ours.mTimingFunction = others.mTimingFunction.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_animation_timing_function(&mut self, other: &Self) {
        self.copy_animation_timing_function_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn animation_timing_function_count(&self) -> usize {
        self.mAnimationTimingFunctionCount as usize
    }



    
    #[allow(non_snake_case)]
    pub fn set_scroll_timeline_name<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::scroll_timeline_name::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mScrollTimelines.ensure_len(input_len);

        self.mScrollTimelineNameCount = input_len as u32;
        for (gecko, servo) in self.mScrollTimelines.iter_mut().take(input_len as usize).zip(v) {
            gecko.mName = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn scroll_timeline_name_at(&self, index: usize)
        -> longhands::scroll_timeline_name::computed_value::SingleComputedValue {
        self.mScrollTimelines[index % self.scroll_timeline_name_count()].mName.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_scroll_timeline_name_from(&mut self, other: &Self) {
        self.mScrollTimelines.ensure_len(other.mScrollTimelines.len());

        let count = other.mScrollTimelineNameCount;
        self.mScrollTimelineNameCount = count;

        let iter = self.mScrollTimelines.iter_mut().take(count as usize).zip(
            other.mScrollTimelines.iter()
        );

        for (ours, others) in iter {
            ours.mName = others.mName.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_scroll_timeline_name(&mut self, other: &Self) {
        self.copy_scroll_timeline_name_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn scroll_timeline_name_count(&self) -> usize {
        self.mScrollTimelineNameCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_scroll_timeline_axis<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::scroll_timeline_axis::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mScrollTimelines.ensure_len(input_len);

        self.mScrollTimelineAxisCount = input_len as u32;
        for (gecko, servo) in self.mScrollTimelines.iter_mut().take(input_len as usize).zip(v) {
            gecko.mAxis = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn scroll_timeline_axis_at(&self, index: usize)
        -> longhands::scroll_timeline_axis::computed_value::SingleComputedValue {
        self.mScrollTimelines[index % self.scroll_timeline_axis_count()].mAxis.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_scroll_timeline_axis_from(&mut self, other: &Self) {
        self.mScrollTimelines.ensure_len(other.mScrollTimelines.len());

        let count = other.mScrollTimelineAxisCount;
        self.mScrollTimelineAxisCount = count;

        let iter = self.mScrollTimelines.iter_mut().take(count as usize).zip(
            other.mScrollTimelines.iter()
        );

        for (ours, others) in iter {
            ours.mAxis = others.mAxis.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_scroll_timeline_axis(&mut self, other: &Self) {
        self.copy_scroll_timeline_axis_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn scroll_timeline_axis_count(&self) -> usize {
        self.mScrollTimelineAxisCount as usize
    }



    pub fn scroll_timelines_equals(&self, other: &Self) -> bool {
        self.mScrollTimelineNameCount == other.mScrollTimelineNameCount
            && self.mScrollTimelineAxisCount == other.mScrollTimelineAxisCount
            && unsafe {
                bindings::Gecko_StyleScrollTimelinesEquals(
                    &self.mScrollTimelines,
                    &other.mScrollTimelines,
                )
            }
    }

    
    #[allow(non_snake_case)]
    pub fn set_view_timeline_name<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::view_timeline_name::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mViewTimelines.ensure_len(input_len);

        self.mViewTimelineNameCount = input_len as u32;
        for (gecko, servo) in self.mViewTimelines.iter_mut().take(input_len as usize).zip(v) {
            gecko.mName = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn view_timeline_name_at(&self, index: usize)
        -> longhands::view_timeline_name::computed_value::SingleComputedValue {
        self.mViewTimelines[index % self.view_timeline_name_count()].mName.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_view_timeline_name_from(&mut self, other: &Self) {
        self.mViewTimelines.ensure_len(other.mViewTimelines.len());

        let count = other.mViewTimelineNameCount;
        self.mViewTimelineNameCount = count;

        let iter = self.mViewTimelines.iter_mut().take(count as usize).zip(
            other.mViewTimelines.iter()
        );

        for (ours, others) in iter {
            ours.mName = others.mName.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_view_timeline_name(&mut self, other: &Self) {
        self.copy_view_timeline_name_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn view_timeline_name_count(&self) -> usize {
        self.mViewTimelineNameCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_view_timeline_axis<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::view_timeline_axis::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mViewTimelines.ensure_len(input_len);

        self.mViewTimelineAxisCount = input_len as u32;
        for (gecko, servo) in self.mViewTimelines.iter_mut().take(input_len as usize).zip(v) {
            gecko.mAxis = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn view_timeline_axis_at(&self, index: usize)
        -> longhands::view_timeline_axis::computed_value::SingleComputedValue {
        self.mViewTimelines[index % self.view_timeline_axis_count()].mAxis.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_view_timeline_axis_from(&mut self, other: &Self) {
        self.mViewTimelines.ensure_len(other.mViewTimelines.len());

        let count = other.mViewTimelineAxisCount;
        self.mViewTimelineAxisCount = count;

        let iter = self.mViewTimelines.iter_mut().take(count as usize).zip(
            other.mViewTimelines.iter()
        );

        for (ours, others) in iter {
            ours.mAxis = others.mAxis.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_view_timeline_axis(&mut self, other: &Self) {
        self.copy_view_timeline_axis_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn view_timeline_axis_count(&self) -> usize {
        self.mViewTimelineAxisCount as usize
    }


    
    #[allow(non_snake_case)]
    pub fn set_view_timeline_inset<I>(&mut self, v: I)
    where
        I: IntoIterator<Item = longhands::view_timeline_inset::computed_value::single_value::T>,
        I::IntoIter: ExactSizeIterator + Clone
    {
        let v = v.into_iter();
        debug_assert_ne!(v.len(), 0);
        let input_len = v.len();
        self.mViewTimelines.ensure_len(input_len);

        self.mViewTimelineInsetCount = input_len as u32;
        for (gecko, servo) in self.mViewTimelines.iter_mut().take(input_len as usize).zip(v) {
            gecko.mInset = servo;
        }
    }
    #[allow(non_snake_case)]
    pub fn view_timeline_inset_at(&self, index: usize)
        -> longhands::view_timeline_inset::computed_value::SingleComputedValue {
        self.mViewTimelines[index % self.view_timeline_inset_count()].mInset.clone()
    }
    
    #[allow(non_snake_case)]
    pub fn copy_view_timeline_inset_from(&mut self, other: &Self) {
        self.mViewTimelines.ensure_len(other.mViewTimelines.len());

        let count = other.mViewTimelineInsetCount;
        self.mViewTimelineInsetCount = count;

        let iter = self.mViewTimelines.iter_mut().take(count as usize).zip(
            other.mViewTimelines.iter()
        );

        for (ours, others) in iter {
            ours.mInset = others.mInset.clone();
        }
    }
    #[allow(non_snake_case)]
    pub fn reset_view_timeline_inset(&mut self, other: &Self) {
        self.copy_view_timeline_inset_from(other)
    }

    
    #[allow(non_snake_case)]
    pub fn view_timeline_inset_count(&self) -> usize {
        self.mViewTimelineInsetCount as usize
    }



    pub fn view_timelines_equals(&self, other: &Self) -> bool {
        self.mViewTimelineNameCount == other.mViewTimelineNameCount
            && self.mViewTimelineAxisCount == other.mViewTimelineAxisCount
            && self.mViewTimelineInsetCount == other.mViewTimelineInsetCount
            && unsafe {
                bindings::Gecko_StyleViewTimelinesEquals(
                    &self.mViewTimelines,
                    &other.mViewTimelines,
                )
            }
    }


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set_ime_mode(&mut self, v: longhands::ime_mode::computed_value::T) {
        use crate::properties::longhands::ime_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleImeMode::Auto ,
                Keyword::Normal =>
                    structs::StyleImeMode::Normal ,
                Keyword::Active =>
                    structs::StyleImeMode::Active ,
                Keyword::Disabled =>
                    structs::StyleImeMode::Disabled ,
                Keyword::Inactive =>
                    structs::StyleImeMode::Inactive ,
        };
        self.mIMEMode = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_ime_mode_from(&mut self, other: &Self) {
        self.mIMEMode = other.mIMEMode.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_ime_mode(&mut self, other: &Self) {
        self.copy_ime_mode_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_ime_mode(&self) -> longhands::ime_mode::computed_value::T {
        use crate::properties::longhands::ime_mode::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mIMEMode {
            structs::StyleImeMode::Auto => Keyword::Auto,
            structs::StyleImeMode::Normal => Keyword::Normal,
            structs::StyleImeMode::Active => Keyword::Active,
            structs::StyleImeMode::Disabled => Keyword::Disabled,
            structs::StyleImeMode::Inactive => Keyword::Inactive,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_scrollbar_width(&mut self, v: longhands::scrollbar_width::computed_value::T) {
        use crate::properties::longhands::scrollbar_width::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleScrollbarWidth::Auto ,
                Keyword::Thin =>
                    structs::StyleScrollbarWidth::Thin ,
                Keyword::None =>
                    structs::StyleScrollbarWidth::None ,
        };
        self.mScrollbarWidth = result;
    }


    #[allow(non_snake_case)]
    pub fn copy_scrollbar_width_from(&mut self, other: &Self) {
        self.mScrollbarWidth = other.mScrollbarWidth.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_scrollbar_width(&mut self, other: &Self) {
        self.copy_scrollbar_width_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_scrollbar_width(&self) -> longhands::scrollbar_width::computed_value::T {
        use crate::properties::longhands::scrollbar_width::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mScrollbarWidth {
            structs::StyleScrollbarWidth::Auto => Keyword::Auto,
            structs::StyleScrollbarWidth::Thin => Keyword::Thin,
            structs::StyleScrollbarWidth::None => Keyword::None,
        }
    }



    #[allow(non_snake_case)]
    pub fn set_user_select(&mut self, v: longhands::user_select::computed_value::T) {
        self.mUserSelect = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy_user_select_from(&mut self, other: &Self) {
        self.mUserSelect = other.mUserSelect.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset_user_select(&mut self, other: &Self) {
        self.copy_user_select_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone_user_select(&self) -> longhands::user_select::computed_value::T {
        From::from(self.mUserSelect.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_window_dragging(&mut self, v: longhands::_moz_window_dragging::computed_value::T) {
        use crate::properties::longhands::_moz_window_dragging::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Default =>
                    structs::StyleWindowDragging::Default ,
                Keyword::Drag =>
                    structs::StyleWindowDragging::Drag ,
                Keyword::NoDrag =>
                    structs::StyleWindowDragging::NoDrag ,
        };
        self.mWindowDragging = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_window_dragging_from(&mut self, other: &Self) {
        self.mWindowDragging = other.mWindowDragging.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_window_dragging(&mut self, other: &Self) {
        self.copy__moz_window_dragging_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_window_dragging(&self) -> longhands::_moz_window_dragging::computed_value::T {
        use crate::properties::longhands::_moz_window_dragging::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mWindowDragging {
            structs::StyleWindowDragging::Default => Keyword::Default,
            structs::StyleWindowDragging::Drag => Keyword::Drag,
            structs::StyleWindowDragging::NoDrag => Keyword::NoDrag,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_window_shadow(&mut self, v: longhands::_moz_window_shadow::computed_value::T) {
        use crate::properties::longhands::_moz_window_shadow::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Auto =>
                    structs::StyleWindowShadow::Auto ,
                Keyword::None =>
                    structs::StyleWindowShadow::None ,
        };
        self.mWindowShadow = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_window_shadow_from(&mut self, other: &Self) {
        self.mWindowShadow = other.mWindowShadow.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_window_shadow(&mut self, other: &Self) {
        self.copy__moz_window_shadow_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_window_shadow(&self) -> longhands::_moz_window_shadow::computed_value::T {
        use crate::properties::longhands::_moz_window_shadow::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mWindowShadow {
            structs::StyleWindowShadow::Auto => Keyword::Auto,
            structs::StyleWindowShadow::None => Keyword::None,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_window_opacity(&mut self, v: longhands::_moz_window_opacity::computed_value::T) {
        self.mWindowOpacity = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_window_opacity_from(&mut self, other: &Self) {
        self.mWindowOpacity = other.mWindowOpacity.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_window_opacity(&mut self, other: &Self) {
        self.copy__moz_window_opacity_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_window_opacity(&self) -> longhands::_moz_window_opacity::computed_value::T {
        From::from(self.mWindowOpacity.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_window_transform(&mut self, v: longhands::_moz_window_transform::computed_value::T) {
        self.mMozWindowTransform = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_window_transform_from(&mut self, other: &Self) {
        self.mMozWindowTransform = other.mMozWindowTransform.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_window_transform(&mut self, other: &Self) {
        self.copy__moz_window_transform_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_window_transform(&self) -> longhands::_moz_window_transform::computed_value::T {
        From::from(self.mMozWindowTransform.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_window_transform_origin(&mut self, v: longhands::_moz_window_transform_origin::computed_value::T) {
        self.mWindowTransformOrigin = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_window_transform_origin_from(&mut self, other: &Self) {
        self.mWindowTransformOrigin = other.mWindowTransformOrigin.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_window_transform_origin(&mut self, other: &Self) {
        self.copy__moz_window_transform_origin_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_window_transform_origin(&self) -> longhands::_moz_window_transform_origin::computed_value::T {
        From::from(self.mWindowTransformOrigin.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_window_input_region_margin(&mut self, v: longhands::_moz_window_input_region_margin::computed_value::T) {
        self.mMozWindowInputRegionMargin = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_window_input_region_margin_from(&mut self, other: &Self) {
        self.mMozWindowInputRegionMargin = other.mMozWindowInputRegionMargin.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_window_input_region_margin(&mut self, other: &Self) {
        self.copy__moz_window_input_region_margin_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_window_input_region_margin(&self) -> longhands::_moz_window_input_region_margin::computed_value::T {
        From::from(self.mMozWindowInputRegionMargin.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_subtree_hidden_only_visually(&mut self, v: longhands::_moz_subtree_hidden_only_visually::computed_value::T) {
        self.mMozSubtreeHiddenOnlyVisually = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_subtree_hidden_only_visually_from(&mut self, other: &Self) {
        self.mMozSubtreeHiddenOnlyVisually = other.mMozSubtreeHiddenOnlyVisually.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_subtree_hidden_only_visually(&mut self, other: &Self) {
        self.copy__moz_subtree_hidden_only_visually_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_subtree_hidden_only_visually(&self) -> longhands::_moz_subtree_hidden_only_visually::computed_value::T {
        From::from(self.mMozSubtreeHiddenOnlyVisually.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_force_broken_image_icon(&mut self, v: longhands::_moz_force_broken_image_icon::computed_value::T) {
        self.mMozForceBrokenImageIcon = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_force_broken_image_icon_from(&mut self, other: &Self) {
        self.mMozForceBrokenImageIcon = other.mMozForceBrokenImageIcon.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_force_broken_image_icon(&mut self, other: &Self) {
        self.copy__moz_force_broken_image_icon_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_force_broken_image_icon(&self) -> longhands::_moz_force_broken_image_icon::computed_value::T {
        From::from(self.mMozForceBrokenImageIcon.clone())
    }


}




impl GeckoXUL {
    /*
     * Manually-Implemented Methods.
     */
    


    /*
     * Auto-Generated Methods.
     */
    

    #[allow(non_snake_case)]
    pub fn set__moz_box_align(&mut self, v: longhands::_moz_box_align::computed_value::T) {
        use crate::properties::longhands::_moz_box_align::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Stretch =>
                    structs::StyleBoxAlign::Stretch ,
                Keyword::Start =>
                    structs::StyleBoxAlign::Start ,
                Keyword::Center =>
                    structs::StyleBoxAlign::Center ,
                Keyword::Baseline =>
                    structs::StyleBoxAlign::Baseline ,
                Keyword::End =>
                    structs::StyleBoxAlign::End ,
        };
        self.mBoxAlign = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_box_align_from(&mut self, other: &Self) {
        self.mBoxAlign = other.mBoxAlign.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_box_align(&mut self, other: &Self) {
        self.copy__moz_box_align_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_box_align(&self) -> longhands::_moz_box_align::computed_value::T {
        use crate::properties::longhands::_moz_box_align::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBoxAlign {
            structs::StyleBoxAlign::Stretch => Keyword::Stretch,
            structs::StyleBoxAlign::Start => Keyword::Start,
            structs::StyleBoxAlign::Center => Keyword::Center,
            structs::StyleBoxAlign::Baseline => Keyword::Baseline,
            structs::StyleBoxAlign::End => Keyword::End,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_box_direction(&mut self, v: longhands::_moz_box_direction::computed_value::T) {
        use crate::properties::longhands::_moz_box_direction::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Normal =>
                    structs::StyleBoxDirection::Normal ,
                Keyword::Reverse =>
                    structs::StyleBoxDirection::Reverse ,
        };
        self.mBoxDirection = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_box_direction_from(&mut self, other: &Self) {
        self.mBoxDirection = other.mBoxDirection.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_box_direction(&mut self, other: &Self) {
        self.copy__moz_box_direction_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_box_direction(&self) -> longhands::_moz_box_direction::computed_value::T {
        use crate::properties::longhands::_moz_box_direction::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBoxDirection {
            structs::StyleBoxDirection::Normal => Keyword::Normal,
            structs::StyleBoxDirection::Reverse => Keyword::Reverse,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_box_flex(&mut self, v: longhands::_moz_box_flex::computed_value::T) {
        self.mBoxFlex = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_box_flex_from(&mut self, other: &Self) {
        self.mBoxFlex = other.mBoxFlex.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_box_flex(&mut self, other: &Self) {
        self.copy__moz_box_flex_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_box_flex(&self) -> longhands::_moz_box_flex::computed_value::T {
        From::from(self.mBoxFlex.clone())
    }



    #[allow(non_snake_case)]
    pub fn set__moz_box_orient(&mut self, v: longhands::_moz_box_orient::computed_value::T) {
        use crate::properties::longhands::_moz_box_orient::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Horizontal =>
                    structs::StyleBoxOrient::Horizontal ,
                Keyword::Vertical =>
                    structs::StyleBoxOrient::Vertical ,
        };
        self.mBoxOrient = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_box_orient_from(&mut self, other: &Self) {
        self.mBoxOrient = other.mBoxOrient.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_box_orient(&mut self, other: &Self) {
        self.copy__moz_box_orient_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_box_orient(&self) -> longhands::_moz_box_orient::computed_value::T {
        use crate::properties::longhands::_moz_box_orient::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBoxOrient {
            structs::StyleBoxOrient::Horizontal => Keyword::Horizontal,
            structs::StyleBoxOrient::Vertical => Keyword::Vertical,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_box_pack(&mut self, v: longhands::_moz_box_pack::computed_value::T) {
        use crate::properties::longhands::_moz_box_pack::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts
        let result = match v {
                Keyword::Start =>
                    structs::StyleBoxPack::Start ,
                Keyword::Center =>
                    structs::StyleBoxPack::Center ,
                Keyword::End =>
                    structs::StyleBoxPack::End ,
                Keyword::Justify =>
                    structs::StyleBoxPack::Justify ,
        };
        self.mBoxPack = result;
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_box_pack_from(&mut self, other: &Self) {
        self.mBoxPack = other.mBoxPack.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_box_pack(&mut self, other: &Self) {
        self.copy__moz_box_pack_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_box_pack(&self) -> longhands::_moz_box_pack::computed_value::T {
        use crate::properties::longhands::_moz_box_pack::computed_value::T as Keyword;
        // FIXME(bholley): Align binary representations and ditch |match| for cast + static_asserts

        // Some constant macros in the gecko are defined as negative integer(e.g. font-stretch).
        // And they are convert to signed integer in Rust bindings. We need to cast then
        // as signed type when we have both signed/unsigned integer in order to use them
        // as match's arms.
        // Also, to use same implementation here we use casted constant if we have only singed values.
        match self.mBoxPack {
            structs::StyleBoxPack::Start => Keyword::Start,
            structs::StyleBoxPack::Center => Keyword::Center,
            structs::StyleBoxPack::End => Keyword::End,
            structs::StyleBoxPack::Justify => Keyword::Justify,
        }
    }



    #[allow(non_snake_case)]
    pub fn set__moz_box_ordinal_group(&mut self, v: longhands::_moz_box_ordinal_group::computed_value::T) {
        self.mBoxOrdinal = From::from(v);
    }


    #[allow(non_snake_case)]
    pub fn copy__moz_box_ordinal_group_from(&mut self, other: &Self) {
        self.mBoxOrdinal = other.mBoxOrdinal.clone();
    }

    #[allow(non_snake_case)]
    pub fn reset__moz_box_ordinal_group(&mut self, other: &Self) {
        self.copy__moz_box_ordinal_group_from(other)
    }


    #[allow(non_snake_case)]
    pub fn clone__moz_box_ordinal_group(&self) -> longhands::_moz_box_ordinal_group::computed_value::T {
        From::from(self.mBoxOrdinal.clone())
    }


}



/// A wrapper for nsStyleBackground, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoBackground(ManuallyDrop<structs::nsStyleBackground>);

impl ops::Deref for GeckoBackground {
    type Target = structs::nsStyleBackground;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoBackground {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoBackground {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoBackground> = unsafe {
                let mut result = UniqueArc::<GeckoBackground>::new_uninit();
                Gecko_Construct_Default_nsStyleBackground(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoBackground {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleBackground(&mut **self);
        }
    }
}
impl Clone for GeckoBackground {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleBackground(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleBorder, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoBorder(ManuallyDrop<structs::nsStyleBorder>);

impl ops::Deref for GeckoBorder {
    type Target = structs::nsStyleBorder;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoBorder {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoBorder {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoBorder> = unsafe {
                let mut result = UniqueArc::<GeckoBorder>::new_uninit();
                Gecko_Construct_Default_nsStyleBorder(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoBorder {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleBorder(&mut **self);
        }
    }
}
impl Clone for GeckoBorder {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleBorder(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleDisplay, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoBox(ManuallyDrop<structs::nsStyleDisplay>);

impl ops::Deref for GeckoBox {
    type Target = structs::nsStyleDisplay;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoBox {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoBox {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoBox> = unsafe {
                let mut result = UniqueArc::<GeckoBox>::new_uninit();
                Gecko_Construct_Default_nsStyleDisplay(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoBox {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleDisplay(&mut **self);
        }
    }
}
impl Clone for GeckoBox {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleDisplay(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleColumn, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoColumn(ManuallyDrop<structs::nsStyleColumn>);

impl ops::Deref for GeckoColumn {
    type Target = structs::nsStyleColumn;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoColumn {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoColumn {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoColumn> = unsafe {
                let mut result = UniqueArc::<GeckoColumn>::new_uninit();
                Gecko_Construct_Default_nsStyleColumn(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoColumn {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleColumn(&mut **self);
        }
    }
}
impl Clone for GeckoColumn {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleColumn(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleContent, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoCounters(ManuallyDrop<structs::nsStyleContent>);

impl ops::Deref for GeckoCounters {
    type Target = structs::nsStyleContent;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoCounters {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoCounters {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoCounters> = unsafe {
                let mut result = UniqueArc::<GeckoCounters>::new_uninit();
                Gecko_Construct_Default_nsStyleContent(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoCounters {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleContent(&mut **self);
        }
    }
}
impl Clone for GeckoCounters {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleContent(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleEffects, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoEffects(ManuallyDrop<structs::nsStyleEffects>);

impl ops::Deref for GeckoEffects {
    type Target = structs::nsStyleEffects;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoEffects {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoEffects {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoEffects> = unsafe {
                let mut result = UniqueArc::<GeckoEffects>::new_uninit();
                Gecko_Construct_Default_nsStyleEffects(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoEffects {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleEffects(&mut **self);
        }
    }
}
impl Clone for GeckoEffects {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleEffects(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleFont, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoFont(ManuallyDrop<structs::nsStyleFont>);

impl ops::Deref for GeckoFont {
    type Target = structs::nsStyleFont;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoFont {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoFont {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        unsafe {
            let mut result = UniqueArc::<Self>::new_uninit();
            Gecko_Construct_Default_nsStyleFont(
                result.as_mut_ptr() as *mut _,
                document,
            );
            UniqueArc::assume_init(result).shareable()
        }
    }
}

impl Drop for GeckoFont {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleFont(&mut **self);
        }
    }
}
impl Clone for GeckoFont {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleFont(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleVisibility, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoInheritedBox(ManuallyDrop<structs::nsStyleVisibility>);

impl ops::Deref for GeckoInheritedBox {
    type Target = structs::nsStyleVisibility;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoInheritedBox {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoInheritedBox {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        unsafe {
            let mut result = UniqueArc::<Self>::new_uninit();
            Gecko_Construct_Default_nsStyleVisibility(
                result.as_mut_ptr() as *mut _,
                document,
            );
            UniqueArc::assume_init(result).shareable()
        }
    }
}

impl Drop for GeckoInheritedBox {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleVisibility(&mut **self);
        }
    }
}
impl Clone for GeckoInheritedBox {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleVisibility(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleSVG, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoInheritedSVG(ManuallyDrop<structs::nsStyleSVG>);

impl ops::Deref for GeckoInheritedSVG {
    type Target = structs::nsStyleSVG;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoInheritedSVG {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoInheritedSVG {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoInheritedSVG> = unsafe {
                let mut result = UniqueArc::<GeckoInheritedSVG>::new_uninit();
                Gecko_Construct_Default_nsStyleSVG(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoInheritedSVG {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleSVG(&mut **self);
        }
    }
}
impl Clone for GeckoInheritedSVG {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleSVG(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleTableBorder, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoInheritedTable(ManuallyDrop<structs::nsStyleTableBorder>);

impl ops::Deref for GeckoInheritedTable {
    type Target = structs::nsStyleTableBorder;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoInheritedTable {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoInheritedTable {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoInheritedTable> = unsafe {
                let mut result = UniqueArc::<GeckoInheritedTable>::new_uninit();
                Gecko_Construct_Default_nsStyleTableBorder(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoInheritedTable {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleTableBorder(&mut **self);
        }
    }
}
impl Clone for GeckoInheritedTable {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleTableBorder(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleText, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoInheritedText(ManuallyDrop<structs::nsStyleText>);

impl ops::Deref for GeckoInheritedText {
    type Target = structs::nsStyleText;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoInheritedText {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoInheritedText {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        unsafe {
            let mut result = UniqueArc::<Self>::new_uninit();
            Gecko_Construct_Default_nsStyleText(
                result.as_mut_ptr() as *mut _,
                document,
            );
            UniqueArc::assume_init(result).shareable()
        }
    }
}

impl Drop for GeckoInheritedText {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleText(&mut **self);
        }
    }
}
impl Clone for GeckoInheritedText {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleText(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleUI, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoInheritedUI(ManuallyDrop<structs::nsStyleUI>);

impl ops::Deref for GeckoInheritedUI {
    type Target = structs::nsStyleUI;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoInheritedUI {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoInheritedUI {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoInheritedUI> = unsafe {
                let mut result = UniqueArc::<GeckoInheritedUI>::new_uninit();
                Gecko_Construct_Default_nsStyleUI(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoInheritedUI {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleUI(&mut **self);
        }
    }
}
impl Clone for GeckoInheritedUI {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleUI(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleList, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoList(ManuallyDrop<structs::nsStyleList>);

impl ops::Deref for GeckoList {
    type Target = structs::nsStyleList;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoList {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoList {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoList> = unsafe {
                let mut result = UniqueArc::<GeckoList>::new_uninit();
                Gecko_Construct_Default_nsStyleList(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoList {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleList(&mut **self);
        }
    }
}
impl Clone for GeckoList {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleList(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleMargin, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoMargin(ManuallyDrop<structs::nsStyleMargin>);

impl ops::Deref for GeckoMargin {
    type Target = structs::nsStyleMargin;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoMargin {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoMargin {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoMargin> = unsafe {
                let mut result = UniqueArc::<GeckoMargin>::new_uninit();
                Gecko_Construct_Default_nsStyleMargin(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoMargin {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleMargin(&mut **self);
        }
    }
}
impl Clone for GeckoMargin {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleMargin(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleOutline, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoOutline(ManuallyDrop<structs::nsStyleOutline>);

impl ops::Deref for GeckoOutline {
    type Target = structs::nsStyleOutline;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoOutline {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoOutline {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoOutline> = unsafe {
                let mut result = UniqueArc::<GeckoOutline>::new_uninit();
                Gecko_Construct_Default_nsStyleOutline(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoOutline {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleOutline(&mut **self);
        }
    }
}
impl Clone for GeckoOutline {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleOutline(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStylePadding, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoPadding(ManuallyDrop<structs::nsStylePadding>);

impl ops::Deref for GeckoPadding {
    type Target = structs::nsStylePadding;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoPadding {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoPadding {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoPadding> = unsafe {
                let mut result = UniqueArc::<GeckoPadding>::new_uninit();
                Gecko_Construct_Default_nsStylePadding(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoPadding {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStylePadding(&mut **self);
        }
    }
}
impl Clone for GeckoPadding {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStylePadding(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStylePage, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoPage(ManuallyDrop<structs::nsStylePage>);

impl ops::Deref for GeckoPage {
    type Target = structs::nsStylePage;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoPage {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoPage {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoPage> = unsafe {
                let mut result = UniqueArc::<GeckoPage>::new_uninit();
                Gecko_Construct_Default_nsStylePage(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoPage {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStylePage(&mut **self);
        }
    }
}
impl Clone for GeckoPage {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStylePage(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStylePosition, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoPosition(ManuallyDrop<structs::nsStylePosition>);

impl ops::Deref for GeckoPosition {
    type Target = structs::nsStylePosition;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoPosition {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoPosition {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoPosition> = unsafe {
                let mut result = UniqueArc::<GeckoPosition>::new_uninit();
                Gecko_Construct_Default_nsStylePosition(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoPosition {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStylePosition(&mut **self);
        }
    }
}
impl Clone for GeckoPosition {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStylePosition(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleSVGReset, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoSVG(ManuallyDrop<structs::nsStyleSVGReset>);

impl ops::Deref for GeckoSVG {
    type Target = structs::nsStyleSVGReset;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoSVG {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoSVG {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoSVG> = unsafe {
                let mut result = UniqueArc::<GeckoSVG>::new_uninit();
                Gecko_Construct_Default_nsStyleSVGReset(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoSVG {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleSVGReset(&mut **self);
        }
    }
}
impl Clone for GeckoSVG {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleSVGReset(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleTable, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoTable(ManuallyDrop<structs::nsStyleTable>);

impl ops::Deref for GeckoTable {
    type Target = structs::nsStyleTable;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoTable {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoTable {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoTable> = unsafe {
                let mut result = UniqueArc::<GeckoTable>::new_uninit();
                Gecko_Construct_Default_nsStyleTable(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoTable {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleTable(&mut **self);
        }
    }
}
impl Clone for GeckoTable {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleTable(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleTextReset, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoText(ManuallyDrop<structs::nsStyleTextReset>);

impl ops::Deref for GeckoText {
    type Target = structs::nsStyleTextReset;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoText {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoText {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoText> = unsafe {
                let mut result = UniqueArc::<GeckoText>::new_uninit();
                Gecko_Construct_Default_nsStyleTextReset(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoText {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleTextReset(&mut **self);
        }
    }
}
impl Clone for GeckoText {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleTextReset(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleUIReset, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoUI(ManuallyDrop<structs::nsStyleUIReset>);

impl ops::Deref for GeckoUI {
    type Target = structs::nsStyleUIReset;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoUI {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoUI {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoUI> = unsafe {
                let mut result = UniqueArc::<GeckoUI>::new_uninit();
                Gecko_Construct_Default_nsStyleUIReset(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoUI {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleUIReset(&mut **self);
        }
    }
}
impl Clone for GeckoUI {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleUIReset(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// A wrapper for nsStyleXUL, to be able to manually construct / destruct /
/// clone it.
#[repr(transparent)]
pub struct GeckoXUL(ManuallyDrop<structs::nsStyleXUL>);

impl ops::Deref for GeckoXUL {
    type Target = structs::nsStyleXUL;
    #[inline]
    fn deref(&self) -> &Self::Target {
        &self.0
    }
}

impl ops::DerefMut for GeckoXUL {
    #[inline]
    fn deref_mut(&mut self) -> &mut <Self as ops::Deref>::Target {
        &mut self.0
    }
}

impl GeckoXUL {
    #[allow(dead_code, unused_variables)]
    pub fn default(document: &structs::Document) -> Arc<Self> {
        lazy_static! {
            static ref DEFAULT: Arc<GeckoXUL> = unsafe {
                let mut result = UniqueArc::<GeckoXUL>::new_uninit();
                Gecko_Construct_Default_nsStyleXUL(
                    result.as_mut_ptr() as *mut _,
                    std::ptr::null(),
                );
                let arc = UniqueArc::assume_init(result).shareable();
                arc.mark_as_intentionally_leaked();
                arc
            };
        };
        DEFAULT.clone()
    }
}

impl Drop for GeckoXUL {
    fn drop(&mut self) {
        unsafe {
            Gecko_Destroy_nsStyleXUL(&mut **self);
        }
    }
}
impl Clone for GeckoXUL {
    fn clone(&self) -> Self {
        unsafe {
            let mut result = MaybeUninit::<Self>::uninit();
            // FIXME(bug 1595895): Zero the memory to keep valgrind happy, but
            // these looks like Valgrind false-positives at a quick glance.
            ptr::write_bytes::<Self>(result.as_mut_ptr(), 0, 1);
            Gecko_CopyConstruct_nsStyleXUL(result.as_mut_ptr() as *mut _, &**self);
            result.assume_init()
        }
    }
}


/// Assert that the initial values set in Gecko style struct constructors
/// match the values returned by `get_initial_value()` for each longhand.
#[cfg(feature = "gecko")]
#[inline]
pub fn assert_initial_values_match(data: &PerDocumentStyleData) {
    if cfg!(debug_assertions) {
        let data = data.borrow();
        let cv = data.stylist.device().default_computed_values();
        
        assert_eq!(
            cv.clone_background_color(),
            longhands::background_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_color),
                " must match longhands::",
                stringify!(background_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_image(),
            longhands::background_image::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_image),
                " must match longhands::",
                stringify!(background_image),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_position_x(),
            longhands::background_position_x::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_position_x),
                " must match longhands::",
                stringify!(background_position_x),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_position_y(),
            longhands::background_position_y::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_position_y),
                " must match longhands::",
                stringify!(background_position_y),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_repeat(),
            longhands::background_repeat::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_repeat),
                " must match longhands::",
                stringify!(background_repeat),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_attachment(),
            longhands::background_attachment::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_attachment),
                " must match longhands::",
                stringify!(background_attachment),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_clip(),
            longhands::background_clip::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_clip),
                " must match longhands::",
                stringify!(background_clip),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_origin(),
            longhands::background_origin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_origin),
                " must match longhands::",
                stringify!(background_origin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_size(),
            longhands::background_size::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_size),
                " must match longhands::",
                stringify!(background_size),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_background_blend_mode(),
            longhands::background_blend_mode::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(background_blend_mode),
                " must match longhands::",
                stringify!(background_blend_mode),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_top_color(),
            longhands::border_top_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_top_color),
                " must match longhands::",
                stringify!(border_top_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_top_style(),
            longhands::border_top_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_top_style),
                " must match longhands::",
                stringify!(border_top_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_right_color(),
            longhands::border_right_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_right_color),
                " must match longhands::",
                stringify!(border_right_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_right_style(),
            longhands::border_right_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_right_style),
                " must match longhands::",
                stringify!(border_right_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_bottom_color(),
            longhands::border_bottom_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_bottom_color),
                " must match longhands::",
                stringify!(border_bottom_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_bottom_style(),
            longhands::border_bottom_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_bottom_style),
                " must match longhands::",
                stringify!(border_bottom_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_left_color(),
            longhands::border_left_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_left_color),
                " must match longhands::",
                stringify!(border_left_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_left_style(),
            longhands::border_left_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_left_style),
                " must match longhands::",
                stringify!(border_left_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_top_left_radius(),
            longhands::border_top_left_radius::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_top_left_radius),
                " must match longhands::",
                stringify!(border_top_left_radius),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_top_right_radius(),
            longhands::border_top_right_radius::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_top_right_radius),
                " must match longhands::",
                stringify!(border_top_right_radius),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_bottom_right_radius(),
            longhands::border_bottom_right_radius::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_bottom_right_radius),
                " must match longhands::",
                stringify!(border_bottom_right_radius),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_bottom_left_radius(),
            longhands::border_bottom_left_radius::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_bottom_left_radius),
                " must match longhands::",
                stringify!(border_bottom_left_radius),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_box_decoration_break(),
            longhands::box_decoration_break::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(box_decoration_break),
                " must match longhands::",
                stringify!(box_decoration_break),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_float_edge(),
            longhands::_moz_float_edge::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_float_edge),
                " must match longhands::",
                stringify!(_moz_float_edge),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_image_source(),
            longhands::border_image_source::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_image_source),
                " must match longhands::",
                stringify!(border_image_source),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_image_outset(),
            longhands::border_image_outset::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_image_outset),
                " must match longhands::",
                stringify!(border_image_outset),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_image_repeat(),
            longhands::border_image_repeat::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_image_repeat),
                " must match longhands::",
                stringify!(border_image_repeat),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_image_width(),
            longhands::border_image_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_image_width),
                " must match longhands::",
                stringify!(border_image_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_image_slice(),
            longhands::border_image_slice::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_image_slice),
                " must match longhands::",
                stringify!(border_image_slice),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_display(),
            longhands::display::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(display),
                " must match longhands::",
                stringify!(display),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_top_layer(),
            longhands::_moz_top_layer::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_top_layer),
                " must match longhands::",
                stringify!(_moz_top_layer),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_position(),
            longhands::position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(position),
                " must match longhands::",
                stringify!(position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_anchor_name(),
            longhands::anchor_name::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(anchor_name),
                " must match longhands::",
                stringify!(anchor_name),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_anchor_scope(),
            longhands::anchor_scope::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(anchor_scope),
                " must match longhands::",
                stringify!(anchor_scope),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_float(),
            longhands::float::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(float),
                " must match longhands::",
                stringify!(float),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_clear(),
            longhands::clear::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(clear),
                " must match longhands::",
                stringify!(clear),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_vertical_align(),
            longhands::vertical_align::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(vertical_align),
                " must match longhands::",
                stringify!(vertical_align),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_baseline_source(),
            longhands::baseline_source::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(baseline_source),
                " must match longhands::",
                stringify!(baseline_source),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overflow_clip_box_inline(),
            longhands::overflow_clip_box_inline::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overflow_clip_box_inline),
                " must match longhands::",
                stringify!(overflow_clip_box_inline),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overflow_clip_box_block(),
            longhands::overflow_clip_box_block::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overflow_clip_box_block),
                " must match longhands::",
                stringify!(overflow_clip_box_block),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overflow_y(),
            longhands::overflow_y::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overflow_y),
                " must match longhands::",
                stringify!(overflow_y),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overflow_x(),
            longhands::overflow_x::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overflow_x),
                " must match longhands::",
                stringify!(overflow_x),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overflow_anchor(),
            longhands::overflow_anchor::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overflow_anchor),
                " must match longhands::",
                stringify!(overflow_anchor),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transform(),
            longhands::transform::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transform),
                " must match longhands::",
                stringify!(transform),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_rotate(),
            longhands::rotate::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(rotate),
                " must match longhands::",
                stringify!(rotate),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scale(),
            longhands::scale::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scale),
                " must match longhands::",
                stringify!(scale),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_translate(),
            longhands::translate::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(translate),
                " must match longhands::",
                stringify!(translate),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_offset_path(),
            longhands::offset_path::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(offset_path),
                " must match longhands::",
                stringify!(offset_path),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_offset_distance(),
            longhands::offset_distance::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(offset_distance),
                " must match longhands::",
                stringify!(offset_distance),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_offset_rotate(),
            longhands::offset_rotate::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(offset_rotate),
                " must match longhands::",
                stringify!(offset_rotate),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_offset_anchor(),
            longhands::offset_anchor::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(offset_anchor),
                " must match longhands::",
                stringify!(offset_anchor),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_offset_position(),
            longhands::offset_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(offset_position),
                " must match longhands::",
                stringify!(offset_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_behavior(),
            longhands::scroll_behavior::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_behavior),
                " must match longhands::",
                stringify!(scroll_behavior),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_snap_align(),
            longhands::scroll_snap_align::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_snap_align),
                " must match longhands::",
                stringify!(scroll_snap_align),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_snap_type(),
            longhands::scroll_snap_type::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_snap_type),
                " must match longhands::",
                stringify!(scroll_snap_type),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_snap_stop(),
            longhands::scroll_snap_stop::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_snap_stop),
                " must match longhands::",
                stringify!(scroll_snap_stop),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overscroll_behavior_y(),
            longhands::overscroll_behavior_y::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overscroll_behavior_y),
                " must match longhands::",
                stringify!(overscroll_behavior_y),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overscroll_behavior_x(),
            longhands::overscroll_behavior_x::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overscroll_behavior_x),
                " must match longhands::",
                stringify!(overscroll_behavior_x),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_isolation(),
            longhands::isolation::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(isolation),
                " must match longhands::",
                stringify!(isolation),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_break_after(),
            longhands::break_after::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(break_after),
                " must match longhands::",
                stringify!(break_after),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_break_before(),
            longhands::break_before::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(break_before),
                " must match longhands::",
                stringify!(break_before),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_break_inside(),
            longhands::break_inside::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(break_inside),
                " must match longhands::",
                stringify!(break_inside),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_resize(),
            longhands::resize::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(resize),
                " must match longhands::",
                stringify!(resize),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_perspective(),
            longhands::perspective::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(perspective),
                " must match longhands::",
                stringify!(perspective),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_perspective_origin(),
            longhands::perspective_origin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(perspective_origin),
                " must match longhands::",
                stringify!(perspective_origin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_backface_visibility(),
            longhands::backface_visibility::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(backface_visibility),
                " must match longhands::",
                stringify!(backface_visibility),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transform_box(),
            longhands::transform_box::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transform_box),
                " must match longhands::",
                stringify!(transform_box),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transform_style(),
            longhands::transform_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transform_style),
                " must match longhands::",
                stringify!(transform_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transform_origin(),
            longhands::transform_origin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transform_origin),
                " must match longhands::",
                stringify!(transform_origin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_contain(),
            longhands::contain::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(contain),
                " must match longhands::",
                stringify!(contain),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_content_visibility(),
            longhands::content_visibility::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(content_visibility),
                " must match longhands::",
                stringify!(content_visibility),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_container_type(),
            longhands::container_type::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(container_type),
                " must match longhands::",
                stringify!(container_type),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_container_name(),
            longhands::container_name::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(container_name),
                " must match longhands::",
                stringify!(container_name),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_appearance(),
            longhands::appearance::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(appearance),
                " must match longhands::",
                stringify!(appearance),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_default_appearance(),
            longhands::_moz_default_appearance::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_default_appearance),
                " must match longhands::",
                stringify!(_moz_default_appearance),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_orient(),
            longhands::_moz_orient::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_orient),
                " must match longhands::",
                stringify!(_moz_orient),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_will_change(),
            longhands::will_change::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(will_change),
                " must match longhands::",
                stringify!(will_change),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_shape_image_threshold(),
            longhands::shape_image_threshold::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(shape_image_threshold),
                " must match longhands::",
                stringify!(shape_image_threshold),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_shape_margin(),
            longhands::shape_margin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(shape_margin),
                " must match longhands::",
                stringify!(shape_margin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_shape_outside(),
            longhands::shape_outside::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(shape_outside),
                " must match longhands::",
                stringify!(shape_outside),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_touch_action(),
            longhands::touch_action::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(touch_action),
                " must match longhands::",
                stringify!(touch_action),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__webkit_line_clamp(),
            longhands::_webkit_line_clamp::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_webkit_line_clamp),
                " must match longhands::",
                stringify!(_webkit_line_clamp),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scrollbar_gutter(),
            longhands::scrollbar_gutter::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scrollbar_gutter),
                " must match longhands::",
                stringify!(scrollbar_gutter),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_zoom(),
            longhands::zoom::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(zoom),
                " must match longhands::",
                stringify!(zoom),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_column_width(),
            longhands::column_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(column_width),
                " must match longhands::",
                stringify!(column_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_column_count(),
            longhands::column_count::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(column_count),
                " must match longhands::",
                stringify!(column_count),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_column_fill(),
            longhands::column_fill::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(column_fill),
                " must match longhands::",
                stringify!(column_fill),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_column_rule_color(),
            longhands::column_rule_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(column_rule_color),
                " must match longhands::",
                stringify!(column_rule_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_column_span(),
            longhands::column_span::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(column_span),
                " must match longhands::",
                stringify!(column_span),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_column_rule_style(),
            longhands::column_rule_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(column_rule_style),
                " must match longhands::",
                stringify!(column_rule_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_content(),
            longhands::content::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(content),
                " must match longhands::",
                stringify!(content),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_counter_increment(),
            longhands::counter_increment::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(counter_increment),
                " must match longhands::",
                stringify!(counter_increment),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_counter_reset(),
            longhands::counter_reset::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(counter_reset),
                " must match longhands::",
                stringify!(counter_reset),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_counter_set(),
            longhands::counter_set::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(counter_set),
                " must match longhands::",
                stringify!(counter_set),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_opacity(),
            longhands::opacity::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(opacity),
                " must match longhands::",
                stringify!(opacity),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_box_shadow(),
            longhands::box_shadow::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(box_shadow),
                " must match longhands::",
                stringify!(box_shadow),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_clip(),
            longhands::clip::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(clip),
                " must match longhands::",
                stringify!(clip),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_filter(),
            longhands::filter::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(filter),
                " must match longhands::",
                stringify!(filter),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_backdrop_filter(),
            longhands::backdrop_filter::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(backdrop_filter),
                " must match longhands::",
                stringify!(backdrop_filter),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mix_blend_mode(),
            longhands::mix_blend_mode::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mix_blend_mode),
                " must match longhands::",
                stringify!(mix_blend_mode),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_style(),
            longhands::font_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_style),
                " must match longhands::",
                stringify!(font_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variant_caps(),
            longhands::font_variant_caps::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variant_caps),
                " must match longhands::",
                stringify!(font_variant_caps),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_weight(),
            longhands::font_weight::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_weight),
                " must match longhands::",
                stringify!(font_weight),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_size_adjust(),
            longhands::font_size_adjust::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_size_adjust),
                " must match longhands::",
                stringify!(font_size_adjust),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_synthesis_weight(),
            longhands::font_synthesis_weight::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_synthesis_weight),
                " must match longhands::",
                stringify!(font_synthesis_weight),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_synthesis_style(),
            longhands::font_synthesis_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_synthesis_style),
                " must match longhands::",
                stringify!(font_synthesis_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_synthesis_small_caps(),
            longhands::font_synthesis_small_caps::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_synthesis_small_caps),
                " must match longhands::",
                stringify!(font_synthesis_small_caps),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_synthesis_position(),
            longhands::font_synthesis_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_synthesis_position),
                " must match longhands::",
                stringify!(font_synthesis_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_stretch(),
            longhands::font_stretch::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_stretch),
                " must match longhands::",
                stringify!(font_stretch),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_kerning(),
            longhands::font_kerning::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_kerning),
                " must match longhands::",
                stringify!(font_kerning),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variant_alternates(),
            longhands::font_variant_alternates::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variant_alternates),
                " must match longhands::",
                stringify!(font_variant_alternates),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variant_east_asian(),
            longhands::font_variant_east_asian::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variant_east_asian),
                " must match longhands::",
                stringify!(font_variant_east_asian),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variant_emoji(),
            longhands::font_variant_emoji::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variant_emoji),
                " must match longhands::",
                stringify!(font_variant_emoji),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variant_ligatures(),
            longhands::font_variant_ligatures::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variant_ligatures),
                " must match longhands::",
                stringify!(font_variant_ligatures),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variant_numeric(),
            longhands::font_variant_numeric::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variant_numeric),
                " must match longhands::",
                stringify!(font_variant_numeric),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variant_position(),
            longhands::font_variant_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variant_position),
                " must match longhands::",
                stringify!(font_variant_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_feature_settings(),
            longhands::font_feature_settings::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_feature_settings),
                " must match longhands::",
                stringify!(font_feature_settings),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_variation_settings(),
            longhands::font_variation_settings::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_variation_settings),
                " must match longhands::",
                stringify!(font_variation_settings),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_language_override(),
            longhands::font_language_override::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_language_override),
                " must match longhands::",
                stringify!(font_language_override),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_optical_sizing(),
            longhands::font_optical_sizing::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_optical_sizing),
                " must match longhands::",
                stringify!(font_optical_sizing),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_font_palette(),
            longhands::font_palette::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(font_palette),
                " must match longhands::",
                stringify!(font_palette),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_math_depth(),
            longhands::math_depth::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(math_depth),
                " must match longhands::",
                stringify!(math_depth),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_math_style(),
            longhands::math_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(math_style),
                " must match longhands::",
                stringify!(math_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_line_height(),
            longhands::line_height::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(line_height),
                " must match longhands::",
                stringify!(line_height),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_osx_font_smoothing(),
            longhands::_moz_osx_font_smoothing::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_osx_font_smoothing),
                " must match longhands::",
                stringify!(_moz_osx_font_smoothing),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_min_font_size_ratio(),
            longhands::_moz_min_font_size_ratio::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_min_font_size_ratio),
                " must match longhands::",
                stringify!(_moz_min_font_size_ratio),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_visibility(),
            longhands::visibility::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(visibility),
                " must match longhands::",
                stringify!(visibility),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_writing_mode(),
            longhands::writing_mode::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(writing_mode),
                " must match longhands::",
                stringify!(writing_mode),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_direction(),
            longhands::direction::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(direction),
                " must match longhands::",
                stringify!(direction),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_box_collapse(),
            longhands::_moz_box_collapse::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_box_collapse),
                " must match longhands::",
                stringify!(_moz_box_collapse),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_orientation(),
            longhands::text_orientation::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_orientation),
                " must match longhands::",
                stringify!(text_orientation),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_print_color_adjust(),
            longhands::print_color_adjust::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(print_color_adjust),
                " must match longhands::",
                stringify!(print_color_adjust),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_image_rendering(),
            longhands::image_rendering::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(image_rendering),
                " must match longhands::",
                stringify!(image_rendering),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_image_orientation(),
            longhands::image_orientation::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(image_orientation),
                " must match longhands::",
                stringify!(image_orientation),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_dominant_baseline(),
            longhands::dominant_baseline::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(dominant_baseline),
                " must match longhands::",
                stringify!(dominant_baseline),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_anchor(),
            longhands::text_anchor::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_anchor),
                " must match longhands::",
                stringify!(text_anchor),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_color_interpolation(),
            longhands::color_interpolation::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(color_interpolation),
                " must match longhands::",
                stringify!(color_interpolation),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_color_interpolation_filters(),
            longhands::color_interpolation_filters::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(color_interpolation_filters),
                " must match longhands::",
                stringify!(color_interpolation_filters),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_fill(),
            longhands::fill::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(fill),
                " must match longhands::",
                stringify!(fill),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_fill_opacity(),
            longhands::fill_opacity::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(fill_opacity),
                " must match longhands::",
                stringify!(fill_opacity),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_fill_rule(),
            longhands::fill_rule::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(fill_rule),
                " must match longhands::",
                stringify!(fill_rule),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_shape_rendering(),
            longhands::shape_rendering::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(shape_rendering),
                " must match longhands::",
                stringify!(shape_rendering),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke(),
            longhands::stroke::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke),
                " must match longhands::",
                stringify!(stroke),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke_width(),
            longhands::stroke_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke_width),
                " must match longhands::",
                stringify!(stroke_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke_linecap(),
            longhands::stroke_linecap::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke_linecap),
                " must match longhands::",
                stringify!(stroke_linecap),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke_linejoin(),
            longhands::stroke_linejoin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke_linejoin),
                " must match longhands::",
                stringify!(stroke_linejoin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke_miterlimit(),
            longhands::stroke_miterlimit::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke_miterlimit),
                " must match longhands::",
                stringify!(stroke_miterlimit),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke_opacity(),
            longhands::stroke_opacity::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke_opacity),
                " must match longhands::",
                stringify!(stroke_opacity),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke_dasharray(),
            longhands::stroke_dasharray::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke_dasharray),
                " must match longhands::",
                stringify!(stroke_dasharray),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stroke_dashoffset(),
            longhands::stroke_dashoffset::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stroke_dashoffset),
                " must match longhands::",
                stringify!(stroke_dashoffset),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_clip_rule(),
            longhands::clip_rule::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(clip_rule),
                " must match longhands::",
                stringify!(clip_rule),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_marker_start(),
            longhands::marker_start::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(marker_start),
                " must match longhands::",
                stringify!(marker_start),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_marker_mid(),
            longhands::marker_mid::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(marker_mid),
                " must match longhands::",
                stringify!(marker_mid),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_marker_end(),
            longhands::marker_end::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(marker_end),
                " must match longhands::",
                stringify!(marker_end),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_paint_order(),
            longhands::paint_order::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(paint_order),
                " must match longhands::",
                stringify!(paint_order),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_context_properties(),
            longhands::_moz_context_properties::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_context_properties),
                " must match longhands::",
                stringify!(_moz_context_properties),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_collapse(),
            longhands::border_collapse::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_collapse),
                " must match longhands::",
                stringify!(border_collapse),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_empty_cells(),
            longhands::empty_cells::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(empty_cells),
                " must match longhands::",
                stringify!(empty_cells),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_caption_side(),
            longhands::caption_side::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(caption_side),
                " must match longhands::",
                stringify!(caption_side),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_border_spacing(),
            longhands::border_spacing::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(border_spacing),
                " must match longhands::",
                stringify!(border_spacing),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_transform(),
            longhands::text_transform::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_transform),
                " must match longhands::",
                stringify!(text_transform),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_hyphens(),
            longhands::hyphens::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(hyphens),
                " must match longhands::",
                stringify!(hyphens),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_text_size_adjust(),
            longhands::_moz_text_size_adjust::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_text_size_adjust),
                " must match longhands::",
                stringify!(_moz_text_size_adjust),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_indent(),
            longhands::text_indent::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_indent),
                " must match longhands::",
                stringify!(text_indent),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overflow_wrap(),
            longhands::overflow_wrap::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overflow_wrap),
                " must match longhands::",
                stringify!(overflow_wrap),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_word_break(),
            longhands::word_break::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(word_break),
                " must match longhands::",
                stringify!(word_break),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_justify(),
            longhands::text_justify::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_justify),
                " must match longhands::",
                stringify!(text_justify),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_align_last(),
            longhands::text_align_last::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_align_last),
                " must match longhands::",
                stringify!(text_align_last),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_align(),
            longhands::text_align::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_align),
                " must match longhands::",
                stringify!(text_align),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_letter_spacing(),
            longhands::letter_spacing::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(letter_spacing),
                " must match longhands::",
                stringify!(letter_spacing),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_word_spacing(),
            longhands::word_spacing::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(word_spacing),
                " must match longhands::",
                stringify!(word_spacing),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_white_space_collapse(),
            longhands::white_space_collapse::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(white_space_collapse),
                " must match longhands::",
                stringify!(white_space_collapse),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_shadow(),
            longhands::text_shadow::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_shadow),
                " must match longhands::",
                stringify!(text_shadow),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_emphasis_style(),
            longhands::text_emphasis_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_emphasis_style),
                " must match longhands::",
                stringify!(text_emphasis_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_emphasis_position(),
            longhands::text_emphasis_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_emphasis_position),
                " must match longhands::",
                stringify!(text_emphasis_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_emphasis_color(),
            longhands::text_emphasis_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_emphasis_color),
                " must match longhands::",
                stringify!(text_emphasis_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_tab_size(),
            longhands::tab_size::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(tab_size),
                " must match longhands::",
                stringify!(tab_size),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_line_break(),
            longhands::line_break::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(line_break),
                " must match longhands::",
                stringify!(line_break),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__webkit_text_fill_color(),
            longhands::_webkit_text_fill_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_webkit_text_fill_color),
                " must match longhands::",
                stringify!(_webkit_text_fill_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__webkit_text_stroke_color(),
            longhands::_webkit_text_stroke_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_webkit_text_stroke_color),
                " must match longhands::",
                stringify!(_webkit_text_stroke_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__webkit_text_stroke_width(),
            longhands::_webkit_text_stroke_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_webkit_text_stroke_width),
                " must match longhands::",
                stringify!(_webkit_text_stroke_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_ruby_align(),
            longhands::ruby_align::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(ruby_align),
                " must match longhands::",
                stringify!(ruby_align),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_ruby_position(),
            longhands::ruby_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(ruby_position),
                " must match longhands::",
                stringify!(ruby_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_combine_upright(),
            longhands::text_combine_upright::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_combine_upright),
                " must match longhands::",
                stringify!(text_combine_upright),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_rendering(),
            longhands::text_rendering::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_rendering),
                " must match longhands::",
                stringify!(text_rendering),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_control_character_visibility(),
            longhands::_moz_control_character_visibility::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_control_character_visibility),
                " must match longhands::",
                stringify!(_moz_control_character_visibility),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_underline_offset(),
            longhands::text_underline_offset::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_underline_offset),
                " must match longhands::",
                stringify!(text_underline_offset),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_underline_position(),
            longhands::text_underline_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_underline_position),
                " must match longhands::",
                stringify!(text_underline_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_decoration_skip_ink(),
            longhands::text_decoration_skip_ink::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_decoration_skip_ink),
                " must match longhands::",
                stringify!(text_decoration_skip_ink),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_hyphenate_character(),
            longhands::hyphenate_character::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(hyphenate_character),
                " must match longhands::",
                stringify!(hyphenate_character),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_forced_color_adjust(),
            longhands::forced_color_adjust::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(forced_color_adjust),
                " must match longhands::",
                stringify!(forced_color_adjust),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__webkit_text_security(),
            longhands::_webkit_text_security::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_webkit_text_security),
                " must match longhands::",
                stringify!(_webkit_text_security),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_wrap_mode(),
            longhands::text_wrap_mode::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_wrap_mode),
                " must match longhands::",
                stringify!(text_wrap_mode),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_wrap_style(),
            longhands::text_wrap_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_wrap_style),
                " must match longhands::",
                stringify!(text_wrap_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_cursor(),
            longhands::cursor::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(cursor),
                " must match longhands::",
                stringify!(cursor),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_pointer_events(),
            longhands::pointer_events::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(pointer_events),
                " must match longhands::",
                stringify!(pointer_events),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_inert(),
            longhands::_moz_inert::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_inert),
                " must match longhands::",
                stringify!(_moz_inert),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_user_input(),
            longhands::_moz_user_input::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_user_input),
                " must match longhands::",
                stringify!(_moz_user_input),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_user_modify(),
            longhands::_moz_user_modify::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_user_modify),
                " must match longhands::",
                stringify!(_moz_user_modify),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_user_focus(),
            longhands::_moz_user_focus::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_user_focus),
                " must match longhands::",
                stringify!(_moz_user_focus),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_caret_color(),
            longhands::caret_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(caret_color),
                " must match longhands::",
                stringify!(caret_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_accent_color(),
            longhands::accent_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(accent_color),
                " must match longhands::",
                stringify!(accent_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_color_scheme(),
            longhands::color_scheme::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(color_scheme),
                " must match longhands::",
                stringify!(color_scheme),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scrollbar_color(),
            longhands::scrollbar_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scrollbar_color),
                " must match longhands::",
                stringify!(scrollbar_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_theme(),
            longhands::_moz_theme::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_theme),
                " must match longhands::",
                stringify!(_moz_theme),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_list_style_position(),
            longhands::list_style_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(list_style_position),
                " must match longhands::",
                stringify!(list_style_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_list_style_type(),
            longhands::list_style_type::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(list_style_type),
                " must match longhands::",
                stringify!(list_style_type),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_list_style_image(),
            longhands::list_style_image::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(list_style_image),
                " must match longhands::",
                stringify!(list_style_image),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_quotes(),
            longhands::quotes::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(quotes),
                " must match longhands::",
                stringify!(quotes),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_margin_top(),
            longhands::margin_top::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(margin_top),
                " must match longhands::",
                stringify!(margin_top),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_margin_right(),
            longhands::margin_right::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(margin_right),
                " must match longhands::",
                stringify!(margin_right),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_margin_bottom(),
            longhands::margin_bottom::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(margin_bottom),
                " must match longhands::",
                stringify!(margin_bottom),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_margin_left(),
            longhands::margin_left::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(margin_left),
                " must match longhands::",
                stringify!(margin_left),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_overflow_clip_margin(),
            longhands::overflow_clip_margin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(overflow_clip_margin),
                " must match longhands::",
                stringify!(overflow_clip_margin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_margin_top(),
            longhands::scroll_margin_top::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_margin_top),
                " must match longhands::",
                stringify!(scroll_margin_top),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_margin_right(),
            longhands::scroll_margin_right::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_margin_right),
                " must match longhands::",
                stringify!(scroll_margin_right),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_margin_bottom(),
            longhands::scroll_margin_bottom::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_margin_bottom),
                " must match longhands::",
                stringify!(scroll_margin_bottom),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_margin_left(),
            longhands::scroll_margin_left::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_margin_left),
                " must match longhands::",
                stringify!(scroll_margin_left),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_outline_color(),
            longhands::outline_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(outline_color),
                " must match longhands::",
                stringify!(outline_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_outline_style(),
            longhands::outline_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(outline_style),
                " must match longhands::",
                stringify!(outline_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_outline_offset(),
            longhands::outline_offset::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(outline_offset),
                " must match longhands::",
                stringify!(outline_offset),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_padding_top(),
            longhands::padding_top::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(padding_top),
                " must match longhands::",
                stringify!(padding_top),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_padding_right(),
            longhands::padding_right::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(padding_right),
                " must match longhands::",
                stringify!(padding_right),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_padding_bottom(),
            longhands::padding_bottom::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(padding_bottom),
                " must match longhands::",
                stringify!(padding_bottom),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_padding_left(),
            longhands::padding_left::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(padding_left),
                " must match longhands::",
                stringify!(padding_left),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_padding_top(),
            longhands::scroll_padding_top::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_padding_top),
                " must match longhands::",
                stringify!(scroll_padding_top),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_padding_right(),
            longhands::scroll_padding_right::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_padding_right),
                " must match longhands::",
                stringify!(scroll_padding_right),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_padding_bottom(),
            longhands::scroll_padding_bottom::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_padding_bottom),
                " must match longhands::",
                stringify!(scroll_padding_bottom),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_padding_left(),
            longhands::scroll_padding_left::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_padding_left),
                " must match longhands::",
                stringify!(scroll_padding_left),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_size(),
            longhands::size::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(size),
                " must match longhands::",
                stringify!(size),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_page(),
            longhands::page::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(page),
                " must match longhands::",
                stringify!(page),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_page_orientation(),
            longhands::page_orientation::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(page_orientation),
                " must match longhands::",
                stringify!(page_orientation),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_top(),
            longhands::top::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(top),
                " must match longhands::",
                stringify!(top),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_right(),
            longhands::right::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(right),
                " must match longhands::",
                stringify!(right),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_bottom(),
            longhands::bottom::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(bottom),
                " must match longhands::",
                stringify!(bottom),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_left(),
            longhands::left::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(left),
                " must match longhands::",
                stringify!(left),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_z_index(),
            longhands::z_index::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(z_index),
                " must match longhands::",
                stringify!(z_index),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_flex_direction(),
            longhands::flex_direction::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(flex_direction),
                " must match longhands::",
                stringify!(flex_direction),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_flex_wrap(),
            longhands::flex_wrap::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(flex_wrap),
                " must match longhands::",
                stringify!(flex_wrap),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_justify_content(),
            longhands::justify_content::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(justify_content),
                " must match longhands::",
                stringify!(justify_content),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_align_content(),
            longhands::align_content::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(align_content),
                " must match longhands::",
                stringify!(align_content),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_align_items(),
            longhands::align_items::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(align_items),
                " must match longhands::",
                stringify!(align_items),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_justify_items(),
            longhands::justify_items::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(justify_items),
                " must match longhands::",
                stringify!(justify_items),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_flex_grow(),
            longhands::flex_grow::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(flex_grow),
                " must match longhands::",
                stringify!(flex_grow),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_flex_shrink(),
            longhands::flex_shrink::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(flex_shrink),
                " must match longhands::",
                stringify!(flex_shrink),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_align_self(),
            longhands::align_self::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(align_self),
                " must match longhands::",
                stringify!(align_self),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_justify_self(),
            longhands::justify_self::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(justify_self),
                " must match longhands::",
                stringify!(justify_self),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_order(),
            longhands::order::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(order),
                " must match longhands::",
                stringify!(order),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_flex_basis(),
            longhands::flex_basis::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(flex_basis),
                " must match longhands::",
                stringify!(flex_basis),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_height(),
            longhands::height::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(height),
                " must match longhands::",
                stringify!(height),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_min_height(),
            longhands::min_height::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(min_height),
                " must match longhands::",
                stringify!(min_height),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_max_height(),
            longhands::max_height::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(max_height),
                " must match longhands::",
                stringify!(max_height),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_width(),
            longhands::width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(width),
                " must match longhands::",
                stringify!(width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_min_width(),
            longhands::min_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(min_width),
                " must match longhands::",
                stringify!(min_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_max_width(),
            longhands::max_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(max_width),
                " must match longhands::",
                stringify!(max_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_position_anchor(),
            longhands::position_anchor::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(position_anchor),
                " must match longhands::",
                stringify!(position_anchor),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_position_visibility(),
            longhands::position_visibility::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(position_visibility),
                " must match longhands::",
                stringify!(position_visibility),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_inset_area(),
            longhands::inset_area::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(inset_area),
                " must match longhands::",
                stringify!(inset_area),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_position_try_options(),
            longhands::position_try_options::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(position_try_options),
                " must match longhands::",
                stringify!(position_try_options),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_position_try_order(),
            longhands::position_try_order::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(position_try_order),
                " must match longhands::",
                stringify!(position_try_order),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_box_sizing(),
            longhands::box_sizing::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(box_sizing),
                " must match longhands::",
                stringify!(box_sizing),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_object_fit(),
            longhands::object_fit::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(object_fit),
                " must match longhands::",
                stringify!(object_fit),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_object_position(),
            longhands::object_position::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(object_position),
                " must match longhands::",
                stringify!(object_position),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_row_start(),
            longhands::grid_row_start::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_row_start),
                " must match longhands::",
                stringify!(grid_row_start),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_row_end(),
            longhands::grid_row_end::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_row_end),
                " must match longhands::",
                stringify!(grid_row_end),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_auto_rows(),
            longhands::grid_auto_rows::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_auto_rows),
                " must match longhands::",
                stringify!(grid_auto_rows),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_template_rows(),
            longhands::grid_template_rows::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_template_rows),
                " must match longhands::",
                stringify!(grid_template_rows),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_column_start(),
            longhands::grid_column_start::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_column_start),
                " must match longhands::",
                stringify!(grid_column_start),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_column_end(),
            longhands::grid_column_end::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_column_end),
                " must match longhands::",
                stringify!(grid_column_end),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_auto_columns(),
            longhands::grid_auto_columns::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_auto_columns),
                " must match longhands::",
                stringify!(grid_auto_columns),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_template_columns(),
            longhands::grid_template_columns::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_template_columns),
                " must match longhands::",
                stringify!(grid_template_columns),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_masonry_auto_flow(),
            longhands::masonry_auto_flow::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(masonry_auto_flow),
                " must match longhands::",
                stringify!(masonry_auto_flow),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_auto_flow(),
            longhands::grid_auto_flow::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_auto_flow),
                " must match longhands::",
                stringify!(grid_auto_flow),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_grid_template_areas(),
            longhands::grid_template_areas::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(grid_template_areas),
                " must match longhands::",
                stringify!(grid_template_areas),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_column_gap(),
            longhands::column_gap::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(column_gap),
                " must match longhands::",
                stringify!(column_gap),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_row_gap(),
            longhands::row_gap::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(row_gap),
                " must match longhands::",
                stringify!(row_gap),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_aspect_ratio(),
            longhands::aspect_ratio::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(aspect_ratio),
                " must match longhands::",
                stringify!(aspect_ratio),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_contain_intrinsic_height(),
            longhands::contain_intrinsic_height::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(contain_intrinsic_height),
                " must match longhands::",
                stringify!(contain_intrinsic_height),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_contain_intrinsic_width(),
            longhands::contain_intrinsic_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(contain_intrinsic_width),
                " must match longhands::",
                stringify!(contain_intrinsic_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_vector_effect(),
            longhands::vector_effect::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(vector_effect),
                " must match longhands::",
                stringify!(vector_effect),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stop_color(),
            longhands::stop_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stop_color),
                " must match longhands::",
                stringify!(stop_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_stop_opacity(),
            longhands::stop_opacity::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(stop_opacity),
                " must match longhands::",
                stringify!(stop_opacity),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_flood_color(),
            longhands::flood_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(flood_color),
                " must match longhands::",
                stringify!(flood_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_flood_opacity(),
            longhands::flood_opacity::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(flood_opacity),
                " must match longhands::",
                stringify!(flood_opacity),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_lighting_color(),
            longhands::lighting_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(lighting_color),
                " must match longhands::",
                stringify!(lighting_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_type(),
            longhands::mask_type::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_type),
                " must match longhands::",
                stringify!(mask_type),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_clip_path(),
            longhands::clip_path::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(clip_path),
                " must match longhands::",
                stringify!(clip_path),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_mode(),
            longhands::mask_mode::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_mode),
                " must match longhands::",
                stringify!(mask_mode),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_repeat(),
            longhands::mask_repeat::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_repeat),
                " must match longhands::",
                stringify!(mask_repeat),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_position_x(),
            longhands::mask_position_x::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_position_x),
                " must match longhands::",
                stringify!(mask_position_x),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_position_y(),
            longhands::mask_position_y::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_position_y),
                " must match longhands::",
                stringify!(mask_position_y),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_clip(),
            longhands::mask_clip::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_clip),
                " must match longhands::",
                stringify!(mask_clip),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_origin(),
            longhands::mask_origin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_origin),
                " must match longhands::",
                stringify!(mask_origin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_size(),
            longhands::mask_size::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_size),
                " must match longhands::",
                stringify!(mask_size),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_composite(),
            longhands::mask_composite::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_composite),
                " must match longhands::",
                stringify!(mask_composite),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_mask_image(),
            longhands::mask_image::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(mask_image),
                " must match longhands::",
                stringify!(mask_image),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_x(),
            longhands::x::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(x),
                " must match longhands::",
                stringify!(x),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_y(),
            longhands::y::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(y),
                " must match longhands::",
                stringify!(y),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_cx(),
            longhands::cx::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(cx),
                " must match longhands::",
                stringify!(cx),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_cy(),
            longhands::cy::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(cy),
                " must match longhands::",
                stringify!(cy),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_rx(),
            longhands::rx::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(rx),
                " must match longhands::",
                stringify!(rx),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_ry(),
            longhands::ry::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(ry),
                " must match longhands::",
                stringify!(ry),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_r(),
            longhands::r::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(r),
                " must match longhands::",
                stringify!(r),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_d(),
            longhands::d::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(d),
                " must match longhands::",
                stringify!(d),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_table_layout(),
            longhands::table_layout::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(table_layout),
                " must match longhands::",
                stringify!(table_layout),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_overflow(),
            longhands::text_overflow::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_overflow),
                " must match longhands::",
                stringify!(text_overflow),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_unicode_bidi(),
            longhands::unicode_bidi::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(unicode_bidi),
                " must match longhands::",
                stringify!(unicode_bidi),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_decoration_line(),
            longhands::text_decoration_line::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_decoration_line),
                " must match longhands::",
                stringify!(text_decoration_line),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_decoration_style(),
            longhands::text_decoration_style::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_decoration_style),
                " must match longhands::",
                stringify!(text_decoration_style),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_decoration_color(),
            longhands::text_decoration_color::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_decoration_color),
                " must match longhands::",
                stringify!(text_decoration_color),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_initial_letter(),
            longhands::initial_letter::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(initial_letter),
                " must match longhands::",
                stringify!(initial_letter),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_text_decoration_thickness(),
            longhands::text_decoration_thickness::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(text_decoration_thickness),
                " must match longhands::",
                stringify!(text_decoration_thickness),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_ime_mode(),
            longhands::ime_mode::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(ime_mode),
                " must match longhands::",
                stringify!(ime_mode),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scrollbar_width(),
            longhands::scrollbar_width::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scrollbar_width),
                " must match longhands::",
                stringify!(scrollbar_width),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_user_select(),
            longhands::user_select::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(user_select),
                " must match longhands::",
                stringify!(user_select),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_window_dragging(),
            longhands::_moz_window_dragging::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_window_dragging),
                " must match longhands::",
                stringify!(_moz_window_dragging),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_window_shadow(),
            longhands::_moz_window_shadow::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_window_shadow),
                " must match longhands::",
                stringify!(_moz_window_shadow),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_window_opacity(),
            longhands::_moz_window_opacity::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_window_opacity),
                " must match longhands::",
                stringify!(_moz_window_opacity),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_window_transform(),
            longhands::_moz_window_transform::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_window_transform),
                " must match longhands::",
                stringify!(_moz_window_transform),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_window_transform_origin(),
            longhands::_moz_window_transform_origin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_window_transform_origin),
                " must match longhands::",
                stringify!(_moz_window_transform_origin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_window_input_region_margin(),
            longhands::_moz_window_input_region_margin::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_window_input_region_margin),
                " must match longhands::",
                stringify!(_moz_window_input_region_margin),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_subtree_hidden_only_visually(),
            longhands::_moz_subtree_hidden_only_visually::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_subtree_hidden_only_visually),
                " must match longhands::",
                stringify!(_moz_subtree_hidden_only_visually),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_force_broken_image_icon(),
            longhands::_moz_force_broken_image_icon::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_force_broken_image_icon),
                " must match longhands::",
                stringify!(_moz_force_broken_image_icon),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transition_duration(),
            longhands::transition_duration::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transition_duration),
                " must match longhands::",
                stringify!(transition_duration),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transition_timing_function(),
            longhands::transition_timing_function::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transition_timing_function),
                " must match longhands::",
                stringify!(transition_timing_function),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transition_property(),
            longhands::transition_property::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transition_property),
                " must match longhands::",
                stringify!(transition_property),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transition_delay(),
            longhands::transition_delay::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transition_delay),
                " must match longhands::",
                stringify!(transition_delay),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_transition_behavior(),
            longhands::transition_behavior::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(transition_behavior),
                " must match longhands::",
                stringify!(transition_behavior),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_name(),
            longhands::animation_name::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_name),
                " must match longhands::",
                stringify!(animation_name),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_duration(),
            longhands::animation_duration::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_duration),
                " must match longhands::",
                stringify!(animation_duration),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_timing_function(),
            longhands::animation_timing_function::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_timing_function),
                " must match longhands::",
                stringify!(animation_timing_function),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_iteration_count(),
            longhands::animation_iteration_count::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_iteration_count),
                " must match longhands::",
                stringify!(animation_iteration_count),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_direction(),
            longhands::animation_direction::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_direction),
                " must match longhands::",
                stringify!(animation_direction),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_play_state(),
            longhands::animation_play_state::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_play_state),
                " must match longhands::",
                stringify!(animation_play_state),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_fill_mode(),
            longhands::animation_fill_mode::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_fill_mode),
                " must match longhands::",
                stringify!(animation_fill_mode),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_composition(),
            longhands::animation_composition::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_composition),
                " must match longhands::",
                stringify!(animation_composition),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_delay(),
            longhands::animation_delay::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_delay),
                " must match longhands::",
                stringify!(animation_delay),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_animation_timeline(),
            longhands::animation_timeline::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(animation_timeline),
                " must match longhands::",
                stringify!(animation_timeline),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_timeline_name(),
            longhands::scroll_timeline_name::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_timeline_name),
                " must match longhands::",
                stringify!(scroll_timeline_name),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_scroll_timeline_axis(),
            longhands::scroll_timeline_axis::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(scroll_timeline_axis),
                " must match longhands::",
                stringify!(scroll_timeline_axis),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_view_timeline_name(),
            longhands::view_timeline_name::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(view_timeline_name),
                " must match longhands::",
                stringify!(view_timeline_name),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_view_timeline_axis(),
            longhands::view_timeline_axis::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(view_timeline_axis),
                " must match longhands::",
                stringify!(view_timeline_axis),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone_view_timeline_inset(),
            longhands::view_timeline_inset::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(view_timeline_inset),
                " must match longhands::",
                stringify!(view_timeline_inset),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_box_align(),
            longhands::_moz_box_align::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_box_align),
                " must match longhands::",
                stringify!(_moz_box_align),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_box_direction(),
            longhands::_moz_box_direction::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_box_direction),
                " must match longhands::",
                stringify!(_moz_box_direction),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_box_flex(),
            longhands::_moz_box_flex::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_box_flex),
                " must match longhands::",
                stringify!(_moz_box_flex),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_box_orient(),
            longhands::_moz_box_orient::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_box_orient),
                " must match longhands::",
                stringify!(_moz_box_orient),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_box_pack(),
            longhands::_moz_box_pack::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_box_pack),
                " must match longhands::",
                stringify!(_moz_box_pack),
                "::get_initial_value()"
            )
        );
        assert_eq!(
            cv.clone__moz_box_ordinal_group(),
            longhands::_moz_box_ordinal_group::get_initial_value(),
            concat!(
                "initial value in Gecko style struct for ",
                stringify!(_moz_box_ordinal_group),
                " must match longhands::",
                stringify!(_moz_box_ordinal_group),
                "::get_initial_value()"
            )
        );
    }
}

}


macro_rules! unwrap_or_initial {
    ($prop: ident) => (unwrap_or_initial!($prop, $prop));
    ($prop: ident, $expr: expr) =>
        ($expr.unwrap_or_else(|| $prop::get_initial_specified_value()));
}

/// A module with code for all the shorthand css properties, and a few
/// serialization helpers.
#[allow(missing_docs)]
pub mod shorthands {
    use cssparser::Parser;
    use crate::parser::{Parse, ParserContext};
    use style_traits::{ParseError, StyleParseErrorKind};
    use crate::values::specified;

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */



// TODO: other background-* properties


    /// https://drafts.csswg.org/css-backgrounds/#the-background
    pub mod background {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub background_color:
                    longhands::background_color::SpecifiedValue
                    ,
                pub background_position_x:
                    longhands::background_position_x::SpecifiedValue
                    ,
                pub background_position_y:
                    longhands::background_position_y::SpecifiedValue
                    ,
                pub background_repeat:
                    longhands::background_repeat::SpecifiedValue
                    ,
                pub background_attachment:
                    longhands::background_attachment::SpecifiedValue
                    ,
                pub background_image:
                    longhands::background_image::SpecifiedValue
                    ,
                pub background_size:
                    longhands::background_size::SpecifiedValue
                    ,
                pub background_origin:
                    longhands::background_origin::SpecifiedValue
                    ,
                pub background_clip:
                    longhands::background_clip::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub background_color:
                    &'a longhands::background_color::SpecifiedValue,
                pub background_position_x:
                    &'a longhands::background_position_x::SpecifiedValue,
                pub background_position_y:
                    &'a longhands::background_position_y::SpecifiedValue,
                pub background_repeat:
                    &'a longhands::background_repeat::SpecifiedValue,
                pub background_attachment:
                    &'a longhands::background_attachment::SpecifiedValue,
                pub background_image:
                    &'a longhands::background_image::SpecifiedValue,
                pub background_size:
                    &'a longhands::background_size::SpecifiedValue,
                pub background_origin:
                    &'a longhands::background_origin::SpecifiedValue,
                pub background_clip:
                    &'a longhands::background_clip::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut background_color =
                        None::< &'a longhands::background_color::SpecifiedValue>;
                    let mut background_position_x =
                        None::< &'a longhands::background_position_x::SpecifiedValue>;
                    let mut background_position_y =
                        None::< &'a longhands::background_position_y::SpecifiedValue>;
                    let mut background_repeat =
                        None::< &'a longhands::background_repeat::SpecifiedValue>;
                    let mut background_attachment =
                        None::< &'a longhands::background_attachment::SpecifiedValue>;
                    let mut background_image =
                        None::< &'a longhands::background_image::SpecifiedValue>;
                    let mut background_size =
                        None::< &'a longhands::background_size::SpecifiedValue>;
                    let mut background_origin =
                        None::< &'a longhands::background_origin::SpecifiedValue>;
                    let mut background_clip =
                        None::< &'a longhands::background_clip::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BackgroundColor(ref value) => {
                                background_color = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionX(ref value) => {
                                background_position_x = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionY(ref value) => {
                                background_position_y = Some(value)
                            },
                            PropertyDeclaration::BackgroundRepeat(ref value) => {
                                background_repeat = Some(value)
                            },
                            PropertyDeclaration::BackgroundAttachment(ref value) => {
                                background_attachment = Some(value)
                            },
                            PropertyDeclaration::BackgroundImage(ref value) => {
                                background_image = Some(value)
                            },
                            PropertyDeclaration::BackgroundSize(ref value) => {
                                background_size = Some(value)
                            },
                            PropertyDeclaration::BackgroundOrigin(ref value) => {
                                background_origin = Some(value)
                            },
                            PropertyDeclaration::BackgroundClip(ref value) => {
                                background_clip = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        background_color,
                        background_position_x,
                        background_position_y,
                        background_repeat,
                        background_attachment,
                        background_image,
                        background_size,
                        background_origin,
                        background_clip,
                ) {

                    (
                        Some(background_color),
                        Some(background_position_x),
                        Some(background_position_y),
                        Some(background_repeat),
                        Some(background_attachment),
                        Some(background_image),
                        Some(background_size),
                        Some(background_origin),
                        Some(background_clip),
                    ) =>
                    Ok(LonghandsToSerialize {
                            background_color,
                            background_position_x,
                            background_position_y,
                            background_repeat,
                            background_attachment,
                            background_image,
                            background_size,
                            background_origin,
                            background_clip,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BackgroundColor(
                        longhands.background_color
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionX(
                        longhands.background_position_x
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionY(
                        longhands.background_position_y
                    ));
                    declarations.push(PropertyDeclaration::BackgroundRepeat(
                        longhands.background_repeat
                    ));
                    declarations.push(PropertyDeclaration::BackgroundAttachment(
                        longhands.background_attachment
                    ));
                    declarations.push(PropertyDeclaration::BackgroundImage(
                        longhands.background_image
                    ));
                    declarations.push(PropertyDeclaration::BackgroundSize(
                        longhands.background_size
                    ));
                    declarations.push(PropertyDeclaration::BackgroundOrigin(
                        longhands.background_origin
                    ));
                    declarations.push(PropertyDeclaration::BackgroundClip(
                        longhands.background_clip
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{background_position_x, background_position_y, background_repeat};
    use crate::properties::longhands::{background_attachment, background_color, background_image, background_size, background_origin};
    use crate::properties::longhands::background_clip;
    use crate::properties::longhands::background_clip::single_value::computed_value::T as Clip;
    use crate::properties::longhands::background_origin::single_value::computed_value::T as Origin;
    use crate::values::specified::{AllowQuirks, Color, Position, PositionComponent};
    use crate::parser::Parse;

    // FIXME(emilio): Should be the same type!
    impl From<background_origin::single_value::SpecifiedValue> for background_clip::single_value::SpecifiedValue {
        fn from(origin: background_origin::single_value::SpecifiedValue) ->
            background_clip::single_value::SpecifiedValue {
            match origin {
                background_origin::single_value::SpecifiedValue::ContentBox =>
                    background_clip::single_value::SpecifiedValue::ContentBox,
                background_origin::single_value::SpecifiedValue::PaddingBox =>
                    background_clip::single_value::SpecifiedValue::PaddingBox,
                background_origin::single_value::SpecifiedValue::BorderBox =>
                    background_clip::single_value::SpecifiedValue::BorderBox,
            }
        }
    }

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut background_color = None;

        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_image = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_position_x = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_position_y = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_repeat = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_size = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_attachment = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_origin = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut background_clip = Vec::with_capacity(1);
        input.parse_comma_separated(|input| {
            // background-color can only be in the last element, so if it
            // is parsed anywhere before, the value is invalid.
            if background_color.is_some() {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
            }

                let mut image = None;
                let mut position = None;
                let mut repeat = None;
                let mut size = None;
                let mut attachment = None;
                let mut origin = None;
                let mut clip = None;
            loop {
                if background_color.is_none() {
                    if let Ok(value) = input.try_parse(|i| Color::parse(context, i)) {
                        background_color = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try_parse(|input| {
                        Position::parse_three_value_quirky(context, input, AllowQuirks::No)
                    }) {
                        position = Some(value);

                        // Parse background size, if applicable.
                        size = input.try_parse(|input| {
                            input.expect_delim('/')?;
                            background_size::single_value::parse(context, input)
                        }).ok();

                        continue
                    }
                }
                    if image.is_none() {
                        if let Ok(value) = input.try_parse(|input| background_image::single_value
                                                                               ::parse(context, input)) {
                            image = Some(value);
                            continue
                        }
                    }
                    if repeat.is_none() {
                        if let Ok(value) = input.try_parse(|input| background_repeat::single_value
                                                                               ::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                    if attachment.is_none() {
                        if let Ok(value) = input.try_parse(|input| background_attachment::single_value
                                                                               ::parse(context, input)) {
                            attachment = Some(value);
                            continue
                        }
                    }
                    if origin.is_none() {
                        if let Ok(value) = input.try_parse(|input| background_origin::single_value
                                                                               ::parse(context, input)) {
                            origin = Some(value);
                            continue
                        }
                    }
                    if clip.is_none() {
                        if let Ok(value) = input.try_parse(|input| background_clip::single_value
                                                                               ::parse(context, input)) {
                            clip = Some(value);
                            continue
                        }
                    }
                break
            }
            if clip.is_none() {
                if let Some(origin) = origin {
                    clip = Some(background_clip::single_value::SpecifiedValue::from(origin));
                }
            }
            let mut any = false;
                any = any || image.is_some();
                any = any || position.is_some();
                any = any || repeat.is_some();
                any = any || size.is_some();
                any = any || attachment.is_some();
                any = any || origin.is_some();
                any = any || clip.is_some();
            any = any || background_color.is_some();
            if any {
                if let Some(position) = position {
                    background_position_x.push(position.horizontal);
                    background_position_y.push(position.vertical);
                } else {
                    background_position_x.push(PositionComponent::zero());
                    background_position_y.push(PositionComponent::zero());
                }
                    if let Some(bg_image) = image {
                        background_image.push(bg_image);
                    } else {
                        background_image.push(background_image::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_repeat) = repeat {
                        background_repeat.push(bg_repeat);
                    } else {
                        background_repeat.push(background_repeat::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_size) = size {
                        background_size.push(bg_size);
                    } else {
                        background_size.push(background_size::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_attachment) = attachment {
                        background_attachment.push(bg_attachment);
                    } else {
                        background_attachment.push(background_attachment::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_origin) = origin {
                        background_origin.push(bg_origin);
                    } else {
                        background_origin.push(background_origin::single_value
                                                                    ::get_initial_specified_value());
                    }
                    if let Some(bg_clip) = clip {
                        background_clip.push(bg_clip);
                    } else {
                        background_clip.push(background_clip::single_value
                                                                    ::get_initial_specified_value());
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        })?;

        Ok(expanded! {
             background_color: background_color.unwrap_or(Color::transparent()),
             background_image: background_image::SpecifiedValue(background_image.into()),
             background_position_x: background_position_x::SpecifiedValue(background_position_x.into()),
             background_position_y: background_position_y::SpecifiedValue(background_position_y.into()),
             background_repeat: background_repeat::SpecifiedValue(background_repeat.into()),
             background_size: background_size::SpecifiedValue(background_size.into()),
             background_attachment: background_attachment::SpecifiedValue(background_attachment.into()),
             background_origin: background_origin::SpecifiedValue(background_origin.into()),
             background_clip: background_clip::SpecifiedValue(background_clip.into()),
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.background_image.0.len();
            // There should be at least one declared value
            if len == 0 {
                return Ok(());
            }

            // If a value list length is differs then we don't do a shorthand serialization.
            // The exceptions to this is color which appears once only and is serialized
            // with the last item.
                if len != self.background_image.0.len() {
                    return Ok(());
                }
                if len != self.background_position_x.0.len() {
                    return Ok(());
                }
                if len != self.background_position_y.0.len() {
                    return Ok(());
                }
                if len != self.background_size.0.len() {
                    return Ok(());
                }
                if len != self.background_repeat.0.len() {
                    return Ok(());
                }
                if len != self.background_origin.0.len() {
                    return Ok(());
                }
                if len != self.background_clip.0.len() {
                    return Ok(());
                }
                if len != self.background_attachment.0.len() {
                    return Ok(());
                }

            for i in 0..len {
                    let image = &self.background_image.0[i];
                    let position_x = &self.background_position_x.0[i];
                    let position_y = &self.background_position_y.0[i];
                    let repeat = &self.background_repeat.0[i];
                    let size = &self.background_size.0[i];
                    let attachment = &self.background_attachment.0[i];
                    let origin = &self.background_origin.0[i];
                    let clip = &self.background_clip.0[i];

                if i != 0 {
                    dest.write_str(", ")?;
                }

                let mut wrote_value = false;

                if i == len - 1 {
                    if *self.background_color != background_color::get_initial_specified_value() {
                        self.background_color.to_css(dest)?;
                        wrote_value = true;
                    }
                }

                if *image != background_image::single_value::get_initial_specified_value() {
                    if wrote_value {
                        dest.write_char(' ')?;
                    }
                    image.to_css(dest)?;
                    wrote_value = true;
                }

                // Size is only valid after a position so when there is a
                // non-initial size we must also serialize position
                if *position_x != PositionComponent::zero() ||
                    *position_y != PositionComponent::zero() ||
                    *size != background_size::single_value::get_initial_specified_value()
                {
                    if wrote_value {
                        dest.write_char(' ')?;
                    }

                    Position {
                        horizontal: position_x.clone(),
                        vertical: position_y.clone()
                    }.to_css(dest)?;

                    wrote_value = true;

                    if *size != background_size::single_value::get_initial_specified_value() {
                        dest.write_str(" / ")?;
                        size.to_css(dest)?;
                    }
                }

                    if *repeat != background_repeat::single_value::get_initial_specified_value() {
                        if wrote_value {
                            dest.write_char(' ')?;
                        }
                        repeat.to_css(dest)?;
                        wrote_value = true;
                    }
                    if *attachment != background_attachment::single_value::get_initial_specified_value() {
                        if wrote_value {
                            dest.write_char(' ')?;
                        }
                        attachment.to_css(dest)?;
                        wrote_value = true;
                    }

                if *origin != Origin::PaddingBox || *clip != Clip::BorderBox {
                    if wrote_value {
                        dest.write_char(' ')?;
                    }
                    origin.to_css(dest)?;
                    if *clip != From::from(*origin) {
                        dest.write_char(' ')?;
                        clip.to_css(dest)?;
                    }

                    wrote_value = true;
                }

                if !wrote_value {
                    image.to_css(dest)?;
                }
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-backgrounds-4/#the-background-position
    pub mod background_position {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub background_position_x:
                    longhands::background_position_x::SpecifiedValue
                    ,
                pub background_position_y:
                    longhands::background_position_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub background_position_x:
                    &'a longhands::background_position_x::SpecifiedValue,
                pub background_position_y:
                    &'a longhands::background_position_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut background_position_x =
                        None::< &'a longhands::background_position_x::SpecifiedValue>;
                    let mut background_position_y =
                        None::< &'a longhands::background_position_y::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BackgroundPositionX(ref value) => {
                                background_position_x = Some(value)
                            },
                            PropertyDeclaration::BackgroundPositionY(ref value) => {
                                background_position_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        background_position_x,
                        background_position_y,
                ) {

                    (
                        Some(background_position_x),
                        Some(background_position_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            background_position_x,
                            background_position_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BackgroundPositionX(
                        longhands.background_position_x
                    ));
                    declarations.push(PropertyDeclaration::BackgroundPositionY(
                        longhands.background_position_y
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{background_position_x, background_position_y};
    use crate::values::specified::AllowQuirks;
    use crate::values::specified::position::Position;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut position_x = Vec::with_capacity(1);
        let mut position_y = Vec::with_capacity(1);
        let mut any = false;

        input.parse_comma_separated(|input| {
            let value = Position::parse_three_value_quirky(context, input, AllowQuirks::Yes)?;
            position_x.push(value.horizontal);
            position_y.push(value.vertical);
            any = true;
            Ok(())
        })?;
        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            background_position_x: background_position_x::SpecifiedValue(position_x.into()),
            background_position_y: background_position_y::SpecifiedValue(position_y.into()),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.background_position_x.0.len();
            if len == 0 || len != self.background_position_y.0.len() {
                return Ok(());
            }
            for i in 0..len {
                Position {
                    horizontal: self.background_position_x.0[i].clone(),
                    vertical: self.background_position_y.0[i].clone()
                }.to_css(dest)?;

                if i < len - 1 {
                    dest.write_str(", ")?;
                }
            }
            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-color
    pub mod border_color {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_color =
                        None::< &'a longhands::border_top_color::SpecifiedValue>;
                    let mut border_right_color =
                        None::< &'a longhands::border_right_color::SpecifiedValue>;
                    let mut border_bottom_color =
                        None::< &'a longhands::border_bottom_color::SpecifiedValue>;
                    let mut border_left_color =
                        None::< &'a longhands::border_left_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_color,
                        border_right_color,
                        border_bottom_color,
                        border_left_color,
                ) {

                    (
                        Some(border_top_color),
                        Some(border_right_color),
                        Some(border_bottom_color),
                        Some(border_left_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_color,
                            border_right_color,
                            border_bottom_color,
                            border_left_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        #[allow(unused_imports)]
        use crate::parser::Parse;
        use crate::values::generics::rect::Rect;
        #[allow(unused_imports)]
        use crate::values::specified;

        fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |c, i| -> Result<
                crate::properties::longhands::border_top_color::SpecifiedValue,
                ParseError<'i>
            > {
                specified::Color::parse_quirky(c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    border_top_color: rect.0,
                    border_right_color: rect.1,
                    border_bottom_color: rect.2,
                    border_left_color: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.border_top_color,
                    &self.border_right_color,
                    &self.border_bottom_color,
                    &self.border_left_color,
                );
                rect.to_css(dest)
            }
        }
    
    }




    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-style
    pub mod border_style {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_style =
                        None::< &'a longhands::border_top_style::SpecifiedValue>;
                    let mut border_right_style =
                        None::< &'a longhands::border_right_style::SpecifiedValue>;
                    let mut border_bottom_style =
                        None::< &'a longhands::border_bottom_style::SpecifiedValue>;
                    let mut border_left_style =
                        None::< &'a longhands::border_left_style::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_style,
                        border_right_style,
                        border_bottom_style,
                        border_left_style,
                ) {

                    (
                        Some(border_top_style),
                        Some(border_right_style),
                        Some(border_bottom_style),
                        Some(border_left_style),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_style,
                            border_right_style,
                            border_bottom_style,
                            border_left_style,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        #[allow(unused_imports)]
        use crate::parser::Parse;
        use crate::values::generics::rect::Rect;
        #[allow(unused_imports)]
        use crate::values::specified;

        fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |c, i| -> Result<
                crate::properties::longhands::border_top_style::SpecifiedValue,
                ParseError<'i>
            > {
                crate::parser::Parse::parse(c, i)
            })?;
            Ok(expanded! {
                    border_top_style: rect.0,
                    border_right_style: rect.1,
                    border_bottom_style: rect.2,
                    border_left_style: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.border_top_style,
                    &self.border_right_style,
                    &self.border_bottom_style,
                    &self.border_left_style,
                );
                rect.to_css(dest)
            }
        }
    
    }





    /// https://drafts.csswg.org/css-backgrounds/#border-width
    pub mod border_width {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_width =
                        None::< &'a longhands::border_top_width::SpecifiedValue>;
                    let mut border_right_width =
                        None::< &'a longhands::border_right_width::SpecifiedValue>;
                    let mut border_bottom_width =
                        None::< &'a longhands::border_bottom_width::SpecifiedValue>;
                    let mut border_left_width =
                        None::< &'a longhands::border_left_width::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_width,
                        border_right_width,
                        border_bottom_width,
                        border_left_width,
                ) {

                    (
                        Some(border_top_width),
                        Some(border_right_width),
                        Some(border_bottom_width),
                        Some(border_left_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_width,
                            border_right_width,
                            border_bottom_width,
                            border_left_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::generics::rect::Rect;
    use crate::values::specified::{AllowQuirks, BorderSideWidth};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let rect = Rect::parse_with(context, input, |_, i| {
            BorderSideWidth::parse_quirky(context, i, AllowQuirks::Yes)
        })?;
        Ok(expanded! {
            border_top_width: rect.0,
            border_right_width: rect.1,
            border_bottom_width: rect.2,
            border_left_width: rect.3,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let top = &self.border_top_width;
            let right = &self.border_right_width;
            let bottom = &self.border_bottom_width;
            let left = &self.border_left_width;
            Rect::new(top, right, bottom, left).to_css(dest)
        }
    }

    }



pub fn parse_border<'i, 't>(
    context: &ParserContext,
    input: &mut Parser<'i, 't>,
) -> Result<(specified::Color, specified::BorderStyle, specified::BorderSideWidth), ParseError<'i>> {
    use crate::values::specified::{Color, BorderStyle, BorderSideWidth};
    let _unused = context;
    let mut color = None;
    let mut style = None;
    let mut width = None;
    let mut any = false;
    loop {
        if width.is_none() {
            if let Ok(value) = input.try_parse(|i| BorderSideWidth::parse(context, i)) {
                width = Some(value);
                any = true;
            }
        }
        if style.is_none() {
            if let Ok(value) = input.try_parse(BorderStyle::parse) {
                style = Some(value);
                any = true;
                continue
            }
        }
        if color.is_none() {
            if let Ok(value) = input.try_parse(|i| Color::parse(context, i)) {
                color = Some(value);
                any = true;
                continue
            }
        }
        break
    }
    if !any {
        return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
    }
    Ok((color.unwrap_or(Color::CurrentColor), style.unwrap_or(BorderStyle::None), width.unwrap_or(BorderSideWidth::medium())))
}

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-top
    pub mod border_top {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_width =
                        None::< &'a longhands::border_top_width::SpecifiedValue>;
                    let mut border_top_style =
                        None::< &'a longhands::border_top_style::SpecifiedValue>;
                    let mut border_top_color =
                        None::< &'a longhands::border_top_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_width,
                        border_top_style,
                        border_top_color,
                ) {

                    (
                        Some(border_top_width),
                        Some(border_top_style),
                        Some(border_top_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_width,
                            border_top_style,
                            border_top_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_top_color: color,
            border_top_style: style,
            border_top_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_top_width,
                self.border_top_style,
                self.border_top_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-right
    pub mod border_right {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_right_width =
                        None::< &'a longhands::border_right_width::SpecifiedValue>;
                    let mut border_right_style =
                        None::< &'a longhands::border_right_style::SpecifiedValue>;
                    let mut border_right_color =
                        None::< &'a longhands::border_right_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_right_width,
                        border_right_style,
                        border_right_color,
                ) {

                    (
                        Some(border_right_width),
                        Some(border_right_style),
                        Some(border_right_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_right_width,
                            border_right_style,
                            border_right_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_right_color: color,
            border_right_style: style,
            border_right_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_right_width,
                self.border_right_style,
                self.border_right_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-bottom
    pub mod border_bottom {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_bottom_width =
                        None::< &'a longhands::border_bottom_width::SpecifiedValue>;
                    let mut border_bottom_style =
                        None::< &'a longhands::border_bottom_style::SpecifiedValue>;
                    let mut border_bottom_color =
                        None::< &'a longhands::border_bottom_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_bottom_width,
                        border_bottom_style,
                        border_bottom_color,
                ) {

                    (
                        Some(border_bottom_width),
                        Some(border_bottom_style),
                        Some(border_bottom_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_bottom_width,
                            border_bottom_style,
                            border_bottom_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_bottom_color: color,
            border_bottom_style: style,
            border_bottom_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_bottom_width,
                self.border_bottom_style,
                self.border_bottom_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-backgrounds/#border-left
    pub mod border_left {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_left_width =
                        None::< &'a longhands::border_left_width::SpecifiedValue>;
                    let mut border_left_style =
                        None::< &'a longhands::border_left_style::SpecifiedValue>;
                    let mut border_left_color =
                        None::< &'a longhands::border_left_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_left_width,
                        border_left_style,
                        border_left_color,
                ) {

                    (
                        Some(border_left_width),
                        Some(border_left_style),
                        Some(border_left_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_left_width,
                            border_left_style,
                            border_left_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_left_color: color,
            border_left_style: style,
            border_left_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_left_width,
                self.border_left_style,
                self.border_left_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-start
    pub mod border_block_start {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_block_start_width:
                    longhands::border_block_start_width::SpecifiedValue
                    ,
                pub border_block_start_style:
                    longhands::border_block_start_style::SpecifiedValue
                    ,
                pub border_block_start_color:
                    longhands::border_block_start_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_start_width:
                    &'a longhands::border_block_start_width::SpecifiedValue,
                pub border_block_start_style:
                    &'a longhands::border_block_start_style::SpecifiedValue,
                pub border_block_start_color:
                    &'a longhands::border_block_start_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_start_width =
                        None::< &'a longhands::border_block_start_width::SpecifiedValue>;
                    let mut border_block_start_style =
                        None::< &'a longhands::border_block_start_style::SpecifiedValue>;
                    let mut border_block_start_color =
                        None::< &'a longhands::border_block_start_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                                border_block_start_width = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                                border_block_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartColor(ref value) => {
                                border_block_start_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_start_width,
                        border_block_start_style,
                        border_block_start_color,
                ) {

                    (
                        Some(border_block_start_width),
                        Some(border_block_start_style),
                        Some(border_block_start_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_start_width,
                            border_block_start_style,
                            border_block_start_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockStartWidth(
                        longhands.border_block_start_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartStyle(
                        longhands.border_block_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartColor(
                        longhands.border_block_start_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_block_start_color: color,
            border_block_start_style: style,
            border_block_start_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_block_start_width,
                self.border_block_start_style,
                self.border_block_start_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-block-end
    pub mod border_block_end {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_block_end_width:
                    longhands::border_block_end_width::SpecifiedValue
                    ,
                pub border_block_end_style:
                    longhands::border_block_end_style::SpecifiedValue
                    ,
                pub border_block_end_color:
                    longhands::border_block_end_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_end_width:
                    &'a longhands::border_block_end_width::SpecifiedValue,
                pub border_block_end_style:
                    &'a longhands::border_block_end_style::SpecifiedValue,
                pub border_block_end_color:
                    &'a longhands::border_block_end_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_end_width =
                        None::< &'a longhands::border_block_end_width::SpecifiedValue>;
                    let mut border_block_end_style =
                        None::< &'a longhands::border_block_end_style::SpecifiedValue>;
                    let mut border_block_end_color =
                        None::< &'a longhands::border_block_end_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                                border_block_end_width = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                                border_block_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndColor(ref value) => {
                                border_block_end_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_end_width,
                        border_block_end_style,
                        border_block_end_color,
                ) {

                    (
                        Some(border_block_end_width),
                        Some(border_block_end_style),
                        Some(border_block_end_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_end_width,
                            border_block_end_style,
                            border_block_end_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockEndWidth(
                        longhands.border_block_end_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndStyle(
                        longhands.border_block_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndColor(
                        longhands.border_block_end_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_block_end_color: color,
            border_block_end_style: style,
            border_block_end_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_block_end_width,
                self.border_block_end_style,
                self.border_block_end_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-start
    pub mod border_inline_start {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_inline_start_width:
                    longhands::border_inline_start_width::SpecifiedValue
                    ,
                pub border_inline_start_style:
                    longhands::border_inline_start_style::SpecifiedValue
                    ,
                pub border_inline_start_color:
                    longhands::border_inline_start_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_start_width:
                    &'a longhands::border_inline_start_width::SpecifiedValue,
                pub border_inline_start_style:
                    &'a longhands::border_inline_start_style::SpecifiedValue,
                pub border_inline_start_color:
                    &'a longhands::border_inline_start_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_start_width =
                        None::< &'a longhands::border_inline_start_width::SpecifiedValue>;
                    let mut border_inline_start_style =
                        None::< &'a longhands::border_inline_start_style::SpecifiedValue>;
                    let mut border_inline_start_color =
                        None::< &'a longhands::border_inline_start_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                                border_inline_start_width = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                                border_inline_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartColor(ref value) => {
                                border_inline_start_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_start_width,
                        border_inline_start_style,
                        border_inline_start_color,
                ) {

                    (
                        Some(border_inline_start_width),
                        Some(border_inline_start_style),
                        Some(border_inline_start_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_start_width,
                            border_inline_start_style,
                            border_inline_start_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineStartWidth(
                        longhands.border_inline_start_width
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartStyle(
                        longhands.border_inline_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartColor(
                        longhands.border_inline_start_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_inline_start_color: color,
            border_inline_start_style: style,
            border_inline_start_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_inline_start_width,
                self.border_inline_start_style,
                self.border_inline_start_color
            )
        }
    }

    
    }

    
    

    /// https://drafts.csswg.org/css-logical-props/#propdef-border-inline-end
    pub mod border_inline_end {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_inline_end_width:
                    longhands::border_inline_end_width::SpecifiedValue
                    ,
                pub border_inline_end_style:
                    longhands::border_inline_end_style::SpecifiedValue
                    ,
                pub border_inline_end_color:
                    longhands::border_inline_end_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_end_width:
                    &'a longhands::border_inline_end_width::SpecifiedValue,
                pub border_inline_end_style:
                    &'a longhands::border_inline_end_style::SpecifiedValue,
                pub border_inline_end_color:
                    &'a longhands::border_inline_end_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_end_width =
                        None::< &'a longhands::border_inline_end_width::SpecifiedValue>;
                    let mut border_inline_end_style =
                        None::< &'a longhands::border_inline_end_style::SpecifiedValue>;
                    let mut border_inline_end_color =
                        None::< &'a longhands::border_inline_end_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                                border_inline_end_width = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                                border_inline_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndColor(ref value) => {
                                border_inline_end_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_end_width,
                        border_inline_end_style,
                        border_inline_end_color,
                ) {

                    (
                        Some(border_inline_end_width),
                        Some(border_inline_end_style),
                        Some(border_inline_end_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_end_width,
                            border_inline_end_style,
                            border_inline_end_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineEndWidth(
                        longhands.border_inline_end_width
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndStyle(
                        longhands.border_inline_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndColor(
                        longhands.border_inline_end_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
            border_inline_end_color: color,
            border_inline_end_style: style,
            border_inline_end_width: width
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_inline_end_width,
                self.border_inline_end_style,
                self.border_inline_end_color
            )
        }
    }

    
    }




    /// https://drafts.csswg.org/css-backgrounds/#border
    pub mod border {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        pub struct Longhands {
                pub border_top_width:
                    longhands::border_top_width::SpecifiedValue
                    ,
                pub border_top_style:
                    longhands::border_top_style::SpecifiedValue
                    ,
                pub border_top_color:
                    longhands::border_top_color::SpecifiedValue
                    ,
                pub border_right_width:
                    longhands::border_right_width::SpecifiedValue
                    ,
                pub border_right_style:
                    longhands::border_right_style::SpecifiedValue
                    ,
                pub border_right_color:
                    longhands::border_right_color::SpecifiedValue
                    ,
                pub border_bottom_width:
                    longhands::border_bottom_width::SpecifiedValue
                    ,
                pub border_bottom_style:
                    longhands::border_bottom_style::SpecifiedValue
                    ,
                pub border_bottom_color:
                    longhands::border_bottom_color::SpecifiedValue
                    ,
                pub border_left_width:
                    longhands::border_left_width::SpecifiedValue
                    ,
                pub border_left_style:
                    longhands::border_left_style::SpecifiedValue
                    ,
                pub border_left_color:
                    longhands::border_left_color::SpecifiedValue
                    ,
                pub border_image_outset:
                        Box<
                    longhands::border_image_outset::SpecifiedValue
                        >
                    ,
                pub border_image_repeat:
                    longhands::border_image_repeat::SpecifiedValue
                    ,
                pub border_image_slice:
                        Box<
                    longhands::border_image_slice::SpecifiedValue
                        >
                    ,
                pub border_image_source:
                    longhands::border_image_source::SpecifiedValue
                    ,
                pub border_image_width:
                        Box<
                    longhands::border_image_width::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_width:
                    &'a longhands::border_top_width::SpecifiedValue,
                pub border_top_style:
                    &'a longhands::border_top_style::SpecifiedValue,
                pub border_top_color:
                    &'a longhands::border_top_color::SpecifiedValue,
                pub border_right_width:
                    &'a longhands::border_right_width::SpecifiedValue,
                pub border_right_style:
                    &'a longhands::border_right_style::SpecifiedValue,
                pub border_right_color:
                    &'a longhands::border_right_color::SpecifiedValue,
                pub border_bottom_width:
                    &'a longhands::border_bottom_width::SpecifiedValue,
                pub border_bottom_style:
                    &'a longhands::border_bottom_style::SpecifiedValue,
                pub border_bottom_color:
                    &'a longhands::border_bottom_color::SpecifiedValue,
                pub border_left_width:
                    &'a longhands::border_left_width::SpecifiedValue,
                pub border_left_style:
                    &'a longhands::border_left_style::SpecifiedValue,
                pub border_left_color:
                    &'a longhands::border_left_color::SpecifiedValue,
                pub border_image_outset:
                    &'a longhands::border_image_outset::SpecifiedValue,
                pub border_image_repeat:
                    &'a longhands::border_image_repeat::SpecifiedValue,
                pub border_image_slice:
                    &'a longhands::border_image_slice::SpecifiedValue,
                pub border_image_source:
                    &'a longhands::border_image_source::SpecifiedValue,
                pub border_image_width:
                    &'a longhands::border_image_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_width =
                        None::< &'a longhands::border_top_width::SpecifiedValue>;
                    let mut border_top_style =
                        None::< &'a longhands::border_top_style::SpecifiedValue>;
                    let mut border_top_color =
                        None::< &'a longhands::border_top_color::SpecifiedValue>;
                    let mut border_right_width =
                        None::< &'a longhands::border_right_width::SpecifiedValue>;
                    let mut border_right_style =
                        None::< &'a longhands::border_right_style::SpecifiedValue>;
                    let mut border_right_color =
                        None::< &'a longhands::border_right_color::SpecifiedValue>;
                    let mut border_bottom_width =
                        None::< &'a longhands::border_bottom_width::SpecifiedValue>;
                    let mut border_bottom_style =
                        None::< &'a longhands::border_bottom_style::SpecifiedValue>;
                    let mut border_bottom_color =
                        None::< &'a longhands::border_bottom_color::SpecifiedValue>;
                    let mut border_left_width =
                        None::< &'a longhands::border_left_width::SpecifiedValue>;
                    let mut border_left_style =
                        None::< &'a longhands::border_left_style::SpecifiedValue>;
                    let mut border_left_color =
                        None::< &'a longhands::border_left_color::SpecifiedValue>;
                    let mut border_image_outset =
                        None::< &'a longhands::border_image_outset::SpecifiedValue>;
                    let mut border_image_repeat =
                        None::< &'a longhands::border_image_repeat::SpecifiedValue>;
                    let mut border_image_slice =
                        None::< &'a longhands::border_image_slice::SpecifiedValue>;
                    let mut border_image_source =
                        None::< &'a longhands::border_image_source::SpecifiedValue>;
                    let mut border_image_width =
                        None::< &'a longhands::border_image_width::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderTopWidth(ref value) => {
                                border_top_width = Some(value)
                            },
                            PropertyDeclaration::BorderTopStyle(ref value) => {
                                border_top_style = Some(value)
                            },
                            PropertyDeclaration::BorderTopColor(ref value) => {
                                border_top_color = Some(value)
                            },
                            PropertyDeclaration::BorderRightWidth(ref value) => {
                                border_right_width = Some(value)
                            },
                            PropertyDeclaration::BorderRightStyle(ref value) => {
                                border_right_style = Some(value)
                            },
                            PropertyDeclaration::BorderRightColor(ref value) => {
                                border_right_color = Some(value)
                            },
                            PropertyDeclaration::BorderBottomWidth(ref value) => {
                                border_bottom_width = Some(value)
                            },
                            PropertyDeclaration::BorderBottomStyle(ref value) => {
                                border_bottom_style = Some(value)
                            },
                            PropertyDeclaration::BorderBottomColor(ref value) => {
                                border_bottom_color = Some(value)
                            },
                            PropertyDeclaration::BorderLeftWidth(ref value) => {
                                border_left_width = Some(value)
                            },
                            PropertyDeclaration::BorderLeftStyle(ref value) => {
                                border_left_style = Some(value)
                            },
                            PropertyDeclaration::BorderLeftColor(ref value) => {
                                border_left_color = Some(value)
                            },
                            PropertyDeclaration::BorderImageOutset(ref value) => {
                                border_image_outset = Some(value)
                            },
                            PropertyDeclaration::BorderImageRepeat(ref value) => {
                                border_image_repeat = Some(value)
                            },
                            PropertyDeclaration::BorderImageSlice(ref value) => {
                                border_image_slice = Some(value)
                            },
                            PropertyDeclaration::BorderImageSource(ref value) => {
                                border_image_source = Some(value)
                            },
                            PropertyDeclaration::BorderImageWidth(ref value) => {
                                border_image_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_width,
                        border_top_style,
                        border_top_color,
                        border_right_width,
                        border_right_style,
                        border_right_color,
                        border_bottom_width,
                        border_bottom_style,
                        border_bottom_color,
                        border_left_width,
                        border_left_style,
                        border_left_color,
                        border_image_outset,
                        border_image_repeat,
                        border_image_slice,
                        border_image_source,
                        border_image_width,
                ) {

                    (
                        Some(border_top_width),
                        Some(border_top_style),
                        Some(border_top_color),
                        Some(border_right_width),
                        Some(border_right_style),
                        Some(border_right_color),
                        Some(border_bottom_width),
                        Some(border_bottom_style),
                        Some(border_bottom_color),
                        Some(border_left_width),
                        Some(border_left_style),
                        Some(border_left_color),
                        Some(border_image_outset),
                        Some(border_image_repeat),
                        Some(border_image_slice),
                        Some(border_image_source),
                        Some(border_image_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_width,
                            border_top_style,
                            border_top_color,
                            border_right_width,
                            border_right_style,
                            border_right_color,
                            border_bottom_width,
                            border_bottom_style,
                            border_bottom_color,
                            border_left_width,
                            border_left_style,
                            border_left_color,
                            border_image_outset,
                            border_image_repeat,
                            border_image_slice,
                            border_image_source,
                            border_image_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopWidth(
                        longhands.border_top_width
                    ));
                    declarations.push(PropertyDeclaration::BorderTopStyle(
                        longhands.border_top_style
                    ));
                    declarations.push(PropertyDeclaration::BorderTopColor(
                        longhands.border_top_color
                    ));
                    declarations.push(PropertyDeclaration::BorderRightWidth(
                        longhands.border_right_width
                    ));
                    declarations.push(PropertyDeclaration::BorderRightStyle(
                        longhands.border_right_style
                    ));
                    declarations.push(PropertyDeclaration::BorderRightColor(
                        longhands.border_right_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomWidth(
                        longhands.border_bottom_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomStyle(
                        longhands.border_bottom_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomColor(
                        longhands.border_bottom_color
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftWidth(
                        longhands.border_left_width
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftStyle(
                        longhands.border_left_style
                    ));
                    declarations.push(PropertyDeclaration::BorderLeftColor(
                        longhands.border_left_color
                    ));
                    declarations.push(PropertyDeclaration::BorderImageOutset(
                        longhands.border_image_outset
                    ));
                    declarations.push(PropertyDeclaration::BorderImageRepeat(
                        longhands.border_image_repeat
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSlice(
                        longhands.border_image_slice
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSource(
                        longhands.border_image_source
                    ));
                    declarations.push(PropertyDeclaration::BorderImageWidth(
                        longhands.border_image_width
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::properties::longhands::{border_image_outset, border_image_repeat, border_image_slice};
        use crate::properties::longhands::{border_image_source, border_image_width};

        let (color, style, width) = super::parse_border(context, input)?;
        Ok(expanded! {
                border_top_color: color.clone(),
                border_top_style: style,
                border_top_width: width.clone(),
                border_right_color: color.clone(),
                border_right_style: style,
                border_right_width: width.clone(),
                border_bottom_color: color.clone(),
                border_bottom_style: style,
                border_bottom_width: width.clone(),
                border_left_color: color.clone(),
                border_left_style: style,
                border_left_width: width.clone(),

            // The ‘border’ shorthand resets ‘border-image’ to its initial value.
            // See https://drafts.csswg.org/css-backgrounds-3/#the-border-shorthands
                border_image_outset: border_image_outset::get_initial_specified_value(),
                border_image_repeat: border_image_repeat::get_initial_specified_value(),
                border_image_slice: border_image_slice::get_initial_specified_value(),
                border_image_source: border_image_source::get_initial_specified_value(),
                border_image_width: border_image_width::get_initial_specified_value(),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use crate::properties::longhands;

            // If any of the border-image longhands differ from their initial specified values we should not
            // invoke serialize_directional_border(), so there is no point in continuing on to compute all_equal.
                if *self.border_image_outset != longhands::border_image_outset::get_initial_specified_value() {
                    return Ok(());
                }
                if *self.border_image_repeat != longhands::border_image_repeat::get_initial_specified_value() {
                    return Ok(());
                }
                if *self.border_image_slice != longhands::border_image_slice::get_initial_specified_value() {
                    return Ok(());
                }
                if *self.border_image_source != longhands::border_image_source::get_initial_specified_value() {
                    return Ok(());
                }
                if *self.border_image_width != longhands::border_image_width::get_initial_specified_value() {
                    return Ok(());
                }

            let all_equal = {
                  let border_top_width = self.border_top_width;
                  let border_top_style = self.border_top_style;
                  let border_top_color = self.border_top_color;
                  let border_right_width = self.border_right_width;
                  let border_right_style = self.border_right_style;
                  let border_right_color = self.border_right_color;
                  let border_bottom_width = self.border_bottom_width;
                  let border_bottom_style = self.border_bottom_style;
                  let border_bottom_color = self.border_bottom_color;
                  let border_left_width = self.border_left_width;
                  let border_left_style = self.border_left_style;
                  let border_left_color = self.border_left_color;

                border_top_width == border_right_width &&
                border_right_width == border_bottom_width &&
                border_bottom_width == border_left_width &&

                border_top_style == border_right_style &&
                border_right_style == border_bottom_style &&
                border_bottom_style == border_left_style &&

                border_top_color == border_right_color &&
                border_right_color == border_bottom_color &&
                border_bottom_color == border_left_color
            };

            // If all longhands are all present, then all sides should be the same,
            // so we can just one set of color/style/width
            if !all_equal {
                return Ok(())
            }
            crate::values::specified::border::serialize_directional_border(
                dest,
                self.border_left_width,
                self.border_left_style,
                self.border_left_color
            )
        }
    }

    // Just use the same as border-left. The border shorthand can't accept
    // any value that the sub-shorthand couldn't.
    
    impl SpecifiedValueInfo for Longhands {
        const SUPPORTED_TYPES: u8 = <crate::properties::shorthands::border_left::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES;
        fn collect_completion_keywords(f: KeywordsCollectFn) {
            <crate::properties::shorthands::border_left::Longhands as SpecifiedValueInfo>::collect_completion_keywords(f);
        }
    }

    }




    /// https://drafts.csswg.org/css-backgrounds/#border-radius
    pub mod border_radius {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_top_left_radius:
                        Box<
                    longhands::border_top_left_radius::SpecifiedValue
                        >
                    ,
                pub border_top_right_radius:
                        Box<
                    longhands::border_top_right_radius::SpecifiedValue
                        >
                    ,
                pub border_bottom_right_radius:
                        Box<
                    longhands::border_bottom_right_radius::SpecifiedValue
                        >
                    ,
                pub border_bottom_left_radius:
                        Box<
                    longhands::border_bottom_left_radius::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_top_left_radius:
                    &'a longhands::border_top_left_radius::SpecifiedValue,
                pub border_top_right_radius:
                    &'a longhands::border_top_right_radius::SpecifiedValue,
                pub border_bottom_right_radius:
                    &'a longhands::border_bottom_right_radius::SpecifiedValue,
                pub border_bottom_left_radius:
                    &'a longhands::border_bottom_left_radius::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_top_left_radius =
                        None::< &'a longhands::border_top_left_radius::SpecifiedValue>;
                    let mut border_top_right_radius =
                        None::< &'a longhands::border_top_right_radius::SpecifiedValue>;
                    let mut border_bottom_right_radius =
                        None::< &'a longhands::border_bottom_right_radius::SpecifiedValue>;
                    let mut border_bottom_left_radius =
                        None::< &'a longhands::border_bottom_left_radius::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderTopLeftRadius(ref value) => {
                                border_top_left_radius = Some(value)
                            },
                            PropertyDeclaration::BorderTopRightRadius(ref value) => {
                                border_top_right_radius = Some(value)
                            },
                            PropertyDeclaration::BorderBottomRightRadius(ref value) => {
                                border_bottom_right_radius = Some(value)
                            },
                            PropertyDeclaration::BorderBottomLeftRadius(ref value) => {
                                border_bottom_left_radius = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_top_left_radius,
                        border_top_right_radius,
                        border_bottom_right_radius,
                        border_bottom_left_radius,
                ) {

                    (
                        Some(border_top_left_radius),
                        Some(border_top_right_radius),
                        Some(border_bottom_right_radius),
                        Some(border_bottom_left_radius),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_top_left_radius,
                            border_top_right_radius,
                            border_bottom_right_radius,
                            border_bottom_left_radius,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderTopLeftRadius(
                        longhands.border_top_left_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderTopRightRadius(
                        longhands.border_top_right_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomRightRadius(
                        longhands.border_bottom_right_radius
                    ));
                    declarations.push(PropertyDeclaration::BorderBottomLeftRadius(
                        longhands.border_bottom_left_radius
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::generics::rect::Rect;
    use crate::values::generics::border::BorderCornerRadius;
    use crate::values::specified::border::BorderRadius;
    use crate::parser::Parse;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let radii = BorderRadius::parse(context, input)?;
        Ok(expanded! {
            border_top_left_radius: radii.top_left,
            border_top_right_radius: radii.top_right,
            border_bottom_right_radius: radii.bottom_right,
            border_bottom_left_radius: radii.bottom_left,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let LonghandsToSerialize {
                border_top_left_radius: &BorderCornerRadius(ref tl),
                border_top_right_radius: &BorderCornerRadius(ref tr),
                border_bottom_right_radius: &BorderCornerRadius(ref br),
                border_bottom_left_radius: &BorderCornerRadius(ref bl),
            } = *self;


            let widths = Rect::new(tl.width(), tr.width(), br.width(), bl.width());
            let heights = Rect::new(tl.height(), tr.height(), br.height(), bl.height());

            BorderRadius::serialize_rects(widths, heights, dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-backgrounds-3/#border-image
    pub mod border_image {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_image_outset:
                        Box<
                    longhands::border_image_outset::SpecifiedValue
                        >
                    ,
                pub border_image_repeat:
                    longhands::border_image_repeat::SpecifiedValue
                    ,
                pub border_image_slice:
                        Box<
                    longhands::border_image_slice::SpecifiedValue
                        >
                    ,
                pub border_image_source:
                    longhands::border_image_source::SpecifiedValue
                    ,
                pub border_image_width:
                        Box<
                    longhands::border_image_width::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_image_outset:
                    &'a longhands::border_image_outset::SpecifiedValue,
                pub border_image_repeat:
                    &'a longhands::border_image_repeat::SpecifiedValue,
                pub border_image_slice:
                    &'a longhands::border_image_slice::SpecifiedValue,
                pub border_image_source:
                    &'a longhands::border_image_source::SpecifiedValue,
                pub border_image_width:
                    &'a longhands::border_image_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_image_outset =
                        None::< &'a longhands::border_image_outset::SpecifiedValue>;
                    let mut border_image_repeat =
                        None::< &'a longhands::border_image_repeat::SpecifiedValue>;
                    let mut border_image_slice =
                        None::< &'a longhands::border_image_slice::SpecifiedValue>;
                    let mut border_image_source =
                        None::< &'a longhands::border_image_source::SpecifiedValue>;
                    let mut border_image_width =
                        None::< &'a longhands::border_image_width::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderImageOutset(ref value) => {
                                border_image_outset = Some(value)
                            },
                            PropertyDeclaration::BorderImageRepeat(ref value) => {
                                border_image_repeat = Some(value)
                            },
                            PropertyDeclaration::BorderImageSlice(ref value) => {
                                border_image_slice = Some(value)
                            },
                            PropertyDeclaration::BorderImageSource(ref value) => {
                                border_image_source = Some(value)
                            },
                            PropertyDeclaration::BorderImageWidth(ref value) => {
                                border_image_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_image_outset,
                        border_image_repeat,
                        border_image_slice,
                        border_image_source,
                        border_image_width,
                ) {

                    (
                        Some(border_image_outset),
                        Some(border_image_repeat),
                        Some(border_image_slice),
                        Some(border_image_source),
                        Some(border_image_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_image_outset,
                            border_image_repeat,
                            border_image_slice,
                            border_image_source,
                            border_image_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderImageOutset(
                        longhands.border_image_outset
                    ));
                    declarations.push(PropertyDeclaration::BorderImageRepeat(
                        longhands.border_image_repeat
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSlice(
                        longhands.border_image_slice
                    ));
                    declarations.push(PropertyDeclaration::BorderImageSource(
                        longhands.border_image_source
                    ));
                    declarations.push(PropertyDeclaration::BorderImageWidth(
                        longhands.border_image_width
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{border_image_outset, border_image_repeat, border_image_slice};
    use crate::properties::longhands::{border_image_source, border_image_width};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut outset = border_image_outset::get_initial_specified_value();
        let mut repeat = border_image_repeat::get_initial_specified_value();
        let mut slice = border_image_slice::get_initial_specified_value();
        let mut source = border_image_source::get_initial_specified_value();
        let mut width = border_image_width::get_initial_specified_value();
        let mut any = false;
        let mut parsed_slice = false;
        let mut parsed_source = false;
        let mut parsed_repeat = false;
        loop {
            if !parsed_slice {
                if let Ok(value) = input.try_parse(|input| border_image_slice::parse(context, input)) {
                    parsed_slice = true;
                    any = true;
                    slice = value;
                    // Parse border image width and outset, if applicable.
                    let maybe_width_outset: Result<_, ParseError> = input.try_parse(|input| {
                        input.expect_delim('/')?;

                        // Parse border image width, if applicable.
                        let w = input.try_parse(|input| border_image_width::parse(context, input)).ok();

                        // Parse border image outset if applicable.
                        let o = input.try_parse(|input| {
                            input.expect_delim('/')?;
                            border_image_outset::parse(context, input)
                        }).ok();
                        if w.is_none() && o.is_none() {
                            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                        }
                        Ok((w, o))
                    });
                    if let Ok((w, o)) = maybe_width_outset {
                        if let Some(w) = w {
                            width = w;
                        }
                        if let Some(o) = o {
                            outset = o;
                        }
                    }
                    continue;
                }
            }
                if !parsed_source {
                    if let Ok(value) = input.try_parse(|input| border_image_source::parse(context, input)) {
                        source = value;
                        parsed_source = true;
                        any = true;
                        continue
                    }
                }
                if !parsed_repeat {
                    if let Ok(value) = input.try_parse(|input| border_image_repeat::parse(context, input)) {
                        repeat = value;
                        parsed_repeat = true;
                        any = true;
                        continue
                    }
                }
            break
        }
        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
        Ok(expanded! {
                border_image_outset: outset,
                border_image_repeat: repeat,
                border_image_slice: slice,
                border_image_source: source,
                border_image_width: width,
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let mut has_any = false;
            let has_source = *self.border_image_source != border_image_source::get_initial_specified_value();
            has_any = has_any || has_source;
            let has_slice = *self.border_image_slice != border_image_slice::get_initial_specified_value();
            has_any = has_any || has_slice;
            let has_outset = *self.border_image_outset != border_image_outset::get_initial_specified_value();
            has_any = has_any || has_outset;
            let has_width = *self.border_image_width != border_image_width::get_initial_specified_value();
            has_any = has_any || has_width;
            let has_repeat = *self.border_image_repeat != border_image_repeat::get_initial_specified_value();
            has_any = has_any || has_repeat;
            if has_source || !has_any {
                self.border_image_source.to_css(dest)?;
                if !has_any {
                    return Ok(());
                }
            }
            let needs_slice = has_slice || has_width || has_outset;
            if needs_slice {
                if has_source {
                    dest.write_char(' ')?;
                }
                self.border_image_slice.to_css(dest)?;
                if has_width || has_outset {
                    dest.write_str(" /")?;
                    if has_width {
                        dest.write_char(' ')?;
                        self.border_image_width.to_css(dest)?;
                    }
                    if has_outset {
                        dest.write_str(" / ")?;
                        self.border_image_outset.to_css(dest)?;
                    }
                }
            }
            if has_repeat {
                if has_source || needs_slice {
                    dest.write_char(' ')?;
                }
                self.border_image_repeat.to_css(dest)?;
            }
            Ok(())
        }
    }

    }


        
        

    /// https://drafts.csswg.org/css-logical/#propdef-border-block-width
    pub mod border_block_width {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_block_start_width:
                    longhands::border_block_start_width::SpecifiedValue
                    ,
                pub border_block_end_width:
                    longhands::border_block_end_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_start_width:
                    &'a longhands::border_block_start_width::SpecifiedValue,
                pub border_block_end_width:
                    &'a longhands::border_block_end_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_start_width =
                        None::< &'a longhands::border_block_start_width::SpecifiedValue>;
                    let mut border_block_end_width =
                        None::< &'a longhands::border_block_end_width::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                                border_block_start_width = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                                border_block_end_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_start_width,
                        border_block_end_width,
                ) {

                    (
                        Some(border_block_start_width),
                        Some(border_block_end_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_start_width,
                            border_block_end_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockStartWidth(
                        longhands.border_block_start_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndWidth(
                        longhands.border_block_end_width
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

            use crate::properties::longhands::border_block_start_width;
            pub fn parse_value<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<Longhands, ParseError<'i>> {
                let start_value = border_block_start_width::parse(context, input)?;
                let end_value =
                    input.try_parse(|input| border_block_start_width::parse(context, input))
                        .unwrap_or_else(|_| start_value.clone());

                Ok(expanded! {
                    border_block_start_width: start_value,
                    border_block_end_width: end_value,
                })
            }

            impl<'a> ToCss for LonghandsToSerialize<'a>  {
                fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                    self.border_block_start_width.to_css(dest)?;

                    if self.border_block_end_width != self.border_block_start_width {
                        dest.write_char(' ')?;
                        self.border_block_end_width.to_css(dest)?;
                    }

                    Ok(())
                }
            }
        
    }

        
        

    /// https://drafts.csswg.org/css-logical/#propdef-border-block-style
    pub mod border_block_style {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_block_start_style:
                    longhands::border_block_start_style::SpecifiedValue
                    ,
                pub border_block_end_style:
                    longhands::border_block_end_style::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_start_style:
                    &'a longhands::border_block_start_style::SpecifiedValue,
                pub border_block_end_style:
                    &'a longhands::border_block_end_style::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_start_style =
                        None::< &'a longhands::border_block_start_style::SpecifiedValue>;
                    let mut border_block_end_style =
                        None::< &'a longhands::border_block_end_style::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                                border_block_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                                border_block_end_style = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_start_style,
                        border_block_end_style,
                ) {

                    (
                        Some(border_block_start_style),
                        Some(border_block_end_style),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_start_style,
                            border_block_end_style,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockStartStyle(
                        longhands.border_block_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndStyle(
                        longhands.border_block_end_style
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

            use crate::properties::longhands::border_block_start_style;
            pub fn parse_value<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<Longhands, ParseError<'i>> {
                let start_value = border_block_start_style::parse(context, input)?;
                let end_value =
                    input.try_parse(|input| border_block_start_style::parse(context, input))
                        .unwrap_or_else(|_| start_value.clone());

                Ok(expanded! {
                    border_block_start_style: start_value,
                    border_block_end_style: end_value,
                })
            }

            impl<'a> ToCss for LonghandsToSerialize<'a>  {
                fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                    self.border_block_start_style.to_css(dest)?;

                    if self.border_block_end_style != self.border_block_start_style {
                        dest.write_char(' ')?;
                        self.border_block_end_style.to_css(dest)?;
                    }

                    Ok(())
                }
            }
        
    }

        
        

    /// https://drafts.csswg.org/css-logical/#propdef-border-block-color
    pub mod border_block_color {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_block_start_color:
                    longhands::border_block_start_color::SpecifiedValue
                    ,
                pub border_block_end_color:
                    longhands::border_block_end_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_start_color:
                    &'a longhands::border_block_start_color::SpecifiedValue,
                pub border_block_end_color:
                    &'a longhands::border_block_end_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_start_color =
                        None::< &'a longhands::border_block_start_color::SpecifiedValue>;
                    let mut border_block_end_color =
                        None::< &'a longhands::border_block_end_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderBlockStartColor(ref value) => {
                                border_block_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndColor(ref value) => {
                                border_block_end_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_start_color,
                        border_block_end_color,
                ) {

                    (
                        Some(border_block_start_color),
                        Some(border_block_end_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_start_color,
                            border_block_end_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockStartColor(
                        longhands.border_block_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndColor(
                        longhands.border_block_end_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

            use crate::properties::longhands::border_block_start_color;
            pub fn parse_value<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<Longhands, ParseError<'i>> {
                let start_value = border_block_start_color::parse(context, input)?;
                let end_value =
                    input.try_parse(|input| border_block_start_color::parse(context, input))
                        .unwrap_or_else(|_| start_value.clone());

                Ok(expanded! {
                    border_block_start_color: start_value,
                    border_block_end_color: end_value,
                })
            }

            impl<'a> ToCss for LonghandsToSerialize<'a>  {
                fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                    self.border_block_start_color.to_css(dest)?;

                    if self.border_block_end_color != self.border_block_start_color {
                        dest.write_char(' ')?;
                        self.border_block_end_color.to_css(dest)?;
                    }

                    Ok(())
                }
            }
        
    }

        
        

    /// https://drafts.csswg.org/css-logical/#propdef-border-inline-width
    pub mod border_inline_width {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_inline_start_width:
                    longhands::border_inline_start_width::SpecifiedValue
                    ,
                pub border_inline_end_width:
                    longhands::border_inline_end_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_start_width:
                    &'a longhands::border_inline_start_width::SpecifiedValue,
                pub border_inline_end_width:
                    &'a longhands::border_inline_end_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_start_width =
                        None::< &'a longhands::border_inline_start_width::SpecifiedValue>;
                    let mut border_inline_end_width =
                        None::< &'a longhands::border_inline_end_width::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                                border_inline_start_width = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                                border_inline_end_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_start_width,
                        border_inline_end_width,
                ) {

                    (
                        Some(border_inline_start_width),
                        Some(border_inline_end_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_start_width,
                            border_inline_end_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineStartWidth(
                        longhands.border_inline_start_width
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndWidth(
                        longhands.border_inline_end_width
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

            use crate::properties::longhands::border_inline_start_width;
            pub fn parse_value<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<Longhands, ParseError<'i>> {
                let start_value = border_inline_start_width::parse(context, input)?;
                let end_value =
                    input.try_parse(|input| border_inline_start_width::parse(context, input))
                        .unwrap_or_else(|_| start_value.clone());

                Ok(expanded! {
                    border_inline_start_width: start_value,
                    border_inline_end_width: end_value,
                })
            }

            impl<'a> ToCss for LonghandsToSerialize<'a>  {
                fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                    self.border_inline_start_width.to_css(dest)?;

                    if self.border_inline_end_width != self.border_inline_start_width {
                        dest.write_char(' ')?;
                        self.border_inline_end_width.to_css(dest)?;
                    }

                    Ok(())
                }
            }
        
    }

        
        

    /// https://drafts.csswg.org/css-logical/#propdef-border-inline-style
    pub mod border_inline_style {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_inline_start_style:
                    longhands::border_inline_start_style::SpecifiedValue
                    ,
                pub border_inline_end_style:
                    longhands::border_inline_end_style::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_start_style:
                    &'a longhands::border_inline_start_style::SpecifiedValue,
                pub border_inline_end_style:
                    &'a longhands::border_inline_end_style::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_start_style =
                        None::< &'a longhands::border_inline_start_style::SpecifiedValue>;
                    let mut border_inline_end_style =
                        None::< &'a longhands::border_inline_end_style::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                                border_inline_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                                border_inline_end_style = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_start_style,
                        border_inline_end_style,
                ) {

                    (
                        Some(border_inline_start_style),
                        Some(border_inline_end_style),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_start_style,
                            border_inline_end_style,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineStartStyle(
                        longhands.border_inline_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndStyle(
                        longhands.border_inline_end_style
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

            use crate::properties::longhands::border_inline_start_style;
            pub fn parse_value<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<Longhands, ParseError<'i>> {
                let start_value = border_inline_start_style::parse(context, input)?;
                let end_value =
                    input.try_parse(|input| border_inline_start_style::parse(context, input))
                        .unwrap_or_else(|_| start_value.clone());

                Ok(expanded! {
                    border_inline_start_style: start_value,
                    border_inline_end_style: end_value,
                })
            }

            impl<'a> ToCss for LonghandsToSerialize<'a>  {
                fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                    self.border_inline_start_style.to_css(dest)?;

                    if self.border_inline_end_style != self.border_inline_start_style {
                        dest.write_char(' ')?;
                        self.border_inline_end_style.to_css(dest)?;
                    }

                    Ok(())
                }
            }
        
    }

        
        

    /// https://drafts.csswg.org/css-logical/#propdef-border-inline-color
    pub mod border_inline_color {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_inline_start_color:
                    longhands::border_inline_start_color::SpecifiedValue
                    ,
                pub border_inline_end_color:
                    longhands::border_inline_end_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_start_color:
                    &'a longhands::border_inline_start_color::SpecifiedValue,
                pub border_inline_end_color:
                    &'a longhands::border_inline_end_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_start_color =
                        None::< &'a longhands::border_inline_start_color::SpecifiedValue>;
                    let mut border_inline_end_color =
                        None::< &'a longhands::border_inline_end_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderInlineStartColor(ref value) => {
                                border_inline_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndColor(ref value) => {
                                border_inline_end_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_start_color,
                        border_inline_end_color,
                ) {

                    (
                        Some(border_inline_start_color),
                        Some(border_inline_end_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_start_color,
                            border_inline_end_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineStartColor(
                        longhands.border_inline_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndColor(
                        longhands.border_inline_end_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

            use crate::properties::longhands::border_inline_start_color;
            pub fn parse_value<'i, 't>(
                context: &ParserContext,
                input: &mut Parser<'i, 't>,
            ) -> Result<Longhands, ParseError<'i>> {
                let start_value = border_inline_start_color::parse(context, input)?;
                let end_value =
                    input.try_parse(|input| border_inline_start_color::parse(context, input))
                        .unwrap_or_else(|_| start_value.clone());

                Ok(expanded! {
                    border_inline_start_color: start_value,
                    border_inline_end_color: end_value,
                })
            }

            impl<'a> ToCss for LonghandsToSerialize<'a>  {
                fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                    self.border_inline_start_color.to_css(dest)?;

                    if self.border_inline_end_color != self.border_inline_start_color {
                        dest.write_char(' ')?;
                        self.border_inline_end_color.to_css(dest)?;
                    }

                    Ok(())
                }
            }
        
    }


    
    

    /// https://drafts.csswg.org/css-logical/#propdef-border-block
    pub mod border_block {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_block_start_width:
                    longhands::border_block_start_width::SpecifiedValue
                    ,
                pub border_block_end_width:
                    longhands::border_block_end_width::SpecifiedValue
                    ,
                pub border_block_start_style:
                    longhands::border_block_start_style::SpecifiedValue
                    ,
                pub border_block_end_style:
                    longhands::border_block_end_style::SpecifiedValue
                    ,
                pub border_block_start_color:
                    longhands::border_block_start_color::SpecifiedValue
                    ,
                pub border_block_end_color:
                    longhands::border_block_end_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_block_start_width:
                    &'a longhands::border_block_start_width::SpecifiedValue,
                pub border_block_end_width:
                    &'a longhands::border_block_end_width::SpecifiedValue,
                pub border_block_start_style:
                    &'a longhands::border_block_start_style::SpecifiedValue,
                pub border_block_end_style:
                    &'a longhands::border_block_end_style::SpecifiedValue,
                pub border_block_start_color:
                    &'a longhands::border_block_start_color::SpecifiedValue,
                pub border_block_end_color:
                    &'a longhands::border_block_end_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_block_start_width =
                        None::< &'a longhands::border_block_start_width::SpecifiedValue>;
                    let mut border_block_end_width =
                        None::< &'a longhands::border_block_end_width::SpecifiedValue>;
                    let mut border_block_start_style =
                        None::< &'a longhands::border_block_start_style::SpecifiedValue>;
                    let mut border_block_end_style =
                        None::< &'a longhands::border_block_end_style::SpecifiedValue>;
                    let mut border_block_start_color =
                        None::< &'a longhands::border_block_start_color::SpecifiedValue>;
                    let mut border_block_end_color =
                        None::< &'a longhands::border_block_end_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderBlockStartWidth(ref value) => {
                                border_block_start_width = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndWidth(ref value) => {
                                border_block_end_width = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartStyle(ref value) => {
                                border_block_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndStyle(ref value) => {
                                border_block_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderBlockStartColor(ref value) => {
                                border_block_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderBlockEndColor(ref value) => {
                                border_block_end_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_block_start_width,
                        border_block_end_width,
                        border_block_start_style,
                        border_block_end_style,
                        border_block_start_color,
                        border_block_end_color,
                ) {

                    (
                        Some(border_block_start_width),
                        Some(border_block_end_width),
                        Some(border_block_start_style),
                        Some(border_block_end_style),
                        Some(border_block_start_color),
                        Some(border_block_end_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_block_start_width,
                            border_block_end_width,
                            border_block_start_style,
                            border_block_end_style,
                            border_block_start_color,
                            border_block_end_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderBlockStartWidth(
                        longhands.border_block_start_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndWidth(
                        longhands.border_block_end_width
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartStyle(
                        longhands.border_block_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndStyle(
                        longhands.border_block_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockStartColor(
                        longhands.border_block_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderBlockEndColor(
                        longhands.border_block_end_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

        use crate::properties::shorthands::border_block_start;
        pub fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let start_value = border_block_start::parse_value(context, input)?;
            Ok(expanded! {
                border_block_start_width: start_value.border_block_start_width.clone(),
                border_block_end_width: start_value.border_block_start_width,
                border_block_start_style: start_value.border_block_start_style.clone(),
                border_block_end_style: start_value.border_block_start_style,
                border_block_start_color: start_value.border_block_start_color.clone(),
                border_block_end_color: start_value.border_block_start_color,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a>  {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                crate::values::specified::border::serialize_directional_border(
                    dest,
                    self.border_block_start_width,
                    self.border_block_start_style,
                    self.border_block_start_color
                )
            }
        }
    
    }

    
    

    /// https://drafts.csswg.org/css-logical/#propdef-border-inline
    pub mod border_inline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub border_inline_start_width:
                    longhands::border_inline_start_width::SpecifiedValue
                    ,
                pub border_inline_end_width:
                    longhands::border_inline_end_width::SpecifiedValue
                    ,
                pub border_inline_start_style:
                    longhands::border_inline_start_style::SpecifiedValue
                    ,
                pub border_inline_end_style:
                    longhands::border_inline_end_style::SpecifiedValue
                    ,
                pub border_inline_start_color:
                    longhands::border_inline_start_color::SpecifiedValue
                    ,
                pub border_inline_end_color:
                    longhands::border_inline_end_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub border_inline_start_width:
                    &'a longhands::border_inline_start_width::SpecifiedValue,
                pub border_inline_end_width:
                    &'a longhands::border_inline_end_width::SpecifiedValue,
                pub border_inline_start_style:
                    &'a longhands::border_inline_start_style::SpecifiedValue,
                pub border_inline_end_style:
                    &'a longhands::border_inline_end_style::SpecifiedValue,
                pub border_inline_start_color:
                    &'a longhands::border_inline_start_color::SpecifiedValue,
                pub border_inline_end_color:
                    &'a longhands::border_inline_end_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut border_inline_start_width =
                        None::< &'a longhands::border_inline_start_width::SpecifiedValue>;
                    let mut border_inline_end_width =
                        None::< &'a longhands::border_inline_end_width::SpecifiedValue>;
                    let mut border_inline_start_style =
                        None::< &'a longhands::border_inline_start_style::SpecifiedValue>;
                    let mut border_inline_end_style =
                        None::< &'a longhands::border_inline_end_style::SpecifiedValue>;
                    let mut border_inline_start_color =
                        None::< &'a longhands::border_inline_start_color::SpecifiedValue>;
                    let mut border_inline_end_color =
                        None::< &'a longhands::border_inline_end_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BorderInlineStartWidth(ref value) => {
                                border_inline_start_width = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndWidth(ref value) => {
                                border_inline_end_width = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartStyle(ref value) => {
                                border_inline_start_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndStyle(ref value) => {
                                border_inline_end_style = Some(value)
                            },
                            PropertyDeclaration::BorderInlineStartColor(ref value) => {
                                border_inline_start_color = Some(value)
                            },
                            PropertyDeclaration::BorderInlineEndColor(ref value) => {
                                border_inline_end_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        border_inline_start_width,
                        border_inline_end_width,
                        border_inline_start_style,
                        border_inline_end_style,
                        border_inline_start_color,
                        border_inline_end_color,
                ) {

                    (
                        Some(border_inline_start_width),
                        Some(border_inline_end_width),
                        Some(border_inline_start_style),
                        Some(border_inline_end_style),
                        Some(border_inline_start_color),
                        Some(border_inline_end_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            border_inline_start_width,
                            border_inline_end_width,
                            border_inline_start_style,
                            border_inline_end_style,
                            border_inline_start_color,
                            border_inline_end_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BorderInlineStartWidth(
                        longhands.border_inline_start_width
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndWidth(
                        longhands.border_inline_end_width
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartStyle(
                        longhands.border_inline_start_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndStyle(
                        longhands.border_inline_end_style
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineStartColor(
                        longhands.border_inline_start_color
                    ));
                    declarations.push(PropertyDeclaration::BorderInlineEndColor(
                        longhands.border_inline_end_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        

        use crate::properties::shorthands::border_inline_start;
        pub fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let start_value = border_inline_start::parse_value(context, input)?;
            Ok(expanded! {
                border_inline_start_width: start_value.border_inline_start_width.clone(),
                border_inline_end_width: start_value.border_inline_start_width,
                border_inline_start_style: start_value.border_inline_start_style.clone(),
                border_inline_end_style: start_value.border_inline_start_style,
                border_inline_start_color: start_value.border_inline_start_color.clone(),
                border_inline_end_color: start_value.border_inline_start_color,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a>  {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                crate::values::specified::border::serialize_directional_border(
                    dest,
                    self.border_inline_start_width,
                    self.border_inline_start_style,
                    self.border_inline_start_color
                )
            }
        }
    
    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */






    /// https://drafts.csswg.org/css-overflow/#propdef-overflow
    pub mod overflow {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub overflow_x:
                    longhands::overflow_x::SpecifiedValue
                    ,
                pub overflow_y:
                    longhands::overflow_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overflow_x:
                    &'a longhands::overflow_x::SpecifiedValue,
                pub overflow_y:
                    &'a longhands::overflow_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overflow_x =
                        None::< &'a longhands::overflow_x::SpecifiedValue>;
                    let mut overflow_y =
                        None::< &'a longhands::overflow_y::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::OverflowX(ref value) => {
                                overflow_x = Some(value)
                            },
                            PropertyDeclaration::OverflowY(ref value) => {
                                overflow_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overflow_x,
                        overflow_y,
                ) {

                    (
                        Some(overflow_x),
                        Some(overflow_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overflow_x,
                            overflow_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverflowX(
                        longhands.overflow_x
                    ));
                    declarations.push(PropertyDeclaration::OverflowY(
                        longhands.overflow_y
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::overflow_x::SpecifiedValue,
            ParseError<'i>
        > {
            crate::parser::Parse::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            overflow_x: first,
            overflow_y: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.overflow_x;
            let second = &self.overflow_y;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// Internal, may be standardized in the future (https://developer.mozilla.org/en-US/docs/Web/CSS/overflow-clip-box)
    pub mod overflow_clip_box {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub overflow_clip_box_block:
                    longhands::overflow_clip_box_block::SpecifiedValue
                    ,
                pub overflow_clip_box_inline:
                    longhands::overflow_clip_box_inline::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overflow_clip_box_block:
                    &'a longhands::overflow_clip_box_block::SpecifiedValue,
                pub overflow_clip_box_inline:
                    &'a longhands::overflow_clip_box_inline::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overflow_clip_box_block =
                        None::< &'a longhands::overflow_clip_box_block::SpecifiedValue>;
                    let mut overflow_clip_box_inline =
                        None::< &'a longhands::overflow_clip_box_inline::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::OverflowClipBoxBlock(ref value) => {
                                overflow_clip_box_block = Some(value)
                            },
                            PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                                overflow_clip_box_inline = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overflow_clip_box_block,
                        overflow_clip_box_inline,
                ) {

                    (
                        Some(overflow_clip_box_block),
                        Some(overflow_clip_box_inline),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overflow_clip_box_block,
                            overflow_clip_box_inline,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverflowClipBoxBlock(
                        longhands.overflow_clip_box_block
                    ));
                    declarations.push(PropertyDeclaration::OverflowClipBoxInline(
                        longhands.overflow_clip_box_inline
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::overflow_clip_box_block::SpecifiedValue,
            ParseError<'i>
        > {
            crate::parser::Parse::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            overflow_clip_box_block: first,
            overflow_clip_box_inline: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.overflow_clip_box_block;
            let second = &self.overflow_clip_box_inline;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// https://wicg.github.io/overscroll-behavior/#overscroll-behavior-properties
    pub mod overscroll_behavior {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub overscroll_behavior_x:
                    longhands::overscroll_behavior_x::SpecifiedValue
                    ,
                pub overscroll_behavior_y:
                    longhands::overscroll_behavior_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub overscroll_behavior_x:
                    &'a longhands::overscroll_behavior_x::SpecifiedValue,
                pub overscroll_behavior_y:
                    &'a longhands::overscroll_behavior_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut overscroll_behavior_x =
                        None::< &'a longhands::overscroll_behavior_x::SpecifiedValue>;
                    let mut overscroll_behavior_y =
                        None::< &'a longhands::overscroll_behavior_y::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::OverscrollBehaviorX(ref value) => {
                                overscroll_behavior_x = Some(value)
                            },
                            PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                                overscroll_behavior_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        overscroll_behavior_x,
                        overscroll_behavior_y,
                ) {

                    (
                        Some(overscroll_behavior_x),
                        Some(overscroll_behavior_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            overscroll_behavior_x,
                            overscroll_behavior_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OverscrollBehaviorX(
                        longhands.overscroll_behavior_x
                    ));
                    declarations.push(PropertyDeclaration::OverscrollBehaviorY(
                        longhands.overscroll_behavior_y
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::overscroll_behavior_x::SpecifiedValue,
            ParseError<'i>
        > {
            crate::parser::Parse::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            overscroll_behavior_x: first,
            overscroll_behavior_y: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.overscroll_behavior_x;
            let second = &self.overscroll_behavior_y;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }





    /// https://drafts.csswg.org/css-contain-3/#container-shorthand
    pub mod container {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub container_name:
                    longhands::container_name::SpecifiedValue
                    ,
                pub container_type:
                    longhands::container_type::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub container_name:
                    &'a longhands::container_name::SpecifiedValue,
                pub container_type:
                    &'a longhands::container_type::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut container_name =
                        None::< &'a longhands::container_name::SpecifiedValue>;
                    let mut container_type =
                        None::< &'a longhands::container_type::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ContainerName(ref value) => {
                                container_name = Some(value)
                            },
                            PropertyDeclaration::ContainerType(ref value) => {
                                container_type = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        container_name,
                        container_type,
                ) {

                    (
                        Some(container_name),
                        Some(container_type),
                    ) =>
                    Ok(LonghandsToSerialize {
                            container_name,
                            container_type,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ContainerName(
                        longhands.container_name
                    ));
                    declarations.push(PropertyDeclaration::ContainerType(
                        longhands.container_type
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::box_::{ContainerName, ContainerType};
    pub fn parse_value<'i>(
        context: &ParserContext,
        input: &mut Parser<'i, '_>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::parser::Parse;
        // See https://github.com/w3c/csswg-drafts/issues/7180 for why we don't
        // match the spec.
        let container_name = ContainerName::parse(context, input)?;
        let container_type = if input.try_parse(|input| input.expect_delim('/')).is_ok() {
            ContainerType::parse(input)?
        } else {
            ContainerType::Normal
        };
        Ok(expanded! {
            container_name: container_name,
            container_type: container_type,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.container_name.to_css(dest)?;
            if !self.container_type.is_normal() {
                dest.write_str(" / ")?;
                self.container_type.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-break-3/#page-break-properties
    pub mod page_break_before {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub break_before:
                    longhands::break_before::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub break_before:
                    &'a longhands::break_before::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut break_before =
                        None::< &'a longhands::break_before::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BreakBefore(ref value) => {
                                break_before = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        break_before,
                ) {

                    (
                        Some(break_before),
                    ) =>
                    Ok(LonghandsToSerialize {
                            break_before,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BreakBefore(
                        longhands.break_before
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    pub fn parse_value<'i>(
        context: &ParserContext,
        input: &mut Parser<'i, '_>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::values::specified::box_::BreakBetween;
        Ok(expanded! {
            break_before: BreakBetween::parse_legacy(context, input)?,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.break_before.to_css_legacy(dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-break-3/#page-break-properties
    pub mod page_break_after {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub break_after:
                    longhands::break_after::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub break_after:
                    &'a longhands::break_after::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut break_after =
                        None::< &'a longhands::break_after::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BreakAfter(ref value) => {
                                break_after = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        break_after,
                ) {

                    (
                        Some(break_after),
                    ) =>
                    Ok(LonghandsToSerialize {
                            break_after,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BreakAfter(
                        longhands.break_after
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    pub fn parse_value<'i>(
        context: &ParserContext,
        input: &mut Parser<'i, '_>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::values::specified::box_::BreakBetween;
        Ok(expanded! {
            break_after: BreakBetween::parse_legacy(context, input)?,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.break_after.to_css_legacy(dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-break-3/#page-break-properties
    pub mod page_break_inside {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub break_inside:
                    longhands::break_inside::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub break_inside:
                    &'a longhands::break_inside::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut break_inside =
                        None::< &'a longhands::break_inside::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::BreakInside(ref value) => {
                                break_inside = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        break_inside,
                ) {

                    (
                        Some(break_inside),
                    ) =>
                    Ok(LonghandsToSerialize {
                            break_inside,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::BreakInside(
                        longhands.break_inside
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    pub fn parse_value<'i>(
        context: &ParserContext,
        input: &mut Parser<'i, '_>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::values::specified::box_::BreakWithin;
        Ok(expanded! {
            break_inside: BreakWithin::parse_legacy(context, input)?,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.break_inside.to_css_legacy(dest)
        }
    }

    }




    /// https://drafts.fxtf.org/motion-1/#offset-shorthand
    pub mod offset {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub offset_path:
                    longhands::offset_path::SpecifiedValue
                    ,
                pub offset_distance:
                    longhands::offset_distance::SpecifiedValue
                    ,
                pub offset_rotate:
                    longhands::offset_rotate::SpecifiedValue
                    ,
                pub offset_anchor:
                        Box<
                    longhands::offset_anchor::SpecifiedValue
                        >
                    ,
                pub offset_position:
                        Box<
                    longhands::offset_position::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub offset_path:
                    &'a longhands::offset_path::SpecifiedValue,
                pub offset_distance:
                    &'a longhands::offset_distance::SpecifiedValue,
                pub offset_rotate:
                    &'a longhands::offset_rotate::SpecifiedValue,
                pub offset_anchor:
                    &'a longhands::offset_anchor::SpecifiedValue,
                pub offset_position:
                    &'a longhands::offset_position::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut offset_path =
                        None::< &'a longhands::offset_path::SpecifiedValue>;
                    let mut offset_distance =
                        None::< &'a longhands::offset_distance::SpecifiedValue>;
                    let mut offset_rotate =
                        None::< &'a longhands::offset_rotate::SpecifiedValue>;
                    let mut offset_anchor =
                        None::< &'a longhands::offset_anchor::SpecifiedValue>;
                    let mut offset_position =
                        None::< &'a longhands::offset_position::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::OffsetPath(ref value) => {
                                offset_path = Some(value)
                            },
                            PropertyDeclaration::OffsetDistance(ref value) => {
                                offset_distance = Some(value)
                            },
                            PropertyDeclaration::OffsetRotate(ref value) => {
                                offset_rotate = Some(value)
                            },
                            PropertyDeclaration::OffsetAnchor(ref value) => {
                                offset_anchor = Some(value)
                            },
                            PropertyDeclaration::OffsetPosition(ref value) => {
                                offset_position = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        offset_path,
                        offset_distance,
                        offset_rotate,
                        offset_anchor,
                        offset_position,
                ) {

                    (
                        Some(offset_path),
                        Some(offset_distance),
                        Some(offset_rotate),
                        Some(offset_anchor),
                        Some(offset_position),
                    ) =>
                    Ok(LonghandsToSerialize {
                            offset_path,
                            offset_distance,
                            offset_rotate,
                            offset_anchor,
                            offset_position,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OffsetPath(
                        longhands.offset_path
                    ));
                    declarations.push(PropertyDeclaration::OffsetDistance(
                        longhands.offset_distance
                    ));
                    declarations.push(PropertyDeclaration::OffsetRotate(
                        longhands.offset_rotate
                    ));
                    declarations.push(PropertyDeclaration::OffsetAnchor(
                        longhands.offset_anchor
                    ));
                    declarations.push(PropertyDeclaration::OffsetPosition(
                        longhands.offset_position
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::parser::Parse;
    use crate::values::specified::motion::{OffsetPath, OffsetPosition, OffsetRotate};
    use crate::values::specified::{LengthPercentage, PositionOrAuto};
    use crate::Zero;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let offset_position = input.try_parse(|i| OffsetPosition::parse(context, i)).ok();
        let offset_path = input.try_parse(|i| OffsetPath::parse(context, i)).ok();

        // Must have one of [offset-position, offset-path].
        // FIXME: The syntax is out-of-date after the update of the spec.
        // https://github.com/w3c/fxtf-drafts/issues/515
        if offset_position.is_none() && offset_path.is_none() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        let mut offset_distance = None;
        let mut offset_rotate = None;
        // offset-distance and offset-rotate are grouped with offset-path.
        if offset_path.is_some() {
            loop {
                if offset_distance.is_none() {
                    if let Ok(value) = input.try_parse(|i| LengthPercentage::parse(context, i)) {
                        offset_distance = Some(value);
                    }
                }

                if offset_rotate.is_none() {
                    if let Ok(value) = input.try_parse(|i| OffsetRotate::parse(context, i)) {
                        offset_rotate = Some(value);
                        continue;
                    }
                }
                break;
            }
        }

        let offset_anchor = input.try_parse(|i| {
            i.expect_delim('/')?;
            PositionOrAuto::parse(context, i)
        }).ok();

        Ok(expanded! {
            offset_position: offset_position.unwrap_or(OffsetPosition::normal()),
            offset_path: offset_path.unwrap_or(OffsetPath::none()),
            offset_distance: offset_distance.unwrap_or(LengthPercentage::zero()),
            offset_rotate: offset_rotate.unwrap_or(OffsetRotate::auto()),
            offset_anchor: offset_anchor.unwrap_or(PositionOrAuto::auto()),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            // The basic concept is: we must serialize offset-position or offset-path group.
            // offset-path group means "offset-path offset-distance offset-rotate".
            let must_serialize_path = *self.offset_path != OffsetPath::None
                || (!self.offset_distance.is_zero() || !self.offset_rotate.is_auto());
            let position_is_default = matches!(self.offset_position, OffsetPosition::Normal);
            if !position_is_default || !must_serialize_path {
                self.offset_position.to_css(dest)?;
            }

            if must_serialize_path {
                if !position_is_default {
                    dest.write_char(' ')?;
                }
                self.offset_path.to_css(dest)?;
            }

            if !self.offset_distance.is_zero() {
                dest.write_char(' ')?;
                self.offset_distance.to_css(dest)?;
            }

            if !self.offset_rotate.is_auto() {
                dest.write_char(' ')?;
                self.offset_rotate.to_css(dest)?;
            }

            if *self.offset_anchor != PositionOrAuto::auto() {
                dest.write_str(" / ")?;
                self.offset_anchor.to_css(dest)?;
            }
            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-multicol/#propdef-columns
    pub mod columns {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub column_width:
                    longhands::column_width::SpecifiedValue
                    ,
                pub column_count:
                    longhands::column_count::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub column_width:
                    &'a longhands::column_width::SpecifiedValue,
                pub column_count:
                    &'a longhands::column_count::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut column_width =
                        None::< &'a longhands::column_width::SpecifiedValue>;
                    let mut column_count =
                        None::< &'a longhands::column_count::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ColumnWidth(ref value) => {
                                column_width = Some(value)
                            },
                            PropertyDeclaration::ColumnCount(ref value) => {
                                column_count = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        column_width,
                        column_count,
                ) {

                    (
                        Some(column_width),
                        Some(column_count),
                    ) =>
                    Ok(LonghandsToSerialize {
                            column_width,
                            column_count,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ColumnWidth(
                        longhands.column_width
                    ));
                    declarations.push(PropertyDeclaration::ColumnCount(
                        longhands.column_count
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{column_count, column_width};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut column_count = None;
        let mut column_width = None;
        let mut autos = 0;

        loop {
            if input.try_parse(|input| input.expect_ident_matching("auto")).is_ok() {
                // Leave the options to None, 'auto' is the initial value.
                autos += 1;
                continue
            }

            if column_count.is_none() {
                if let Ok(value) = input.try_parse(|input| column_count::parse(context, input)) {
                    column_count = Some(value);
                    continue
                }
            }

            if column_width.is_none() {
                if let Ok(value) = input.try_parse(|input| column_width::parse(context, input)) {
                    column_width = Some(value);
                    continue
                }
            }

            break
        }

        let values = autos + column_count.iter().len() + column_width.iter().len();
        if values == 0 || values > 2 {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        } else {
            Ok(expanded! {
                column_count: unwrap_or_initial!(column_count),
                column_width: unwrap_or_initial!(column_width),
            })
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.column_width.is_auto() {
                return self.column_count.to_css(dest)
            }
            self.column_width.to_css(dest)?;
            if !self.column_count.is_auto() {
                dest.write_char(' ')?;
                self.column_count.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-multicol/#propdef-column-rule
    pub mod column_rule {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub column_rule_width:
                    longhands::column_rule_width::SpecifiedValue
                    ,
                pub column_rule_style:
                    longhands::column_rule_style::SpecifiedValue
                    ,
                pub column_rule_color:
                    longhands::column_rule_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub column_rule_width:
                    &'a longhands::column_rule_width::SpecifiedValue,
                pub column_rule_style:
                    &'a longhands::column_rule_style::SpecifiedValue,
                pub column_rule_color:
                    &'a longhands::column_rule_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut column_rule_width =
                        None::< &'a longhands::column_rule_width::SpecifiedValue>;
                    let mut column_rule_style =
                        None::< &'a longhands::column_rule_style::SpecifiedValue>;
                    let mut column_rule_color =
                        None::< &'a longhands::column_rule_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ColumnRuleWidth(ref value) => {
                                column_rule_width = Some(value)
                            },
                            PropertyDeclaration::ColumnRuleStyle(ref value) => {
                                column_rule_style = Some(value)
                            },
                            PropertyDeclaration::ColumnRuleColor(ref value) => {
                                column_rule_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        column_rule_width,
                        column_rule_style,
                        column_rule_color,
                ) {

                    (
                        Some(column_rule_width),
                        Some(column_rule_style),
                        Some(column_rule_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            column_rule_width,
                            column_rule_style,
                            column_rule_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ColumnRuleWidth(
                        longhands.column_rule_width
                    ));
                    declarations.push(PropertyDeclaration::ColumnRuleStyle(
                        longhands.column_rule_style
                    ));
                    declarations.push(PropertyDeclaration::ColumnRuleColor(
                        longhands.column_rule_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{column_rule_width, column_rule_style};
    use crate::properties::longhands::column_rule_color;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut column_rule_width = None;
        let mut column_rule_style = None;
        let mut column_rule_color = None;
        let mut any = false;

        loop {
            if column_rule_width.is_none() {
                if let Ok(value) = input.try_parse(|input|
                        column_rule_width::parse(context, input)) {
                    column_rule_width = Some(value);
                    any = true;
                    continue
                }
            }
            if column_rule_style.is_none() {
                if let Ok(value) = input.try_parse(|input|
                        column_rule_style::parse(context, input)) {
                    column_rule_style = Some(value);
                    any = true;
                    continue
                }
            }
            if column_rule_color.is_none() {
                if let Ok(value) = input.try_parse(|input|
                        column_rule_color::parse(context, input)) {
                    column_rule_color = Some(value);
                    any = true;
                    continue
                }
            }

            break
        }
        if any {
            Ok(expanded! {
                column_rule_width: unwrap_or_initial!(column_rule_width),
                column_rule_style: unwrap_or_initial!(column_rule_style),
                column_rule_color: unwrap_or_initial!(column_rule_color),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */






    /// https://drafts.csswg.org/css-fonts-3/#propdef-font
    pub mod font {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        pub struct Longhands {
                pub font_style:
                    longhands::font_style::SpecifiedValue
                    ,
                pub font_variant_caps:
                    longhands::font_variant_caps::SpecifiedValue
                    ,
                pub font_weight:
                    longhands::font_weight::SpecifiedValue
                    ,
                pub font_stretch:
                    longhands::font_stretch::SpecifiedValue
                    ,
                pub font_size:
                    longhands::font_size::SpecifiedValue
                    ,
                pub line_height:
                    longhands::line_height::SpecifiedValue
                    ,
                pub font_family:
                    longhands::font_family::SpecifiedValue
                    ,
                pub font_size_adjust:
                    longhands::font_size_adjust::SpecifiedValue
                    ,
                pub font_kerning:
                    longhands::font_kerning::SpecifiedValue
                    ,
                pub font_optical_sizing:
                    longhands::font_optical_sizing::SpecifiedValue
                    ,
                pub font_variant_alternates:
                    longhands::font_variant_alternates::SpecifiedValue
                    ,
                pub font_variant_east_asian:
                    longhands::font_variant_east_asian::SpecifiedValue
                    ,
                pub font_variant_emoji:
                    longhands::font_variant_emoji::SpecifiedValue
                    ,
                pub font_variant_ligatures:
                    longhands::font_variant_ligatures::SpecifiedValue
                    ,
                pub font_variant_numeric:
                    longhands::font_variant_numeric::SpecifiedValue
                    ,
                pub font_variant_position:
                    longhands::font_variant_position::SpecifiedValue
                    ,
                pub font_language_override:
                    longhands::font_language_override::SpecifiedValue
                    ,
                pub font_feature_settings:
                    longhands::font_feature_settings::SpecifiedValue
                    ,
                pub font_variation_settings:
                    longhands::font_variation_settings::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub font_style:
                    &'a longhands::font_style::SpecifiedValue,
                pub font_variant_caps:
                    &'a longhands::font_variant_caps::SpecifiedValue,
                pub font_weight:
                    &'a longhands::font_weight::SpecifiedValue,
                pub font_stretch:
                    &'a longhands::font_stretch::SpecifiedValue,
                pub font_size:
                    &'a longhands::font_size::SpecifiedValue,
                pub line_height:
                    &'a longhands::line_height::SpecifiedValue,
                pub font_family:
                    &'a longhands::font_family::SpecifiedValue,
                pub font_size_adjust:
                    &'a longhands::font_size_adjust::SpecifiedValue,
                pub font_kerning:
                    &'a longhands::font_kerning::SpecifiedValue,
                pub font_optical_sizing:
                    Option<
                    &'a longhands::font_optical_sizing::SpecifiedValue,
                    >,
                pub font_variant_alternates:
                    &'a longhands::font_variant_alternates::SpecifiedValue,
                pub font_variant_east_asian:
                    &'a longhands::font_variant_east_asian::SpecifiedValue,
                pub font_variant_emoji:
                    Option<
                    &'a longhands::font_variant_emoji::SpecifiedValue,
                    >,
                pub font_variant_ligatures:
                    &'a longhands::font_variant_ligatures::SpecifiedValue,
                pub font_variant_numeric:
                    &'a longhands::font_variant_numeric::SpecifiedValue,
                pub font_variant_position:
                    &'a longhands::font_variant_position::SpecifiedValue,
                pub font_language_override:
                    &'a longhands::font_language_override::SpecifiedValue,
                pub font_feature_settings:
                    &'a longhands::font_feature_settings::SpecifiedValue,
                pub font_variation_settings:
                    Option<
                    &'a longhands::font_variation_settings::SpecifiedValue,
                    >,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut font_style =
                        None::< &'a longhands::font_style::SpecifiedValue>;
                    let mut font_variant_caps =
                        None::< &'a longhands::font_variant_caps::SpecifiedValue>;
                    let mut font_weight =
                        None::< &'a longhands::font_weight::SpecifiedValue>;
                    let mut font_stretch =
                        None::< &'a longhands::font_stretch::SpecifiedValue>;
                    let mut font_size =
                        None::< &'a longhands::font_size::SpecifiedValue>;
                    let mut line_height =
                        None::< &'a longhands::line_height::SpecifiedValue>;
                    let mut font_family =
                        None::< &'a longhands::font_family::SpecifiedValue>;
                    let mut font_size_adjust =
                        None::< &'a longhands::font_size_adjust::SpecifiedValue>;
                    let mut font_kerning =
                        None::< &'a longhands::font_kerning::SpecifiedValue>;
                    let mut font_optical_sizing =
                        None::< &'a longhands::font_optical_sizing::SpecifiedValue>;
                    let mut font_variant_alternates =
                        None::< &'a longhands::font_variant_alternates::SpecifiedValue>;
                    let mut font_variant_east_asian =
                        None::< &'a longhands::font_variant_east_asian::SpecifiedValue>;
                    let mut font_variant_emoji =
                        None::< &'a longhands::font_variant_emoji::SpecifiedValue>;
                    let mut font_variant_ligatures =
                        None::< &'a longhands::font_variant_ligatures::SpecifiedValue>;
                    let mut font_variant_numeric =
                        None::< &'a longhands::font_variant_numeric::SpecifiedValue>;
                    let mut font_variant_position =
                        None::< &'a longhands::font_variant_position::SpecifiedValue>;
                    let mut font_language_override =
                        None::< &'a longhands::font_language_override::SpecifiedValue>;
                    let mut font_feature_settings =
                        None::< &'a longhands::font_feature_settings::SpecifiedValue>;
                    let mut font_variation_settings =
                        None::< &'a longhands::font_variation_settings::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::FontStyle(ref value) => {
                                font_style = Some(value)
                            },
                            PropertyDeclaration::FontVariantCaps(ref value) => {
                                font_variant_caps = Some(value)
                            },
                            PropertyDeclaration::FontWeight(ref value) => {
                                font_weight = Some(value)
                            },
                            PropertyDeclaration::FontStretch(ref value) => {
                                font_stretch = Some(value)
                            },
                            PropertyDeclaration::FontSize(ref value) => {
                                font_size = Some(value)
                            },
                            PropertyDeclaration::LineHeight(ref value) => {
                                line_height = Some(value)
                            },
                            PropertyDeclaration::FontFamily(ref value) => {
                                font_family = Some(value)
                            },
                            PropertyDeclaration::FontSizeAdjust(ref value) => {
                                font_size_adjust = Some(value)
                            },
                            PropertyDeclaration::FontKerning(ref value) => {
                                font_kerning = Some(value)
                            },
                            PropertyDeclaration::FontOpticalSizing(ref value) => {
                                font_optical_sizing = Some(value)
                            },
                            PropertyDeclaration::FontVariantAlternates(ref value) => {
                                font_variant_alternates = Some(value)
                            },
                            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                                font_variant_east_asian = Some(value)
                            },
                            PropertyDeclaration::FontVariantEmoji(ref value) => {
                                font_variant_emoji = Some(value)
                            },
                            PropertyDeclaration::FontVariantLigatures(ref value) => {
                                font_variant_ligatures = Some(value)
                            },
                            PropertyDeclaration::FontVariantNumeric(ref value) => {
                                font_variant_numeric = Some(value)
                            },
                            PropertyDeclaration::FontVariantPosition(ref value) => {
                                font_variant_position = Some(value)
                            },
                            PropertyDeclaration::FontLanguageOverride(ref value) => {
                                font_language_override = Some(value)
                            },
                            PropertyDeclaration::FontFeatureSettings(ref value) => {
                                font_feature_settings = Some(value)
                            },
                            PropertyDeclaration::FontVariationSettings(ref value) => {
                                font_variation_settings = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        font_style,
                        font_variant_caps,
                        font_weight,
                        font_stretch,
                        font_size,
                        line_height,
                        font_family,
                        font_size_adjust,
                        font_kerning,
                        font_optical_sizing,
                        font_variant_alternates,
                        font_variant_east_asian,
                        font_variant_emoji,
                        font_variant_ligatures,
                        font_variant_numeric,
                        font_variant_position,
                        font_language_override,
                        font_feature_settings,
                        font_variation_settings,
                ) {

                    (
                        Some(font_style),
                        Some(font_variant_caps),
                        Some(font_weight),
                        Some(font_stretch),
                        Some(font_size),
                        Some(line_height),
                        Some(font_family),
                        Some(font_size_adjust),
                        Some(font_kerning),
                        font_optical_sizing,
                        Some(font_variant_alternates),
                        Some(font_variant_east_asian),
                        font_variant_emoji,
                        Some(font_variant_ligatures),
                        Some(font_variant_numeric),
                        Some(font_variant_position),
                        Some(font_language_override),
                        Some(font_feature_settings),
                        font_variation_settings,
                    ) =>
                    Ok(LonghandsToSerialize {
                            font_style,
                            font_variant_caps,
                            font_weight,
                            font_stretch,
                            font_size,
                            line_height,
                            font_family,
                            font_size_adjust,
                            font_kerning,
                            font_optical_sizing,
                            font_variant_alternates,
                            font_variant_east_asian,
                            font_variant_emoji,
                            font_variant_ligatures,
                            font_variant_numeric,
                            font_variant_position,
                            font_language_override,
                            font_feature_settings,
                            font_variation_settings,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FontStyle(
                        longhands.font_style
                    ));
                    declarations.push(PropertyDeclaration::FontVariantCaps(
                        longhands.font_variant_caps
                    ));
                    declarations.push(PropertyDeclaration::FontWeight(
                        longhands.font_weight
                    ));
                    declarations.push(PropertyDeclaration::FontStretch(
                        longhands.font_stretch
                    ));
                    declarations.push(PropertyDeclaration::FontSize(
                        longhands.font_size
                    ));
                    declarations.push(PropertyDeclaration::LineHeight(
                        longhands.line_height
                    ));
                    declarations.push(PropertyDeclaration::FontFamily(
                        longhands.font_family
                    ));
                    declarations.push(PropertyDeclaration::FontSizeAdjust(
                        longhands.font_size_adjust
                    ));
                    declarations.push(PropertyDeclaration::FontKerning(
                        longhands.font_kerning
                    ));
                if NonCustomPropertyId::from(LonghandId::FontOpticalSizing)
                    .allowed_in_ignoring_rule_type(context) {
                    declarations.push(PropertyDeclaration::FontOpticalSizing(
                        longhands.font_optical_sizing
                    ));
                }
                    declarations.push(PropertyDeclaration::FontVariantAlternates(
                        longhands.font_variant_alternates
                    ));
                    declarations.push(PropertyDeclaration::FontVariantEastAsian(
                        longhands.font_variant_east_asian
                    ));
                if NonCustomPropertyId::from(LonghandId::FontVariantEmoji)
                    .allowed_in_ignoring_rule_type(context) {
                    declarations.push(PropertyDeclaration::FontVariantEmoji(
                        longhands.font_variant_emoji
                    ));
                }
                    declarations.push(PropertyDeclaration::FontVariantLigatures(
                        longhands.font_variant_ligatures
                    ));
                    declarations.push(PropertyDeclaration::FontVariantNumeric(
                        longhands.font_variant_numeric
                    ));
                    declarations.push(PropertyDeclaration::FontVariantPosition(
                        longhands.font_variant_position
                    ));
                    declarations.push(PropertyDeclaration::FontLanguageOverride(
                        longhands.font_language_override
                    ));
                    declarations.push(PropertyDeclaration::FontFeatureSettings(
                        longhands.font_feature_settings
                    ));
                if NonCustomPropertyId::from(LonghandId::FontVariationSettings)
                    .allowed_in_ignoring_rule_type(context) {
                    declarations.push(PropertyDeclaration::FontVariationSettings(
                        longhands.font_variation_settings
                    ));
                }
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::computed_values::font_variant_caps::T::SmallCaps;
    use crate::parser::Parse;
    use crate::properties::longhands::{font_family, font_style, font_size, font_weight, font_stretch};
    use crate::properties::longhands::font_variant_caps;
    use crate::values::specified::font::LineHeight;
    use crate::values::specified::{FontSize, FontWeight};
    use crate::values::specified::font::{FontStretch, FontStretchKeyword};
    #[cfg(feature = "gecko")]
    use crate::values::specified::font::SystemFont;

    
            use crate::properties::longhands::font_kerning;
            use crate::properties::longhands::font_language_override;
            use crate::properties::longhands::font_size_adjust;
            use crate::properties::longhands::font_variant_alternates;
            use crate::properties::longhands::font_variant_east_asian;
            use crate::properties::longhands::font_variant_emoji;
            use crate::properties::longhands::font_variant_ligatures;
            use crate::properties::longhands::font_variant_numeric;
            use crate::properties::longhands::font_variant_position;
            use crate::properties::longhands::font_feature_settings;
            use crate::properties::longhands::font_variation_settings;
            use crate::properties::longhands::font_optical_sizing;
    use self::font_family::SpecifiedValue as FontFamily;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut nb_normals = 0;
        let mut style = None;
        let mut variant_caps = None;
        let mut weight = None;
        let mut stretch = None;
        let size;
            if let Ok(sys) = input.try_parse(|i| SystemFont::parse(context, i)) {
                return Ok(expanded! {
                        font_family: font_family::SpecifiedValue::system_font(sys),
                        font_size: font_size::SpecifiedValue::system_font(sys),
                        font_style: font_style::SpecifiedValue::system_font(sys),
                        font_stretch: font_stretch::SpecifiedValue::system_font(sys),
                        font_weight: font_weight::SpecifiedValue::system_font(sys),
                     line_height: LineHeight::normal(),
                         font_kerning: font_kerning::get_initial_specified_value(),
                         font_language_override: font_language_override::get_initial_specified_value(),
                         font_size_adjust: font_size_adjust::get_initial_specified_value(),
                         font_variant_alternates: font_variant_alternates::get_initial_specified_value(),
                         font_variant_east_asian: font_variant_east_asian::get_initial_specified_value(),
                         font_variant_emoji: font_variant_emoji::get_initial_specified_value(),
                         font_variant_ligatures: font_variant_ligatures::get_initial_specified_value(),
                         font_variant_numeric: font_variant_numeric::get_initial_specified_value(),
                         font_variant_position: font_variant_position::get_initial_specified_value(),
                         font_feature_settings: font_feature_settings::get_initial_specified_value(),
                         font_variation_settings: font_variation_settings::get_initial_specified_value(),
                         font_optical_sizing: font_optical_sizing::get_initial_specified_value(),
                         font_variant_caps: font_variant_caps::get_initial_specified_value(),
                 })
            }
        loop {
            // Special-case 'normal' because it is valid in each of
            // font-style, font-weight, font-variant and font-stretch.
            // Leaves the values to None, 'normal' is the initial value for each of them.
            if input.try_parse(|input| input.expect_ident_matching("normal")).is_ok() {
                nb_normals += 1;
                continue;
            }
            if style.is_none() {
                if let Ok(value) = input.try_parse(|input| font_style::parse(context, input)) {
                    style = Some(value);
                    continue
                }
            }
            if weight.is_none() {
                if let Ok(value) = input.try_parse(|input| font_weight::parse(context, input)) {
                    weight = Some(value);
                    continue
                }
            }
            if variant_caps.is_none() {
                // The only variant-caps value allowed is small-caps (from CSS2); the added values
                // defined by CSS Fonts 3 and later are not accepted.
                // https://www.w3.org/TR/css-fonts-4/#font-prop
                if input.try_parse(|input| input.expect_ident_matching("small-caps")).is_ok() {
                    variant_caps = Some(SmallCaps);
                    continue
                }
            }
            if stretch.is_none() {
                if let Ok(value) = input.try_parse(FontStretchKeyword::parse) {
                    stretch = Some(FontStretch::Keyword(value));
                    continue
                }
            }
            size = Some(FontSize::parse(context, input)?);
            break
        }

        let size = match size {
            Some(s) => s,
            None => {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        };

        let line_height = if input.try_parse(|input| input.expect_delim('/')).is_ok() {
            Some(LineHeight::parse(context, input)?)
        } else {
            None
        };

        #[inline]
        fn count<T>(opt: &Option<T>) -> u8 {
            if opt.is_some() { 1 } else { 0 }
        }

        if (count(&style) + count(&weight) + count(&variant_caps) + count(&stretch) + nb_normals) > 4 {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }

        let family = FontFamily::parse(context, input)?;
        Ok(expanded! {
                font_style: unwrap_or_initial!(font_style, style),
                font_weight: unwrap_or_initial!(font_weight, weight),
                font_stretch: unwrap_or_initial!(font_stretch, stretch),
                font_variant_caps: unwrap_or_initial!(font_variant_caps, variant_caps),
            font_size: size,
            line_height: line_height.unwrap_or(LineHeight::normal()),
            font_family: family,
                    font_kerning: font_kerning::get_initial_specified_value(),
                    font_language_override: font_language_override::get_initial_specified_value(),
                    font_size_adjust: font_size_adjust::get_initial_specified_value(),
                    font_variant_alternates: font_variant_alternates::get_initial_specified_value(),
                    font_variant_east_asian: font_variant_east_asian::get_initial_specified_value(),
                    font_variant_emoji: font_variant_emoji::get_initial_specified_value(),
                    font_variant_ligatures: font_variant_ligatures::get_initial_specified_value(),
                    font_variant_numeric: font_variant_numeric::get_initial_specified_value(),
                    font_variant_position: font_variant_position::get_initial_specified_value(),
                    font_feature_settings: font_feature_settings::get_initial_specified_value(),
                    font_variation_settings: font_variation_settings::get_initial_specified_value(),
                    font_optical_sizing: font_optical_sizing::get_initial_specified_value(),
        })
    }

        enum CheckSystemResult {
            AllSystem(SystemFont),
            SomeSystem,
            None
        }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
                match self.check_system() {
                    CheckSystemResult::AllSystem(sys) => return sys.to_css(dest),
                    CheckSystemResult::SomeSystem => return Ok(()),
                    CheckSystemResult::None => {}
                }

            if let Some(v) = self.font_optical_sizing {
                if v != &font_optical_sizing::get_initial_specified_value() {
                    return Ok(());
                }
            }
            if let Some(v) = self.font_variation_settings {
                if v != &font_variation_settings::get_initial_specified_value() {
                    return Ok(());
                }
            }
            if let Some(v) = self.font_variant_emoji {
                if v != &font_variant_emoji::get_initial_specified_value() {
                    return Ok(());
                }
            }

            if self.font_kerning != &font_kerning::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_language_override != &font_language_override::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_size_adjust != &font_size_adjust::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_alternates != &font_variant_alternates::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_east_asian != &font_variant_east_asian::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_ligatures != &font_variant_ligatures::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_numeric != &font_variant_numeric::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_variant_position != &font_variant_position::get_initial_specified_value() {
                return Ok(());
            }
            if self.font_feature_settings != &font_feature_settings::get_initial_specified_value() {
                return Ok(());
            }

            // Only font-stretch keywords are allowed as part as the font
            // shorthand.
            let font_stretch = match *self.font_stretch {
                FontStretch::Keyword(kw) => kw,
                FontStretch::Stretch(percentage) => {
                    match FontStretchKeyword::from_percentage(percentage.0.get()) {
                        Some(kw) => kw,
                        None => return Ok(()),
                    }
                }
                FontStretch::System(..) => return Ok(()),
            };

            // The only variant-caps value allowed in the shorthand is small-caps (from CSS2);
            // the added values defined by CSS Fonts 3 and later are not supported.
            // https://www.w3.org/TR/css-fonts-4/#font-prop
            if self.font_variant_caps != &font_variant_caps::get_initial_specified_value() &&
                *self.font_variant_caps != SmallCaps {
                return Ok(());
            }

                if self.font_style != &font_style::get_initial_specified_value() {
                    self.font_style.to_css(dest)?;
                    dest.write_char(' ')?;
                }
                if self.font_variant_caps != &font_variant_caps::get_initial_specified_value() {
                    self.font_variant_caps.to_css(dest)?;
                    dest.write_char(' ')?;
                }

            // The initial specified font-weight value of 'normal' computes as a number (400),
            // not to the keyword, so we need to check for that as well in order to properly
            // serialize the computed style.
            if self.font_weight != &FontWeight::normal() &&
               self.font_weight != &FontWeight::from_gecko_keyword(400)  {
                self.font_weight.to_css(dest)?;
                dest.write_char(' ')?;
            }

            if font_stretch != FontStretchKeyword::Normal {
                font_stretch.to_css(dest)?;
                dest.write_char(' ')?;
            }

            self.font_size.to_css(dest)?;

            if *self.line_height != LineHeight::normal() {
                dest.write_str(" / ")?;
                self.line_height.to_css(dest)?;
            }

            dest.write_char(' ')?;
            self.font_family.to_css(dest)?;

            Ok(())
        }
    }

    impl<'a> LonghandsToSerialize<'a> {
        /// Check if some or all members are system fonts
        fn check_system(&self) -> CheckSystemResult {
            let mut sys = None;
            let mut all = true;

            {
                let value = self.font_family;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_size;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_style;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_stretch;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            {
                let value = self.font_weight;
                match value.get_system() {
                    Some(s) => {
                        debug_assert!(sys.is_none() || s == sys.unwrap());
                        sys = Some(s);
                    }
                    None => {
                        all = false;
                    }
                }
            }
            if self.line_height != &LineHeight::normal() {
                all = false
            }
            if all {
                CheckSystemResult::AllSystem(sys.unwrap())
            } else if sys.is_some() {
                CheckSystemResult::SomeSystem
            } else {
                CheckSystemResult::None
            }
        }
    }

    
    impl SpecifiedValueInfo for Longhands {
        const SUPPORTED_TYPES: u8 = 0
            | <longhands::font_style::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES
            | <longhands::font_weight::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES
            | <longhands::font_stretch::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES
            | <longhands::font_variant_caps::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES
            | <longhands::font_size::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES
            | <longhands::font_family::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES
            ;

        fn collect_completion_keywords(f: KeywordsCollectFn) {
            <longhands::font_style::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords(f);
            <longhands::font_weight::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords(f);
            <longhands::font_stretch::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords(f);
            <longhands::font_variant_caps::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords(f);
            <longhands::font_size::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords(f);
            <longhands::font_family::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords(f);
            <SystemFont as SpecifiedValueInfo>::collect_completion_keywords(f);
        }
    }

    }




    /// https://drafts.csswg.org/css-fonts-3/#propdef-font-variant
    pub mod font_variant {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub font_variant_caps:
                    longhands::font_variant_caps::SpecifiedValue
                    ,
                pub font_variant_alternates:
                    longhands::font_variant_alternates::SpecifiedValue
                    ,
                pub font_variant_east_asian:
                    longhands::font_variant_east_asian::SpecifiedValue
                    ,
                pub font_variant_emoji:
                    longhands::font_variant_emoji::SpecifiedValue
                    ,
                pub font_variant_ligatures:
                    longhands::font_variant_ligatures::SpecifiedValue
                    ,
                pub font_variant_numeric:
                    longhands::font_variant_numeric::SpecifiedValue
                    ,
                pub font_variant_position:
                    longhands::font_variant_position::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub font_variant_caps:
                    &'a longhands::font_variant_caps::SpecifiedValue,
                pub font_variant_alternates:
                    &'a longhands::font_variant_alternates::SpecifiedValue,
                pub font_variant_east_asian:
                    &'a longhands::font_variant_east_asian::SpecifiedValue,
                pub font_variant_emoji:
                    Option<
                    &'a longhands::font_variant_emoji::SpecifiedValue,
                    >,
                pub font_variant_ligatures:
                    &'a longhands::font_variant_ligatures::SpecifiedValue,
                pub font_variant_numeric:
                    &'a longhands::font_variant_numeric::SpecifiedValue,
                pub font_variant_position:
                    &'a longhands::font_variant_position::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut font_variant_caps =
                        None::< &'a longhands::font_variant_caps::SpecifiedValue>;
                    let mut font_variant_alternates =
                        None::< &'a longhands::font_variant_alternates::SpecifiedValue>;
                    let mut font_variant_east_asian =
                        None::< &'a longhands::font_variant_east_asian::SpecifiedValue>;
                    let mut font_variant_emoji =
                        None::< &'a longhands::font_variant_emoji::SpecifiedValue>;
                    let mut font_variant_ligatures =
                        None::< &'a longhands::font_variant_ligatures::SpecifiedValue>;
                    let mut font_variant_numeric =
                        None::< &'a longhands::font_variant_numeric::SpecifiedValue>;
                    let mut font_variant_position =
                        None::< &'a longhands::font_variant_position::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::FontVariantCaps(ref value) => {
                                font_variant_caps = Some(value)
                            },
                            PropertyDeclaration::FontVariantAlternates(ref value) => {
                                font_variant_alternates = Some(value)
                            },
                            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                                font_variant_east_asian = Some(value)
                            },
                            PropertyDeclaration::FontVariantEmoji(ref value) => {
                                font_variant_emoji = Some(value)
                            },
                            PropertyDeclaration::FontVariantLigatures(ref value) => {
                                font_variant_ligatures = Some(value)
                            },
                            PropertyDeclaration::FontVariantNumeric(ref value) => {
                                font_variant_numeric = Some(value)
                            },
                            PropertyDeclaration::FontVariantPosition(ref value) => {
                                font_variant_position = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        font_variant_caps,
                        font_variant_alternates,
                        font_variant_east_asian,
                        font_variant_emoji,
                        font_variant_ligatures,
                        font_variant_numeric,
                        font_variant_position,
                ) {

                    (
                        Some(font_variant_caps),
                        Some(font_variant_alternates),
                        Some(font_variant_east_asian),
                        font_variant_emoji,
                        Some(font_variant_ligatures),
                        Some(font_variant_numeric),
                        Some(font_variant_position),
                    ) =>
                    Ok(LonghandsToSerialize {
                            font_variant_caps,
                            font_variant_alternates,
                            font_variant_east_asian,
                            font_variant_emoji,
                            font_variant_ligatures,
                            font_variant_numeric,
                            font_variant_position,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FontVariantCaps(
                        longhands.font_variant_caps
                    ));
                    declarations.push(PropertyDeclaration::FontVariantAlternates(
                        longhands.font_variant_alternates
                    ));
                    declarations.push(PropertyDeclaration::FontVariantEastAsian(
                        longhands.font_variant_east_asian
                    ));
                if NonCustomPropertyId::from(LonghandId::FontVariantEmoji)
                    .allowed_in_ignoring_rule_type(context) {
                    declarations.push(PropertyDeclaration::FontVariantEmoji(
                        longhands.font_variant_emoji
                    ));
                }
                    declarations.push(PropertyDeclaration::FontVariantLigatures(
                        longhands.font_variant_ligatures
                    ));
                    declarations.push(PropertyDeclaration::FontVariantNumeric(
                        longhands.font_variant_numeric
                    ));
                    declarations.push(PropertyDeclaration::FontVariantPosition(
                        longhands.font_variant_position
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    

    use crate::properties::longhands::font_variant_ligatures;
    use crate::properties::longhands::font_variant_caps;
    use crate::properties::longhands::font_variant_alternates;
    use crate::properties::longhands::font_variant_numeric;
    use crate::properties::longhands::font_variant_east_asian;
    use crate::properties::longhands::font_variant_position;
    use crate::properties::longhands::font_variant_emoji;
    #[allow(unused_imports)]
    use crate::values::specified::FontVariantLigatures;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut ligatures = None;
        let mut caps = None;
        let mut alternates = None;
        let mut numeric = None;
        let mut east_asian = None;
        let mut position = None;
        let mut emoji = None;

        if input.try_parse(|input| input.expect_ident_matching("normal")).is_ok() {
            // Leave the values to None, 'normal' is the initial value for all the sub properties.
        } else if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
            // The 'none' value sets 'font-variant-ligatures' to 'none' and resets all other sub properties
            // to their initial value.
            ligatures = Some(FontVariantLigatures::NONE);
        } else {
            let mut has_custom_value: bool = false;
            loop {
                if input.try_parse(|input| input.expect_ident_matching("normal")).is_ok() ||
                   input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
                    return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                }
                if ligatures.is_none() {
                    if let Ok(value) = input.try_parse(|i| font_variant_ligatures::parse(context, i)) {
                        has_custom_value = true;
                        ligatures = Some(value);
                        continue
                    }
                }
                if caps.is_none() {
                    if let Ok(value) = input.try_parse(|i| font_variant_caps::parse(context, i)) {
                        has_custom_value = true;
                        caps = Some(value);
                        continue
                    }
                }
                if alternates.is_none() {
                    if let Ok(value) = input.try_parse(|i| font_variant_alternates::parse(context, i)) {
                        has_custom_value = true;
                        alternates = Some(value);
                        continue
                    }
                }
                if numeric.is_none() {
                    if let Ok(value) = input.try_parse(|i| font_variant_numeric::parse(context, i)) {
                        has_custom_value = true;
                        numeric = Some(value);
                        continue
                    }
                }
                if east_asian.is_none() {
                    if let Ok(value) = input.try_parse(|i| font_variant_east_asian::parse(context, i)) {
                        has_custom_value = true;
                        east_asian = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try_parse(|i| font_variant_position::parse(context, i)) {
                        has_custom_value = true;
                        position = Some(value);
                        continue
                    }
                }
                if emoji.is_none() {
                    if let Ok(value) = input.try_parse(|i| font_variant_emoji::parse(context, i)) {
                        has_custom_value = true;
                        emoji = Some(value);
                        continue
                    }
                }

                break
            }

            if !has_custom_value {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }

        Ok(expanded! {
            font_variant_ligatures: unwrap_or_initial!(font_variant_ligatures, ligatures),
            font_variant_caps: unwrap_or_initial!(font_variant_caps, caps),
            font_variant_alternates: unwrap_or_initial!(font_variant_alternates, alternates),
            font_variant_numeric: unwrap_or_initial!(font_variant_numeric, numeric),
            font_variant_east_asian: unwrap_or_initial!(font_variant_east_asian, east_asian),
            font_variant_position: unwrap_or_initial!(font_variant_position, position),
            font_variant_emoji: unwrap_or_initial!(font_variant_emoji, emoji),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        #[allow(unused_assignments)]
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {

            let has_none_ligatures =
                self.font_variant_ligatures == &FontVariantLigatures::NONE;

            const TOTAL_SUBPROPS: usize = 7;
            let mut nb_normals = 0;
            {
                let value = self.font_variant_ligatures;
                if value == &font_variant_ligatures::get_initial_specified_value() {
                   nb_normals += 1;
                }
            }
            {
                let value = self.font_variant_caps;
                if value == &font_variant_caps::get_initial_specified_value() {
                   nb_normals += 1;
                }
            }
            {
                let value = self.font_variant_alternates;
                if value == &font_variant_alternates::get_initial_specified_value() {
                   nb_normals += 1;
                }
            }
            {
                let value = self.font_variant_numeric;
                if value == &font_variant_numeric::get_initial_specified_value() {
                   nb_normals += 1;
                }
            }
            {
                let value = self.font_variant_east_asian;
                if value == &font_variant_east_asian::get_initial_specified_value() {
                   nb_normals += 1;
                }
            }
            {
                let value = self.font_variant_position;
                if value == &font_variant_position::get_initial_specified_value() {
                   nb_normals += 1;
                }
            }
            if let Some(value) = self.font_variant_emoji {
                if value == &font_variant_emoji::get_initial_specified_value() {
                   nb_normals += 1;
                }
            }
            else {
                // The property was disabled, so we count it as 'normal' for the purpose
                // of deciding how the shorthand can be serialized.
                nb_normals += 1;
            }


            if nb_normals > 0 && nb_normals == TOTAL_SUBPROPS {
                dest.write_str("normal")?;
            } else if has_none_ligatures {
                if nb_normals == TOTAL_SUBPROPS - 1 {
                    // Serialize to 'none' if 'font-variant-ligatures' is set to 'none' and all other
                    // font feature properties are reset to their initial value.
                    dest.write_str("none")?;
                } else {
                    return Ok(())
                }
            } else {
                let mut has_any = false;
                {
                    let value = self.font_variant_ligatures;
                    if value != &font_variant_ligatures::get_initial_specified_value() {
                        if has_any {
                            dest.write_char(' ')?;
                        }
                        has_any = true;
                        value.to_css(dest)?;
                    }
                }
                {
                    let value = self.font_variant_caps;
                    if value != &font_variant_caps::get_initial_specified_value() {
                        if has_any {
                            dest.write_char(' ')?;
                        }
                        has_any = true;
                        value.to_css(dest)?;
                    }
                }
                {
                    let value = self.font_variant_alternates;
                    if value != &font_variant_alternates::get_initial_specified_value() {
                        if has_any {
                            dest.write_char(' ')?;
                        }
                        has_any = true;
                        value.to_css(dest)?;
                    }
                }
                {
                    let value = self.font_variant_numeric;
                    if value != &font_variant_numeric::get_initial_specified_value() {
                        if has_any {
                            dest.write_char(' ')?;
                        }
                        has_any = true;
                        value.to_css(dest)?;
                    }
                }
                {
                    let value = self.font_variant_east_asian;
                    if value != &font_variant_east_asian::get_initial_specified_value() {
                        if has_any {
                            dest.write_char(' ')?;
                        }
                        has_any = true;
                        value.to_css(dest)?;
                    }
                }
                {
                    let value = self.font_variant_position;
                    if value != &font_variant_position::get_initial_specified_value() {
                        if has_any {
                            dest.write_char(' ')?;
                        }
                        has_any = true;
                        value.to_css(dest)?;
                    }
                }
                if let Some(value) = self.font_variant_emoji {
                    if value != &font_variant_emoji::get_initial_specified_value() {
                        if has_any {
                            dest.write_char(' ')?;
                        }
                        has_any = true;
                        value.to_css(dest)?;
                    }
                }
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-fonts-3/#propdef-font-variant
    pub mod font_synthesis {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        pub struct Longhands {
                pub font_synthesis_weight:
                    longhands::font_synthesis_weight::SpecifiedValue
                    ,
                pub font_synthesis_style:
                    longhands::font_synthesis_style::SpecifiedValue
                    ,
                pub font_synthesis_small_caps:
                    longhands::font_synthesis_small_caps::SpecifiedValue
                    ,
                pub font_synthesis_position:
                    longhands::font_synthesis_position::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub font_synthesis_weight:
                    &'a longhands::font_synthesis_weight::SpecifiedValue,
                pub font_synthesis_style:
                    &'a longhands::font_synthesis_style::SpecifiedValue,
                pub font_synthesis_small_caps:
                    &'a longhands::font_synthesis_small_caps::SpecifiedValue,
                pub font_synthesis_position:
                    &'a longhands::font_synthesis_position::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut font_synthesis_weight =
                        None::< &'a longhands::font_synthesis_weight::SpecifiedValue>;
                    let mut font_synthesis_style =
                        None::< &'a longhands::font_synthesis_style::SpecifiedValue>;
                    let mut font_synthesis_small_caps =
                        None::< &'a longhands::font_synthesis_small_caps::SpecifiedValue>;
                    let mut font_synthesis_position =
                        None::< &'a longhands::font_synthesis_position::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::FontSynthesisWeight(ref value) => {
                                font_synthesis_weight = Some(value)
                            },
                            PropertyDeclaration::FontSynthesisStyle(ref value) => {
                                font_synthesis_style = Some(value)
                            },
                            PropertyDeclaration::FontSynthesisSmallCaps(ref value) => {
                                font_synthesis_small_caps = Some(value)
                            },
                            PropertyDeclaration::FontSynthesisPosition(ref value) => {
                                font_synthesis_position = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        font_synthesis_weight,
                        font_synthesis_style,
                        font_synthesis_small_caps,
                        font_synthesis_position,
                ) {

                    (
                        Some(font_synthesis_weight),
                        Some(font_synthesis_style),
                        Some(font_synthesis_small_caps),
                        Some(font_synthesis_position),
                    ) =>
                    Ok(LonghandsToSerialize {
                            font_synthesis_weight,
                            font_synthesis_style,
                            font_synthesis_small_caps,
                            font_synthesis_position,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FontSynthesisWeight(
                        longhands.font_synthesis_weight
                    ));
                    declarations.push(PropertyDeclaration::FontSynthesisStyle(
                        longhands.font_synthesis_style
                    ));
                    declarations.push(PropertyDeclaration::FontSynthesisSmallCaps(
                        longhands.font_synthesis_small_caps
                    ));
                    declarations.push(PropertyDeclaration::FontSynthesisPosition(
                        longhands.font_synthesis_position
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    

    use crate::values::specified::FontSynthesis;

    pub fn parse_value<'i, 't>(
        _context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut weight = FontSynthesis::None;
        let mut style = FontSynthesis::None;
        let mut small_caps = FontSynthesis::None;
        let mut position = FontSynthesis::None;

        if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
            // Leave all the individual values as None
        } else {
            let mut has_custom_value = false;
            while !input.is_exhausted() {
                try_match_ident_ignore_ascii_case! { input,
                    "weight" if weight == FontSynthesis::None => {
                        has_custom_value = true;
                        weight = FontSynthesis::Auto;
                        continue;
                    },
                    "style" if style == FontSynthesis::None => {
                        has_custom_value = true;
                        style = FontSynthesis::Auto;
                        continue;
                    },
                    "small-caps" if small_caps == FontSynthesis::None => {
                        has_custom_value = true;
                        small_caps = FontSynthesis::Auto;
                        continue;
                    },
                    "position" if position == FontSynthesis::None => {
                        has_custom_value = true;
                        position = FontSynthesis::Auto;
                        continue;
                    },
                }
            }
            if !has_custom_value {
                return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
            }
        }

        Ok(expanded! {
            font_synthesis_weight: weight,
            font_synthesis_style: style,
            font_synthesis_small_caps: small_caps,
            font_synthesis_position: position,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let mut has_any = false;

            if self.font_synthesis_weight == &FontSynthesis::Auto {
                if has_any {
                    dest.write_char(' ')?;
                }
                has_any = true;
                dest.write_str("weight")?;
            }
            if self.font_synthesis_style == &FontSynthesis::Auto {
                if has_any {
                    dest.write_char(' ')?;
                }
                has_any = true;
                dest.write_str("style")?;
            }
            if self.font_synthesis_small_caps == &FontSynthesis::Auto {
                if has_any {
                    dest.write_char(' ')?;
                }
                has_any = true;
                dest.write_str("small-caps")?;
            }
            if self.font_synthesis_position == &FontSynthesis::Auto {
                if has_any {
                    dest.write_char(' ')?;
                }
                has_any = true;
                dest.write_str("position")?;
            }

            if !has_any {
                dest.write_str("none")?;
            }

            Ok(())
        }
    }

    // The shorthand takes the sub-property names of the longhands, and not the
    // 'auto' keyword like they do, so we can't automatically derive this.
    impl SpecifiedValueInfo for Longhands {
        fn collect_completion_keywords(f: KeywordsCollectFn) {
            f(&[
                "none",
                "weight",
                "style",
                "small-caps",
                "position",
            ]);
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://svgwg.org/svg2-draft/painting.html#MarkerShorthand
    pub mod marker {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub marker_start:
                    longhands::marker_start::SpecifiedValue
                    ,
                pub marker_end:
                    longhands::marker_end::SpecifiedValue
                    ,
                pub marker_mid:
                    longhands::marker_mid::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub marker_start:
                    &'a longhands::marker_start::SpecifiedValue,
                pub marker_end:
                    &'a longhands::marker_end::SpecifiedValue,
                pub marker_mid:
                    &'a longhands::marker_mid::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut marker_start =
                        None::< &'a longhands::marker_start::SpecifiedValue>;
                    let mut marker_end =
                        None::< &'a longhands::marker_end::SpecifiedValue>;
                    let mut marker_mid =
                        None::< &'a longhands::marker_mid::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::MarkerStart(ref value) => {
                                marker_start = Some(value)
                            },
                            PropertyDeclaration::MarkerEnd(ref value) => {
                                marker_end = Some(value)
                            },
                            PropertyDeclaration::MarkerMid(ref value) => {
                                marker_mid = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        marker_start,
                        marker_end,
                        marker_mid,
                ) {

                    (
                        Some(marker_start),
                        Some(marker_end),
                        Some(marker_mid),
                    ) =>
                    Ok(LonghandsToSerialize {
                            marker_start,
                            marker_end,
                            marker_mid,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarkerStart(
                        longhands.marker_start
                    ));
                    declarations.push(PropertyDeclaration::MarkerEnd(
                        longhands.marker_end
                    ));
                    declarations.push(PropertyDeclaration::MarkerMid(
                        longhands.marker_mid
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::url::UrlOrNone;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::parser::Parse;
        let url = UrlOrNone::parse(context, input)?;

        Ok(expanded! {
            marker_start: url.clone(),
            marker_mid: url.clone(),
            marker_end: url,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.marker_start == self.marker_mid && self.marker_mid == self.marker_end {
                self.marker_start.to_css(dest)
            } else {
                Ok(())
            }
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-text-decor-3/#text-emphasis-property
    pub mod text_emphasis {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub text_emphasis_style:
                    longhands::text_emphasis_style::SpecifiedValue
                    ,
                pub text_emphasis_color:
                    longhands::text_emphasis_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub text_emphasis_style:
                    &'a longhands::text_emphasis_style::SpecifiedValue,
                pub text_emphasis_color:
                    &'a longhands::text_emphasis_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_emphasis_style =
                        None::< &'a longhands::text_emphasis_style::SpecifiedValue>;
                    let mut text_emphasis_color =
                        None::< &'a longhands::text_emphasis_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::TextEmphasisStyle(ref value) => {
                                text_emphasis_style = Some(value)
                            },
                            PropertyDeclaration::TextEmphasisColor(ref value) => {
                                text_emphasis_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_emphasis_style,
                        text_emphasis_color,
                ) {

                    (
                        Some(text_emphasis_style),
                        Some(text_emphasis_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_emphasis_style,
                            text_emphasis_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextEmphasisStyle(
                        longhands.text_emphasis_style
                    ));
                    declarations.push(PropertyDeclaration::TextEmphasisColor(
                        longhands.text_emphasis_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{text_emphasis_color, text_emphasis_style};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut color = None;
        let mut style = None;

        loop {
            if color.is_none() {
                if let Ok(value) = input.try_parse(|input| text_emphasis_color::parse(context, input)) {
                    color = Some(value);
                    continue
                }
            }
            if style.is_none() {
                if let Ok(value) = input.try_parse(|input| text_emphasis_style::parse(context, input)) {
                    style = Some(value);
                    continue
                }
            }
            break
        }
        if color.is_some() || style.is_some() {
            Ok(expanded! {
                text_emphasis_color: unwrap_or_initial!(text_emphasis_color, color),
                text_emphasis_style: unwrap_or_initial!(text_emphasis_style, style),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }




    /// https://www.w3.org/TR/css-text-4/#text-wrap
    pub mod text_wrap {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub text_wrap_mode:
                    longhands::text_wrap_mode::SpecifiedValue
                    ,
                pub text_wrap_style:
                    longhands::text_wrap_style::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub text_wrap_mode:
                    &'a longhands::text_wrap_mode::SpecifiedValue,
                pub text_wrap_style:
                    Option<
                    &'a longhands::text_wrap_style::SpecifiedValue,
                    >,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_wrap_mode =
                        None::< &'a longhands::text_wrap_mode::SpecifiedValue>;
                    let mut text_wrap_style =
                        None::< &'a longhands::text_wrap_style::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::TextWrapMode(ref value) => {
                                text_wrap_mode = Some(value)
                            },
                            PropertyDeclaration::TextWrapStyle(ref value) => {
                                text_wrap_style = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_wrap_mode,
                        text_wrap_style,
                ) {

                    (
                        Some(text_wrap_mode),
                        text_wrap_style,
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_wrap_mode,
                            text_wrap_style,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextWrapMode(
                        longhands.text_wrap_mode
                    ));
                if NonCustomPropertyId::from(LonghandId::TextWrapStyle)
                    .allowed_in_ignoring_rule_type(context) {
                    declarations.push(PropertyDeclaration::TextWrapStyle(
                        longhands.text_wrap_style
                    ));
                }
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{text_wrap_mode, text_wrap_style};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut mode = None;
        let mut style = None;

        loop {
            if mode.is_none() {
                if let Ok(value) = input.try_parse(|input| text_wrap_mode::parse(context, input)) {
                    mode = Some(value);
                    continue
                }
            }
            if style.is_none() {
                if let Ok(value) = input.try_parse(|input| text_wrap_style::parse(context, input)) {
                    style = Some(value);
                    continue
                }
            }
            break
        }
        if mode.is_some() || style.is_some() {
            Ok(expanded! {
                text_wrap_mode: unwrap_or_initial!(text_wrap_mode, mode),
                text_wrap_style: unwrap_or_initial!(text_wrap_style, style),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use text_wrap_mode::computed_value::T as Mode;
            use text_wrap_style::computed_value::T as Style;

            if matches!(self.text_wrap_style, None | Some(&Style::Auto)) {
                return self.text_wrap_mode.to_css(dest);
            }

            if *self.text_wrap_mode != Mode::Wrap {
                self.text_wrap_mode.to_css(dest)?;
                dest.write_char(' ')?;
            }

            self.text_wrap_style.to_css(dest)
        }
    }

    }




    /// https://www.w3.org/TR/css-text-4/#white-space-property
    pub mod white_space {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        pub struct Longhands {
                pub text_wrap_mode:
                    longhands::text_wrap_mode::SpecifiedValue
                    ,
                pub white_space_collapse:
                    longhands::white_space_collapse::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub text_wrap_mode:
                    &'a longhands::text_wrap_mode::SpecifiedValue,
                pub white_space_collapse:
                    &'a longhands::white_space_collapse::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_wrap_mode =
                        None::< &'a longhands::text_wrap_mode::SpecifiedValue>;
                    let mut white_space_collapse =
                        None::< &'a longhands::white_space_collapse::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::TextWrapMode(ref value) => {
                                text_wrap_mode = Some(value)
                            },
                            PropertyDeclaration::WhiteSpaceCollapse(ref value) => {
                                white_space_collapse = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_wrap_mode,
                        white_space_collapse,
                ) {

                    (
                        Some(text_wrap_mode),
                        Some(white_space_collapse),
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_wrap_mode,
                            white_space_collapse,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextWrapMode(
                        longhands.text_wrap_mode
                    ));
                    declarations.push(PropertyDeclaration::WhiteSpaceCollapse(
                        longhands.white_space_collapse
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{text_wrap_mode, white_space_collapse};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        use white_space_collapse::computed_value::T as Collapse;
        use text_wrap_mode::computed_value::T as Wrap;

        fn parse_special_shorthands<'i, 't>(input: &mut Parser<'i, 't>) -> Result<Longhands, ParseError<'i>> {
            let (mode, collapse) = try_match_ident_ignore_ascii_case! { input,
                "normal" => (Wrap::Wrap, Collapse::Collapse),
                "pre" => (Wrap::Nowrap, Collapse::Preserve),
                "pre-wrap" => (Wrap::Wrap, Collapse::Preserve),
                "pre-line" => (Wrap::Wrap, Collapse::PreserveBreaks),
                // TODO: deprecate/remove -moz-pre-space; the white-space-collapse: preserve-spaces value
                // should serve this purpose?
                "-moz-pre-space" => (Wrap::Wrap, Collapse::PreserveSpaces),
            };
            Ok(expanded! {
                text_wrap_mode: mode,
                white_space_collapse: collapse,
            })
        }

        if let Ok(result) = input.try_parse(parse_special_shorthands) {
            return Ok(result);
        }

        let mut wrap = None;
        let mut collapse = None;

        loop {
            if wrap.is_none() {
                if let Ok(value) = input.try_parse(|input| text_wrap_mode::parse(context, input)) {
                    wrap = Some(value);
                    continue
                }
            }
            if collapse.is_none() {
                if let Ok(value) = input.try_parse(|input| white_space_collapse::parse(context, input)) {
                    collapse = Some(value);
                    continue
                }
            }
            break
        }

        if wrap.is_some() || collapse.is_some() {
            Ok(expanded! {
                text_wrap_mode: unwrap_or_initial!(text_wrap_mode, wrap),
                white_space_collapse: unwrap_or_initial!(white_space_collapse, collapse),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use white_space_collapse::computed_value::T as Collapse;
            use text_wrap_mode::computed_value::T as Wrap;

            match *self.text_wrap_mode {
                Wrap::Wrap => {
                    match *self.white_space_collapse {
                        Collapse::Collapse => return dest.write_str("normal"),
                        Collapse::Preserve => return dest.write_str("pre-wrap"),
                        Collapse::PreserveBreaks => return dest.write_str("pre-line"),
                        Collapse::PreserveSpaces => return dest.write_str("-moz-pre-space"),
                        _ => (),
                    }
                },
                Wrap::Nowrap => {
                    if let Collapse::Preserve = *self.white_space_collapse {
                        return dest.write_str("pre");
                    }
                },
            }

            let mut has_value = false;
            if *self.white_space_collapse != Collapse::Collapse {
                self.white_space_collapse.to_css(dest)?;
                has_value = true;
            }

            if *self.text_wrap_mode != Wrap::Wrap {
                if has_value {
                    dest.write_char(' ')?;
                }
                self.text_wrap_mode.to_css(dest)?;
            }

            Ok(())
        }
    }

    impl SpecifiedValueInfo for Longhands {
        fn collect_completion_keywords(f: KeywordsCollectFn) {
            // Collect keywords from our longhands.
            text_wrap_mode::SpecifiedValue::collect_completion_keywords(f);
            white_space_collapse::SpecifiedValue::collect_completion_keywords(f);

            // Add the special values supported only by the shorthand
            // (see parse_special_shorthands() above).
            f(&["normal", "pre", "pre-wrap", "pre-line"])
        }
    }

    }


// CSS Compatibility
// https://compat.spec.whatwg.org/


    /// https://compat.spec.whatwg.org/#the-webkit-text-stroke
    pub mod _webkit_text_stroke {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub _webkit_text_stroke_width:
                    longhands::_webkit_text_stroke_width::SpecifiedValue
                    ,
                pub _webkit_text_stroke_color:
                    longhands::_webkit_text_stroke_color::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub _webkit_text_stroke_width:
                    &'a longhands::_webkit_text_stroke_width::SpecifiedValue,
                pub _webkit_text_stroke_color:
                    &'a longhands::_webkit_text_stroke_color::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut _webkit_text_stroke_width =
                        None::< &'a longhands::_webkit_text_stroke_width::SpecifiedValue>;
                    let mut _webkit_text_stroke_color =
                        None::< &'a longhands::_webkit_text_stroke_color::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                                _webkit_text_stroke_width = Some(value)
                            },
                            PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                                _webkit_text_stroke_color = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        _webkit_text_stroke_width,
                        _webkit_text_stroke_color,
                ) {

                    (
                        Some(_webkit_text_stroke_width),
                        Some(_webkit_text_stroke_color),
                    ) =>
                    Ok(LonghandsToSerialize {
                            _webkit_text_stroke_width,
                            _webkit_text_stroke_color,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::WebkitTextStrokeWidth(
                        longhands._webkit_text_stroke_width
                    ));
                    declarations.push(PropertyDeclaration::WebkitTextStrokeColor(
                        longhands._webkit_text_stroke_color
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{_webkit_text_stroke_color, _webkit_text_stroke_width};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut color = None;
        let mut width = None;
        loop {
            if color.is_none() {
                if let Ok(value) = input.try_parse(|input| _webkit_text_stroke_color::parse(context, input)) {
                    color = Some(value);
                    continue
                }
            }

            if width.is_none() {
                if let Ok(value) = input.try_parse(|input| _webkit_text_stroke_width::parse(context, input)) {
                    width = Some(value);
                    continue
                }
            }
            break
        }

        if color.is_some() || width.is_some() {
            Ok(expanded! {
                _webkit_text_stroke_color: unwrap_or_initial!(_webkit_text_stroke_color, color),
                _webkit_text_stroke_width: unwrap_or_initial!(_webkit_text_stroke_width, width),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-lists/#propdef-list-style
    pub mod list_style {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub list_style_position:
                    longhands::list_style_position::SpecifiedValue
                    ,
                pub list_style_image:
                    longhands::list_style_image::SpecifiedValue
                    ,
                pub list_style_type:
                    longhands::list_style_type::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub list_style_position:
                    &'a longhands::list_style_position::SpecifiedValue,
                pub list_style_image:
                    &'a longhands::list_style_image::SpecifiedValue,
                pub list_style_type:
                    &'a longhands::list_style_type::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut list_style_position =
                        None::< &'a longhands::list_style_position::SpecifiedValue>;
                    let mut list_style_image =
                        None::< &'a longhands::list_style_image::SpecifiedValue>;
                    let mut list_style_type =
                        None::< &'a longhands::list_style_type::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ListStylePosition(ref value) => {
                                list_style_position = Some(value)
                            },
                            PropertyDeclaration::ListStyleImage(ref value) => {
                                list_style_image = Some(value)
                            },
                            PropertyDeclaration::ListStyleType(ref value) => {
                                list_style_type = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        list_style_position,
                        list_style_image,
                        list_style_type,
                ) {

                    (
                        Some(list_style_position),
                        Some(list_style_image),
                        Some(list_style_type),
                    ) =>
                    Ok(LonghandsToSerialize {
                            list_style_position,
                            list_style_image,
                            list_style_type,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ListStylePosition(
                        longhands.list_style_position
                    ));
                    declarations.push(PropertyDeclaration::ListStyleImage(
                        longhands.list_style_image
                    ));
                    declarations.push(PropertyDeclaration::ListStyleType(
                        longhands.list_style_type
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{list_style_image, list_style_position, list_style_type};
    use crate::values::specified::Image;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        // `none` is ambiguous until we've finished parsing the shorthands, so we count the number
        // of times we see it.
        let mut nones = 0u8;
        let (mut image, mut position, mut list_style_type, mut any) = (None, None, None, false);
        loop {
            if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
                nones = nones + 1;
                if nones > 2 {
                    return Err(input.new_custom_error(SelectorParseErrorKind::UnexpectedIdent("none".into())))
                }
                any = true;
                continue
            }

            if image.is_none() {
                if let Ok(value) = input.try_parse(|input| list_style_image::parse(context, input)) {
                    image = Some(value);
                    any = true;
                    continue
                }
            }

            if position.is_none() {
                if let Ok(value) = input.try_parse(|input| list_style_position::parse(context, input)) {
                    position = Some(value);
                    any = true;
                    continue
                }
            }

            // list-style-type must be checked the last, because it accepts
            // arbitrary identifier for custom counter style, and thus may
            // affect values of list-style-position.
            if list_style_type.is_none() {
                if let Ok(value) = input.try_parse(|input| list_style_type::parse(context, input)) {
                    list_style_type = Some(value);
                    any = true;
                    continue
                }
            }
            break
        }

        let position = unwrap_or_initial!(list_style_position, position);

        // If there are two `none`s, then we can't have a type or image; if there is one `none`,
        // then we can't have both a type *and* an image; if there is no `none` then we're fine as
        // long as we parsed something.
        use self::list_style_type::SpecifiedValue as ListStyleType;
        match (any, nones, list_style_type, image) {
            (true, 2, None, None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: Image::None,
                    list_style_type: ListStyleType::none(),
                })
            }
            (true, 1, None, Some(image)) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: image,
                    list_style_type: ListStyleType::none(),
                })
            }
            (true, 1, Some(list_style_type), None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: Image::None,
                    list_style_type: list_style_type,
                })
            }
            (true, 1, None, None) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: Image::None,
                    list_style_type: ListStyleType::none(),
                })
            }
            (true, 0, list_style_type, image) => {
                Ok(expanded! {
                    list_style_position: position,
                    list_style_image: unwrap_or_initial!(list_style_image, image),
                    list_style_type: unwrap_or_initial!(list_style_type),
                })
            }
            _ => Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError)),
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use longhands::list_style_position::SpecifiedValue as ListStylePosition;
            use longhands::list_style_type::SpecifiedValue as ListStyleType;
            use longhands::list_style_image::SpecifiedValue as ListStyleImage;
            let mut have_one_non_initial_value = false;
            #[cfg(feature = "gecko")]
            let position_is_initial = self.list_style_position == &ListStylePosition::Outside;
            #[cfg(feature = "servo")]
            let position_is_initial = matches!(self.list_style_position, None | Some(&ListStylePosition::Outside));
            if !position_is_initial {
                self.list_style_position.to_css(dest)?;
                have_one_non_initial_value = true;
            }
            if self.list_style_image != &ListStyleImage::None {
                if have_one_non_initial_value {
                    dest.write_char(' ')?;
                }
                self.list_style_image.to_css(dest)?;
                have_one_non_initial_value = true;
            }
            #[cfg(feature = "gecko")]
            let type_is_initial = self.list_style_type == &ListStyleType::disc();
            #[cfg(feature = "servo")]
            let type_is_initial = self.list_style_type == &ListStyleType::Disc;
            if !type_is_initial {
                if have_one_non_initial_value {
                    dest.write_char(' ')?;
                }
                self.list_style_type.to_css(dest)?;
                have_one_non_initial_value = true;
            }
            if !have_one_non_initial_value {
                #[cfg(feature = "gecko")]
                self.list_style_position.to_css(dest)?;
                #[cfg(feature = "servo")]
                if let Some(position) = self.list_style_position {
                    position.to_css(dest)?;
                } else {
                    self.list_style_type.to_css(dest)?;
                }
            }
            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    
    

    /// https://drafts.csswg.org/css-box/#propdef-margin
    pub mod margin {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub margin_top:
                    longhands::margin_top::SpecifiedValue
                    ,
                pub margin_right:
                    longhands::margin_right::SpecifiedValue
                    ,
                pub margin_bottom:
                    longhands::margin_bottom::SpecifiedValue
                    ,
                pub margin_left:
                    longhands::margin_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub margin_top:
                    &'a longhands::margin_top::SpecifiedValue,
                pub margin_right:
                    &'a longhands::margin_right::SpecifiedValue,
                pub margin_bottom:
                    &'a longhands::margin_bottom::SpecifiedValue,
                pub margin_left:
                    &'a longhands::margin_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut margin_top =
                        None::< &'a longhands::margin_top::SpecifiedValue>;
                    let mut margin_right =
                        None::< &'a longhands::margin_right::SpecifiedValue>;
                    let mut margin_bottom =
                        None::< &'a longhands::margin_bottom::SpecifiedValue>;
                    let mut margin_left =
                        None::< &'a longhands::margin_left::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::MarginTop(ref value) => {
                                margin_top = Some(value)
                            },
                            PropertyDeclaration::MarginRight(ref value) => {
                                margin_right = Some(value)
                            },
                            PropertyDeclaration::MarginBottom(ref value) => {
                                margin_bottom = Some(value)
                            },
                            PropertyDeclaration::MarginLeft(ref value) => {
                                margin_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        margin_top,
                        margin_right,
                        margin_bottom,
                        margin_left,
                ) {

                    (
                        Some(margin_top),
                        Some(margin_right),
                        Some(margin_bottom),
                        Some(margin_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            margin_top,
                            margin_right,
                            margin_bottom,
                            margin_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarginTop(
                        longhands.margin_top
                    ));
                    declarations.push(PropertyDeclaration::MarginRight(
                        longhands.margin_right
                    ));
                    declarations.push(PropertyDeclaration::MarginBottom(
                        longhands.margin_bottom
                    ));
                    declarations.push(PropertyDeclaration::MarginLeft(
                        longhands.margin_left
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        #[allow(unused_imports)]
        use crate::parser::Parse;
        use crate::values::generics::rect::Rect;
        #[allow(unused_imports)]
        use crate::values::specified;

        fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |c, i| -> Result<
                crate::properties::longhands::margin_top::SpecifiedValue,
                ParseError<'i>
            > {
                specified::LengthPercentageOrAuto::parse_quirky(c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    margin_top: rect.0,
                    margin_right: rect.1,
                    margin_bottom: rect.2,
                    margin_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.margin_top,
                    &self.margin_right,
                    &self.margin_bottom,
                    &self.margin_left,
                );
                rect.to_css(dest)
            }
        }
    
    }






    /// https://drafts.csswg.org/css-logical/#propdef-margin-block
    pub mod margin_block {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub margin_block_start:
                    longhands::margin_block_start::SpecifiedValue
                    ,
                pub margin_block_end:
                    longhands::margin_block_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub margin_block_start:
                    &'a longhands::margin_block_start::SpecifiedValue,
                pub margin_block_end:
                    &'a longhands::margin_block_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut margin_block_start =
                        None::< &'a longhands::margin_block_start::SpecifiedValue>;
                    let mut margin_block_end =
                        None::< &'a longhands::margin_block_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::MarginBlockStart(ref value) => {
                                margin_block_start = Some(value)
                            },
                            PropertyDeclaration::MarginBlockEnd(ref value) => {
                                margin_block_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        margin_block_start,
                        margin_block_end,
                ) {

                    (
                        Some(margin_block_start),
                        Some(margin_block_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            margin_block_start,
                            margin_block_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarginBlockStart(
                        longhands.margin_block_start
                    ));
                    declarations.push(PropertyDeclaration::MarginBlockEnd(
                        longhands.margin_block_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::margin_block_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::LengthPercentageOrAuto::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            margin_block_start: first,
            margin_block_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.margin_block_start;
            let second = &self.margin_block_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// https://drafts.csswg.org/css-logical/#propdef-margin-inline
    pub mod margin_inline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub margin_inline_start:
                    longhands::margin_inline_start::SpecifiedValue
                    ,
                pub margin_inline_end:
                    longhands::margin_inline_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub margin_inline_start:
                    &'a longhands::margin_inline_start::SpecifiedValue,
                pub margin_inline_end:
                    &'a longhands::margin_inline_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut margin_inline_start =
                        None::< &'a longhands::margin_inline_start::SpecifiedValue>;
                    let mut margin_inline_end =
                        None::< &'a longhands::margin_inline_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::MarginInlineStart(ref value) => {
                                margin_inline_start = Some(value)
                            },
                            PropertyDeclaration::MarginInlineEnd(ref value) => {
                                margin_inline_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        margin_inline_start,
                        margin_inline_end,
                ) {

                    (
                        Some(margin_inline_start),
                        Some(margin_inline_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            margin_inline_start,
                            margin_inline_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MarginInlineStart(
                        longhands.margin_inline_start
                    ));
                    declarations.push(PropertyDeclaration::MarginInlineEnd(
                        longhands.margin_inline_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::margin_inline_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::LengthPercentageOrAuto::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            margin_inline_start: first,
            margin_inline_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.margin_inline_start;
            let second = &self.margin_inline_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    
    

    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin
    pub mod scroll_margin {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub scroll_margin_top:
                    longhands::scroll_margin_top::SpecifiedValue
                    ,
                pub scroll_margin_right:
                    longhands::scroll_margin_right::SpecifiedValue
                    ,
                pub scroll_margin_bottom:
                    longhands::scroll_margin_bottom::SpecifiedValue
                    ,
                pub scroll_margin_left:
                    longhands::scroll_margin_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_margin_top:
                    &'a longhands::scroll_margin_top::SpecifiedValue,
                pub scroll_margin_right:
                    &'a longhands::scroll_margin_right::SpecifiedValue,
                pub scroll_margin_bottom:
                    &'a longhands::scroll_margin_bottom::SpecifiedValue,
                pub scroll_margin_left:
                    &'a longhands::scroll_margin_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_margin_top =
                        None::< &'a longhands::scroll_margin_top::SpecifiedValue>;
                    let mut scroll_margin_right =
                        None::< &'a longhands::scroll_margin_right::SpecifiedValue>;
                    let mut scroll_margin_bottom =
                        None::< &'a longhands::scroll_margin_bottom::SpecifiedValue>;
                    let mut scroll_margin_left =
                        None::< &'a longhands::scroll_margin_left::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ScrollMarginTop(ref value) => {
                                scroll_margin_top = Some(value)
                            },
                            PropertyDeclaration::ScrollMarginRight(ref value) => {
                                scroll_margin_right = Some(value)
                            },
                            PropertyDeclaration::ScrollMarginBottom(ref value) => {
                                scroll_margin_bottom = Some(value)
                            },
                            PropertyDeclaration::ScrollMarginLeft(ref value) => {
                                scroll_margin_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_margin_top,
                        scroll_margin_right,
                        scroll_margin_bottom,
                        scroll_margin_left,
                ) {

                    (
                        Some(scroll_margin_top),
                        Some(scroll_margin_right),
                        Some(scroll_margin_bottom),
                        Some(scroll_margin_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_margin_top,
                            scroll_margin_right,
                            scroll_margin_bottom,
                            scroll_margin_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollMarginTop(
                        longhands.scroll_margin_top
                    ));
                    declarations.push(PropertyDeclaration::ScrollMarginRight(
                        longhands.scroll_margin_right
                    ));
                    declarations.push(PropertyDeclaration::ScrollMarginBottom(
                        longhands.scroll_margin_bottom
                    ));
                    declarations.push(PropertyDeclaration::ScrollMarginLeft(
                        longhands.scroll_margin_left
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        #[allow(unused_imports)]
        use crate::parser::Parse;
        use crate::values::generics::rect::Rect;
        #[allow(unused_imports)]
        use crate::values::specified;

        fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |c, i| -> Result<
                crate::properties::longhands::scroll_margin_top::SpecifiedValue,
                ParseError<'i>
            > {
                specified::Length::parse(c, i)
            })?;
            Ok(expanded! {
                    scroll_margin_top: rect.0,
                    scroll_margin_right: rect.1,
                    scroll_margin_bottom: rect.2,
                    scroll_margin_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.scroll_margin_top,
                    &self.scroll_margin_right,
                    &self.scroll_margin_bottom,
                    &self.scroll_margin_left,
                );
                rect.to_css(dest)
            }
        }
    
    }






    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-block
    pub mod scroll_margin_block {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub scroll_margin_block_start:
                    longhands::scroll_margin_block_start::SpecifiedValue
                    ,
                pub scroll_margin_block_end:
                    longhands::scroll_margin_block_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_margin_block_start:
                    &'a longhands::scroll_margin_block_start::SpecifiedValue,
                pub scroll_margin_block_end:
                    &'a longhands::scroll_margin_block_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_margin_block_start =
                        None::< &'a longhands::scroll_margin_block_start::SpecifiedValue>;
                    let mut scroll_margin_block_end =
                        None::< &'a longhands::scroll_margin_block_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ScrollMarginBlockStart(ref value) => {
                                scroll_margin_block_start = Some(value)
                            },
                            PropertyDeclaration::ScrollMarginBlockEnd(ref value) => {
                                scroll_margin_block_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_margin_block_start,
                        scroll_margin_block_end,
                ) {

                    (
                        Some(scroll_margin_block_start),
                        Some(scroll_margin_block_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_margin_block_start,
                            scroll_margin_block_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollMarginBlockStart(
                        longhands.scroll_margin_block_start
                    ));
                    declarations.push(PropertyDeclaration::ScrollMarginBlockEnd(
                        longhands.scroll_margin_block_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::scroll_margin_block_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::Length::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            scroll_margin_block_start: first,
            scroll_margin_block_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.scroll_margin_block_start;
            let second = &self.scroll_margin_block_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-margin-inline
    pub mod scroll_margin_inline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub scroll_margin_inline_start:
                    longhands::scroll_margin_inline_start::SpecifiedValue
                    ,
                pub scroll_margin_inline_end:
                    longhands::scroll_margin_inline_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_margin_inline_start:
                    &'a longhands::scroll_margin_inline_start::SpecifiedValue,
                pub scroll_margin_inline_end:
                    &'a longhands::scroll_margin_inline_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_margin_inline_start =
                        None::< &'a longhands::scroll_margin_inline_start::SpecifiedValue>;
                    let mut scroll_margin_inline_end =
                        None::< &'a longhands::scroll_margin_inline_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ScrollMarginInlineStart(ref value) => {
                                scroll_margin_inline_start = Some(value)
                            },
                            PropertyDeclaration::ScrollMarginInlineEnd(ref value) => {
                                scroll_margin_inline_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_margin_inline_start,
                        scroll_margin_inline_end,
                ) {

                    (
                        Some(scroll_margin_inline_start),
                        Some(scroll_margin_inline_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_margin_inline_start,
                            scroll_margin_inline_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollMarginInlineStart(
                        longhands.scroll_margin_inline_start
                    ));
                    declarations.push(PropertyDeclaration::ScrollMarginInlineEnd(
                        longhands.scroll_margin_inline_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::scroll_margin_inline_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::Length::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            scroll_margin_inline_start: first,
            scroll_margin_inline_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.scroll_margin_inline_start;
            let second = &self.scroll_margin_inline_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-ui/#propdef-outline
    pub mod outline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub outline_color:
                    longhands::outline_color::SpecifiedValue
                    ,
                pub outline_style:
                    longhands::outline_style::SpecifiedValue
                    ,
                pub outline_width:
                    longhands::outline_width::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub outline_color:
                    &'a longhands::outline_color::SpecifiedValue,
                pub outline_style:
                    &'a longhands::outline_style::SpecifiedValue,
                pub outline_width:
                    &'a longhands::outline_width::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut outline_color =
                        None::< &'a longhands::outline_color::SpecifiedValue>;
                    let mut outline_style =
                        None::< &'a longhands::outline_style::SpecifiedValue>;
                    let mut outline_width =
                        None::< &'a longhands::outline_width::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::OutlineColor(ref value) => {
                                outline_color = Some(value)
                            },
                            PropertyDeclaration::OutlineStyle(ref value) => {
                                outline_style = Some(value)
                            },
                            PropertyDeclaration::OutlineWidth(ref value) => {
                                outline_width = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        outline_color,
                        outline_style,
                        outline_width,
                ) {

                    (
                        Some(outline_color),
                        Some(outline_style),
                        Some(outline_width),
                    ) =>
                    Ok(LonghandsToSerialize {
                            outline_color,
                            outline_style,
                            outline_width,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::OutlineColor(
                        longhands.outline_color
                    ));
                    declarations.push(PropertyDeclaration::OutlineStyle(
                        longhands.outline_style
                    ));
                    declarations.push(PropertyDeclaration::OutlineWidth(
                        longhands.outline_width
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{outline_color, outline_width, outline_style};
    use crate::values::specified;
    use crate::parser::Parse;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let _unused = context;
        let mut color = None;
        let mut style = None;
        let mut width = None;
        let mut any = false;
        loop {
            if color.is_none() {
                if let Ok(value) = input.try_parse(|i| specified::Color::parse(context, i)) {
                    color = Some(value);
                    any = true;
                    continue
                }
            }
            if style.is_none() {
                if let Ok(value) = input.try_parse(|input| outline_style::parse(context, input)) {
                    style = Some(value);
                    any = true;
                    continue
                }
            }
            if width.is_none() {
                if let Ok(value) = input.try_parse(|input| outline_width::parse(context, input)) {
                    width = Some(value);
                    any = true;
                    continue
                }
            }
            break
        }
        if any {
            Ok(expanded! {
                outline_color: unwrap_or_initial!(outline_color, color),
                outline_style: unwrap_or_initial!(outline_style, style),
                outline_width: unwrap_or_initial!(outline_width, width),
            })
        } else {
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let mut wrote_value = false;

                if *self.outline_color != outline_color::get_initial_specified_value() {
                    if wrote_value {
                        dest.write_char(' ')?;
                    }
                    self.outline_color.to_css(dest)?;
                    wrote_value = true;
                }
                if *self.outline_style != outline_style::get_initial_specified_value() {
                    if wrote_value {
                        dest.write_char(' ')?;
                    }
                    self.outline_style.to_css(dest)?;
                    wrote_value = true;
                }
                if *self.outline_width != outline_width::get_initial_specified_value() {
                    if wrote_value {
                        dest.write_char(' ')?;
                    }
                    self.outline_width.to_css(dest)?;
                    wrote_value = true;
                }

            if !wrote_value {
                self.outline_style.to_css(dest)?;
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */




    
    

    /// https://drafts.csswg.org/css-box-3/#propdef-padding
    pub mod padding {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub padding_top:
                    longhands::padding_top::SpecifiedValue
                    ,
                pub padding_right:
                    longhands::padding_right::SpecifiedValue
                    ,
                pub padding_bottom:
                    longhands::padding_bottom::SpecifiedValue
                    ,
                pub padding_left:
                    longhands::padding_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub padding_top:
                    &'a longhands::padding_top::SpecifiedValue,
                pub padding_right:
                    &'a longhands::padding_right::SpecifiedValue,
                pub padding_bottom:
                    &'a longhands::padding_bottom::SpecifiedValue,
                pub padding_left:
                    &'a longhands::padding_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut padding_top =
                        None::< &'a longhands::padding_top::SpecifiedValue>;
                    let mut padding_right =
                        None::< &'a longhands::padding_right::SpecifiedValue>;
                    let mut padding_bottom =
                        None::< &'a longhands::padding_bottom::SpecifiedValue>;
                    let mut padding_left =
                        None::< &'a longhands::padding_left::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::PaddingTop(ref value) => {
                                padding_top = Some(value)
                            },
                            PropertyDeclaration::PaddingRight(ref value) => {
                                padding_right = Some(value)
                            },
                            PropertyDeclaration::PaddingBottom(ref value) => {
                                padding_bottom = Some(value)
                            },
                            PropertyDeclaration::PaddingLeft(ref value) => {
                                padding_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        padding_top,
                        padding_right,
                        padding_bottom,
                        padding_left,
                ) {

                    (
                        Some(padding_top),
                        Some(padding_right),
                        Some(padding_bottom),
                        Some(padding_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            padding_top,
                            padding_right,
                            padding_bottom,
                            padding_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::PaddingTop(
                        longhands.padding_top
                    ));
                    declarations.push(PropertyDeclaration::PaddingRight(
                        longhands.padding_right
                    ));
                    declarations.push(PropertyDeclaration::PaddingBottom(
                        longhands.padding_bottom
                    ));
                    declarations.push(PropertyDeclaration::PaddingLeft(
                        longhands.padding_left
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        #[allow(unused_imports)]
        use crate::parser::Parse;
        use crate::values::generics::rect::Rect;
        #[allow(unused_imports)]
        use crate::values::specified;

        fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |c, i| -> Result<
                crate::properties::longhands::padding_top::SpecifiedValue,
                ParseError<'i>
            > {
                specified::NonNegativeLengthPercentage::parse_quirky(c, i, specified::AllowQuirks::Yes)
            })?;
            Ok(expanded! {
                    padding_top: rect.0,
                    padding_right: rect.1,
                    padding_bottom: rect.2,
                    padding_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.padding_top,
                    &self.padding_right,
                    &self.padding_bottom,
                    &self.padding_left,
                );
                rect.to_css(dest)
            }
        }
    
    }






    /// https://drafts.csswg.org/css-logical/#propdef-padding-block
    pub mod padding_block {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub padding_block_start:
                    longhands::padding_block_start::SpecifiedValue
                    ,
                pub padding_block_end:
                    longhands::padding_block_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub padding_block_start:
                    &'a longhands::padding_block_start::SpecifiedValue,
                pub padding_block_end:
                    &'a longhands::padding_block_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut padding_block_start =
                        None::< &'a longhands::padding_block_start::SpecifiedValue>;
                    let mut padding_block_end =
                        None::< &'a longhands::padding_block_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::PaddingBlockStart(ref value) => {
                                padding_block_start = Some(value)
                            },
                            PropertyDeclaration::PaddingBlockEnd(ref value) => {
                                padding_block_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        padding_block_start,
                        padding_block_end,
                ) {

                    (
                        Some(padding_block_start),
                        Some(padding_block_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            padding_block_start,
                            padding_block_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::PaddingBlockStart(
                        longhands.padding_block_start
                    ));
                    declarations.push(PropertyDeclaration::PaddingBlockEnd(
                        longhands.padding_block_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::padding_block_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::NonNegativeLengthPercentage::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            padding_block_start: first,
            padding_block_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.padding_block_start;
            let second = &self.padding_block_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// https://drafts.csswg.org/css-logical/#propdef-padding-inline
    pub mod padding_inline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub padding_inline_start:
                    longhands::padding_inline_start::SpecifiedValue
                    ,
                pub padding_inline_end:
                    longhands::padding_inline_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub padding_inline_start:
                    &'a longhands::padding_inline_start::SpecifiedValue,
                pub padding_inline_end:
                    &'a longhands::padding_inline_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut padding_inline_start =
                        None::< &'a longhands::padding_inline_start::SpecifiedValue>;
                    let mut padding_inline_end =
                        None::< &'a longhands::padding_inline_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::PaddingInlineStart(ref value) => {
                                padding_inline_start = Some(value)
                            },
                            PropertyDeclaration::PaddingInlineEnd(ref value) => {
                                padding_inline_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        padding_inline_start,
                        padding_inline_end,
                ) {

                    (
                        Some(padding_inline_start),
                        Some(padding_inline_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            padding_inline_start,
                            padding_inline_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::PaddingInlineStart(
                        longhands.padding_inline_start
                    ));
                    declarations.push(PropertyDeclaration::PaddingInlineEnd(
                        longhands.padding_inline_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::padding_inline_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::NonNegativeLengthPercentage::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            padding_inline_start: first,
            padding_inline_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.padding_inline_start;
            let second = &self.padding_inline_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    
    

    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding
    pub mod scroll_padding {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub scroll_padding_top:
                    longhands::scroll_padding_top::SpecifiedValue
                    ,
                pub scroll_padding_right:
                    longhands::scroll_padding_right::SpecifiedValue
                    ,
                pub scroll_padding_bottom:
                    longhands::scroll_padding_bottom::SpecifiedValue
                    ,
                pub scroll_padding_left:
                    longhands::scroll_padding_left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_padding_top:
                    &'a longhands::scroll_padding_top::SpecifiedValue,
                pub scroll_padding_right:
                    &'a longhands::scroll_padding_right::SpecifiedValue,
                pub scroll_padding_bottom:
                    &'a longhands::scroll_padding_bottom::SpecifiedValue,
                pub scroll_padding_left:
                    &'a longhands::scroll_padding_left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_padding_top =
                        None::< &'a longhands::scroll_padding_top::SpecifiedValue>;
                    let mut scroll_padding_right =
                        None::< &'a longhands::scroll_padding_right::SpecifiedValue>;
                    let mut scroll_padding_bottom =
                        None::< &'a longhands::scroll_padding_bottom::SpecifiedValue>;
                    let mut scroll_padding_left =
                        None::< &'a longhands::scroll_padding_left::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ScrollPaddingTop(ref value) => {
                                scroll_padding_top = Some(value)
                            },
                            PropertyDeclaration::ScrollPaddingRight(ref value) => {
                                scroll_padding_right = Some(value)
                            },
                            PropertyDeclaration::ScrollPaddingBottom(ref value) => {
                                scroll_padding_bottom = Some(value)
                            },
                            PropertyDeclaration::ScrollPaddingLeft(ref value) => {
                                scroll_padding_left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_padding_top,
                        scroll_padding_right,
                        scroll_padding_bottom,
                        scroll_padding_left,
                ) {

                    (
                        Some(scroll_padding_top),
                        Some(scroll_padding_right),
                        Some(scroll_padding_bottom),
                        Some(scroll_padding_left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_padding_top,
                            scroll_padding_right,
                            scroll_padding_bottom,
                            scroll_padding_left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollPaddingTop(
                        longhands.scroll_padding_top
                    ));
                    declarations.push(PropertyDeclaration::ScrollPaddingRight(
                        longhands.scroll_padding_right
                    ));
                    declarations.push(PropertyDeclaration::ScrollPaddingBottom(
                        longhands.scroll_padding_bottom
                    ));
                    declarations.push(PropertyDeclaration::ScrollPaddingLeft(
                        longhands.scroll_padding_left
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        #[allow(unused_imports)]
        use crate::parser::Parse;
        use crate::values::generics::rect::Rect;
        #[allow(unused_imports)]
        use crate::values::specified;

        fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |c, i| -> Result<
                crate::properties::longhands::scroll_padding_top::SpecifiedValue,
                ParseError<'i>
            > {
                specified::NonNegativeLengthPercentageOrAuto::parse(c, i)
            })?;
            Ok(expanded! {
                    scroll_padding_top: rect.0,
                    scroll_padding_right: rect.1,
                    scroll_padding_bottom: rect.2,
                    scroll_padding_left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.scroll_padding_top,
                    &self.scroll_padding_right,
                    &self.scroll_padding_bottom,
                    &self.scroll_padding_left,
                );
                rect.to_css(dest)
            }
        }
    
    }






    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-block
    pub mod scroll_padding_block {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub scroll_padding_block_start:
                    longhands::scroll_padding_block_start::SpecifiedValue
                    ,
                pub scroll_padding_block_end:
                    longhands::scroll_padding_block_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_padding_block_start:
                    &'a longhands::scroll_padding_block_start::SpecifiedValue,
                pub scroll_padding_block_end:
                    &'a longhands::scroll_padding_block_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_padding_block_start =
                        None::< &'a longhands::scroll_padding_block_start::SpecifiedValue>;
                    let mut scroll_padding_block_end =
                        None::< &'a longhands::scroll_padding_block_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ScrollPaddingBlockStart(ref value) => {
                                scroll_padding_block_start = Some(value)
                            },
                            PropertyDeclaration::ScrollPaddingBlockEnd(ref value) => {
                                scroll_padding_block_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_padding_block_start,
                        scroll_padding_block_end,
                ) {

                    (
                        Some(scroll_padding_block_start),
                        Some(scroll_padding_block_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_padding_block_start,
                            scroll_padding_block_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollPaddingBlockStart(
                        longhands.scroll_padding_block_start
                    ));
                    declarations.push(PropertyDeclaration::ScrollPaddingBlockEnd(
                        longhands.scroll_padding_block_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::scroll_padding_block_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::NonNegativeLengthPercentageOrAuto::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            scroll_padding_block_start: first,
            scroll_padding_block_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.scroll_padding_block_start;
            let second = &self.scroll_padding_block_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// https://drafts.csswg.org/css-scroll-snap-1/#propdef-scroll-padding-inline
    pub mod scroll_padding_inline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub scroll_padding_inline_start:
                    longhands::scroll_padding_inline_start::SpecifiedValue
                    ,
                pub scroll_padding_inline_end:
                    longhands::scroll_padding_inline_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_padding_inline_start:
                    &'a longhands::scroll_padding_inline_start::SpecifiedValue,
                pub scroll_padding_inline_end:
                    &'a longhands::scroll_padding_inline_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_padding_inline_start =
                        None::< &'a longhands::scroll_padding_inline_start::SpecifiedValue>;
                    let mut scroll_padding_inline_end =
                        None::< &'a longhands::scroll_padding_inline_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ScrollPaddingInlineStart(ref value) => {
                                scroll_padding_inline_start = Some(value)
                            },
                            PropertyDeclaration::ScrollPaddingInlineEnd(ref value) => {
                                scroll_padding_inline_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_padding_inline_start,
                        scroll_padding_inline_end,
                ) {

                    (
                        Some(scroll_padding_inline_start),
                        Some(scroll_padding_inline_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_padding_inline_start,
                            scroll_padding_inline_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollPaddingInlineStart(
                        longhands.scroll_padding_inline_start
                    ));
                    declarations.push(PropertyDeclaration::ScrollPaddingInlineEnd(
                        longhands.scroll_padding_inline_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::scroll_padding_inline_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::NonNegativeLengthPercentageOrAuto::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            scroll_padding_inline_start: first,
            scroll_padding_inline_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.scroll_padding_inline_start;
            let second = &self.scroll_padding_inline_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-flexbox/#flex-flow-property
    pub mod flex_flow {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub flex_direction:
                    longhands::flex_direction::SpecifiedValue
                    ,
                pub flex_wrap:
                    longhands::flex_wrap::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub flex_direction:
                    &'a longhands::flex_direction::SpecifiedValue,
                pub flex_wrap:
                    &'a longhands::flex_wrap::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut flex_direction =
                        None::< &'a longhands::flex_direction::SpecifiedValue>;
                    let mut flex_wrap =
                        None::< &'a longhands::flex_wrap::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::FlexDirection(ref value) => {
                                flex_direction = Some(value)
                            },
                            PropertyDeclaration::FlexWrap(ref value) => {
                                flex_wrap = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        flex_direction,
                        flex_wrap,
                ) {

                    (
                        Some(flex_direction),
                        Some(flex_wrap),
                    ) =>
                    Ok(LonghandsToSerialize {
                            flex_direction,
                            flex_wrap,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FlexDirection(
                        longhands.flex_direction
                    ));
                    declarations.push(PropertyDeclaration::FlexWrap(
                        longhands.flex_wrap
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{flex_direction, flex_wrap};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut direction = None;
        let mut wrap = None;
        loop {
            if direction.is_none() {
                if let Ok(value) = input.try_parse(|input| flex_direction::parse(context, input)) {
                    direction = Some(value);
                    continue
                }
            }
            if wrap.is_none() {
                if let Ok(value) = input.try_parse(|input| flex_wrap::parse(context, input)) {
                    wrap = Some(value);
                    continue
                }
            }
            break
        }

        if direction.is_none() && wrap.is_none() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
        Ok(expanded! {
            flex_direction: unwrap_or_initial!(flex_direction, direction),
            flex_wrap: unwrap_or_initial!(flex_wrap, wrap),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if *self.flex_direction == flex_direction::get_initial_specified_value() &&
               *self.flex_wrap != flex_wrap::get_initial_specified_value() {
                return self.flex_wrap.to_css(dest)
            }
            self.flex_direction.to_css(dest)?;
            if *self.flex_wrap != flex_wrap::get_initial_specified_value() {
                dest.write_char(' ')?;
                self.flex_wrap.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-flexbox/#flex-property
    pub mod flex {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub flex_grow:
                    longhands::flex_grow::SpecifiedValue
                    ,
                pub flex_shrink:
                    longhands::flex_shrink::SpecifiedValue
                    ,
                pub flex_basis:
                        Box<
                    longhands::flex_basis::SpecifiedValue
                        >
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        #[derive(ToCss)]
        pub struct LonghandsToSerialize<'a> {
                pub flex_grow:
                    &'a longhands::flex_grow::SpecifiedValue,
                pub flex_shrink:
                    &'a longhands::flex_shrink::SpecifiedValue,
                pub flex_basis:
                    &'a longhands::flex_basis::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut flex_grow =
                        None::< &'a longhands::flex_grow::SpecifiedValue>;
                    let mut flex_shrink =
                        None::< &'a longhands::flex_shrink::SpecifiedValue>;
                    let mut flex_basis =
                        None::< &'a longhands::flex_basis::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::FlexGrow(ref value) => {
                                flex_grow = Some(value)
                            },
                            PropertyDeclaration::FlexShrink(ref value) => {
                                flex_shrink = Some(value)
                            },
                            PropertyDeclaration::FlexBasis(ref value) => {
                                flex_basis = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        flex_grow,
                        flex_shrink,
                        flex_basis,
                ) {

                    (
                        Some(flex_grow),
                        Some(flex_shrink),
                        Some(flex_basis),
                    ) =>
                    Ok(LonghandsToSerialize {
                            flex_grow,
                            flex_shrink,
                            flex_basis,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::FlexGrow(
                        longhands.flex_grow
                    ));
                    declarations.push(PropertyDeclaration::FlexShrink(
                        longhands.flex_shrink
                    ));
                    declarations.push(PropertyDeclaration::FlexBasis(
                        longhands.flex_basis
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::parser::Parse;
    use crate::values::specified::NonNegativeNumber;
    use crate::properties::longhands::flex_basis::SpecifiedValue as FlexBasis;

    fn parse_flexibility<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<(NonNegativeNumber, Option<NonNegativeNumber>),ParseError<'i>> {
        let grow = NonNegativeNumber::parse(context, input)?;
        let shrink = input.try_parse(|i| NonNegativeNumber::parse(context, i)).ok();
        Ok((grow, shrink))
    }

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut grow = None;
        let mut shrink = None;
        let mut basis = None;

        if input.try_parse(|input| input.expect_ident_matching("none")).is_ok() {
            return Ok(expanded! {
                flex_grow: NonNegativeNumber::new(0.0),
                flex_shrink: NonNegativeNumber::new(0.0),
                flex_basis: FlexBasis::auto(),
            })
        }
        loop {
            if grow.is_none() {
                if let Ok((flex_grow, flex_shrink)) = input.try_parse(|i| parse_flexibility(context, i)) {
                    grow = Some(flex_grow);
                    shrink = flex_shrink;
                    continue
                }
            }
            if basis.is_none() {
                if let Ok(value) = input.try_parse(|input| FlexBasis::parse(context, input)) {
                    basis = Some(value);
                    continue
                }
            }
            break
        }

        if grow.is_none() && basis.is_none() {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }
        Ok(expanded! {
            flex_grow: grow.unwrap_or(NonNegativeNumber::new(1.0)),
            flex_shrink: shrink.unwrap_or(NonNegativeNumber::new(1.0)),
            // Per spec, this should be SpecifiedValue::zero(), but all
            // browsers currently agree on using `0%`. This is a spec
            // change which hasn't been adopted by browsers:
            // https://github.com/w3c/csswg-drafts/commit/2c446befdf0f686217905bdd7c92409f6bd3921b
            flex_basis: basis.unwrap_or(FlexBasis::zero_percent()),
        })
    }

    }




    /// https://drafts.csswg.org/css-align-3/#gap-shorthand
    pub mod gap {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub row_gap:
                    longhands::row_gap::SpecifiedValue
                    ,
                pub column_gap:
                    longhands::column_gap::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub row_gap:
                    &'a longhands::row_gap::SpecifiedValue,
                pub column_gap:
                    &'a longhands::column_gap::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut row_gap =
                        None::< &'a longhands::row_gap::SpecifiedValue>;
                    let mut column_gap =
                        None::< &'a longhands::column_gap::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::RowGap(ref value) => {
                                row_gap = Some(value)
                            },
                            PropertyDeclaration::ColumnGap(ref value) => {
                                column_gap = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        row_gap,
                        column_gap,
                ) {

                    (
                        Some(row_gap),
                        Some(column_gap),
                    ) =>
                    Ok(LonghandsToSerialize {
                            row_gap,
                            column_gap,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::RowGap(
                        longhands.row_gap
                    ));
                    declarations.push(PropertyDeclaration::ColumnGap(
                        longhands.column_gap
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
  use crate::properties::longhands::{row_gap, column_gap};

  pub fn parse_value<'i, 't>(context: &ParserContext, input: &mut Parser<'i, 't>)
                             -> Result<Longhands, ParseError<'i>> {
      let r_gap = row_gap::parse(context, input)?;
      let c_gap = input.try_parse(|input| column_gap::parse(context, input)).unwrap_or(r_gap.clone());

      Ok(expanded! {
        row_gap: r_gap,
        column_gap: c_gap,
      })
  }

  impl<'a> ToCss for LonghandsToSerialize<'a>  {
      fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
          if self.row_gap == self.column_gap {
            self.row_gap.to_css(dest)
          } else {
            self.row_gap.to_css(dest)?;
            dest.write_char(' ')?;
            self.column_gap.to_css(dest)
          }
      }
  }


    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-row
    pub mod grid_row {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub grid_row_start:
                    longhands::grid_row_start::SpecifiedValue
                    ,
                pub grid_row_end:
                    longhands::grid_row_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_start:
                    &'a longhands::grid_row_start::SpecifiedValue,
                pub grid_row_end:
                    &'a longhands::grid_row_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_start =
                        None::< &'a longhands::grid_row_start::SpecifiedValue>;
                    let mut grid_row_end =
                        None::< &'a longhands::grid_row_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::GridRowStart(ref value) => {
                                grid_row_start = Some(value)
                            },
                            PropertyDeclaration::GridRowEnd(ref value) => {
                                grid_row_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_start,
                        grid_row_end,
                ) {

                    (
                        Some(grid_row_start),
                        Some(grid_row_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_start,
                            grid_row_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowStart(
                        longhands.grid_row_start
                    ));
                    declarations.push(PropertyDeclaration::GridRowEnd(
                        longhands.grid_row_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::GridLine;
    use crate::parser::Parse;
    use crate::Zero;

    // NOTE: Since both the shorthands have the same code, we should (re-)use code from one to implement
    // the other. This might not be a big deal for now, but we should consider looking into this in the future
    // to limit the amount of code generated.
    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let start = input.try_parse(|i| GridLine::parse(context, i))?;
        let end = if input.try_parse(|i| i.expect_delim('/')).is_ok() {
            GridLine::parse(context, input)?
        } else {
            let mut line = GridLine::auto();
            if start.line_num.is_zero() && !start.is_span {
                line.ident = start.ident.clone(); // ident from start value should be taken
            }

            line
        };

        Ok(expanded! {
            grid_row_start: start,
            grid_row_end: end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        // Return the shortest possible serialization of the `grid-row-[start/end]` values.
        // This function exploits the opportunities to omit the end value per this spec text:
        //
        // https://drafts.csswg.org/css-grid/#propdef-grid-column
        // "When the second value is omitted, if the first value is a <custom-ident>,
        // the grid-row-end/grid-column-end longhand is also set to that <custom-ident>;
        // otherwise, it is set to auto."
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_row_start.to_css(dest)?;
            if self.grid_row_start.can_omit(self.grid_row_end) {
                return Ok(());  // the end value is redundant
            }
            dest.write_str(" / ")?;
            self.grid_row_end.to_css(dest)
        }
    }

    }



    /// https://drafts.csswg.org/css-grid/#propdef-grid-column
    pub mod grid_column {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub grid_column_start:
                    longhands::grid_column_start::SpecifiedValue
                    ,
                pub grid_column_end:
                    longhands::grid_column_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_column_start:
                    &'a longhands::grid_column_start::SpecifiedValue,
                pub grid_column_end:
                    &'a longhands::grid_column_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_column_start =
                        None::< &'a longhands::grid_column_start::SpecifiedValue>;
                    let mut grid_column_end =
                        None::< &'a longhands::grid_column_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::GridColumnStart(ref value) => {
                                grid_column_start = Some(value)
                            },
                            PropertyDeclaration::GridColumnEnd(ref value) => {
                                grid_column_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_column_start,
                        grid_column_end,
                ) {

                    (
                        Some(grid_column_start),
                        Some(grid_column_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_column_start,
                            grid_column_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridColumnStart(
                        longhands.grid_column_start
                    ));
                    declarations.push(PropertyDeclaration::GridColumnEnd(
                        longhands.grid_column_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::GridLine;
    use crate::parser::Parse;
    use crate::Zero;

    // NOTE: Since both the shorthands have the same code, we should (re-)use code from one to implement
    // the other. This might not be a big deal for now, but we should consider looking into this in the future
    // to limit the amount of code generated.
    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let start = input.try_parse(|i| GridLine::parse(context, i))?;
        let end = if input.try_parse(|i| i.expect_delim('/')).is_ok() {
            GridLine::parse(context, input)?
        } else {
            let mut line = GridLine::auto();
            if start.line_num.is_zero() && !start.is_span {
                line.ident = start.ident.clone(); // ident from start value should be taken
            }

            line
        };

        Ok(expanded! {
            grid_column_start: start,
            grid_column_end: end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        // Return the shortest possible serialization of the `grid-column-[start/end]` values.
        // This function exploits the opportunities to omit the end value per this spec text:
        //
        // https://drafts.csswg.org/css-grid/#propdef-grid-column
        // "When the second value is omitted, if the first value is a <custom-ident>,
        // the grid-row-end/grid-column-end longhand is also set to that <custom-ident>;
        // otherwise, it is set to auto."
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_column_start.to_css(dest)?;
            if self.grid_column_start.can_omit(self.grid_column_end) {
                return Ok(());  // the end value is redundant
            }
            dest.write_str(" / ")?;
            self.grid_column_end.to_css(dest)
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-area
    pub mod grid_area {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub grid_row_start:
                    longhands::grid_row_start::SpecifiedValue
                    ,
                pub grid_row_end:
                    longhands::grid_row_end::SpecifiedValue
                    ,
                pub grid_column_start:
                    longhands::grid_column_start::SpecifiedValue
                    ,
                pub grid_column_end:
                    longhands::grid_column_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_row_start:
                    &'a longhands::grid_row_start::SpecifiedValue,
                pub grid_row_end:
                    &'a longhands::grid_row_end::SpecifiedValue,
                pub grid_column_start:
                    &'a longhands::grid_column_start::SpecifiedValue,
                pub grid_column_end:
                    &'a longhands::grid_column_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_row_start =
                        None::< &'a longhands::grid_row_start::SpecifiedValue>;
                    let mut grid_row_end =
                        None::< &'a longhands::grid_row_end::SpecifiedValue>;
                    let mut grid_column_start =
                        None::< &'a longhands::grid_column_start::SpecifiedValue>;
                    let mut grid_column_end =
                        None::< &'a longhands::grid_column_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::GridRowStart(ref value) => {
                                grid_row_start = Some(value)
                            },
                            PropertyDeclaration::GridRowEnd(ref value) => {
                                grid_row_end = Some(value)
                            },
                            PropertyDeclaration::GridColumnStart(ref value) => {
                                grid_column_start = Some(value)
                            },
                            PropertyDeclaration::GridColumnEnd(ref value) => {
                                grid_column_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_row_start,
                        grid_row_end,
                        grid_column_start,
                        grid_column_end,
                ) {

                    (
                        Some(grid_row_start),
                        Some(grid_row_end),
                        Some(grid_column_start),
                        Some(grid_column_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_row_start,
                            grid_row_end,
                            grid_column_start,
                            grid_column_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridRowStart(
                        longhands.grid_row_start
                    ));
                    declarations.push(PropertyDeclaration::GridRowEnd(
                        longhands.grid_row_end
                    ));
                    declarations.push(PropertyDeclaration::GridColumnStart(
                        longhands.grid_column_start
                    ));
                    declarations.push(PropertyDeclaration::GridColumnEnd(
                        longhands.grid_column_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::GridLine;
    use crate::parser::Parse;
    use crate::Zero;

    // The code is the same as `grid-{row,column}` except that this can have four values at most.
    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        fn line_with_ident_from(other: &GridLine) -> GridLine {
            let mut this = GridLine::auto();
            if other.line_num.is_zero() && !other.is_span {
                this.ident = other.ident.clone();
            }

            this
        }

        let row_start = input.try_parse(|i| GridLine::parse(context, i))?;
        let (column_start, row_end, column_end) = if input.try_parse(|i| i.expect_delim('/')).is_ok() {
            let column_start = GridLine::parse(context, input)?;
            let (row_end, column_end) = if input.try_parse(|i| i.expect_delim('/')).is_ok() {
                let row_end = GridLine::parse(context, input)?;
                let column_end = if input.try_parse(|i| i.expect_delim('/')).is_ok() {
                    GridLine::parse(context, input)?
                } else {        // grid-column-end has not been given
                    line_with_ident_from(&column_start)
                };

                (row_end, column_end)
            } else {        // grid-row-start and grid-column-start has been given
                let row_end = line_with_ident_from(&row_start);
                let column_end = line_with_ident_from(&column_start);
                (row_end, column_end)
            };

            (column_start, row_end, column_end)
        } else {        // only grid-row-start is given
            let line = line_with_ident_from(&row_start);
            (line.clone(), line.clone(), line)
        };

        Ok(expanded! {
            grid_row_start: row_start,
            grid_row_end: row_end,
            grid_column_start: column_start,
            grid_column_end: column_end,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        // Return the shortest possible serialization of the `grid-[column/row]-[start/end]` values.
        // This function exploits the opportunities to omit trailing values per this spec text:
        //
        // https://drafts.csswg.org/css-grid/#propdef-grid-area
        // "If four <grid-line> values are specified, grid-row-start is set to the first value,
        // grid-column-start is set to the second value, grid-row-end is set to the third value,
        // and grid-column-end is set to the fourth value.
        //
        // When grid-column-end is omitted, if grid-column-start is a <custom-ident>,
        // grid-column-end is set to that <custom-ident>; otherwise, it is set to auto.
        //
        // When grid-row-end is omitted, if grid-row-start is a <custom-ident>, grid-row-end is
        // set to that <custom-ident>; otherwise, it is set to auto.
        //
        // When grid-column-start is omitted, if grid-row-start is a <custom-ident>, all four
        // longhands are set to that value. Otherwise, it is set to auto."
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.grid_row_start.to_css(dest)?;
            let mut trailing_values = 3;
            if self.grid_column_start.can_omit(self.grid_column_end) {
                trailing_values -= 1;
                if self.grid_row_start.can_omit(self.grid_row_end) {
                    trailing_values -= 1;
                    if self.grid_row_start.can_omit(self.grid_column_start) {
                        trailing_values -= 1;
                    }
                }
            }
            let values = [&self.grid_column_start, &self.grid_row_end, &self.grid_column_end];
            for value in values.iter().take(trailing_values) {
                dest.write_str(" / ")?;
                value.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid-template
    pub mod grid_template {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub grid_template_rows:
                    longhands::grid_template_rows::SpecifiedValue
                    ,
                pub grid_template_columns:
                    longhands::grid_template_columns::SpecifiedValue
                    ,
                pub grid_template_areas:
                    longhands::grid_template_areas::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_template_rows:
                    &'a longhands::grid_template_rows::SpecifiedValue,
                pub grid_template_columns:
                    &'a longhands::grid_template_columns::SpecifiedValue,
                pub grid_template_areas:
                    &'a longhands::grid_template_areas::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_template_rows =
                        None::< &'a longhands::grid_template_rows::SpecifiedValue>;
                    let mut grid_template_columns =
                        None::< &'a longhands::grid_template_columns::SpecifiedValue>;
                    let mut grid_template_areas =
                        None::< &'a longhands::grid_template_areas::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::GridTemplateRows(ref value) => {
                                grid_template_rows = Some(value)
                            },
                            PropertyDeclaration::GridTemplateColumns(ref value) => {
                                grid_template_columns = Some(value)
                            },
                            PropertyDeclaration::GridTemplateAreas(ref value) => {
                                grid_template_areas = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_template_rows,
                        grid_template_columns,
                        grid_template_areas,
                ) {

                    (
                        Some(grid_template_rows),
                        Some(grid_template_columns),
                        Some(grid_template_areas),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_template_rows,
                            grid_template_columns,
                            grid_template_areas,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridTemplateRows(
                        longhands.grid_template_rows
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateColumns(
                        longhands.grid_template_columns
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateAreas(
                        longhands.grid_template_areas
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::parser::Parse;
    use servo_arc::Arc;
    use crate::values::generics::grid::{TrackSize, TrackList};
    use crate::values::generics::grid::{TrackListValue, concat_serialize_idents};
    use crate::values::specified::{GridTemplateComponent, GenericGridTemplateComponent};
    use crate::values::specified::grid::parse_line_names;
    use crate::values::specified::position::{GridTemplateAreas, TemplateAreasParser, TemplateAreasArc};

    /// Parsing for `<grid-template>` shorthand (also used by `grid` shorthand).
    pub fn parse_grid_template<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<(GridTemplateComponent, GridTemplateComponent, GridTemplateAreas), ParseError<'i>> {
        // Other shorthand sub properties also parse the `none` keyword and this shorthand
        // should know after this keyword there is nothing to parse. Otherwise it gets
        // confused and rejects the sub properties that contains `none`.
        
            if let Ok(x) = input.try_parse(|i| {
                if i.try_parse(|i| i.expect_ident_matching("none")).is_ok() {
                    if !i.is_exhausted() {
                        return Err(());
                    }
                    return Ok((GenericGridTemplateComponent::None, GenericGridTemplateComponent::None, GridTemplateAreas::None));
                }
                Err(())
            }) {
                return Ok(x);
            }

        let first_line_names = input.try_parse(parse_line_names).unwrap_or_default();
        let mut areas_parser = TemplateAreasParser::default();
        if areas_parser.try_parse_string(input).is_ok() {
            let mut values = vec![];
            let mut line_names = vec![];
            line_names.push(first_line_names);
            loop {
                let size = input.try_parse(|i| TrackSize::parse(context, i)).unwrap_or_default();
                values.push(TrackListValue::TrackSize(size));
                let mut names = input.try_parse(parse_line_names).unwrap_or_default();
                let more_names = input.try_parse(parse_line_names);

                match areas_parser.try_parse_string(input) {
                    Ok(()) => {
                        if let Ok(v) = more_names {
                            // We got `[names] [more_names] "string"` - merge the two name lists.
                            let mut names_vec = names.into_vec();
                            names_vec.extend(v.into_iter());
                            names = names_vec.into();
                        }
                        line_names.push(names);
                    },
                    Err(e) => {
                        if more_names.is_ok() {
                            // We've parsed `"string" [names] [more_names]` but then failed to parse another `"string"`.
                            // The grammar doesn't allow two trailing `<line-names>` so this is an invalid value.
                            return Err(e);
                        }
                        // only the named area determines whether we should bail out
                        line_names.push(names);
                        break
                    },
                };
            }

            if line_names.len() == values.len() {
                // should be one longer than track sizes
                line_names.push(Default::default());
            }

            let template_areas = areas_parser.finish()
                .map_err(|()| input.new_custom_error(StyleParseErrorKind::UnspecifiedError))?;
            let template_rows = TrackList {
                values: values.into(),
                line_names: line_names.into(),
                auto_repeat_index: std::usize::MAX,
            };

            let template_cols = if input.try_parse(|i| i.expect_delim('/')).is_ok() {
                let value = GridTemplateComponent::parse_without_none(context, input)?;
                if let GenericGridTemplateComponent::TrackList(ref list) = value {
                    if !list.is_explicit() {
                        return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
                    }
                }

                value
            } else {
                GridTemplateComponent::default()
            };

            Ok((
                GenericGridTemplateComponent::TrackList(Box::new(template_rows)),
                template_cols,
                GridTemplateAreas::Areas(TemplateAreasArc(Arc::new(template_areas)))
            ))
        } else {
            let mut template_rows = GridTemplateComponent::parse(context, input)?;
            if let GenericGridTemplateComponent::TrackList(ref mut list) = template_rows {
                // Fist line names are parsed already and it shouldn't be parsed again.
                // If line names are not empty, that means given property value is not acceptable
                if list.line_names[0].is_empty() {
                    list.line_names[0] = first_line_names;      // won't panic
                } else {
                    return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
                }
            }

            input.expect_delim('/')?;
            Ok((template_rows, GridTemplateComponent::parse(context, input)?, GridTemplateAreas::None))
        }
    }

    #[inline]
    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let (rows, columns, areas) = parse_grid_template(context, input)?;
        Ok(expanded! {
            grid_template_rows: rows,
            grid_template_columns: columns,
            grid_template_areas: areas,
        })
    }

    /// Serialization for `<grid-template>` shorthand (also used by `grid` shorthand).
    pub fn serialize_grid_template<W>(
        template_rows: &GridTemplateComponent,
        template_columns: &GridTemplateComponent,
        template_areas: &GridTemplateAreas,
        dest: &mut CssWriter<W>,
    ) -> fmt::Result
    where
        W: Write {
        match *template_areas {
            GridTemplateAreas::None => {
                if template_rows.is_initial() && template_columns.is_initial() {
                    return GridTemplateComponent::default().to_css(dest);
                }
                template_rows.to_css(dest)?;
                dest.write_str(" / ")?;
                template_columns.to_css(dest)
            },
            GridTemplateAreas::Areas(ref areas) => {
                // The length of template-area and template-rows values should be equal.
                if areas.0.strings.len() != template_rows.track_list_len() {
                    return Ok(());
                }

                let track_list = match *template_rows {
                    GenericGridTemplateComponent::TrackList(ref list) => {
                        // We should fail if there is a `repeat` function.
                        // `grid` and `grid-template` shorthands doesn't accept
                        // that. Only longhand accepts.
                        if !list.is_explicit() {
                            return Ok(());
                        }
                        list
                    },
                    // Others template components shouldn't exist with normal shorthand values.
                    // But if we need to serialize a group of longhand sub-properties for
                    // the shorthand, we should be able to return empty string instead of crashing.
                    _ => return Ok(()),
                };

                // We need to check some values that longhand accepts but shorthands don't.
                match *template_columns {
                    // We should fail if there is a `repeat` function. `grid` and
                    // `grid-template` shorthands doesn't accept that. Only longhand accepts that.
                    GenericGridTemplateComponent::TrackList(ref list) => {
                        if !list.is_explicit() {
                            return Ok(());
                        }
                    },
                    // Also the shorthands don't accept subgrids unlike longhand.
                    // We should fail without an error here.
                    GenericGridTemplateComponent::Subgrid(_) => {
                        return Ok(());
                    },
                    _ => {},
                }

                let mut names_iter = track_list.line_names.iter();
                for (((i, string), names), value) in areas.0.strings.iter().enumerate()
                                                                  .zip(&mut names_iter)
                                                                  .zip(track_list.values.iter()) {
                    if i > 0 {
                        dest.write_char(' ')?;
                    }

                    if !names.is_empty() {
                        concat_serialize_idents("[", "] ", names, " ", dest)?;
                    }

                    string.to_css(dest)?;

                    // If the track size is the initial value then it's redundant here.
                    if !value.is_initial() {
                        dest.write_char(' ')?;
                        value.to_css(dest)?;
                    }
                }

                if let Some(names) = names_iter.next() {
                    concat_serialize_idents(" [", "]", names, " ", dest)?;
                }

                if let GenericGridTemplateComponent::TrackList(ref list) = *template_columns {
                    dest.write_str(" / ")?;
                    list.to_css(dest)?;
                }

                Ok(())
            },
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        #[inline]
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            serialize_grid_template(
                self.grid_template_rows,
                self.grid_template_columns,
                self.grid_template_areas,
                dest
            )
        }
    }

    }




    /// https://drafts.csswg.org/css-grid/#propdef-grid
    pub mod grid {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub grid_template_rows:
                    longhands::grid_template_rows::SpecifiedValue
                    ,
                pub grid_template_columns:
                    longhands::grid_template_columns::SpecifiedValue
                    ,
                pub grid_template_areas:
                    longhands::grid_template_areas::SpecifiedValue
                    ,
                pub grid_auto_rows:
                    longhands::grid_auto_rows::SpecifiedValue
                    ,
                pub grid_auto_columns:
                    longhands::grid_auto_columns::SpecifiedValue
                    ,
                pub grid_auto_flow:
                    longhands::grid_auto_flow::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub grid_template_rows:
                    &'a longhands::grid_template_rows::SpecifiedValue,
                pub grid_template_columns:
                    &'a longhands::grid_template_columns::SpecifiedValue,
                pub grid_template_areas:
                    &'a longhands::grid_template_areas::SpecifiedValue,
                pub grid_auto_rows:
                    &'a longhands::grid_auto_rows::SpecifiedValue,
                pub grid_auto_columns:
                    &'a longhands::grid_auto_columns::SpecifiedValue,
                pub grid_auto_flow:
                    &'a longhands::grid_auto_flow::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut grid_template_rows =
                        None::< &'a longhands::grid_template_rows::SpecifiedValue>;
                    let mut grid_template_columns =
                        None::< &'a longhands::grid_template_columns::SpecifiedValue>;
                    let mut grid_template_areas =
                        None::< &'a longhands::grid_template_areas::SpecifiedValue>;
                    let mut grid_auto_rows =
                        None::< &'a longhands::grid_auto_rows::SpecifiedValue>;
                    let mut grid_auto_columns =
                        None::< &'a longhands::grid_auto_columns::SpecifiedValue>;
                    let mut grid_auto_flow =
                        None::< &'a longhands::grid_auto_flow::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::GridTemplateRows(ref value) => {
                                grid_template_rows = Some(value)
                            },
                            PropertyDeclaration::GridTemplateColumns(ref value) => {
                                grid_template_columns = Some(value)
                            },
                            PropertyDeclaration::GridTemplateAreas(ref value) => {
                                grid_template_areas = Some(value)
                            },
                            PropertyDeclaration::GridAutoRows(ref value) => {
                                grid_auto_rows = Some(value)
                            },
                            PropertyDeclaration::GridAutoColumns(ref value) => {
                                grid_auto_columns = Some(value)
                            },
                            PropertyDeclaration::GridAutoFlow(ref value) => {
                                grid_auto_flow = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        grid_template_rows,
                        grid_template_columns,
                        grid_template_areas,
                        grid_auto_rows,
                        grid_auto_columns,
                        grid_auto_flow,
                ) {

                    (
                        Some(grid_template_rows),
                        Some(grid_template_columns),
                        Some(grid_template_areas),
                        Some(grid_auto_rows),
                        Some(grid_auto_columns),
                        Some(grid_auto_flow),
                    ) =>
                    Ok(LonghandsToSerialize {
                            grid_template_rows,
                            grid_template_columns,
                            grid_template_areas,
                            grid_auto_rows,
                            grid_auto_columns,
                            grid_auto_flow,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::GridTemplateRows(
                        longhands.grid_template_rows
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateColumns(
                        longhands.grid_template_columns
                    ));
                    declarations.push(PropertyDeclaration::GridTemplateAreas(
                        longhands.grid_template_areas
                    ));
                    declarations.push(PropertyDeclaration::GridAutoRows(
                        longhands.grid_auto_rows
                    ));
                    declarations.push(PropertyDeclaration::GridAutoColumns(
                        longhands.grid_auto_columns
                    ));
                    declarations.push(PropertyDeclaration::GridAutoFlow(
                        longhands.grid_auto_flow
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::parser::Parse;
    use crate::properties::longhands::{grid_auto_columns, grid_auto_rows, grid_auto_flow};
    use crate::values::generics::grid::GridTemplateComponent;
    use crate::values::specified::{GenericGridTemplateComponent, ImplicitGridTracks};
    use crate::values::specified::position::{GridAutoFlow, GridTemplateAreas};

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let mut temp_rows = GridTemplateComponent::default();
        let mut temp_cols = GridTemplateComponent::default();
        let mut temp_areas = GridTemplateAreas::None;
        let mut auto_rows = ImplicitGridTracks::default();
        let mut auto_cols = ImplicitGridTracks::default();
        let mut flow = grid_auto_flow::get_initial_value();

        fn parse_auto_flow<'i, 't>(
            input: &mut Parser<'i, 't>,
            is_row: bool,
        ) -> Result<GridAutoFlow, ParseError<'i>> {
            let mut track = None;
            let mut dense = GridAutoFlow::empty();

            for _ in 0..2 {
                if input.try_parse(|i| i.expect_ident_matching("auto-flow")).is_ok() {
                    track = if is_row {
                        Some(GridAutoFlow::ROW)
                    } else {
                        Some(GridAutoFlow::COLUMN)
                    };
                } else if input.try_parse(|i| i.expect_ident_matching("dense")).is_ok() {
                    dense = GridAutoFlow::DENSE
                } else {
                    break
                }
            }

            if track.is_some() {
                Ok(track.unwrap() | dense)
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }

        if let Ok((rows, cols, areas)) = input.try_parse(|i| super::grid_template::parse_grid_template(context, i)) {
            temp_rows = rows;
            temp_cols = cols;
            temp_areas = areas;
        } else if let Ok(rows) = input.try_parse(|i| GridTemplateComponent::parse(context, i)) {
            temp_rows = rows;
            input.expect_delim('/')?;
            flow = parse_auto_flow(input, false)?;
            auto_cols = input.try_parse(|i| grid_auto_columns::parse(context, i)).unwrap_or_default();
        } else {
            flow = parse_auto_flow(input, true)?;
            auto_rows = input.try_parse(|i| grid_auto_rows::parse(context, i)).unwrap_or_default();
            input.expect_delim('/')?;
            temp_cols = GridTemplateComponent::parse(context, input)?;
        }

        Ok(expanded! {
            grid_template_rows: temp_rows,
            grid_template_columns: temp_cols,
            grid_template_areas: temp_areas,
            grid_auto_rows: auto_rows,
            grid_auto_columns: auto_cols,
            grid_auto_flow: flow,
        })
    }

    impl<'a> LonghandsToSerialize<'a> {
        /// Returns true if other sub properties except template-{rows,columns} are initial.
        fn is_grid_template(&self) -> bool {
            self.grid_auto_rows.is_initial() &&
            self.grid_auto_columns.is_initial() &&
            *self.grid_auto_flow == grid_auto_flow::get_initial_value()
        }
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            if self.is_grid_template() {
                return super::grid_template::serialize_grid_template(
                    self.grid_template_rows,
                    self.grid_template_columns,
                    self.grid_template_areas,
                    dest
                );
            }

            if *self.grid_template_areas != GridTemplateAreas::None {
                // No other syntax can set the template areas, so fail to
                // serialize.
                return Ok(());
            }

            if self.grid_auto_flow.contains(GridAutoFlow::COLUMN) {
                // It should fail to serialize if other branch of the if condition's values are set.
                if !self.grid_auto_rows.is_initial() ||
                    !self.grid_template_columns.is_initial() {
                    return Ok(());
                }

                // It should fail to serialize if template-rows value is not Explicit.
                if let GenericGridTemplateComponent::TrackList(ref list) = *self.grid_template_rows {
                    if !list.is_explicit() {
                        return Ok(());
                    }
                }

                self.grid_template_rows.to_css(dest)?;
                dest.write_str(" / auto-flow")?;
                if self.grid_auto_flow.contains(GridAutoFlow::DENSE) {
                    dest.write_str(" dense")?;
                }

                if !self.grid_auto_columns.is_initial() {
                    dest.write_char(' ')?;
                    self.grid_auto_columns.to_css(dest)?;
                }

                return Ok(());
            }

            // It should fail to serialize if other branch of the if condition's values are set.
            if !self.grid_auto_columns.is_initial() ||
                !self.grid_template_rows.is_initial() {
                return Ok(());
            }

            // It should fail to serialize if template-column value is not Explicit.
            if let GenericGridTemplateComponent::TrackList(ref list) = *self.grid_template_columns {
                if !list.is_explicit() {
                    return Ok(());
                }
            }

            dest.write_str("auto-flow")?;
            if self.grid_auto_flow.contains(GridAutoFlow::DENSE) {
                dest.write_str(" dense")?;
            }

            if !self.grid_auto_rows.is_initial() {
                dest.write_char(' ')?;
                self.grid_auto_rows.to_css(dest)?;
            }

            dest.write_str(" / ")?;
            self.grid_template_columns.to_css(dest)?;
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#propdef-place-content
    pub mod place_content {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub align_content:
                    longhands::align_content::SpecifiedValue
                    ,
                pub justify_content:
                    longhands::justify_content::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_content:
                    &'a longhands::align_content::SpecifiedValue,
                pub justify_content:
                    &'a longhands::justify_content::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_content =
                        None::< &'a longhands::align_content::SpecifiedValue>;
                    let mut justify_content =
                        None::< &'a longhands::justify_content::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::AlignContent(ref value) => {
                                align_content = Some(value)
                            },
                            PropertyDeclaration::JustifyContent(ref value) => {
                                justify_content = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_content,
                        justify_content,
                ) {

                    (
                        Some(align_content),
                        Some(justify_content),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_content,
                            justify_content,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignContent(
                        longhands.align_content
                    ));
                    declarations.push(PropertyDeclaration::JustifyContent(
                        longhands.justify_content
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::align::{AlignContent, JustifyContent, ContentDistribution, AxisDirection};

    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let align_content =
            ContentDistribution::parse(input, AxisDirection::Block)?;

        let justify_content = input.try_parse(|input| {
            ContentDistribution::parse(input, AxisDirection::Inline)
        });

        let justify_content = match justify_content {
            Ok(v) => v,
            Err(..) => {
                // https://drafts.csswg.org/css-align-3/#place-content:
                //
                //   The second value is assigned to justify-content; if
                //   omitted, it is copied from the first value, unless that
                //   value is a <baseline-position> in which case it is
                //   defaulted to start.
                //
                if !align_content.is_baseline_position() {
                    align_content
                } else {
                    ContentDistribution::start()
                }
            }
        };

        Ok(expanded! {
            align_content: AlignContent(align_content),
            justify_content: JustifyContent(justify_content),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.align_content.to_css(dest)?;
            if self.align_content.0 != self.justify_content.0 {
                dest.write_char(' ')?;
                self.justify_content.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#place-self-property
    pub mod place_self {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub align_self:
                    longhands::align_self::SpecifiedValue
                    ,
                pub justify_self:
                    longhands::justify_self::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_self:
                    &'a longhands::align_self::SpecifiedValue,
                pub justify_self:
                    &'a longhands::justify_self::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_self =
                        None::< &'a longhands::align_self::SpecifiedValue>;
                    let mut justify_self =
                        None::< &'a longhands::justify_self::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::AlignSelf(ref value) => {
                                align_self = Some(value)
                            },
                            PropertyDeclaration::JustifySelf(ref value) => {
                                justify_self = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_self,
                        justify_self,
                ) {

                    (
                        Some(align_self),
                        Some(justify_self),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_self,
                            justify_self,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignSelf(
                        longhands.align_self
                    ));
                    declarations.push(PropertyDeclaration::JustifySelf(
                        longhands.justify_self
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::align::{AlignSelf, JustifySelf, SelfAlignment, AxisDirection};

    pub fn parse_value<'i, 't>(
        _: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let align = SelfAlignment::parse(input, AxisDirection::Block)?;
        let justify = input.try_parse(|input| SelfAlignment::parse(input, AxisDirection::Inline));

        let justify = match justify {
            Ok(v) => v,
            Err(..) => {
                debug_assert!(align.is_valid_on_both_axes());
                align
            }
        };

        Ok(expanded! {
            align_self: AlignSelf(align),
            justify_self: JustifySelf(justify),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.align_self.to_css(dest)?;
            if self.align_self.0 != self.justify_self.0 {
                dest.write_char(' ')?;
                self.justify_self.to_css(dest)?;
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-align/#place-items-property
    pub mod place_items {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub align_items:
                    longhands::align_items::SpecifiedValue
                    ,
                pub justify_items:
                    longhands::justify_items::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub align_items:
                    &'a longhands::align_items::SpecifiedValue,
                pub justify_items:
                    &'a longhands::justify_items::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut align_items =
                        None::< &'a longhands::align_items::SpecifiedValue>;
                    let mut justify_items =
                        None::< &'a longhands::justify_items::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::AlignItems(ref value) => {
                                align_items = Some(value)
                            },
                            PropertyDeclaration::JustifyItems(ref value) => {
                                justify_items = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        align_items,
                        justify_items,
                ) {

                    (
                        Some(align_items),
                        Some(justify_items),
                    ) =>
                    Ok(LonghandsToSerialize {
                            align_items,
                            justify_items,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AlignItems(
                        longhands.align_items
                    ));
                    declarations.push(PropertyDeclaration::JustifyItems(
                        longhands.justify_items
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::values::specified::align::{AlignItems, JustifyItems};
    use crate::parser::Parse;

    impl From<AlignItems> for JustifyItems {
        fn from(align: AlignItems) -> JustifyItems {
            JustifyItems(align.0)
        }
    }

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let align = AlignItems::parse(context, input)?;
        let justify =
            input.try_parse(|input| JustifyItems::parse(context, input))
                 .unwrap_or_else(|_| JustifyItems::from(align));

        Ok(expanded! {
            align_items: align,
            justify_items: justify,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a> {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            self.align_items.to_css(dest)?;
            if self.align_items.0 != self.justify_items.0 {
                dest.write_char(' ')?;
                self.justify_items.to_css(dest)?;
            }

            Ok(())
        }
    }

    }


// See https://github.com/w3c/csswg-drafts/issues/3525 for the quirks stuff.

    
    

    /// https://drafts.csswg.org/css-logical/#propdef-inset
    pub mod inset {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub top:
                    longhands::top::SpecifiedValue
                    ,
                pub right:
                    longhands::right::SpecifiedValue
                    ,
                pub bottom:
                    longhands::bottom::SpecifiedValue
                    ,
                pub left:
                    longhands::left::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub top:
                    &'a longhands::top::SpecifiedValue,
                pub right:
                    &'a longhands::right::SpecifiedValue,
                pub bottom:
                    &'a longhands::bottom::SpecifiedValue,
                pub left:
                    &'a longhands::left::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut top =
                        None::< &'a longhands::top::SpecifiedValue>;
                    let mut right =
                        None::< &'a longhands::right::SpecifiedValue>;
                    let mut bottom =
                        None::< &'a longhands::bottom::SpecifiedValue>;
                    let mut left =
                        None::< &'a longhands::left::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::Top(ref value) => {
                                top = Some(value)
                            },
                            PropertyDeclaration::Right(ref value) => {
                                right = Some(value)
                            },
                            PropertyDeclaration::Bottom(ref value) => {
                                bottom = Some(value)
                            },
                            PropertyDeclaration::Left(ref value) => {
                                left = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        top,
                        right,
                        bottom,
                        left,
                ) {

                    (
                        Some(top),
                        Some(right),
                        Some(bottom),
                        Some(left),
                    ) =>
                    Ok(LonghandsToSerialize {
                            top,
                            right,
                            bottom,
                            left,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::Top(
                        longhands.top
                    ));
                    declarations.push(PropertyDeclaration::Right(
                        longhands.right
                    ));
                    declarations.push(PropertyDeclaration::Bottom(
                        longhands.bottom
                    ));
                    declarations.push(PropertyDeclaration::Left(
                        longhands.left
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        #[allow(unused_imports)]
        use crate::parser::Parse;
        use crate::values::generics::rect::Rect;
        #[allow(unused_imports)]
        use crate::values::specified;

        fn parse_value<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<Longhands, ParseError<'i>> {
            let rect = Rect::parse_with(context, input, |c, i| -> Result<
                crate::properties::longhands::top::SpecifiedValue,
                ParseError<'i>
            > {
                specified::LengthPercentageOrAuto::parse(c, i)
            })?;
            Ok(expanded! {
                    top: rect.0,
                    right: rect.1,
                    bottom: rect.2,
                    left: rect.3,
            })
        }

        impl<'a> ToCss for LonghandsToSerialize<'a> {
            fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result
            where
                W: Write,
            {
                let rect = Rect::new(
                    &self.top,
                    &self.right,
                    &self.bottom,
                    &self.left,
                );
                rect.to_css(dest)
            }
        }
    
    }






    /// https://drafts.csswg.org/css-logical/#propdef-inset-block
    pub mod inset_block {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub inset_block_start:
                    longhands::inset_block_start::SpecifiedValue
                    ,
                pub inset_block_end:
                    longhands::inset_block_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub inset_block_start:
                    &'a longhands::inset_block_start::SpecifiedValue,
                pub inset_block_end:
                    &'a longhands::inset_block_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut inset_block_start =
                        None::< &'a longhands::inset_block_start::SpecifiedValue>;
                    let mut inset_block_end =
                        None::< &'a longhands::inset_block_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::InsetBlockStart(ref value) => {
                                inset_block_start = Some(value)
                            },
                            PropertyDeclaration::InsetBlockEnd(ref value) => {
                                inset_block_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        inset_block_start,
                        inset_block_end,
                ) {

                    (
                        Some(inset_block_start),
                        Some(inset_block_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            inset_block_start,
                            inset_block_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::InsetBlockStart(
                        longhands.inset_block_start
                    ));
                    declarations.push(PropertyDeclaration::InsetBlockEnd(
                        longhands.inset_block_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::inset_block_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::LengthPercentageOrAuto::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            inset_block_start: first,
            inset_block_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.inset_block_start;
            let second = &self.inset_block_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// https://drafts.csswg.org/css-logical/#propdef-inset-inline
    pub mod inset_inline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub inset_inline_start:
                    longhands::inset_inline_start::SpecifiedValue
                    ,
                pub inset_inline_end:
                    longhands::inset_inline_end::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub inset_inline_start:
                    &'a longhands::inset_inline_start::SpecifiedValue,
                pub inset_inline_end:
                    &'a longhands::inset_inline_end::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut inset_inline_start =
                        None::< &'a longhands::inset_inline_start::SpecifiedValue>;
                    let mut inset_inline_end =
                        None::< &'a longhands::inset_inline_end::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::InsetInlineStart(ref value) => {
                                inset_inline_start = Some(value)
                            },
                            PropertyDeclaration::InsetInlineEnd(ref value) => {
                                inset_inline_end = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        inset_inline_start,
                        inset_inline_end,
                ) {

                    (
                        Some(inset_inline_start),
                        Some(inset_inline_end),
                    ) =>
                    Ok(LonghandsToSerialize {
                            inset_inline_start,
                            inset_inline_end,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::InsetInlineStart(
                        longhands.inset_inline_start
                    ));
                    declarations.push(PropertyDeclaration::InsetInlineEnd(
                        longhands.inset_inline_end
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::inset_inline_start::SpecifiedValue,
            ParseError<'i>
        > {
            specified::LengthPercentageOrAuto::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            inset_inline_start: first,
            inset_inline_end: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.inset_inline_start;
            let second = &self.inset_inline_end;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }






    /// https://drafts.csswg.org/css-sizing-4/#intrinsic-size-override
    pub mod contain_intrinsic_size {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub contain_intrinsic_width:
                    longhands::contain_intrinsic_width::SpecifiedValue
                    ,
                pub contain_intrinsic_height:
                    longhands::contain_intrinsic_height::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub contain_intrinsic_width:
                    &'a longhands::contain_intrinsic_width::SpecifiedValue,
                pub contain_intrinsic_height:
                    &'a longhands::contain_intrinsic_height::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut contain_intrinsic_width =
                        None::< &'a longhands::contain_intrinsic_width::SpecifiedValue>;
                    let mut contain_intrinsic_height =
                        None::< &'a longhands::contain_intrinsic_height::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ContainIntrinsicWidth(ref value) => {
                                contain_intrinsic_width = Some(value)
                            },
                            PropertyDeclaration::ContainIntrinsicHeight(ref value) => {
                                contain_intrinsic_height = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        contain_intrinsic_width,
                        contain_intrinsic_height,
                ) {

                    (
                        Some(contain_intrinsic_width),
                        Some(contain_intrinsic_height),
                    ) =>
                    Ok(LonghandsToSerialize {
                            contain_intrinsic_width,
                            contain_intrinsic_height,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ContainIntrinsicWidth(
                        longhands.contain_intrinsic_width
                    ));
                    declarations.push(PropertyDeclaration::ContainIntrinsicHeight(
                        longhands.contain_intrinsic_height
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    #[allow(unused_imports)]
    use crate::parser::Parse;
    #[allow(unused_imports)]
    use crate::values::specified;

    fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        let parse_one = |c: &ParserContext, input: &mut Parser<'i, 't>| -> Result<
            crate::properties::longhands::contain_intrinsic_width::SpecifiedValue,
            ParseError<'i>
        > {
            crate::parser::Parse::parse(c, input)
        };

        let first = parse_one(context, input)?;
        let second =
            input.try_parse(|input| parse_one(context, input)).unwrap_or_else(|_| first.clone());
        Ok(expanded! {
            contain_intrinsic_width: first,
            contain_intrinsic_height: second,
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let first = &self.contain_intrinsic_width;
            let second = &self.contain_intrinsic_height;

            first.to_css(dest)?;
            if first != second {
                dest.write_char(' ')?;
                second.to_css(dest)?;
            }
            Ok(())
        }
    }

    }



    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://drafts.fxtf.org/css-masking/#propdef-mask
    pub mod mask {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub mask_mode:
                    longhands::mask_mode::SpecifiedValue
                    ,
                pub mask_repeat:
                    longhands::mask_repeat::SpecifiedValue
                    ,
                pub mask_clip:
                    longhands::mask_clip::SpecifiedValue
                    ,
                pub mask_origin:
                    longhands::mask_origin::SpecifiedValue
                    ,
                pub mask_composite:
                    longhands::mask_composite::SpecifiedValue
                    ,
                pub mask_position_x:
                    longhands::mask_position_x::SpecifiedValue
                    ,
                pub mask_position_y:
                    longhands::mask_position_y::SpecifiedValue
                    ,
                pub mask_size:
                    longhands::mask_size::SpecifiedValue
                    ,
                pub mask_image:
                    longhands::mask_image::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub mask_mode:
                    &'a longhands::mask_mode::SpecifiedValue,
                pub mask_repeat:
                    &'a longhands::mask_repeat::SpecifiedValue,
                pub mask_clip:
                    &'a longhands::mask_clip::SpecifiedValue,
                pub mask_origin:
                    &'a longhands::mask_origin::SpecifiedValue,
                pub mask_composite:
                    &'a longhands::mask_composite::SpecifiedValue,
                pub mask_position_x:
                    &'a longhands::mask_position_x::SpecifiedValue,
                pub mask_position_y:
                    &'a longhands::mask_position_y::SpecifiedValue,
                pub mask_size:
                    &'a longhands::mask_size::SpecifiedValue,
                pub mask_image:
                    &'a longhands::mask_image::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut mask_mode =
                        None::< &'a longhands::mask_mode::SpecifiedValue>;
                    let mut mask_repeat =
                        None::< &'a longhands::mask_repeat::SpecifiedValue>;
                    let mut mask_clip =
                        None::< &'a longhands::mask_clip::SpecifiedValue>;
                    let mut mask_origin =
                        None::< &'a longhands::mask_origin::SpecifiedValue>;
                    let mut mask_composite =
                        None::< &'a longhands::mask_composite::SpecifiedValue>;
                    let mut mask_position_x =
                        None::< &'a longhands::mask_position_x::SpecifiedValue>;
                    let mut mask_position_y =
                        None::< &'a longhands::mask_position_y::SpecifiedValue>;
                    let mut mask_size =
                        None::< &'a longhands::mask_size::SpecifiedValue>;
                    let mut mask_image =
                        None::< &'a longhands::mask_image::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::MaskMode(ref value) => {
                                mask_mode = Some(value)
                            },
                            PropertyDeclaration::MaskRepeat(ref value) => {
                                mask_repeat = Some(value)
                            },
                            PropertyDeclaration::MaskClip(ref value) => {
                                mask_clip = Some(value)
                            },
                            PropertyDeclaration::MaskOrigin(ref value) => {
                                mask_origin = Some(value)
                            },
                            PropertyDeclaration::MaskComposite(ref value) => {
                                mask_composite = Some(value)
                            },
                            PropertyDeclaration::MaskPositionX(ref value) => {
                                mask_position_x = Some(value)
                            },
                            PropertyDeclaration::MaskPositionY(ref value) => {
                                mask_position_y = Some(value)
                            },
                            PropertyDeclaration::MaskSize(ref value) => {
                                mask_size = Some(value)
                            },
                            PropertyDeclaration::MaskImage(ref value) => {
                                mask_image = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        mask_mode,
                        mask_repeat,
                        mask_clip,
                        mask_origin,
                        mask_composite,
                        mask_position_x,
                        mask_position_y,
                        mask_size,
                        mask_image,
                ) {

                    (
                        Some(mask_mode),
                        Some(mask_repeat),
                        Some(mask_clip),
                        Some(mask_origin),
                        Some(mask_composite),
                        Some(mask_position_x),
                        Some(mask_position_y),
                        Some(mask_size),
                        Some(mask_image),
                    ) =>
                    Ok(LonghandsToSerialize {
                            mask_mode,
                            mask_repeat,
                            mask_clip,
                            mask_origin,
                            mask_composite,
                            mask_position_x,
                            mask_position_y,
                            mask_size,
                            mask_image,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MaskMode(
                        longhands.mask_mode
                    ));
                    declarations.push(PropertyDeclaration::MaskRepeat(
                        longhands.mask_repeat
                    ));
                    declarations.push(PropertyDeclaration::MaskClip(
                        longhands.mask_clip
                    ));
                    declarations.push(PropertyDeclaration::MaskOrigin(
                        longhands.mask_origin
                    ));
                    declarations.push(PropertyDeclaration::MaskComposite(
                        longhands.mask_composite
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionX(
                        longhands.mask_position_x
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionY(
                        longhands.mask_position_y
                    ));
                    declarations.push(PropertyDeclaration::MaskSize(
                        longhands.mask_size
                    ));
                    declarations.push(PropertyDeclaration::MaskImage(
                        longhands.mask_image
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{mask_mode, mask_repeat, mask_clip, mask_origin, mask_composite, mask_position_x,
                                mask_position_y};
    use crate::properties::longhands::{mask_size, mask_image};
    use crate::values::specified::{Position, PositionComponent};
    use crate::parser::Parse;

    // FIXME(emilio): These two mask types should be the same!
    impl From<mask_origin::single_value::SpecifiedValue> for mask_clip::single_value::SpecifiedValue {
        fn from(origin: mask_origin::single_value::SpecifiedValue) -> mask_clip::single_value::SpecifiedValue {
            match origin {
                mask_origin::single_value::SpecifiedValue::ContentBox =>
                    mask_clip::single_value::SpecifiedValue::ContentBox,
                mask_origin::single_value::SpecifiedValue::PaddingBox =>
                    mask_clip::single_value::SpecifiedValue::PaddingBox ,
                mask_origin::single_value::SpecifiedValue::BorderBox =>
                    mask_clip::single_value::SpecifiedValue::BorderBox,
                mask_origin::single_value::SpecifiedValue::FillBox =>
                    mask_clip::single_value::SpecifiedValue::FillBox ,
                mask_origin::single_value::SpecifiedValue::StrokeBox =>
                    mask_clip::single_value::SpecifiedValue::StrokeBox,
                mask_origin::single_value::SpecifiedValue::ViewBox=>
                    mask_clip::single_value::SpecifiedValue::ViewBox,
            }
        }
    }

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_image = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_mode = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_position_x = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_position_y = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_size = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_repeat = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_origin = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_clip = Vec::with_capacity(1);
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut mask_composite = Vec::with_capacity(1);

        input.parse_comma_separated(|input| {
                let mut image = None;
                let mut mode = None;
                let mut position = None;
                let mut size = None;
                let mut repeat = None;
                let mut origin = None;
                let mut clip = None;
                let mut composite = None;
            loop {
                if image.is_none() {
                    if let Ok(value) = input.try_parse(|input| mask_image::single_value
                                                                   ::parse(context, input)) {
                        image = Some(value);
                        continue
                    }
                }
                if position.is_none() {
                    if let Ok(value) = input.try_parse(|input| Position::parse(context, input)) {
                        position = Some(value);

                        // Parse mask size, if applicable.
                        size = input.try_parse(|input| {
                            input.expect_delim('/')?;
                            mask_size::single_value::parse(context, input)
                        }).ok();

                        continue
                    }
                }
                    if repeat.is_none() {
                        if let Ok(value) = input.try_parse(|input| mask_repeat::single_value
                                                                               ::parse(context, input)) {
                            repeat = Some(value);
                            continue
                        }
                    }
                    if origin.is_none() {
                        if let Ok(value) = input.try_parse(|input| mask_origin::single_value
                                                                               ::parse(context, input)) {
                            origin = Some(value);
                            continue
                        }
                    }
                    if clip.is_none() {
                        if let Ok(value) = input.try_parse(|input| mask_clip::single_value
                                                                               ::parse(context, input)) {
                            clip = Some(value);
                            continue
                        }
                    }
                    if composite.is_none() {
                        if let Ok(value) = input.try_parse(|input| mask_composite::single_value
                                                                               ::parse(context, input)) {
                            composite = Some(value);
                            continue
                        }
                    }
                    if mode.is_none() {
                        if let Ok(value) = input.try_parse(|input| mask_mode::single_value
                                                                               ::parse(context, input)) {
                            mode = Some(value);
                            continue
                        }
                    }
                break
            }
            if clip.is_none() {
                if let Some(origin) = origin {
                    clip = Some(mask_clip::single_value::SpecifiedValue::from(origin));
                }
            }
            let mut any = false;
                any = any || image.is_some();
                any = any || mode.is_some();
                any = any || position.is_some();
                any = any || size.is_some();
                any = any || repeat.is_some();
                any = any || origin.is_some();
                any = any || clip.is_some();
                any = any || composite.is_some();
            if any {
                if let Some(position) = position {
                    mask_position_x.push(position.horizontal);
                    mask_position_y.push(position.vertical);
                } else {
                    mask_position_x.push(PositionComponent::zero());
                    mask_position_y.push(PositionComponent::zero());
                }
                    if let Some(m_image) = image {
                        mask_image.push(m_image);
                    } else {
                        mask_image.push(mask_image::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_mode) = mode {
                        mask_mode.push(m_mode);
                    } else {
                        mask_mode.push(mask_mode::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_size) = size {
                        mask_size.push(m_size);
                    } else {
                        mask_size.push(mask_size::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_repeat) = repeat {
                        mask_repeat.push(m_repeat);
                    } else {
                        mask_repeat.push(mask_repeat::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_origin) = origin {
                        mask_origin.push(m_origin);
                    } else {
                        mask_origin.push(mask_origin::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_clip) = clip {
                        mask_clip.push(m_clip);
                    } else {
                        mask_clip.push(mask_clip::single_value
                                                        ::get_initial_specified_value());
                    }
                    if let Some(m_composite) = composite {
                        mask_composite.push(m_composite);
                    } else {
                        mask_composite.push(mask_composite::single_value
                                                        ::get_initial_specified_value());
                    }
                Ok(())
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        })?;

        Ok(expanded! {
                mask_image: mask_image::SpecifiedValue(mask_image.into()),
                mask_mode: mask_mode::SpecifiedValue(mask_mode.into()),
                mask_position_x: mask_position_x::SpecifiedValue(mask_position_x.into()),
                mask_position_y: mask_position_y::SpecifiedValue(mask_position_y.into()),
                mask_size: mask_size::SpecifiedValue(mask_size.into()),
                mask_repeat: mask_repeat::SpecifiedValue(mask_repeat.into()),
                mask_origin: mask_origin::SpecifiedValue(mask_origin.into()),
                mask_clip: mask_clip::SpecifiedValue(mask_clip.into()),
                mask_composite: mask_composite::SpecifiedValue(mask_composite.into()),
         })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use crate::properties::longhands::mask_origin::single_value::computed_value::T as Origin;
            use crate::properties::longhands::mask_clip::single_value::computed_value::T as Clip;
            use style_traits::values::SequenceWriter;

            let len = self.mask_image.0.len();
            if len == 0 {
                return Ok(());
            }
                if self.mask_mode.0.len() != len {
                    return Ok(());
                }
                if self.mask_position_x.0.len() != len {
                    return Ok(());
                }
                if self.mask_position_y.0.len() != len {
                    return Ok(());
                }
                if self.mask_size.0.len() != len {
                    return Ok(());
                }
                if self.mask_repeat.0.len() != len {
                    return Ok(());
                }
                if self.mask_origin.0.len() != len {
                    return Ok(());
                }
                if self.mask_clip.0.len() != len {
                    return Ok(());
                }
                if self.mask_composite.0.len() != len {
                    return Ok(());
                }

            // For each <mask-layer>, we serialize it according to the following order:
            // <mask-layer> =
            //   <mask-reference> ||
            //   <position> [ / <bg-size> ]? ||
            //   <repeat-style> ||
            //   <coord-box> ||
            //   [ <coord-box> | no-clip ] ||
            //   <compositing-operator> ||
            //   <masking-mode>
            // https://drafts.fxtf.org/css-masking-1/#the-mask
            for i in 0..len {
                if i > 0 {
                    dest.write_str(", ")?;
                }

                    let image = &self.mask_image.0[i];
                    let mode = &self.mask_mode.0[i];
                    let position_x = &self.mask_position_x.0[i];
                    let position_y = &self.mask_position_y.0[i];
                    let size = &self.mask_size.0[i];
                    let repeat = &self.mask_repeat.0[i];
                    let origin = &self.mask_origin.0[i];
                    let clip = &self.mask_clip.0[i];
                    let composite = &self.mask_composite.0[i];

                let mut has_other = false;
                    let has_image =
                        *image != mask_image::single_value::get_initial_specified_value();
                    has_other |= has_image;
                    let has_mode =
                        *mode != mask_mode::single_value::get_initial_specified_value();
                    has_other |= has_mode;
                    let has_size =
                        *size != mask_size::single_value::get_initial_specified_value();
                    has_other |= has_size;
                    let has_repeat =
                        *repeat != mask_repeat::single_value::get_initial_specified_value();
                    has_other |= has_repeat;
                    let has_composite =
                        *composite != mask_composite::single_value::get_initial_specified_value();
                    has_other |= has_composite;
                let has_position = *position_x != PositionComponent::zero()
                    || *position_y != PositionComponent::zero();
                let has_origin = *origin != Origin::BorderBox;
                let has_clip = *clip != Clip::BorderBox;

                // If all are initial values, we serialize mask-image.
                if !has_other && !has_position && !has_origin && !has_clip {
                    return image.to_css(dest);
                }

                let mut writer = SequenceWriter::new(dest, " ");
                // <mask-reference>
                if has_image {
                    writer.item(image)?;
                }

                // <position> [ / <bg-size> ]?
                if has_position || has_size {
                    writer.item(&Position {
                        horizontal: position_x.clone(),
                        vertical: position_y.clone()
                    })?;

                    if has_size {
                        writer.raw_item("/")?;
                        writer.item(size)?;
                    }
                }

                // <repeat-style>
                if has_repeat {
                    writer.item(repeat)?;
                }

                // <coord-box>
                // Note:
                // Even if 'mask-origin' is at its initial value 'border-box',
                // we still have to serialize it to avoid ambiguity iF the
                // 'mask-clip' longhand has some other <coord-box> value
                // (i.e. neither 'border-box' nor 'no-clip'). (If we naively
                // declined to serialize the 'mask-origin' value in this
                // situation, then whatever value we serialize for 'mask-clip'
                // would implicitly also represent 'mask-origin' and would be
                // providing the wrong value for that longhand.)
                if has_origin || (has_clip && *clip != Clip::NoClip) {
                    writer.item(origin)?;
                }

                // [ <coord-box> | no-clip ]
                if has_clip && *clip != From::from(*origin) {
                    writer.item(clip)?;
                }

                // <compositing-operator>
                if has_composite {
                    writer.item(composite)?;
                }

                // <masking-mode>
                if has_mode {
                    writer.item(mode)?;
                }
            }

            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-masks-4/#the-mask-position
    pub mod mask_position {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub mask_position_x:
                    longhands::mask_position_x::SpecifiedValue
                    ,
                pub mask_position_y:
                    longhands::mask_position_y::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub mask_position_x:
                    &'a longhands::mask_position_x::SpecifiedValue,
                pub mask_position_y:
                    &'a longhands::mask_position_y::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut mask_position_x =
                        None::< &'a longhands::mask_position_x::SpecifiedValue>;
                    let mut mask_position_y =
                        None::< &'a longhands::mask_position_y::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::MaskPositionX(ref value) => {
                                mask_position_x = Some(value)
                            },
                            PropertyDeclaration::MaskPositionY(ref value) => {
                                mask_position_y = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        mask_position_x,
                        mask_position_y,
                ) {

                    (
                        Some(mask_position_x),
                        Some(mask_position_y),
                    ) =>
                    Ok(LonghandsToSerialize {
                            mask_position_x,
                            mask_position_y,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::MaskPositionX(
                        longhands.mask_position_x
                    ));
                    declarations.push(PropertyDeclaration::MaskPositionY(
                        longhands.mask_position_y
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::properties::longhands::{mask_position_x,mask_position_y};
    use crate::values::specified::position::Position;
    use crate::parser::Parse;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        // Vec grows from 0 to 4 by default on first push().  So allocate with
        // capacity 1, so in the common case of only one item we don't way
        // overallocate, then shrink.  Note that we always push at least one
        // item if parsing succeeds.
        let mut position_x = Vec::with_capacity(1);
        let mut position_y = Vec::with_capacity(1);
        let mut any = false;

        input.parse_comma_separated(|input| {
            let value = Position::parse(context, input)?;
            position_x.push(value.horizontal);
            position_y.push(value.vertical);
            any = true;
            Ok(())
        })?;

        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }


        Ok(expanded! {
            mask_position_x: mask_position_x::SpecifiedValue(position_x.into()),
            mask_position_y: mask_position_y::SpecifiedValue(position_y.into()),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            let len = self.mask_position_x.0.len();
            if len == 0 || self.mask_position_y.0.len() != len {
                return Ok(());
            }

            for i in 0..len {
                Position {
                    horizontal: self.mask_position_x.0[i].clone(),
                    vertical: self.mask_position_y.0[i].clone()
                }.to_css(dest)?;

                if i < len - 1 {
                    dest.write_str(", ")?;
                }
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */

    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





    /// https://drafts.csswg.org/css-text-decor/#propdef-text-decoration
    pub mod text_decoration {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub text_decoration_line:
                    longhands::text_decoration_line::SpecifiedValue
                    ,
                pub text_decoration_style:
                    longhands::text_decoration_style::SpecifiedValue
                    ,
                pub text_decoration_color:
                    longhands::text_decoration_color::SpecifiedValue
                    ,
                pub text_decoration_thickness:
                    longhands::text_decoration_thickness::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub text_decoration_line:
                    &'a longhands::text_decoration_line::SpecifiedValue,
                pub text_decoration_style:
                    &'a longhands::text_decoration_style::SpecifiedValue,
                pub text_decoration_color:
                    &'a longhands::text_decoration_color::SpecifiedValue,
                pub text_decoration_thickness:
                    &'a longhands::text_decoration_thickness::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut text_decoration_line =
                        None::< &'a longhands::text_decoration_line::SpecifiedValue>;
                    let mut text_decoration_style =
                        None::< &'a longhands::text_decoration_style::SpecifiedValue>;
                    let mut text_decoration_color =
                        None::< &'a longhands::text_decoration_color::SpecifiedValue>;
                    let mut text_decoration_thickness =
                        None::< &'a longhands::text_decoration_thickness::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::TextDecorationLine(ref value) => {
                                text_decoration_line = Some(value)
                            },
                            PropertyDeclaration::TextDecorationStyle(ref value) => {
                                text_decoration_style = Some(value)
                            },
                            PropertyDeclaration::TextDecorationColor(ref value) => {
                                text_decoration_color = Some(value)
                            },
                            PropertyDeclaration::TextDecorationThickness(ref value) => {
                                text_decoration_thickness = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        text_decoration_line,
                        text_decoration_style,
                        text_decoration_color,
                        text_decoration_thickness,
                ) {

                    (
                        Some(text_decoration_line),
                        Some(text_decoration_style),
                        Some(text_decoration_color),
                        Some(text_decoration_thickness),
                    ) =>
                    Ok(LonghandsToSerialize {
                            text_decoration_line,
                            text_decoration_style,
                            text_decoration_color,
                            text_decoration_thickness,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TextDecorationLine(
                        longhands.text_decoration_line
                    ));
                    declarations.push(PropertyDeclaration::TextDecorationStyle(
                        longhands.text_decoration_style
                    ));
                    declarations.push(PropertyDeclaration::TextDecorationColor(
                        longhands.text_decoration_color
                    ));
                    declarations.push(PropertyDeclaration::TextDecorationThickness(
                        longhands.text_decoration_thickness
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
        use crate::values::specified;
        use crate::properties::longhands::{text_decoration_style, text_decoration_color, text_decoration_thickness};
    use crate::properties::longhands::text_decoration_line;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
            let (mut line, mut style, mut color, mut thickness, mut any) = (None, None, None, None, false);

        loop {
            macro_rules! parse_component {
                ($value:ident, $module:ident) => (
                    if $value.is_none() {
                        if let Ok(value) = input.try_parse(|input| $module::parse(context, input)) {
                            $value = Some(value);
                            any = true;
                            continue;
                        }
                    }
                )
            }

            parse_component!(line, text_decoration_line);

                parse_component!(style, text_decoration_style);
                parse_component!(color, text_decoration_color);
                parse_component!(thickness, text_decoration_thickness);

            break;
        }

        if !any {
            return Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError));
        }

        Ok(expanded! {
            text_decoration_line: unwrap_or_initial!(text_decoration_line, line),

                text_decoration_style: unwrap_or_initial!(text_decoration_style, style),
                text_decoration_color: unwrap_or_initial!(text_decoration_color, color),
                text_decoration_thickness: unwrap_or_initial!(text_decoration_thickness, thickness),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        #[allow(unused)]
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use crate::values::specified::TextDecorationLine;

            let (is_solid_style, is_current_color, is_auto_thickness) =
            (
                *self.text_decoration_style == text_decoration_style::SpecifiedValue::Solid,
                *self.text_decoration_color == specified::Color::CurrentColor,
                self.text_decoration_thickness.is_auto()
            );

            let mut has_value = false;
            let is_none = *self.text_decoration_line == TextDecorationLine::none();
            if (is_solid_style && is_current_color && is_auto_thickness) || !is_none {
                self.text_decoration_line.to_css(dest)?;
                has_value = true;
            }

            if !is_auto_thickness {
                if has_value {
                    dest.write_char(' ')?;
                }
                self.text_decoration_thickness.to_css(dest)?;
                has_value = true;
            }

            if !is_solid_style {
                if has_value {
                    dest.write_char(' ')?;
                }
                self.text_decoration_style.to_css(dest)?;
                has_value = true;
            }

            if !is_current_color {
                if has_value {
                    dest.write_char(' ')?;
                }
                self.text_decoration_color.to_css(dest)?;
                has_value = true;
            }

            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */



macro_rules! try_parse_one {
    ($context: expr, $input: expr, $var: ident, $prop_module: ident) => {
        if $var.is_none() {
            if let Ok(value) = $input.try_parse(|i| {
                $prop_module::single_value::parse($context, i)
            }) {
                $var = Some(value);
                continue;
            }
        }
    };
}



    /// https://drafts.csswg.org/css-transitions/#propdef-transition
    pub mod transition {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub transition_property:
                    longhands::transition_property::SpecifiedValue
                    ,
                pub transition_duration:
                    longhands::transition_duration::SpecifiedValue
                    ,
                pub transition_timing_function:
                    longhands::transition_timing_function::SpecifiedValue
                    ,
                pub transition_delay:
                    longhands::transition_delay::SpecifiedValue
                    ,
                pub transition_behavior:
                    longhands::transition_behavior::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub transition_property:
                    &'a longhands::transition_property::SpecifiedValue,
                pub transition_duration:
                    &'a longhands::transition_duration::SpecifiedValue,
                pub transition_timing_function:
                    &'a longhands::transition_timing_function::SpecifiedValue,
                pub transition_delay:
                    &'a longhands::transition_delay::SpecifiedValue,
                pub transition_behavior:
                    Option<
                    &'a longhands::transition_behavior::SpecifiedValue,
                    >,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut transition_property =
                        None::< &'a longhands::transition_property::SpecifiedValue>;
                    let mut transition_duration =
                        None::< &'a longhands::transition_duration::SpecifiedValue>;
                    let mut transition_timing_function =
                        None::< &'a longhands::transition_timing_function::SpecifiedValue>;
                    let mut transition_delay =
                        None::< &'a longhands::transition_delay::SpecifiedValue>;
                    let mut transition_behavior =
                        None::< &'a longhands::transition_behavior::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::TransitionProperty(ref value) => {
                                transition_property = Some(value)
                            },
                            PropertyDeclaration::TransitionDuration(ref value) => {
                                transition_duration = Some(value)
                            },
                            PropertyDeclaration::TransitionTimingFunction(ref value) => {
                                transition_timing_function = Some(value)
                            },
                            PropertyDeclaration::TransitionDelay(ref value) => {
                                transition_delay = Some(value)
                            },
                            PropertyDeclaration::TransitionBehavior(ref value) => {
                                transition_behavior = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        transition_property,
                        transition_duration,
                        transition_timing_function,
                        transition_delay,
                        transition_behavior,
                ) {

                    (
                        Some(transition_property),
                        Some(transition_duration),
                        Some(transition_timing_function),
                        Some(transition_delay),
                        transition_behavior,
                    ) =>
                    Ok(LonghandsToSerialize {
                            transition_property,
                            transition_duration,
                            transition_timing_function,
                            transition_delay,
                            transition_behavior,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::TransitionProperty(
                        longhands.transition_property
                    ));
                    declarations.push(PropertyDeclaration::TransitionDuration(
                        longhands.transition_duration
                    ));
                    declarations.push(PropertyDeclaration::TransitionTimingFunction(
                        longhands.transition_timing_function
                    ));
                    declarations.push(PropertyDeclaration::TransitionDelay(
                        longhands.transition_delay
                    ));
                if NonCustomPropertyId::from(LonghandId::TransitionBehavior)
                    .allowed_in_ignoring_rule_type(context) {
                    declarations.push(PropertyDeclaration::TransitionBehavior(
                        longhands.transition_behavior
                    ));
                }
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    use crate::parser::Parse;
    use crate::properties::longhands::transition_delay;
    use crate::properties::longhands::transition_duration;
    use crate::properties::longhands::transition_property;
    use crate::properties::longhands::transition_timing_function;
    use crate::properties::longhands::transition_behavior;
    use crate::values::specified::TransitionProperty;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        struct SingleTransition {
            transition_property: transition_property::SingleSpecifiedValue,
            transition_duration: transition_duration::SingleSpecifiedValue,
            transition_timing_function: transition_timing_function::SingleSpecifiedValue,
            transition_delay: transition_delay::SingleSpecifiedValue,
            transition_behavior: transition_behavior::SingleSpecifiedValue,
        }

        fn parse_one_transition<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
            first: bool,
        ) -> Result<SingleTransition,ParseError<'i>> {
            let mut property = None;
            let mut duration = None;
            let mut timing_function = None;
            let mut delay = None;
            let mut behavior = None;

            let mut parsed = 0;
            loop {
                parsed += 1;

                try_parse_one!(context, input, duration, transition_duration);
                try_parse_one!(context, input, timing_function, transition_timing_function);
                try_parse_one!(context, input, delay, transition_delay);
                if static_prefs::pref!("layout.css.transition-behavior.enabled") {
                    try_parse_one!(context, input, behavior, transition_behavior);
                }
                // Must check 'transition-property' after 'transition-timing-function' since
                // 'transition-property' accepts any keyword.
                if property.is_none() {
                    if let Ok(value) = input.try_parse(|i| TransitionProperty::parse(context, i)) {
                        property = Some(value);
                        continue;
                    }

                    // 'none' is not a valid value for <single-transition-property>,
                    // so it's only acceptable as the first item.
                    if first && input.try_parse(|i| i.expect_ident_matching("none")).is_ok() {
                        property = Some(TransitionProperty::none());
                        continue;
                    }
                }

                parsed -= 1;
                break
            }

            if parsed != 0 {
                Ok(SingleTransition {
                    transition_property: property.unwrap_or_else(transition_property::single_value
                                                                                 ::get_initial_specified_value),
                    transition_duration: duration.unwrap_or_else(transition_duration::single_value
                                                                                 ::get_initial_specified_value),
                    transition_timing_function: timing_function.unwrap_or_else(transition_timing_function::single_value
                                                                                 ::get_initial_specified_value),
                    transition_delay: delay.unwrap_or_else(transition_delay::single_value
                                                                                 ::get_initial_specified_value),
                    transition_behavior: behavior.unwrap_or_else(transition_behavior::single_value
                                                                                 ::get_initial_specified_value),
                })
            } else {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
        }

        let mut propertys = Vec::new();
        let mut durations = Vec::new();
        let mut timing_functions = Vec::new();
        let mut delays = Vec::new();
        let mut behaviors = Vec::new();

        let mut first = true;
        let mut has_transition_property_none = false;
        let results = input.parse_comma_separated(|i| {
            if has_transition_property_none {
                // If you specify transition-property: none, multiple items are invalid.
                return Err(i.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            }
            let transition = parse_one_transition(context, i, first)?;
            first = false;
            has_transition_property_none = transition.transition_property.is_none();
            Ok(transition)
        })?;
        for result in results {
            propertys.push(result.transition_property);
            durations.push(result.transition_duration);
            timing_functions.push(result.transition_timing_function);
            delays.push(result.transition_delay);
            behaviors.push(result.transition_behavior);
        }

        Ok(expanded! {
            transition_property: transition_property::SpecifiedValue(propertys.into()),
            transition_duration: transition_duration::SpecifiedValue(durations.into()),
            transition_timing_function: transition_timing_function::SpecifiedValue(timing_functions.into()),
            transition_delay: transition_delay::SpecifiedValue(delays.into()),
            transition_behavior: transition_behavior::SpecifiedValue(behaviors.into()),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use crate::Zero;
            use style_traits::values::SequenceWriter;

            let property_len = self.transition_property.0.len();

            // There are two cases that we can do shorthand serialization:
            // * when all value lists have the same length, or
            // * when transition-property is none, and other value lists have exactly one item.
            if property_len == 0 {
                    if self.transition_duration.0.len() != 1 {
                        return Ok(());
                    }
                    if self.transition_delay.0.len() != 1 {
                        return Ok(());
                    }
                    if self.transition_timing_function.0.len() != 1 {
                        return Ok(());
                    }

                if let Some(behavior) = self.transition_behavior {
                    if behavior.0.len() != 1 {
                        return Ok(());
                    }
                }
            } else {
                    if self.transition_duration.0.len() != property_len {
                        return Ok(());
                    }
                    if self.transition_delay.0.len() != property_len {
                        return Ok(());
                    }
                    if self.transition_timing_function.0.len() != property_len {
                        return Ok(());
                    }

                if let Some(behavior) = self.transition_behavior {
                    if behavior.0.len() != property_len {
                        return Ok(());
                    }
                }
            }

            // Representative length.
            let len = self.transition_duration.0.len();

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }

                let has_duration = !self.transition_duration.0[i].is_zero();
                let has_timing = !self.transition_timing_function.0[i].is_ease();
                let has_delay = !self.transition_delay.0[i].is_zero();
                let has_behavior = match self.transition_behavior {
                    Some(behavior) => !behavior.0[i].is_normal(),
                    _ => false,
                };
                let has_any = has_duration || has_timing || has_delay || has_behavior;

                let mut writer = SequenceWriter::new(dest, " ");

                if property_len == 0 {
                    writer.raw_item("none")?;
                } else if !self.transition_property.0[i].is_all() || !has_any {
                    writer.item(&self.transition_property.0[i])?;
                }

                // In order to avoid ambiguity, we have to serialize duration if we have delay.
                if has_duration || has_delay {
                    writer.item(&self.transition_duration.0[i])?;
                }

                if has_timing {
                    writer.item(&self.transition_timing_function.0[i])?;
                }

                if has_delay {
                    writer.item(&self.transition_delay.0[i])?;
                }

                if has_behavior {
                    writer.item(&self.transition_behavior.unwrap().0[i])?;
                }
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/css-animations/#propdef-animation
    pub mod animation {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub animation_name:
                    longhands::animation_name::SpecifiedValue
                    ,
                pub animation_duration:
                    longhands::animation_duration::SpecifiedValue
                    ,
                pub animation_timing_function:
                    longhands::animation_timing_function::SpecifiedValue
                    ,
                pub animation_delay:
                    longhands::animation_delay::SpecifiedValue
                    ,
                pub animation_iteration_count:
                    longhands::animation_iteration_count::SpecifiedValue
                    ,
                pub animation_direction:
                    longhands::animation_direction::SpecifiedValue
                    ,
                pub animation_fill_mode:
                    longhands::animation_fill_mode::SpecifiedValue
                    ,
                pub animation_play_state:
                    longhands::animation_play_state::SpecifiedValue
                    ,
                pub animation_timeline:
                    longhands::animation_timeline::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub animation_name:
                    &'a longhands::animation_name::SpecifiedValue,
                pub animation_duration:
                    &'a longhands::animation_duration::SpecifiedValue,
                pub animation_timing_function:
                    &'a longhands::animation_timing_function::SpecifiedValue,
                pub animation_delay:
                    &'a longhands::animation_delay::SpecifiedValue,
                pub animation_iteration_count:
                    &'a longhands::animation_iteration_count::SpecifiedValue,
                pub animation_direction:
                    &'a longhands::animation_direction::SpecifiedValue,
                pub animation_fill_mode:
                    &'a longhands::animation_fill_mode::SpecifiedValue,
                pub animation_play_state:
                    &'a longhands::animation_play_state::SpecifiedValue,
                pub animation_timeline:
                    Option<
                    &'a longhands::animation_timeline::SpecifiedValue,
                    >,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut animation_name =
                        None::< &'a longhands::animation_name::SpecifiedValue>;
                    let mut animation_duration =
                        None::< &'a longhands::animation_duration::SpecifiedValue>;
                    let mut animation_timing_function =
                        None::< &'a longhands::animation_timing_function::SpecifiedValue>;
                    let mut animation_delay =
                        None::< &'a longhands::animation_delay::SpecifiedValue>;
                    let mut animation_iteration_count =
                        None::< &'a longhands::animation_iteration_count::SpecifiedValue>;
                    let mut animation_direction =
                        None::< &'a longhands::animation_direction::SpecifiedValue>;
                    let mut animation_fill_mode =
                        None::< &'a longhands::animation_fill_mode::SpecifiedValue>;
                    let mut animation_play_state =
                        None::< &'a longhands::animation_play_state::SpecifiedValue>;
                    let mut animation_timeline =
                        None::< &'a longhands::animation_timeline::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::AnimationName(ref value) => {
                                animation_name = Some(value)
                            },
                            PropertyDeclaration::AnimationDuration(ref value) => {
                                animation_duration = Some(value)
                            },
                            PropertyDeclaration::AnimationTimingFunction(ref value) => {
                                animation_timing_function = Some(value)
                            },
                            PropertyDeclaration::AnimationDelay(ref value) => {
                                animation_delay = Some(value)
                            },
                            PropertyDeclaration::AnimationIterationCount(ref value) => {
                                animation_iteration_count = Some(value)
                            },
                            PropertyDeclaration::AnimationDirection(ref value) => {
                                animation_direction = Some(value)
                            },
                            PropertyDeclaration::AnimationFillMode(ref value) => {
                                animation_fill_mode = Some(value)
                            },
                            PropertyDeclaration::AnimationPlayState(ref value) => {
                                animation_play_state = Some(value)
                            },
                            PropertyDeclaration::AnimationTimeline(ref value) => {
                                animation_timeline = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        animation_name,
                        animation_duration,
                        animation_timing_function,
                        animation_delay,
                        animation_iteration_count,
                        animation_direction,
                        animation_fill_mode,
                        animation_play_state,
                        animation_timeline,
                ) {

                    (
                        Some(animation_name),
                        Some(animation_duration),
                        Some(animation_timing_function),
                        Some(animation_delay),
                        Some(animation_iteration_count),
                        Some(animation_direction),
                        Some(animation_fill_mode),
                        Some(animation_play_state),
                        animation_timeline,
                    ) =>
                    Ok(LonghandsToSerialize {
                            animation_name,
                            animation_duration,
                            animation_timing_function,
                            animation_delay,
                            animation_iteration_count,
                            animation_direction,
                            animation_fill_mode,
                            animation_play_state,
                            animation_timeline,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::AnimationName(
                        longhands.animation_name
                    ));
                    declarations.push(PropertyDeclaration::AnimationDuration(
                        longhands.animation_duration
                    ));
                    declarations.push(PropertyDeclaration::AnimationTimingFunction(
                        longhands.animation_timing_function
                    ));
                    declarations.push(PropertyDeclaration::AnimationDelay(
                        longhands.animation_delay
                    ));
                    declarations.push(PropertyDeclaration::AnimationIterationCount(
                        longhands.animation_iteration_count
                    ));
                    declarations.push(PropertyDeclaration::AnimationDirection(
                        longhands.animation_direction
                    ));
                    declarations.push(PropertyDeclaration::AnimationFillMode(
                        longhands.animation_fill_mode
                    ));
                    declarations.push(PropertyDeclaration::AnimationPlayState(
                        longhands.animation_play_state
                    ));
                if NonCustomPropertyId::from(LonghandId::AnimationTimeline)
                    .allowed_in_ignoring_rule_type(context) {
                    declarations.push(PropertyDeclaration::AnimationTimeline(
                        longhands.animation_timeline
                    ));
                }
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    
    use crate::properties::longhands::animation_name;
    use crate::properties::longhands::animation_timeline;
    use crate::properties::longhands::animation_duration;
    use crate::properties::longhands::animation_timing_function;
    use crate::properties::longhands::animation_delay;
    use crate::properties::longhands::animation_iteration_count;
    use crate::properties::longhands::animation_direction;
    use crate::properties::longhands::animation_fill_mode;
    use crate::properties::longhands::animation_play_state;

    pub fn parse_value<'i, 't>(
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<Longhands, ParseError<'i>> {
        struct SingleAnimation {
            animation_name: animation_name::SingleSpecifiedValue,
            animation_timeline: animation_timeline::SingleSpecifiedValue,
            animation_duration: animation_duration::SingleSpecifiedValue,
            animation_timing_function: animation_timing_function::SingleSpecifiedValue,
            animation_delay: animation_delay::SingleSpecifiedValue,
            animation_iteration_count: animation_iteration_count::SingleSpecifiedValue,
            animation_direction: animation_direction::SingleSpecifiedValue,
            animation_fill_mode: animation_fill_mode::SingleSpecifiedValue,
            animation_play_state: animation_play_state::SingleSpecifiedValue,
        }

        fn parse_one_animation<'i, 't>(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<SingleAnimation, ParseError<'i>> {
            let mut name = None;
            let mut timeline = None;
            let mut duration = None;
            let mut timing_function = None;
            let mut delay = None;
            let mut iteration_count = None;
            let mut direction = None;
            let mut fill_mode = None;
            let mut play_state = None;

            let mut parsed = 0;
            // NB: Name must be the last one here so that keywords valid for other
            // longhands are not interpreted as names.
            //
            // Also, duration must be before delay, see
            // https://drafts.csswg.org/css-animations/#typedef-single-animation
            loop {
                parsed += 1;
                try_parse_one!(context, input, duration, animation_duration);
                try_parse_one!(context, input, timing_function, animation_timing_function);
                try_parse_one!(context, input, delay, animation_delay);
                try_parse_one!(context, input, iteration_count, animation_iteration_count);
                try_parse_one!(context, input, direction, animation_direction);
                try_parse_one!(context, input, fill_mode, animation_fill_mode);
                try_parse_one!(context, input, play_state, animation_play_state);
                try_parse_one!(context, input, name, animation_name);
                if static_prefs::pref!("layout.css.scroll-driven-animations.enabled") {
                    try_parse_one!(context, input, timeline, animation_timeline);
                }

                parsed -= 1;
                break
            }

            // If nothing is parsed, this is an invalid entry.
            if parsed == 0 {
                Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
            } else {
                Ok(SingleAnimation {
                    animation_name: name.unwrap_or_else(animation_name::single_value
                                                              ::get_initial_specified_value),
                    animation_timeline: timeline.unwrap_or_else(animation_timeline::single_value
                                                              ::get_initial_specified_value),
                    animation_duration: duration.unwrap_or_else(animation_duration::single_value
                                                              ::get_initial_specified_value),
                    animation_timing_function: timing_function.unwrap_or_else(animation_timing_function::single_value
                                                              ::get_initial_specified_value),
                    animation_delay: delay.unwrap_or_else(animation_delay::single_value
                                                              ::get_initial_specified_value),
                    animation_iteration_count: iteration_count.unwrap_or_else(animation_iteration_count::single_value
                                                              ::get_initial_specified_value),
                    animation_direction: direction.unwrap_or_else(animation_direction::single_value
                                                              ::get_initial_specified_value),
                    animation_fill_mode: fill_mode.unwrap_or_else(animation_fill_mode::single_value
                                                              ::get_initial_specified_value),
                    animation_play_state: play_state.unwrap_or_else(animation_play_state::single_value
                                                              ::get_initial_specified_value),
                })
            }
        }

        let mut names = vec![];
        let mut timelines = vec![];
        let mut durations = vec![];
        let mut timing_functions = vec![];
        let mut delays = vec![];
        let mut iteration_counts = vec![];
        let mut directions = vec![];
        let mut fill_modes = vec![];
        let mut play_states = vec![];

        let results = input.parse_comma_separated(|i| parse_one_animation(context, i))?;
        for result in results.into_iter() {
            names.push(result.animation_name);
            timelines.push(result.animation_timeline);
            durations.push(result.animation_duration);
            timing_functions.push(result.animation_timing_function);
            delays.push(result.animation_delay);
            iteration_counts.push(result.animation_iteration_count);
            directions.push(result.animation_direction);
            fill_modes.push(result.animation_fill_mode);
            play_states.push(result.animation_play_state);
        }

        Ok(expanded! {
            animation_name: animation_name::SpecifiedValue(names.into()),
            animation_timeline: animation_timeline::SpecifiedValue(timelines.into()),
            animation_duration: animation_duration::SpecifiedValue(durations.into()),
            animation_timing_function: animation_timing_function::SpecifiedValue(timing_functions.into()),
            animation_delay: animation_delay::SpecifiedValue(delays.into()),
            animation_iteration_count: animation_iteration_count::SpecifiedValue(iteration_counts.into()),
            animation_direction: animation_direction::SpecifiedValue(directions.into()),
            animation_fill_mode: animation_fill_mode::SpecifiedValue(fill_modes.into()),
            animation_play_state: animation_play_state::SpecifiedValue(play_states.into()),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            use crate::values::specified::easing::TimingFunction;
            use crate::values::specified::{
                AnimationDirection, AnimationFillMode, AnimationPlayState,
            };
            use crate::Zero;
            use style_traits::values::SequenceWriter;

            let len = self.animation_name.0.len();
            // There should be at least one declared value
            if len == 0 {
                return Ok(());
            }

            // If any value list length is differs then we don't do a shorthand serialization
            // either.
                if len != self.animation_duration.0.len() {
                    return Ok(())
                }
                if len != self.animation_timing_function.0.len() {
                    return Ok(())
                }
                if len != self.animation_delay.0.len() {
                    return Ok(())
                }
                if len != self.animation_iteration_count.0.len() {
                    return Ok(())
                }
                if len != self.animation_direction.0.len() {
                    return Ok(())
                }
                if len != self.animation_fill_mode.0.len() {
                    return Ok(())
                }
                if len != self.animation_play_state.0.len() {
                    return Ok(())
                }

            // If the preference of animation-timeline is disabled, `self.animation_timeline` is
            // None.
            if self.animation_timeline.map_or(false, |v| len != v.0.len()) {
                return Ok(());
            }

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }

                // We follow the order of this syntax:
                // <single-animation> =
                //   <animation-duration> ||
                //   <easing-function> ||
                //   <animation-delay> ||
                //   <single-animation-iteration-count> ||
                //   <single-animation-direction> ||
                //   <single-animation-fill-mode> ||
                //   <single-animation-play-state> ||
                //   [ none | <keyframes-name> ] ||
                //   <single-animation-timeline>
                //
                // https://drafts.csswg.org/css-animations-2/#animation-shorthand
                //
                // FIXME: Bug 1804574. The initial value of duration should be auto, per
                // css-animations-2.
                let has_duration = !self.animation_duration.0[i].is_zero();
                let has_timing_function = !self.animation_timing_function.0[i].is_ease();
                let has_delay = !self.animation_delay.0[i].is_zero();
                let has_iteration_count = !self.animation_iteration_count.0[i].is_one();
                let has_direction =
                    !matches!(self.animation_direction.0[i], AnimationDirection::Normal);
                let has_fill_mode =
                    !matches!(self.animation_fill_mode.0[i], AnimationFillMode::None);
                let has_play_state =
                    !matches!(self.animation_play_state.0[i], AnimationPlayState::Running);
                let animation_name = &self.animation_name.0[i];
                let has_name = !animation_name.is_none();
                let has_timeline = match self.animation_timeline {
                    Some(timeline) => !timeline.0[i].is_auto(),
                    _ => false,
                };

                let mut writer = SequenceWriter::new(dest, " ");

                // To avoid ambiguity, we have to serialize duration if both duration is initial
                // but delay is not. (In other words, it's ambiguous if we serialize delay only.)
                if has_duration || has_delay {
                    writer.item(&self.animation_duration.0[i])?;
                }

                if has_timing_function || TimingFunction::match_keywords(animation_name) {
                    writer.item(&self.animation_timing_function.0[i])?;
                }

                // For animation-delay and animation-iteration-count.
                if has_delay {
                    writer.item(&self.animation_delay.0[i])?;
                }
                if has_iteration_count {
                    writer.item(&self.animation_iteration_count.0[i])?;
                }

                if has_direction || AnimationDirection::match_keywords(animation_name) {
                    writer.item(&self.animation_direction.0[i])?;
                }

                if has_fill_mode || AnimationFillMode::match_keywords(animation_name) {
                    writer.item(&self.animation_fill_mode.0[i])?;
                }

                if has_play_state || AnimationPlayState::match_keywords(animation_name) {
                    writer.item(&self.animation_play_state.0[i])?;
                }

                // If all values are initial, we must serialize animation-name.
                let has_any = {
                    has_timeline
                        || has_duration
                        || has_timing_function
                        || has_delay
                        || has_iteration_count
                        || has_direction
                        || has_fill_mode
                        || has_play_state
                };
                if has_name || !has_any {
                    writer.item(animation_name)?;
                }

                if has_timeline {
                    writer.item(&self.animation_timeline.unwrap().0[i])?;
                }
            }
            Ok(())
        }
    }

    }




    /// https://drafts.csswg.org/scroll-animations-1/#scroll-timeline-shorthand
    pub mod scroll_timeline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub scroll_timeline_name:
                    longhands::scroll_timeline_name::SpecifiedValue
                    ,
                pub scroll_timeline_axis:
                    longhands::scroll_timeline_axis::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub scroll_timeline_name:
                    &'a longhands::scroll_timeline_name::SpecifiedValue,
                pub scroll_timeline_axis:
                    &'a longhands::scroll_timeline_axis::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut scroll_timeline_name =
                        None::< &'a longhands::scroll_timeline_name::SpecifiedValue>;
                    let mut scroll_timeline_axis =
                        None::< &'a longhands::scroll_timeline_axis::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ScrollTimelineName(ref value) => {
                                scroll_timeline_name = Some(value)
                            },
                            PropertyDeclaration::ScrollTimelineAxis(ref value) => {
                                scroll_timeline_axis = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        scroll_timeline_name,
                        scroll_timeline_axis,
                ) {

                    (
                        Some(scroll_timeline_name),
                        Some(scroll_timeline_axis),
                    ) =>
                    Ok(LonghandsToSerialize {
                            scroll_timeline_name,
                            scroll_timeline_axis,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ScrollTimelineName(
                        longhands.scroll_timeline_name
                    ));
                    declarations.push(PropertyDeclaration::ScrollTimelineAxis(
                        longhands.scroll_timeline_axis
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    pub fn parse_value<'i>(
        context: &ParserContext,
        input: &mut Parser<'i, '_>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::properties::longhands::{scroll_timeline_axis, scroll_timeline_name};

        let mut names = Vec::with_capacity(1);
        let mut axes = Vec::with_capacity(1);
        input.parse_comma_separated(|input| {
            let name = scroll_timeline_name::single_value::parse(context, input)?;
            let axis = input.try_parse(|i| scroll_timeline_axis::single_value::parse(context, i));

            names.push(name);
            axes.push(axis.unwrap_or_default());

            Ok(())
        })?;

        Ok(expanded! {
            scroll_timeline_name: scroll_timeline_name::SpecifiedValue(names.into()),
            scroll_timeline_axis: scroll_timeline_axis::SpecifiedValue(axes.into()),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            // If any value list length is differs then we don't do a shorthand serialization
            // either.
            let len = self.scroll_timeline_name.0.len();
            if len != self.scroll_timeline_axis.0.len() {
                return Ok(());
            }

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }

                self.scroll_timeline_name.0[i].to_css(dest)?;

                if self.scroll_timeline_axis.0[i] != Default::default() {
                    dest.write_char(' ')?;
                    self.scroll_timeline_axis.0[i].to_css(dest)?;
                }

            }
            Ok(())
        }
    }

    }


// Note: view-timeline shorthand doesn't take view-timeline-inset into account.


    /// https://drafts.csswg.org/scroll-animations-1/#view-timeline-shorthand
    pub mod view_timeline {
        use cssparser::Parser;
        use crate::parser::ParserContext;
        use crate::properties::{PropertyDeclaration, SourcePropertyDeclaration, MaybeBoxed, longhands};
        #[allow(unused_imports)]
        use selectors::parser::SelectorParseErrorKind;
        #[allow(unused_imports)]
        use std::fmt::{self, Write};
        #[allow(unused_imports)]
        use style_traits::{ParseError, StyleParseErrorKind};
        #[allow(unused_imports)]
        use style_traits::{CssWriter, KeywordsCollectFn, SpecifiedValueInfo, ToCss};

        #[derive(SpecifiedValueInfo)]
        pub struct Longhands {
                pub view_timeline_name:
                    longhands::view_timeline_name::SpecifiedValue
                    ,
                pub view_timeline_axis:
                    longhands::view_timeline_axis::SpecifiedValue
                    ,
        }

        /// Represents a serializable set of all of the longhand properties that
        /// correspond to a shorthand.
        pub struct LonghandsToSerialize<'a> {
                pub view_timeline_name:
                    &'a longhands::view_timeline_name::SpecifiedValue,
                pub view_timeline_axis:
                    &'a longhands::view_timeline_axis::SpecifiedValue,
        }

        impl<'a> LonghandsToSerialize<'a> {
            /// Tries to get a serializable set of longhands given a set of
            /// property declarations.
            pub fn from_iter(iter: impl Iterator<Item = &'a PropertyDeclaration>) -> Result<Self, ()> {
                // Define all of the expected variables that correspond to the shorthand
                    let mut view_timeline_name =
                        None::< &'a longhands::view_timeline_name::SpecifiedValue>;
                    let mut view_timeline_axis =
                        None::< &'a longhands::view_timeline_axis::SpecifiedValue>;

                // Attempt to assign the incoming declarations to the expected variables
                for declaration in iter {
                    match *declaration {
                            PropertyDeclaration::ViewTimelineName(ref value) => {
                                view_timeline_name = Some(value)
                            },
                            PropertyDeclaration::ViewTimelineAxis(ref value) => {
                                view_timeline_axis = Some(value)
                            },
                        _ => {}
                    };
                }

                // If any of the expected variables are missing, return an error
                match (
                        view_timeline_name,
                        view_timeline_axis,
                ) {

                    (
                        Some(view_timeline_name),
                        Some(view_timeline_axis),
                    ) =>
                    Ok(LonghandsToSerialize {
                            view_timeline_name,
                            view_timeline_axis,
                    }),
                    _ => Err(())
                }
            }
        }

        /// Parse the given shorthand and fill the result into the
        /// `declarations` vector.
        pub fn parse_into<'i, 't>(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>> {
            #[allow(unused_imports)]
            use crate::properties::{NonCustomPropertyId, LonghandId};
            input.parse_entirely(|input| parse_value(context, input)).map(|longhands| {
                    declarations.push(PropertyDeclaration::ViewTimelineName(
                        longhands.view_timeline_name
                    ));
                    declarations.push(PropertyDeclaration::ViewTimelineAxis(
                        longhands.view_timeline_axis
                    ));
            })
        }

        /// Try to serialize a given shorthand to a string.
        pub fn to_css(declarations: &[&PropertyDeclaration], dest: &mut crate::str::CssStringWriter) -> fmt::Result {
            match LonghandsToSerialize::from_iter(declarations.iter().cloned()) {
                Ok(longhands) => longhands.to_css(&mut CssWriter::new(dest)),
                Err(_) => Ok(())
            }
        }

        
    pub fn parse_value<'i>(
        context: &ParserContext,
        input: &mut Parser<'i, '_>,
    ) -> Result<Longhands, ParseError<'i>> {
        use crate::properties::longhands::{view_timeline_axis, view_timeline_name};

        let mut names = Vec::with_capacity(1);
        let mut axes = Vec::with_capacity(1);
        input.parse_comma_separated(|input| {
            let name = view_timeline_name::single_value::parse(context, input)?;
            let axis = input.try_parse(|i| view_timeline_axis::single_value::parse(context, i));

            names.push(name);
            axes.push(axis.unwrap_or_default());

            Ok(())
        })?;

        Ok(expanded! {
            view_timeline_name: view_timeline_name::SpecifiedValue(names.into()),
            view_timeline_axis: view_timeline_axis::SpecifiedValue(axes.into()),
        })
    }

    impl<'a> ToCss for LonghandsToSerialize<'a>  {
        fn to_css<W>(&self, dest: &mut CssWriter<W>) -> fmt::Result where W: fmt::Write {
            // If any value list length is differs then we don't do a shorthand serialization
            // either.
            let len = self.view_timeline_name.0.len();
            if len != self.view_timeline_axis.0.len() {
                return Ok(());
            }

            for i in 0..len {
                if i != 0 {
                    dest.write_str(", ")?;
                }

                self.view_timeline_name.0[i].to_css(dest)?;

                if self.view_timeline_axis.0[i] != Default::default() {
                    dest.write_char(' ')?;
                    self.view_timeline_axis.0[i].to_css(dest)?;
                }

            }
            Ok(())
        }
    }

    }


    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */


    // We didn't define the 'all' shorthand using the regular helpers:shorthand
    // mechanism, since it causes some very large types to be generated.
    //
    // Also, make sure logical properties appear before its physical
    // counter-parts, in order to prevent bugs like:
    //
    //   https://bugzilla.mozilla.org/show_bug.cgi?id=1410028
    //
    // FIXME(emilio): Adopt the resolution from:
    //
    //   https://github.com/w3c/csswg-drafts/issues/1898
    //
    // when there is one, whatever that is.
    
}



// WARNING: It is *really* important for the variants of `LonghandId`
// and `PropertyDeclaration` to be defined in the exact same order,
// with the exception of `CSSWideKeyword`, `WithVariables` and `Custom`,
// which don't exist in `LonghandId`.



/// Servo's representation for a property declaration.
#[derive(ToShmem)]
#[repr(u16)]
pub enum PropertyDeclaration {
    /// `align-content`
    AlignContent(crate::values::specified::AlignContent),
    /// `align-items`
    AlignItems(crate::values::specified::AlignItems),
    /// `align-self`
    AlignSelf(crate::values::specified::AlignSelf),
    /// `aspect-ratio`
    AspectRatio(crate::values::specified::AspectRatio),
    /// `backface-visibility`
    BackfaceVisibility(longhands::backface_visibility::SpecifiedValue),
    /// `baseline-source`
    BaselineSource(crate::values::specified::BaselineSource),
    /// `border-collapse`
    BorderCollapse(longhands::border_collapse::SpecifiedValue),
    /// `border-image-repeat`
    BorderImageRepeat(crate::values::specified::BorderImageRepeat),
    /// `box-decoration-break`
    BoxDecorationBreak(longhands::box_decoration_break::SpecifiedValue),
    /// `box-sizing`
    BoxSizing(longhands::box_sizing::SpecifiedValue),
    /// `break-inside`
    BreakInside(crate::values::specified::BreakWithin),
    /// `caption-side`
    CaptionSide(crate::values::specified::table::CaptionSide),
    /// `clear`
    Clear(crate::values::specified::Clear),
    /// `color-interpolation`
    ColorInterpolation(longhands::color_interpolation::SpecifiedValue),
    /// `color-interpolation-filters`
    ColorInterpolationFilters(longhands::color_interpolation_filters::SpecifiedValue),
    /// `column-count`
    ColumnCount(crate::values::specified::ColumnCount),
    /// `column-fill`
    ColumnFill(longhands::column_fill::SpecifiedValue),
    /// `column-span`
    ColumnSpan(longhands::column_span::SpecifiedValue),
    /// `contain`
    Contain(crate::values::specified::Contain),
    /// `container-type`
    ContainerType(crate::values::specified::ContainerType),
    /// `content-visibility`
    ContentVisibility(crate::values::specified::ContentVisibility),
    /// `direction`
    Direction(longhands::direction::SpecifiedValue),
    /// `display`
    Display(crate::values::specified::Display),
    /// `dominant-baseline`
    DominantBaseline(longhands::dominant_baseline::SpecifiedValue),
    /// `empty-cells`
    EmptyCells(longhands::empty_cells::SpecifiedValue),
    /// `flex-direction`
    FlexDirection(longhands::flex_direction::SpecifiedValue),
    /// `flex-wrap`
    FlexWrap(longhands::flex_wrap::SpecifiedValue),
    /// `float`
    Float(crate::values::specified::Float),
    /// `font-kerning`
    FontKerning(longhands::font_kerning::SpecifiedValue),
    /// `font-language-override`
    FontLanguageOverride(crate::values::specified::FontLanguageOverride),
    /// `font-optical-sizing`
    FontOpticalSizing(longhands::font_optical_sizing::SpecifiedValue),
    /// `font-size-adjust`
    FontSizeAdjust(crate::values::specified::FontSizeAdjust),
    /// `font-stretch`
    FontStretch(crate::values::specified::FontStretch),
    /// `font-style`
    FontStyle(crate::values::specified::FontStyle),
    /// `font-variant-caps`
    FontVariantCaps(longhands::font_variant_caps::SpecifiedValue),
    /// `font-variant-east-asian`
    FontVariantEastAsian(crate::values::specified::FontVariantEastAsian),
    /// `font-variant-emoji`
    FontVariantEmoji(longhands::font_variant_emoji::SpecifiedValue),
    /// `font-variant-ligatures`
    FontVariantLigatures(crate::values::specified::FontVariantLigatures),
    /// `font-variant-numeric`
    FontVariantNumeric(crate::values::specified::FontVariantNumeric),
    /// `font-variant-position`
    FontVariantPosition(longhands::font_variant_position::SpecifiedValue),
    /// `font-weight`
    FontWeight(crate::values::specified::FontWeight),
    /// `forced-color-adjust`
    ForcedColorAdjust(crate::values::specified::ForcedColorAdjust),
    /// `grid-auto-flow`
    GridAutoFlow(crate::values::specified::GridAutoFlow),
    /// `hyphens`
    Hyphens(longhands::hyphens::SpecifiedValue),
    /// `image-orientation`
    ImageOrientation(longhands::image_orientation::SpecifiedValue),
    /// `image-rendering`
    ImageRendering(crate::values::specified::ImageRendering),
    /// `ime-mode`
    ImeMode(longhands::ime_mode::SpecifiedValue),
    /// `initial-letter`
    InitialLetter(crate::values::specified::InitialLetter),
    /// `inset-area`
    InsetArea(crate::values::specified::InsetArea),
    /// `isolation`
    Isolation(longhands::isolation::SpecifiedValue),
    /// `justify-content`
    JustifyContent(crate::values::specified::JustifyContent),
    /// `justify-items`
    JustifyItems(crate::values::specified::JustifyItems),
    /// `justify-self`
    JustifySelf(crate::values::specified::JustifySelf),
    /// `line-break`
    LineBreak(crate::values::specified::LineBreak),
    /// `list-style-position`
    ListStylePosition(longhands::list_style_position::SpecifiedValue),
    /// `mask-type`
    MaskType(longhands::mask_type::SpecifiedValue),
    /// `masonry-auto-flow`
    MasonryAutoFlow(crate::values::specified::MasonryAutoFlow),
    /// `math-depth`
    MathDepth(crate::values::specified::MathDepth),
    /// `math-style`
    MathStyle(longhands::math_style::SpecifiedValue),
    /// `mix-blend-mode`
    MixBlendMode(longhands::mix_blend_mode::SpecifiedValue),
    /// `-moz-box-align`
    MozBoxAlign(longhands::_moz_box_align::SpecifiedValue),
    /// `-moz-box-collapse`
    MozBoxCollapse(longhands::_moz_box_collapse::SpecifiedValue),
    /// `-moz-box-direction`
    MozBoxDirection(longhands::_moz_box_direction::SpecifiedValue),
    /// `-moz-box-orient`
    MozBoxOrient(longhands::_moz_box_orient::SpecifiedValue),
    /// `-moz-box-pack`
    MozBoxPack(longhands::_moz_box_pack::SpecifiedValue),
    /// `-moz-control-character-visibility`
    MozControlCharacterVisibility(crate::values::specified::text::MozControlCharacterVisibility),
    /// `-moz-float-edge`
    MozFloatEdge(longhands::_moz_float_edge::SpecifiedValue),
    /// `-moz-inert`
    MozInert(longhands::_moz_inert::SpecifiedValue),
    /// `-moz-math-variant`
    MozMathVariant(longhands::_moz_math_variant::SpecifiedValue),
    /// `-moz-min-font-size-ratio`
    MozMinFontSizeRatio(crate::values::specified::Percentage),
    /// `-moz-orient`
    MozOrient(longhands::_moz_orient::SpecifiedValue),
    /// `-moz-osx-font-smoothing`
    MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::SpecifiedValue),
    /// `-moz-text-size-adjust`
    MozTextSizeAdjust(longhands::_moz_text_size_adjust::SpecifiedValue),
    /// `-moz-theme`
    MozTheme(crate::values::specified::ui::MozTheme),
    /// `-moz-top-layer`
    MozTopLayer(longhands::_moz_top_layer::SpecifiedValue),
    /// `-moz-user-focus`
    MozUserFocus(longhands::_moz_user_focus::SpecifiedValue),
    /// `-moz-user-input`
    MozUserInput(longhands::_moz_user_input::SpecifiedValue),
    /// `-moz-user-modify`
    MozUserModify(longhands::_moz_user_modify::SpecifiedValue),
    /// `-moz-window-dragging`
    MozWindowDragging(longhands::_moz_window_dragging::SpecifiedValue),
    /// `-moz-window-shadow`
    MozWindowShadow(longhands::_moz_window_shadow::SpecifiedValue),
    /// `object-fit`
    ObjectFit(longhands::object_fit::SpecifiedValue),
    /// `offset-rotate`
    OffsetRotate(crate::values::specified::OffsetRotate),
    /// `outline-style`
    OutlineStyle(crate::values::specified::OutlineStyle),
    /// `overflow-anchor`
    OverflowAnchor(crate::values::specified::OverflowAnchor),
    /// `overflow-wrap`
    OverflowWrap(crate::values::specified::OverflowWrap),
    /// `page-orientation`
    PageOrientation(crate::values::specified::PageOrientation),
    /// `paint-order`
    PaintOrder(crate::values::specified::SVGPaintOrder),
    /// `pointer-events`
    PointerEvents(longhands::pointer_events::SpecifiedValue),
    /// `position`
    Position(longhands::position::SpecifiedValue),
    /// `position-try-order`
    PositionTryOrder(crate::values::specified::PositionTryOrder),
    /// `position-visibility`
    PositionVisibility(crate::values::specified::PositionVisibility),
    /// `print-color-adjust`
    PrintColorAdjust(crate::values::specified::PrintColorAdjust),
    /// `resize`
    Resize(crate::values::specified::Resize),
    /// `ruby-align`
    RubyAlign(longhands::ruby_align::SpecifiedValue),
    /// `ruby-position`
    RubyPosition(crate::values::specified::RubyPosition),
    /// `scroll-behavior`
    ScrollBehavior(longhands::scroll_behavior::SpecifiedValue),
    /// `scroll-snap-align`
    ScrollSnapAlign(crate::values::specified::ScrollSnapAlign),
    /// `scroll-snap-stop`
    ScrollSnapStop(crate::values::specified::ScrollSnapStop),
    /// `scroll-snap-type`
    ScrollSnapType(crate::values::specified::ScrollSnapType),
    /// `scrollbar-gutter`
    ScrollbarGutter(crate::values::specified::ScrollbarGutter),
    /// `scrollbar-width`
    ScrollbarWidth(longhands::scrollbar_width::SpecifiedValue),
    /// `shape-rendering`
    ShapeRendering(longhands::shape_rendering::SpecifiedValue),
    /// `stroke-linecap`
    StrokeLinecap(longhands::stroke_linecap::SpecifiedValue),
    /// `stroke-linejoin`
    StrokeLinejoin(longhands::stroke_linejoin::SpecifiedValue),
    /// `table-layout`
    TableLayout(longhands::table_layout::SpecifiedValue),
    /// `text-align`
    TextAlign(crate::values::specified::TextAlign),
    /// `text-align-last`
    TextAlignLast(crate::values::specified::TextAlignLast),
    /// `text-anchor`
    TextAnchor(longhands::text_anchor::SpecifiedValue),
    /// `text-combine-upright`
    TextCombineUpright(longhands::text_combine_upright::SpecifiedValue),
    /// `text-decoration-line`
    TextDecorationLine(crate::values::specified::TextDecorationLine),
    /// `text-decoration-skip-ink`
    TextDecorationSkipInk(crate::values::specified::TextDecorationSkipInk),
    /// `text-decoration-style`
    TextDecorationStyle(longhands::text_decoration_style::SpecifiedValue),
    /// `text-emphasis-position`
    TextEmphasisPosition(crate::values::specified::TextEmphasisPosition),
    /// `text-justify`
    TextJustify(crate::values::specified::TextJustify),
    /// `text-orientation`
    TextOrientation(longhands::text_orientation::SpecifiedValue),
    /// `text-rendering`
    TextRendering(longhands::text_rendering::SpecifiedValue),
    /// `text-transform`
    TextTransform(crate::values::specified::TextTransform),
    /// `text-underline-position`
    TextUnderlinePosition(crate::values::specified::TextUnderlinePosition),
    /// `text-wrap-mode`
    TextWrapMode(longhands::text_wrap_mode::SpecifiedValue),
    /// `text-wrap-style`
    TextWrapStyle(longhands::text_wrap_style::SpecifiedValue),
    /// `touch-action`
    TouchAction(crate::values::specified::TouchAction),
    /// `transform-box`
    TransformBox(crate::values::specified::TransformBox),
    /// `transform-style`
    TransformStyle(crate::values::specified::TransformStyle),
    /// `unicode-bidi`
    UnicodeBidi(longhands::unicode_bidi::SpecifiedValue),
    /// `user-select`
    UserSelect(crate::values::specified::UserSelect),
    /// `vector-effect`
    VectorEffect(longhands::vector_effect::SpecifiedValue),
    /// `visibility`
    Visibility(longhands::visibility::SpecifiedValue),
    /// `-webkit-line-clamp`
    WebkitLineClamp(crate::values::specified::LineClamp),
    /// `-webkit-text-security`
    WebkitTextSecurity(longhands::_webkit_text_security::SpecifiedValue),
    /// `white-space-collapse`
    WhiteSpaceCollapse(longhands::white_space_collapse::SpecifiedValue),
    /// `word-break`
    WordBreak(crate::values::specified::WordBreak),
    /// `writing-mode`
    WritingMode(longhands::writing_mode::SpecifiedValue),
    /// `-x-text-scale`
    XTextScale(crate::values::specified::XTextScale),
    /// `z-index`
    ZIndex(crate::values::specified::ZIndex),
    /// `zoom`
    Zoom(crate::values::specified::Zoom),
    /// `appearance`
    Appearance(crate::values::specified::Appearance),
    /// `-moz-default-appearance`
    MozDefaultAppearance(crate::values::specified::Appearance),
    /// `-moz-force-broken-image-icon`
    MozForceBrokenImageIcon(crate::values::specified::BoolInteger),
    /// `-moz-subtree-hidden-only-visually`
    MozSubtreeHiddenOnlyVisually(crate::values::specified::BoolInteger),
    /// `break-after`
    BreakAfter(crate::values::specified::BreakBetween),
    /// `break-before`
    BreakBefore(crate::values::specified::BreakBetween),
    /// `clip-rule`
    ClipRule(crate::values::specified::FillRule),
    /// `fill-rule`
    FillRule(crate::values::specified::FillRule),
    /// `overflow-clip-box-block`
    OverflowClipBoxBlock(crate::values::specified::OverflowClipBox),
    /// `overflow-clip-box-inline`
    OverflowClipBoxInline(crate::values::specified::OverflowClipBox),
    /// `fill-opacity`
    FillOpacity(crate::values::specified::SVGOpacity),
    /// `stroke-opacity`
    StrokeOpacity(crate::values::specified::SVGOpacity),
    /// `-moz-box-ordinal-group`
    MozBoxOrdinalGroup(crate::values::specified::Integer),
    /// `order`
    Order(crate::values::specified::Integer),
    /// `-x-span`
    XSpan(crate::values::specified::Integer),
    /// `font-synthesis-position`
    FontSynthesisPosition(crate::values::specified::FontSynthesis),
    /// `font-synthesis-small-caps`
    FontSynthesisSmallCaps(crate::values::specified::FontSynthesis),
    /// `font-synthesis-style`
    FontSynthesisStyle(crate::values::specified::FontSynthesis),
    /// `font-synthesis-weight`
    FontSynthesisWeight(crate::values::specified::FontSynthesis),
    /// `flex-grow`
    FlexGrow(crate::values::specified::NonNegativeNumber),
    /// `flex-shrink`
    FlexShrink(crate::values::specified::NonNegativeNumber),
    /// `-moz-box-flex`
    MozBoxFlex(crate::values::specified::NonNegativeNumber),
    /// `stroke-miterlimit`
    StrokeMiterlimit(crate::values::specified::NonNegativeNumber),
    /// `overflow-block`
    OverflowBlock(crate::values::specified::Overflow),
    /// `overflow-inline`
    OverflowInline(crate::values::specified::Overflow),
    /// `overflow-x`
    OverflowX(crate::values::specified::Overflow),
    /// `overflow-y`
    OverflowY(crate::values::specified::Overflow),
    /// `overscroll-behavior-block`
    OverscrollBehaviorBlock(crate::values::specified::OverscrollBehavior),
    /// `overscroll-behavior-inline`
    OverscrollBehaviorInline(crate::values::specified::OverscrollBehavior),
    /// `overscroll-behavior-x`
    OverscrollBehaviorX(crate::values::specified::OverscrollBehavior),
    /// `overscroll-behavior-y`
    OverscrollBehaviorY(crate::values::specified::OverscrollBehavior),
    /// `flood-opacity`
    FloodOpacity(crate::values::specified::Opacity),
    /// `-moz-window-opacity`
    MozWindowOpacity(crate::values::specified::Opacity),
    /// `opacity`
    Opacity(crate::values::specified::Opacity),
    /// `shape-image-threshold`
    ShapeImageThreshold(crate::values::specified::Opacity),
    /// `stop-opacity`
    StopOpacity(crate::values::specified::Opacity),
    /// `border-block-end-style`
    BorderBlockEndStyle(crate::values::specified::BorderStyle),
    /// `border-block-start-style`
    BorderBlockStartStyle(crate::values::specified::BorderStyle),
    /// `border-bottom-style`
    BorderBottomStyle(crate::values::specified::BorderStyle),
    /// `border-inline-end-style`
    BorderInlineEndStyle(crate::values::specified::BorderStyle),
    /// `border-inline-start-style`
    BorderInlineStartStyle(crate::values::specified::BorderStyle),
    /// `border-left-style`
    BorderLeftStyle(crate::values::specified::BorderStyle),
    /// `border-right-style`
    BorderRightStyle(crate::values::specified::BorderStyle),
    /// `border-top-style`
    BorderTopStyle(crate::values::specified::BorderStyle),
    /// `column-rule-style`
    ColumnRuleStyle(crate::values::specified::BorderStyle),
    /// `accent-color`
    AccentColor(crate::values::specified::ColorOrAuto),
    /// `anchor-name`
    AnchorName(crate::values::specified::AnchorName),
    /// `anchor-scope`
    AnchorScope(crate::values::specified::AnchorScope),
    /// `animation-composition`
    AnimationComposition(longhands::animation_composition::SpecifiedValue),
    /// `animation-delay`
    AnimationDelay(longhands::animation_delay::SpecifiedValue),
    /// `animation-direction`
    AnimationDirection(longhands::animation_direction::SpecifiedValue),
    /// `animation-duration`
    AnimationDuration(longhands::animation_duration::SpecifiedValue),
    /// `animation-fill-mode`
    AnimationFillMode(longhands::animation_fill_mode::SpecifiedValue),
    /// `animation-iteration-count`
    AnimationIterationCount(longhands::animation_iteration_count::SpecifiedValue),
    /// `animation-name`
    AnimationName(longhands::animation_name::SpecifiedValue),
    /// `animation-play-state`
    AnimationPlayState(longhands::animation_play_state::SpecifiedValue),
    /// `animation-timeline`
    AnimationTimeline(longhands::animation_timeline::SpecifiedValue),
    /// `animation-timing-function`
    AnimationTimingFunction(longhands::animation_timing_function::SpecifiedValue),
    /// `backdrop-filter`
    BackdropFilter(longhands::backdrop_filter::SpecifiedValue),
    /// `background-attachment`
    BackgroundAttachment(longhands::background_attachment::SpecifiedValue),
    /// `background-blend-mode`
    BackgroundBlendMode(longhands::background_blend_mode::SpecifiedValue),
    /// `background-clip`
    BackgroundClip(longhands::background_clip::SpecifiedValue),
    /// `background-image`
    BackgroundImage(longhands::background_image::SpecifiedValue),
    /// `background-origin`
    BackgroundOrigin(longhands::background_origin::SpecifiedValue),
    /// `background-position-x`
    BackgroundPositionX(longhands::background_position_x::SpecifiedValue),
    /// `background-position-y`
    BackgroundPositionY(longhands::background_position_y::SpecifiedValue),
    /// `background-repeat`
    BackgroundRepeat(longhands::background_repeat::SpecifiedValue),
    /// `background-size`
    BackgroundSize(longhands::background_size::SpecifiedValue),
    /// `border-image-outset`
    BorderImageOutset(Box<crate::values::specified::NonNegativeLengthOrNumberRect>),
    /// `border-image-slice`
    BorderImageSlice(Box<crate::values::specified::BorderImageSlice>),
    /// `border-image-width`
    BorderImageWidth(Box<crate::values::specified::BorderImageWidth>),
    /// `border-spacing`
    BorderSpacing(Box<crate::values::specified::BorderSpacing>),
    /// `box-shadow`
    BoxShadow(longhands::box_shadow::SpecifiedValue),
    /// `caret-color`
    CaretColor(crate::values::specified::color::CaretColor),
    /// `clip`
    Clip(Box<crate::values::specified::ClipRectOrAuto>),
    /// `clip-path`
    ClipPath(crate::values::specified::basic_shape::ClipPath),
    /// `color`
    Color(crate::values::specified::ColorPropertyValue),
    /// `color-scheme`
    ColorScheme(crate::values::specified::ColorScheme),
    /// `column-width`
    ColumnWidth(crate::values::specified::length::NonNegativeLengthOrAuto),
    /// `container-name`
    ContainerName(crate::values::specified::ContainerName),
    /// `content`
    Content(crate::values::specified::Content),
    /// `counter-increment`
    CounterIncrement(crate::values::specified::CounterIncrement),
    /// `counter-reset`
    CounterReset(crate::values::specified::CounterReset),
    /// `counter-set`
    CounterSet(crate::values::specified::CounterSet),
    /// `cursor`
    Cursor(crate::values::specified::Cursor),
    /// `d`
    D(crate::values::specified::DProperty),
    /// `filter`
    Filter(longhands::filter::SpecifiedValue),
    /// `flex-basis`
    FlexBasis(Box<crate::values::specified::FlexBasis>),
    /// `font-family`
    FontFamily(crate::values::specified::FontFamily),
    /// `font-feature-settings`
    FontFeatureSettings(crate::values::specified::FontFeatureSettings),
    /// `font-palette`
    FontPalette(crate::values::specified::FontPalette),
    /// `font-size`
    FontSize(crate::values::specified::FontSize),
    /// `font-variant-alternates`
    FontVariantAlternates(crate::values::specified::FontVariantAlternates),
    /// `font-variation-settings`
    FontVariationSettings(crate::values::specified::FontVariationSettings),
    /// `grid-template-areas`
    GridTemplateAreas(crate::values::specified::GridTemplateAreas),
    /// `hyphenate-character`
    HyphenateCharacter(crate::values::specified::HyphenateCharacter),
    /// `letter-spacing`
    LetterSpacing(crate::values::specified::LetterSpacing),
    /// `line-height`
    LineHeight(crate::values::specified::LineHeight),
    /// `list-style-type`
    ListStyleType(crate::values::specified::ListStyleType),
    /// `mask-clip`
    MaskClip(longhands::mask_clip::SpecifiedValue),
    /// `mask-composite`
    MaskComposite(longhands::mask_composite::SpecifiedValue),
    /// `mask-image`
    MaskImage(longhands::mask_image::SpecifiedValue),
    /// `mask-mode`
    MaskMode(longhands::mask_mode::SpecifiedValue),
    /// `mask-origin`
    MaskOrigin(longhands::mask_origin::SpecifiedValue),
    /// `mask-position-x`
    MaskPositionX(longhands::mask_position_x::SpecifiedValue),
    /// `mask-position-y`
    MaskPositionY(longhands::mask_position_y::SpecifiedValue),
    /// `mask-repeat`
    MaskRepeat(longhands::mask_repeat::SpecifiedValue),
    /// `mask-size`
    MaskSize(longhands::mask_size::SpecifiedValue),
    /// `-moz-context-properties`
    MozContextProperties(crate::values::specified::MozContextProperties),
    /// `offset-anchor`
    OffsetAnchor(Box<crate::values::specified::PositionOrAuto>),
    /// `offset-path`
    OffsetPath(crate::values::specified::OffsetPath),
    /// `offset-position`
    OffsetPosition(Box<crate::values::specified::OffsetPosition>),
    /// `page`
    Page(crate::values::specified::PageName),
    /// `perspective`
    Perspective(crate::values::specified::Perspective),
    /// `position-anchor`
    PositionAnchor(crate::values::specified::PositionAnchor),
    /// `position-try-options`
    PositionTryOptions(crate::values::specified::PositionTryOptions),
    /// `quotes`
    Quotes(crate::values::specified::Quotes),
    /// `rotate`
    Rotate(Box<crate::values::specified::Rotate>),
    /// `scale`
    Scale(Box<crate::values::specified::Scale>),
    /// `scroll-timeline-axis`
    ScrollTimelineAxis(longhands::scroll_timeline_axis::SpecifiedValue),
    /// `scroll-timeline-name`
    ScrollTimelineName(longhands::scroll_timeline_name::SpecifiedValue),
    /// `scrollbar-color`
    ScrollbarColor(Box<crate::values::specified::ui::ScrollbarColor>),
    /// `shape-outside`
    ShapeOutside(crate::values::specified::basic_shape::ShapeOutside),
    /// `size`
    Size(Box<crate::values::specified::PageSize>),
    /// `stroke-dasharray`
    StrokeDasharray(crate::values::specified::SVGStrokeDashArray),
    /// `stroke-dashoffset`
    StrokeDashoffset(crate::values::specified::SVGLength),
    /// `stroke-width`
    StrokeWidth(crate::values::specified::SVGWidth),
    /// `tab-size`
    TabSize(crate::values::specified::NonNegativeLengthOrNumber),
    /// `text-decoration-thickness`
    TextDecorationThickness(crate::values::specified::TextDecorationLength),
    /// `text-emphasis-style`
    TextEmphasisStyle(crate::values::specified::TextEmphasisStyle),
    /// `text-indent`
    TextIndent(crate::values::specified::TextIndent),
    /// `text-overflow`
    TextOverflow(Box<crate::values::specified::TextOverflow>),
    /// `text-shadow`
    TextShadow(longhands::text_shadow::SpecifiedValue),
    /// `transition-behavior`
    TransitionBehavior(longhands::transition_behavior::SpecifiedValue),
    /// `transition-delay`
    TransitionDelay(longhands::transition_delay::SpecifiedValue),
    /// `transition-duration`
    TransitionDuration(longhands::transition_duration::SpecifiedValue),
    /// `transition-property`
    TransitionProperty(longhands::transition_property::SpecifiedValue),
    /// `transition-timing-function`
    TransitionTimingFunction(longhands::transition_timing_function::SpecifiedValue),
    /// `translate`
    Translate(Box<crate::values::specified::Translate>),
    /// `vertical-align`
    VerticalAlign(crate::values::specified::VerticalAlign),
    /// `view-timeline-axis`
    ViewTimelineAxis(longhands::view_timeline_axis::SpecifiedValue),
    /// `view-timeline-inset`
    ViewTimelineInset(longhands::view_timeline_inset::SpecifiedValue),
    /// `view-timeline-name`
    ViewTimelineName(longhands::view_timeline_name::SpecifiedValue),
    /// `-webkit-text-stroke-width`
    WebkitTextStrokeWidth(crate::values::specified::LineWidth),
    /// `will-change`
    WillChange(crate::values::specified::WillChange),
    /// `word-spacing`
    WordSpacing(crate::values::specified::WordSpacing),
    /// `-x-lang`
    XLang(crate::values::specified::XLang),
    /// `object-position`
    ObjectPosition(Box<crate::values::specified::Position>),
    /// `perspective-origin`
    PerspectiveOrigin(Box<crate::values::specified::Position>),
    /// `fill`
    Fill(Box<crate::values::specified::SVGPaint>),
    /// `stroke`
    Stroke(Box<crate::values::specified::SVGPaint>),
    /// `-moz-window-transform-origin`
    MozWindowTransformOrigin(Box<crate::values::specified::TransformOrigin>),
    /// `transform-origin`
    TransformOrigin(Box<crate::values::specified::TransformOrigin>),
    /// `grid-template-columns`
    GridTemplateColumns(crate::values::specified::GridTemplateComponent),
    /// `grid-template-rows`
    GridTemplateRows(crate::values::specified::GridTemplateComponent),
    /// `border-image-source`
    BorderImageSource(crate::values::specified::Image),
    /// `list-style-image`
    ListStyleImage(crate::values::specified::Image),
    /// `grid-auto-columns`
    GridAutoColumns(crate::values::specified::ImplicitGridTracks),
    /// `grid-auto-rows`
    GridAutoRows(crate::values::specified::ImplicitGridTracks),
    /// `-moz-window-transform`
    MozWindowTransform(crate::values::specified::Transform),
    /// `transform`
    Transform(crate::values::specified::Transform),
    /// `column-gap`
    ColumnGap(crate::values::specified::length::NonNegativeLengthPercentageOrNormal),
    /// `row-gap`
    RowGap(crate::values::specified::length::NonNegativeLengthPercentageOrNormal),
    /// `marker-end`
    MarkerEnd(crate::values::specified::url::UrlOrNone),
    /// `marker-mid`
    MarkerMid(crate::values::specified::url::UrlOrNone),
    /// `marker-start`
    MarkerStart(crate::values::specified::url::UrlOrNone),
    /// `contain-intrinsic-block-size`
    ContainIntrinsicBlockSize(crate::values::specified::ContainIntrinsicSize),
    /// `contain-intrinsic-height`
    ContainIntrinsicHeight(crate::values::specified::ContainIntrinsicSize),
    /// `contain-intrinsic-inline-size`
    ContainIntrinsicInlineSize(crate::values::specified::ContainIntrinsicSize),
    /// `contain-intrinsic-width`
    ContainIntrinsicWidth(crate::values::specified::ContainIntrinsicSize),
    /// `grid-column-end`
    GridColumnEnd(crate::values::specified::GridLine),
    /// `grid-column-start`
    GridColumnStart(crate::values::specified::GridLine),
    /// `grid-row-end`
    GridRowEnd(crate::values::specified::GridLine),
    /// `grid-row-start`
    GridRowStart(crate::values::specified::GridLine),
    /// `max-block-size`
    MaxBlockSize(crate::values::specified::MaxSize),
    /// `max-height`
    MaxHeight(crate::values::specified::MaxSize),
    /// `max-inline-size`
    MaxInlineSize(crate::values::specified::MaxSize),
    /// `max-width`
    MaxWidth(crate::values::specified::MaxSize),
    /// `cx`
    Cx(crate::values::specified::LengthPercentage),
    /// `cy`
    Cy(crate::values::specified::LengthPercentage),
    /// `offset-distance`
    OffsetDistance(crate::values::specified::LengthPercentage),
    /// `x`
    X(crate::values::specified::LengthPercentage),
    /// `y`
    Y(crate::values::specified::LengthPercentage),
    /// `border-bottom-left-radius`
    BorderBottomLeftRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `border-bottom-right-radius`
    BorderBottomRightRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `border-end-end-radius`
    BorderEndEndRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `border-end-start-radius`
    BorderEndStartRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `border-start-end-radius`
    BorderStartEndRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `border-start-start-radius`
    BorderStartStartRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `border-top-left-radius`
    BorderTopLeftRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `border-top-right-radius`
    BorderTopRightRadius(Box<crate::values::specified::BorderCornerRadius>),
    /// `block-size`
    BlockSize(crate::values::specified::Size),
    /// `height`
    Height(crate::values::specified::Size),
    /// `inline-size`
    InlineSize(crate::values::specified::Size),
    /// `min-block-size`
    MinBlockSize(crate::values::specified::Size),
    /// `min-height`
    MinHeight(crate::values::specified::Size),
    /// `min-inline-size`
    MinInlineSize(crate::values::specified::Size),
    /// `min-width`
    MinWidth(crate::values::specified::Size),
    /// `width`
    Width(crate::values::specified::Size),
    /// `border-block-end-width`
    BorderBlockEndWidth(crate::values::specified::BorderSideWidth),
    /// `border-block-start-width`
    BorderBlockStartWidth(crate::values::specified::BorderSideWidth),
    /// `border-bottom-width`
    BorderBottomWidth(crate::values::specified::BorderSideWidth),
    /// `border-inline-end-width`
    BorderInlineEndWidth(crate::values::specified::BorderSideWidth),
    /// `border-inline-start-width`
    BorderInlineStartWidth(crate::values::specified::BorderSideWidth),
    /// `border-left-width`
    BorderLeftWidth(crate::values::specified::BorderSideWidth),
    /// `border-right-width`
    BorderRightWidth(crate::values::specified::BorderSideWidth),
    /// `border-top-width`
    BorderTopWidth(crate::values::specified::BorderSideWidth),
    /// `column-rule-width`
    ColumnRuleWidth(crate::values::specified::BorderSideWidth),
    /// `outline-width`
    OutlineWidth(crate::values::specified::BorderSideWidth),
    /// `padding-block-end`
    PaddingBlockEnd(crate::values::specified::NonNegativeLengthPercentage),
    /// `padding-block-start`
    PaddingBlockStart(crate::values::specified::NonNegativeLengthPercentage),
    /// `padding-bottom`
    PaddingBottom(crate::values::specified::NonNegativeLengthPercentage),
    /// `padding-inline-end`
    PaddingInlineEnd(crate::values::specified::NonNegativeLengthPercentage),
    /// `padding-inline-start`
    PaddingInlineStart(crate::values::specified::NonNegativeLengthPercentage),
    /// `padding-left`
    PaddingLeft(crate::values::specified::NonNegativeLengthPercentage),
    /// `padding-right`
    PaddingRight(crate::values::specified::NonNegativeLengthPercentage),
    /// `padding-top`
    PaddingTop(crate::values::specified::NonNegativeLengthPercentage),
    /// `r`
    R(crate::values::specified::NonNegativeLengthPercentage),
    /// `shape-margin`
    ShapeMargin(crate::values::specified::NonNegativeLengthPercentage),
    /// `rx`
    Rx(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `ry`
    Ry(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-block-end`
    ScrollPaddingBlockEnd(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-block-start`
    ScrollPaddingBlockStart(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-bottom`
    ScrollPaddingBottom(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-inline-end`
    ScrollPaddingInlineEnd(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-inline-start`
    ScrollPaddingInlineStart(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-left`
    ScrollPaddingLeft(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-right`
    ScrollPaddingRight(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `scroll-padding-top`
    ScrollPaddingTop(crate::values::specified::NonNegativeLengthPercentageOrAuto),
    /// `-moz-window-input-region-margin`
    MozWindowInputRegionMargin(crate::values::specified::Length),
    /// `outline-offset`
    OutlineOffset(crate::values::specified::Length),
    /// `overflow-clip-margin`
    OverflowClipMargin(crate::values::specified::Length),
    /// `scroll-margin-block-end`
    ScrollMarginBlockEnd(crate::values::specified::Length),
    /// `scroll-margin-block-start`
    ScrollMarginBlockStart(crate::values::specified::Length),
    /// `scroll-margin-bottom`
    ScrollMarginBottom(crate::values::specified::Length),
    /// `scroll-margin-inline-end`
    ScrollMarginInlineEnd(crate::values::specified::Length),
    /// `scroll-margin-inline-start`
    ScrollMarginInlineStart(crate::values::specified::Length),
    /// `scroll-margin-left`
    ScrollMarginLeft(crate::values::specified::Length),
    /// `scroll-margin-right`
    ScrollMarginRight(crate::values::specified::Length),
    /// `scroll-margin-top`
    ScrollMarginTop(crate::values::specified::Length),
    /// `bottom`
    Bottom(crate::values::specified::LengthPercentageOrAuto),
    /// `inset-block-end`
    InsetBlockEnd(crate::values::specified::LengthPercentageOrAuto),
    /// `inset-block-start`
    InsetBlockStart(crate::values::specified::LengthPercentageOrAuto),
    /// `inset-inline-end`
    InsetInlineEnd(crate::values::specified::LengthPercentageOrAuto),
    /// `inset-inline-start`
    InsetInlineStart(crate::values::specified::LengthPercentageOrAuto),
    /// `left`
    Left(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-block-end`
    MarginBlockEnd(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-block-start`
    MarginBlockStart(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-bottom`
    MarginBottom(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-inline-end`
    MarginInlineEnd(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-inline-start`
    MarginInlineStart(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-left`
    MarginLeft(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-right`
    MarginRight(crate::values::specified::LengthPercentageOrAuto),
    /// `margin-top`
    MarginTop(crate::values::specified::LengthPercentageOrAuto),
    /// `right`
    Right(crate::values::specified::LengthPercentageOrAuto),
    /// `text-underline-offset`
    TextUnderlineOffset(crate::values::specified::LengthPercentageOrAuto),
    /// `top`
    Top(crate::values::specified::LengthPercentageOrAuto),
    /// `background-color`
    BackgroundColor(crate::values::specified::Color),
    /// `border-block-end-color`
    BorderBlockEndColor(crate::values::specified::Color),
    /// `border-block-start-color`
    BorderBlockStartColor(crate::values::specified::Color),
    /// `border-bottom-color`
    BorderBottomColor(crate::values::specified::Color),
    /// `border-inline-end-color`
    BorderInlineEndColor(crate::values::specified::Color),
    /// `border-inline-start-color`
    BorderInlineStartColor(crate::values::specified::Color),
    /// `border-left-color`
    BorderLeftColor(crate::values::specified::Color),
    /// `border-right-color`
    BorderRightColor(crate::values::specified::Color),
    /// `border-top-color`
    BorderTopColor(crate::values::specified::Color),
    /// `column-rule-color`
    ColumnRuleColor(crate::values::specified::Color),
    /// `flood-color`
    FloodColor(crate::values::specified::Color),
    /// `lighting-color`
    LightingColor(crate::values::specified::Color),
    /// `outline-color`
    OutlineColor(crate::values::specified::Color),
    /// `stop-color`
    StopColor(crate::values::specified::Color),
    /// `text-decoration-color`
    TextDecorationColor(crate::values::specified::Color),
    /// `text-emphasis-color`
    TextEmphasisColor(crate::values::specified::Color),
    /// `-webkit-text-fill-color`
    WebkitTextFillColor(crate::values::specified::Color),
    /// `-webkit-text-stroke-color`
    WebkitTextStrokeColor(crate::values::specified::Color),
    /// A CSS-wide keyword.
    CSSWideKeyword(WideKeywordDeclaration),
    /// An unparsed declaration.
    WithVariables(VariableDeclaration),
    /// A custom property declaration.
    Custom(CustomDeclaration),
}

// There's one of these for each parsed declaration so it better be small.
size_of_test!(PropertyDeclaration, 32);

#[repr(C)]
struct PropertyDeclarationVariantRepr<T> {
    tag: u16,
    value: T
}

impl Clone for PropertyDeclaration {
    #[inline]
    fn clone(&self) -> Self {
        use self::PropertyDeclaration::*;

        

        let self_tag = unsafe {
            (*(self as *const _ as *const PropertyDeclarationVariantRepr<()>)).tag
        };
        if self_tag <= LonghandId::ColumnRuleStyle as u16 {
            #[derive(Clone, Copy)]
            #[repr(u16)]
            enum CopyVariants {
                _AlignContent(crate::values::specified::AlignContent),
                _AlignItems(crate::values::specified::AlignItems),
                _AlignSelf(crate::values::specified::AlignSelf),
                _AspectRatio(crate::values::specified::AspectRatio),
                _BackfaceVisibility(longhands::backface_visibility::SpecifiedValue),
                _BaselineSource(crate::values::specified::BaselineSource),
                _BorderCollapse(longhands::border_collapse::SpecifiedValue),
                _BorderImageRepeat(crate::values::specified::BorderImageRepeat),
                _BoxDecorationBreak(longhands::box_decoration_break::SpecifiedValue),
                _BoxSizing(longhands::box_sizing::SpecifiedValue),
                _BreakInside(crate::values::specified::BreakWithin),
                _CaptionSide(crate::values::specified::table::CaptionSide),
                _Clear(crate::values::specified::Clear),
                _ColorInterpolation(longhands::color_interpolation::SpecifiedValue),
                _ColorInterpolationFilters(longhands::color_interpolation_filters::SpecifiedValue),
                _ColumnCount(crate::values::specified::ColumnCount),
                _ColumnFill(longhands::column_fill::SpecifiedValue),
                _ColumnSpan(longhands::column_span::SpecifiedValue),
                _Contain(crate::values::specified::Contain),
                _ContainerType(crate::values::specified::ContainerType),
                _ContentVisibility(crate::values::specified::ContentVisibility),
                _Direction(longhands::direction::SpecifiedValue),
                _Display(crate::values::specified::Display),
                _DominantBaseline(longhands::dominant_baseline::SpecifiedValue),
                _EmptyCells(longhands::empty_cells::SpecifiedValue),
                _FlexDirection(longhands::flex_direction::SpecifiedValue),
                _FlexWrap(longhands::flex_wrap::SpecifiedValue),
                _Float(crate::values::specified::Float),
                _FontKerning(longhands::font_kerning::SpecifiedValue),
                _FontLanguageOverride(crate::values::specified::FontLanguageOverride),
                _FontOpticalSizing(longhands::font_optical_sizing::SpecifiedValue),
                _FontSizeAdjust(crate::values::specified::FontSizeAdjust),
                _FontStretch(crate::values::specified::FontStretch),
                _FontStyle(crate::values::specified::FontStyle),
                _FontVariantCaps(longhands::font_variant_caps::SpecifiedValue),
                _FontVariantEastAsian(crate::values::specified::FontVariantEastAsian),
                _FontVariantEmoji(longhands::font_variant_emoji::SpecifiedValue),
                _FontVariantLigatures(crate::values::specified::FontVariantLigatures),
                _FontVariantNumeric(crate::values::specified::FontVariantNumeric),
                _FontVariantPosition(longhands::font_variant_position::SpecifiedValue),
                _FontWeight(crate::values::specified::FontWeight),
                _ForcedColorAdjust(crate::values::specified::ForcedColorAdjust),
                _GridAutoFlow(crate::values::specified::GridAutoFlow),
                _Hyphens(longhands::hyphens::SpecifiedValue),
                _ImageOrientation(longhands::image_orientation::SpecifiedValue),
                _ImageRendering(crate::values::specified::ImageRendering),
                _ImeMode(longhands::ime_mode::SpecifiedValue),
                _InitialLetter(crate::values::specified::InitialLetter),
                _InsetArea(crate::values::specified::InsetArea),
                _Isolation(longhands::isolation::SpecifiedValue),
                _JustifyContent(crate::values::specified::JustifyContent),
                _JustifyItems(crate::values::specified::JustifyItems),
                _JustifySelf(crate::values::specified::JustifySelf),
                _LineBreak(crate::values::specified::LineBreak),
                _ListStylePosition(longhands::list_style_position::SpecifiedValue),
                _MaskType(longhands::mask_type::SpecifiedValue),
                _MasonryAutoFlow(crate::values::specified::MasonryAutoFlow),
                _MathDepth(crate::values::specified::MathDepth),
                _MathStyle(longhands::math_style::SpecifiedValue),
                _MixBlendMode(longhands::mix_blend_mode::SpecifiedValue),
                _MozBoxAlign(longhands::_moz_box_align::SpecifiedValue),
                _MozBoxCollapse(longhands::_moz_box_collapse::SpecifiedValue),
                _MozBoxDirection(longhands::_moz_box_direction::SpecifiedValue),
                _MozBoxOrient(longhands::_moz_box_orient::SpecifiedValue),
                _MozBoxPack(longhands::_moz_box_pack::SpecifiedValue),
                _MozControlCharacterVisibility(crate::values::specified::text::MozControlCharacterVisibility),
                _MozFloatEdge(longhands::_moz_float_edge::SpecifiedValue),
                _MozInert(longhands::_moz_inert::SpecifiedValue),
                _MozMathVariant(longhands::_moz_math_variant::SpecifiedValue),
                _MozMinFontSizeRatio(crate::values::specified::Percentage),
                _MozOrient(longhands::_moz_orient::SpecifiedValue),
                _MozOsxFontSmoothing(longhands::_moz_osx_font_smoothing::SpecifiedValue),
                _MozTextSizeAdjust(longhands::_moz_text_size_adjust::SpecifiedValue),
                _MozTheme(crate::values::specified::ui::MozTheme),
                _MozTopLayer(longhands::_moz_top_layer::SpecifiedValue),
                _MozUserFocus(longhands::_moz_user_focus::SpecifiedValue),
                _MozUserInput(longhands::_moz_user_input::SpecifiedValue),
                _MozUserModify(longhands::_moz_user_modify::SpecifiedValue),
                _MozWindowDragging(longhands::_moz_window_dragging::SpecifiedValue),
                _MozWindowShadow(longhands::_moz_window_shadow::SpecifiedValue),
                _ObjectFit(longhands::object_fit::SpecifiedValue),
                _OffsetRotate(crate::values::specified::OffsetRotate),
                _OutlineStyle(crate::values::specified::OutlineStyle),
                _OverflowAnchor(crate::values::specified::OverflowAnchor),
                _OverflowWrap(crate::values::specified::OverflowWrap),
                _PageOrientation(crate::values::specified::PageOrientation),
                _PaintOrder(crate::values::specified::SVGPaintOrder),
                _PointerEvents(longhands::pointer_events::SpecifiedValue),
                _Position(longhands::position::SpecifiedValue),
                _PositionTryOrder(crate::values::specified::PositionTryOrder),
                _PositionVisibility(crate::values::specified::PositionVisibility),
                _PrintColorAdjust(crate::values::specified::PrintColorAdjust),
                _Resize(crate::values::specified::Resize),
                _RubyAlign(longhands::ruby_align::SpecifiedValue),
                _RubyPosition(crate::values::specified::RubyPosition),
                _ScrollBehavior(longhands::scroll_behavior::SpecifiedValue),
                _ScrollSnapAlign(crate::values::specified::ScrollSnapAlign),
                _ScrollSnapStop(crate::values::specified::ScrollSnapStop),
                _ScrollSnapType(crate::values::specified::ScrollSnapType),
                _ScrollbarGutter(crate::values::specified::ScrollbarGutter),
                _ScrollbarWidth(longhands::scrollbar_width::SpecifiedValue),
                _ShapeRendering(longhands::shape_rendering::SpecifiedValue),
                _StrokeLinecap(longhands::stroke_linecap::SpecifiedValue),
                _StrokeLinejoin(longhands::stroke_linejoin::SpecifiedValue),
                _TableLayout(longhands::table_layout::SpecifiedValue),
                _TextAlign(crate::values::specified::TextAlign),
                _TextAlignLast(crate::values::specified::TextAlignLast),
                _TextAnchor(longhands::text_anchor::SpecifiedValue),
                _TextCombineUpright(longhands::text_combine_upright::SpecifiedValue),
                _TextDecorationLine(crate::values::specified::TextDecorationLine),
                _TextDecorationSkipInk(crate::values::specified::TextDecorationSkipInk),
                _TextDecorationStyle(longhands::text_decoration_style::SpecifiedValue),
                _TextEmphasisPosition(crate::values::specified::TextEmphasisPosition),
                _TextJustify(crate::values::specified::TextJustify),
                _TextOrientation(longhands::text_orientation::SpecifiedValue),
                _TextRendering(longhands::text_rendering::SpecifiedValue),
                _TextTransform(crate::values::specified::TextTransform),
                _TextUnderlinePosition(crate::values::specified::TextUnderlinePosition),
                _TextWrapMode(longhands::text_wrap_mode::SpecifiedValue),
                _TextWrapStyle(longhands::text_wrap_style::SpecifiedValue),
                _TouchAction(crate::values::specified::TouchAction),
                _TransformBox(crate::values::specified::TransformBox),
                _TransformStyle(crate::values::specified::TransformStyle),
                _UnicodeBidi(longhands::unicode_bidi::SpecifiedValue),
                _UserSelect(crate::values::specified::UserSelect),
                _VectorEffect(longhands::vector_effect::SpecifiedValue),
                _Visibility(longhands::visibility::SpecifiedValue),
                _WebkitLineClamp(crate::values::specified::LineClamp),
                _WebkitTextSecurity(longhands::_webkit_text_security::SpecifiedValue),
                _WhiteSpaceCollapse(longhands::white_space_collapse::SpecifiedValue),
                _WordBreak(crate::values::specified::WordBreak),
                _WritingMode(longhands::writing_mode::SpecifiedValue),
                _XTextScale(crate::values::specified::XTextScale),
                _ZIndex(crate::values::specified::ZIndex),
                _Zoom(crate::values::specified::Zoom),
                _Appearance(crate::values::specified::Appearance),
                _MozDefaultAppearance(crate::values::specified::Appearance),
                _MozForceBrokenImageIcon(crate::values::specified::BoolInteger),
                _MozSubtreeHiddenOnlyVisually(crate::values::specified::BoolInteger),
                _BreakAfter(crate::values::specified::BreakBetween),
                _BreakBefore(crate::values::specified::BreakBetween),
                _ClipRule(crate::values::specified::FillRule),
                _FillRule(crate::values::specified::FillRule),
                _OverflowClipBoxBlock(crate::values::specified::OverflowClipBox),
                _OverflowClipBoxInline(crate::values::specified::OverflowClipBox),
                _FillOpacity(crate::values::specified::SVGOpacity),
                _StrokeOpacity(crate::values::specified::SVGOpacity),
                _MozBoxOrdinalGroup(crate::values::specified::Integer),
                _Order(crate::values::specified::Integer),
                _XSpan(crate::values::specified::Integer),
                _FontSynthesisPosition(crate::values::specified::FontSynthesis),
                _FontSynthesisSmallCaps(crate::values::specified::FontSynthesis),
                _FontSynthesisStyle(crate::values::specified::FontSynthesis),
                _FontSynthesisWeight(crate::values::specified::FontSynthesis),
                _FlexGrow(crate::values::specified::NonNegativeNumber),
                _FlexShrink(crate::values::specified::NonNegativeNumber),
                _MozBoxFlex(crate::values::specified::NonNegativeNumber),
                _StrokeMiterlimit(crate::values::specified::NonNegativeNumber),
                _OverflowBlock(crate::values::specified::Overflow),
                _OverflowInline(crate::values::specified::Overflow),
                _OverflowX(crate::values::specified::Overflow),
                _OverflowY(crate::values::specified::Overflow),
                _OverscrollBehaviorBlock(crate::values::specified::OverscrollBehavior),
                _OverscrollBehaviorInline(crate::values::specified::OverscrollBehavior),
                _OverscrollBehaviorX(crate::values::specified::OverscrollBehavior),
                _OverscrollBehaviorY(crate::values::specified::OverscrollBehavior),
                _FloodOpacity(crate::values::specified::Opacity),
                _MozWindowOpacity(crate::values::specified::Opacity),
                _Opacity(crate::values::specified::Opacity),
                _ShapeImageThreshold(crate::values::specified::Opacity),
                _StopOpacity(crate::values::specified::Opacity),
                _BorderBlockEndStyle(crate::values::specified::BorderStyle),
                _BorderBlockStartStyle(crate::values::specified::BorderStyle),
                _BorderBottomStyle(crate::values::specified::BorderStyle),
                _BorderInlineEndStyle(crate::values::specified::BorderStyle),
                _BorderInlineStartStyle(crate::values::specified::BorderStyle),
                _BorderLeftStyle(crate::values::specified::BorderStyle),
                _BorderRightStyle(crate::values::specified::BorderStyle),
                _BorderTopStyle(crate::values::specified::BorderStyle),
                _ColumnRuleStyle(crate::values::specified::BorderStyle),
            }

            unsafe {
                let mut out = mem::MaybeUninit::uninit();
                ptr::write(
                    out.as_mut_ptr() as *mut CopyVariants,
                    *(self as *const _ as *const CopyVariants),
                );
                return out.assume_init();
            }
        }

        // This function ensures that all properties not handled above
        // do not have a specified value implements Copy. If you hit
        // compile error here, you may want to add the type name into
        // Longhand.specified_is_copy in data.py.
        fn _static_assert_others_are_not_copy() {
            struct Helper<T>(T);
            trait AssertCopy { fn assert() {} }
            trait AssertNotCopy { fn assert() {} }
            impl<T: Copy> AssertCopy for Helper<T> {}
            impl AssertNotCopy for Helper<Box<crate::values::specified::BorderCornerRadius>> {}
            Helper::<Box<crate::values::specified::BorderCornerRadius>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::BorderImageSlice>> {}
            Helper::<Box<crate::values::specified::BorderImageSlice>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::BorderImageWidth>> {}
            Helper::<Box<crate::values::specified::BorderImageWidth>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::BorderSpacing>> {}
            Helper::<Box<crate::values::specified::BorderSpacing>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::ClipRectOrAuto>> {}
            Helper::<Box<crate::values::specified::ClipRectOrAuto>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::FlexBasis>> {}
            Helper::<Box<crate::values::specified::FlexBasis>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::NonNegativeLengthOrNumberRect>> {}
            Helper::<Box<crate::values::specified::NonNegativeLengthOrNumberRect>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::OffsetPosition>> {}
            Helper::<Box<crate::values::specified::OffsetPosition>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::PageSize>> {}
            Helper::<Box<crate::values::specified::PageSize>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::Position>> {}
            Helper::<Box<crate::values::specified::Position>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::PositionOrAuto>> {}
            Helper::<Box<crate::values::specified::PositionOrAuto>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::Rotate>> {}
            Helper::<Box<crate::values::specified::Rotate>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::SVGPaint>> {}
            Helper::<Box<crate::values::specified::SVGPaint>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::Scale>> {}
            Helper::<Box<crate::values::specified::Scale>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::TextOverflow>> {}
            Helper::<Box<crate::values::specified::TextOverflow>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::TransformOrigin>> {}
            Helper::<Box<crate::values::specified::TransformOrigin>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::Translate>> {}
            Helper::<Box<crate::values::specified::Translate>>::assert();
            impl AssertNotCopy for Helper<Box<crate::values::specified::ui::ScrollbarColor>> {}
            Helper::<Box<crate::values::specified::ui::ScrollbarColor>>::assert();
            impl AssertNotCopy for Helper<CustomDeclaration> {}
            Helper::<CustomDeclaration>::assert();
            impl AssertNotCopy for Helper<VariableDeclaration> {}
            Helper::<VariableDeclaration>::assert();
            impl AssertNotCopy for Helper<WideKeywordDeclaration> {}
            Helper::<WideKeywordDeclaration>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::AnchorName> {}
            Helper::<crate::values::specified::AnchorName>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::AnchorScope> {}
            Helper::<crate::values::specified::AnchorScope>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::BorderSideWidth> {}
            Helper::<crate::values::specified::BorderSideWidth>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Color> {}
            Helper::<crate::values::specified::Color>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::ColorOrAuto> {}
            Helper::<crate::values::specified::ColorOrAuto>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::ColorPropertyValue> {}
            Helper::<crate::values::specified::ColorPropertyValue>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::ColorScheme> {}
            Helper::<crate::values::specified::ColorScheme>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::ContainIntrinsicSize> {}
            Helper::<crate::values::specified::ContainIntrinsicSize>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::ContainerName> {}
            Helper::<crate::values::specified::ContainerName>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Content> {}
            Helper::<crate::values::specified::Content>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::CounterIncrement> {}
            Helper::<crate::values::specified::CounterIncrement>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::CounterReset> {}
            Helper::<crate::values::specified::CounterReset>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::CounterSet> {}
            Helper::<crate::values::specified::CounterSet>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Cursor> {}
            Helper::<crate::values::specified::Cursor>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::DProperty> {}
            Helper::<crate::values::specified::DProperty>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::FontFamily> {}
            Helper::<crate::values::specified::FontFamily>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::FontFeatureSettings> {}
            Helper::<crate::values::specified::FontFeatureSettings>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::FontPalette> {}
            Helper::<crate::values::specified::FontPalette>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::FontSize> {}
            Helper::<crate::values::specified::FontSize>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::FontVariantAlternates> {}
            Helper::<crate::values::specified::FontVariantAlternates>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::FontVariationSettings> {}
            Helper::<crate::values::specified::FontVariationSettings>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::GridLine> {}
            Helper::<crate::values::specified::GridLine>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::GridTemplateAreas> {}
            Helper::<crate::values::specified::GridTemplateAreas>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::GridTemplateComponent> {}
            Helper::<crate::values::specified::GridTemplateComponent>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::HyphenateCharacter> {}
            Helper::<crate::values::specified::HyphenateCharacter>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Image> {}
            Helper::<crate::values::specified::Image>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::ImplicitGridTracks> {}
            Helper::<crate::values::specified::ImplicitGridTracks>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Length> {}
            Helper::<crate::values::specified::Length>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::LengthPercentage> {}
            Helper::<crate::values::specified::LengthPercentage>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::LengthPercentageOrAuto> {}
            Helper::<crate::values::specified::LengthPercentageOrAuto>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::LetterSpacing> {}
            Helper::<crate::values::specified::LetterSpacing>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::LineHeight> {}
            Helper::<crate::values::specified::LineHeight>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::LineWidth> {}
            Helper::<crate::values::specified::LineWidth>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::ListStyleType> {}
            Helper::<crate::values::specified::ListStyleType>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::MaxSize> {}
            Helper::<crate::values::specified::MaxSize>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::MozContextProperties> {}
            Helper::<crate::values::specified::MozContextProperties>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::NonNegativeLengthOrNumber> {}
            Helper::<crate::values::specified::NonNegativeLengthOrNumber>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::NonNegativeLengthPercentage> {}
            Helper::<crate::values::specified::NonNegativeLengthPercentage>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::NonNegativeLengthPercentageOrAuto> {}
            Helper::<crate::values::specified::NonNegativeLengthPercentageOrAuto>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::OffsetPath> {}
            Helper::<crate::values::specified::OffsetPath>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::PageName> {}
            Helper::<crate::values::specified::PageName>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Perspective> {}
            Helper::<crate::values::specified::Perspective>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::PositionAnchor> {}
            Helper::<crate::values::specified::PositionAnchor>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::PositionTryOptions> {}
            Helper::<crate::values::specified::PositionTryOptions>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Quotes> {}
            Helper::<crate::values::specified::Quotes>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::SVGLength> {}
            Helper::<crate::values::specified::SVGLength>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::SVGStrokeDashArray> {}
            Helper::<crate::values::specified::SVGStrokeDashArray>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::SVGWidth> {}
            Helper::<crate::values::specified::SVGWidth>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Size> {}
            Helper::<crate::values::specified::Size>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::TextDecorationLength> {}
            Helper::<crate::values::specified::TextDecorationLength>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::TextEmphasisStyle> {}
            Helper::<crate::values::specified::TextEmphasisStyle>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::TextIndent> {}
            Helper::<crate::values::specified::TextIndent>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::Transform> {}
            Helper::<crate::values::specified::Transform>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::VerticalAlign> {}
            Helper::<crate::values::specified::VerticalAlign>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::WillChange> {}
            Helper::<crate::values::specified::WillChange>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::WordSpacing> {}
            Helper::<crate::values::specified::WordSpacing>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::XLang> {}
            Helper::<crate::values::specified::XLang>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::basic_shape::ClipPath> {}
            Helper::<crate::values::specified::basic_shape::ClipPath>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::basic_shape::ShapeOutside> {}
            Helper::<crate::values::specified::basic_shape::ShapeOutside>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::color::CaretColor> {}
            Helper::<crate::values::specified::color::CaretColor>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::length::NonNegativeLengthOrAuto> {}
            Helper::<crate::values::specified::length::NonNegativeLengthOrAuto>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::length::NonNegativeLengthPercentageOrNormal> {}
            Helper::<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>::assert();
            impl AssertNotCopy for Helper<crate::values::specified::url::UrlOrNone> {}
            Helper::<crate::values::specified::url::UrlOrNone>::assert();
            impl AssertNotCopy for Helper<longhands::animation_composition::SpecifiedValue> {}
            Helper::<longhands::animation_composition::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_delay::SpecifiedValue> {}
            Helper::<longhands::animation_delay::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_direction::SpecifiedValue> {}
            Helper::<longhands::animation_direction::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_duration::SpecifiedValue> {}
            Helper::<longhands::animation_duration::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_fill_mode::SpecifiedValue> {}
            Helper::<longhands::animation_fill_mode::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_iteration_count::SpecifiedValue> {}
            Helper::<longhands::animation_iteration_count::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_name::SpecifiedValue> {}
            Helper::<longhands::animation_name::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_play_state::SpecifiedValue> {}
            Helper::<longhands::animation_play_state::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_timeline::SpecifiedValue> {}
            Helper::<longhands::animation_timeline::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::animation_timing_function::SpecifiedValue> {}
            Helper::<longhands::animation_timing_function::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::backdrop_filter::SpecifiedValue> {}
            Helper::<longhands::backdrop_filter::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_attachment::SpecifiedValue> {}
            Helper::<longhands::background_attachment::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_blend_mode::SpecifiedValue> {}
            Helper::<longhands::background_blend_mode::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_clip::SpecifiedValue> {}
            Helper::<longhands::background_clip::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_image::SpecifiedValue> {}
            Helper::<longhands::background_image::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_origin::SpecifiedValue> {}
            Helper::<longhands::background_origin::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_position_x::SpecifiedValue> {}
            Helper::<longhands::background_position_x::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_position_y::SpecifiedValue> {}
            Helper::<longhands::background_position_y::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_repeat::SpecifiedValue> {}
            Helper::<longhands::background_repeat::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::background_size::SpecifiedValue> {}
            Helper::<longhands::background_size::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::box_shadow::SpecifiedValue> {}
            Helper::<longhands::box_shadow::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::filter::SpecifiedValue> {}
            Helper::<longhands::filter::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_clip::SpecifiedValue> {}
            Helper::<longhands::mask_clip::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_composite::SpecifiedValue> {}
            Helper::<longhands::mask_composite::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_image::SpecifiedValue> {}
            Helper::<longhands::mask_image::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_mode::SpecifiedValue> {}
            Helper::<longhands::mask_mode::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_origin::SpecifiedValue> {}
            Helper::<longhands::mask_origin::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_position_x::SpecifiedValue> {}
            Helper::<longhands::mask_position_x::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_position_y::SpecifiedValue> {}
            Helper::<longhands::mask_position_y::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_repeat::SpecifiedValue> {}
            Helper::<longhands::mask_repeat::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::mask_size::SpecifiedValue> {}
            Helper::<longhands::mask_size::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::scroll_timeline_axis::SpecifiedValue> {}
            Helper::<longhands::scroll_timeline_axis::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::scroll_timeline_name::SpecifiedValue> {}
            Helper::<longhands::scroll_timeline_name::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::text_shadow::SpecifiedValue> {}
            Helper::<longhands::text_shadow::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::transition_behavior::SpecifiedValue> {}
            Helper::<longhands::transition_behavior::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::transition_delay::SpecifiedValue> {}
            Helper::<longhands::transition_delay::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::transition_duration::SpecifiedValue> {}
            Helper::<longhands::transition_duration::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::transition_property::SpecifiedValue> {}
            Helper::<longhands::transition_property::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::transition_timing_function::SpecifiedValue> {}
            Helper::<longhands::transition_timing_function::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::view_timeline_axis::SpecifiedValue> {}
            Helper::<longhands::view_timeline_axis::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::view_timeline_inset::SpecifiedValue> {}
            Helper::<longhands::view_timeline_inset::SpecifiedValue>::assert();
            impl AssertNotCopy for Helper<longhands::view_timeline_name::SpecifiedValue> {}
            Helper::<longhands::view_timeline_name::SpecifiedValue>::assert();
        }

        match *self {
            AlignContent(..) |
AlignItems(..) |
AlignSelf(..) |
AspectRatio(..) |
BackfaceVisibility(..) |
BaselineSource(..) |
BorderCollapse(..) |
BorderImageRepeat(..) |
BoxDecorationBreak(..) |
BoxSizing(..) |
BreakInside(..) |
CaptionSide(..) |
Clear(..) |
ColorInterpolation(..) |
ColorInterpolationFilters(..) |
ColumnCount(..) |
ColumnFill(..) |
ColumnSpan(..) |
Contain(..) |
ContainerType(..) |
ContentVisibility(..) |
Direction(..) |
Display(..) |
DominantBaseline(..) |
EmptyCells(..) |
FlexDirection(..) |
FlexWrap(..) |
Float(..) |
FontKerning(..) |
FontLanguageOverride(..) |
FontOpticalSizing(..) |
FontSizeAdjust(..) |
FontStretch(..) |
FontStyle(..) |
FontVariantCaps(..) |
FontVariantEastAsian(..) |
FontVariantEmoji(..) |
FontVariantLigatures(..) |
FontVariantNumeric(..) |
FontVariantPosition(..) |
FontWeight(..) |
ForcedColorAdjust(..) |
GridAutoFlow(..) |
Hyphens(..) |
ImageOrientation(..) |
ImageRendering(..) |
ImeMode(..) |
InitialLetter(..) |
InsetArea(..) |
Isolation(..) |
JustifyContent(..) |
JustifyItems(..) |
JustifySelf(..) |
LineBreak(..) |
ListStylePosition(..) |
MaskType(..) |
MasonryAutoFlow(..) |
MathDepth(..) |
MathStyle(..) |
MixBlendMode(..) |
MozBoxAlign(..) |
MozBoxCollapse(..) |
MozBoxDirection(..) |
MozBoxOrient(..) |
MozBoxPack(..) |
MozControlCharacterVisibility(..) |
MozFloatEdge(..) |
MozInert(..) |
MozMathVariant(..) |
MozMinFontSizeRatio(..) |
MozOrient(..) |
MozOsxFontSmoothing(..) |
MozTextSizeAdjust(..) |
MozTheme(..) |
MozTopLayer(..) |
MozUserFocus(..) |
MozUserInput(..) |
MozUserModify(..) |
MozWindowDragging(..) |
MozWindowShadow(..) |
ObjectFit(..) |
OffsetRotate(..) |
OutlineStyle(..) |
OverflowAnchor(..) |
OverflowWrap(..) |
PageOrientation(..) |
PaintOrder(..) |
PointerEvents(..) |
Position(..) |
PositionTryOrder(..) |
PositionVisibility(..) |
PrintColorAdjust(..) |
Resize(..) |
RubyAlign(..) |
RubyPosition(..) |
ScrollBehavior(..) |
ScrollSnapAlign(..) |
ScrollSnapStop(..) |
ScrollSnapType(..) |
ScrollbarGutter(..) |
ScrollbarWidth(..) |
ShapeRendering(..) |
StrokeLinecap(..) |
StrokeLinejoin(..) |
TableLayout(..) |
TextAlign(..) |
TextAlignLast(..) |
TextAnchor(..) |
TextCombineUpright(..) |
TextDecorationLine(..) |
TextDecorationSkipInk(..) |
TextDecorationStyle(..) |
TextEmphasisPosition(..) |
TextJustify(..) |
TextOrientation(..) |
TextRendering(..) |
TextTransform(..) |
TextUnderlinePosition(..) |
TextWrapMode(..) |
TextWrapStyle(..) |
TouchAction(..) |
TransformBox(..) |
TransformStyle(..) |
UnicodeBidi(..) |
UserSelect(..) |
VectorEffect(..) |
Visibility(..) |
WebkitLineClamp(..) |
WebkitTextSecurity(..) |
WhiteSpaceCollapse(..) |
WordBreak(..) |
WritingMode(..) |
XTextScale(..) |
ZIndex(..) |
Zoom(..) |
Appearance(..) |
MozDefaultAppearance(..) |
MozForceBrokenImageIcon(..) |
MozSubtreeHiddenOnlyVisually(..) |
BreakAfter(..) |
BreakBefore(..) |
ClipRule(..) |
FillRule(..) |
OverflowClipBoxBlock(..) |
OverflowClipBoxInline(..) |
FillOpacity(..) |
StrokeOpacity(..) |
MozBoxOrdinalGroup(..) |
Order(..) |
XSpan(..) |
FontSynthesisPosition(..) |
FontSynthesisSmallCaps(..) |
FontSynthesisStyle(..) |
FontSynthesisWeight(..) |
FlexGrow(..) |
FlexShrink(..) |
MozBoxFlex(..) |
StrokeMiterlimit(..) |
OverflowBlock(..) |
OverflowInline(..) |
OverflowX(..) |
OverflowY(..) |
OverscrollBehaviorBlock(..) |
OverscrollBehaviorInline(..) |
OverscrollBehaviorX(..) |
OverscrollBehaviorY(..) |
FloodOpacity(..) |
MozWindowOpacity(..) |
Opacity(..) |
ShapeImageThreshold(..) |
StopOpacity(..) |
BorderBlockEndStyle(..) |
BorderBlockStartStyle(..) |
BorderBottomStyle(..) |
BorderInlineEndStyle(..) |
BorderInlineStartStyle(..) |
BorderLeftStyle(..) |
BorderRightStyle(..) |
BorderTopStyle(..) |
ColumnRuleStyle(..) => {
                unsafe { debug_unreachable!() }
            }
            
            AccentColor(ref value) => {
                AccentColor(value.clone())
            }
            
            AnchorName(ref value) => {
                AnchorName(value.clone())
            }
            
            AnchorScope(ref value) => {
                AnchorScope(value.clone())
            }
            
            AnimationComposition(ref value) => {
                AnimationComposition(value.clone())
            }
            
            AnimationDelay(ref value) => {
                AnimationDelay(value.clone())
            }
            
            AnimationDirection(ref value) => {
                AnimationDirection(value.clone())
            }
            
            AnimationDuration(ref value) => {
                AnimationDuration(value.clone())
            }
            
            AnimationFillMode(ref value) => {
                AnimationFillMode(value.clone())
            }
            
            AnimationIterationCount(ref value) => {
                AnimationIterationCount(value.clone())
            }
            
            AnimationName(ref value) => {
                AnimationName(value.clone())
            }
            
            AnimationPlayState(ref value) => {
                AnimationPlayState(value.clone())
            }
            
            AnimationTimeline(ref value) => {
                AnimationTimeline(value.clone())
            }
            
            AnimationTimingFunction(ref value) => {
                AnimationTimingFunction(value.clone())
            }
            
            BackdropFilter(ref value) => {
                BackdropFilter(value.clone())
            }
            
            BackgroundAttachment(ref value) => {
                BackgroundAttachment(value.clone())
            }
            
            BackgroundBlendMode(ref value) => {
                BackgroundBlendMode(value.clone())
            }
            
            BackgroundClip(ref value) => {
                BackgroundClip(value.clone())
            }
            
            BackgroundImage(ref value) => {
                BackgroundImage(value.clone())
            }
            
            BackgroundOrigin(ref value) => {
                BackgroundOrigin(value.clone())
            }
            
            BackgroundPositionX(ref value) => {
                BackgroundPositionX(value.clone())
            }
            
            BackgroundPositionY(ref value) => {
                BackgroundPositionY(value.clone())
            }
            
            BackgroundRepeat(ref value) => {
                BackgroundRepeat(value.clone())
            }
            
            BackgroundSize(ref value) => {
                BackgroundSize(value.clone())
            }
            
            BorderImageOutset(ref value) => {
                BorderImageOutset(value.clone())
            }
            
            BorderImageSlice(ref value) => {
                BorderImageSlice(value.clone())
            }
            
            BorderImageWidth(ref value) => {
                BorderImageWidth(value.clone())
            }
            
            BorderSpacing(ref value) => {
                BorderSpacing(value.clone())
            }
            
            BoxShadow(ref value) => {
                BoxShadow(value.clone())
            }
            
            CaretColor(ref value) => {
                CaretColor(value.clone())
            }
            
            Clip(ref value) => {
                Clip(value.clone())
            }
            
            ClipPath(ref value) => {
                ClipPath(value.clone())
            }
            
            Color(ref value) => {
                Color(value.clone())
            }
            
            ColorScheme(ref value) => {
                ColorScheme(value.clone())
            }
            
            ColumnWidth(ref value) => {
                ColumnWidth(value.clone())
            }
            
            ContainerName(ref value) => {
                ContainerName(value.clone())
            }
            
            Content(ref value) => {
                Content(value.clone())
            }
            
            CounterIncrement(ref value) => {
                CounterIncrement(value.clone())
            }
            
            CounterReset(ref value) => {
                CounterReset(value.clone())
            }
            
            CounterSet(ref value) => {
                CounterSet(value.clone())
            }
            
            Cursor(ref value) => {
                Cursor(value.clone())
            }
            
            D(ref value) => {
                D(value.clone())
            }
            
            Filter(ref value) => {
                Filter(value.clone())
            }
            
            FlexBasis(ref value) => {
                FlexBasis(value.clone())
            }
            
            FontFamily(ref value) => {
                FontFamily(value.clone())
            }
            
            FontFeatureSettings(ref value) => {
                FontFeatureSettings(value.clone())
            }
            
            FontPalette(ref value) => {
                FontPalette(value.clone())
            }
            
            FontSize(ref value) => {
                FontSize(value.clone())
            }
            
            FontVariantAlternates(ref value) => {
                FontVariantAlternates(value.clone())
            }
            
            FontVariationSettings(ref value) => {
                FontVariationSettings(value.clone())
            }
            
            GridTemplateAreas(ref value) => {
                GridTemplateAreas(value.clone())
            }
            
            HyphenateCharacter(ref value) => {
                HyphenateCharacter(value.clone())
            }
            
            LetterSpacing(ref value) => {
                LetterSpacing(value.clone())
            }
            
            LineHeight(ref value) => {
                LineHeight(value.clone())
            }
            
            ListStyleType(ref value) => {
                ListStyleType(value.clone())
            }
            
            MaskClip(ref value) => {
                MaskClip(value.clone())
            }
            
            MaskComposite(ref value) => {
                MaskComposite(value.clone())
            }
            
            MaskImage(ref value) => {
                MaskImage(value.clone())
            }
            
            MaskMode(ref value) => {
                MaskMode(value.clone())
            }
            
            MaskOrigin(ref value) => {
                MaskOrigin(value.clone())
            }
            
            MaskPositionX(ref value) => {
                MaskPositionX(value.clone())
            }
            
            MaskPositionY(ref value) => {
                MaskPositionY(value.clone())
            }
            
            MaskRepeat(ref value) => {
                MaskRepeat(value.clone())
            }
            
            MaskSize(ref value) => {
                MaskSize(value.clone())
            }
            
            MozContextProperties(ref value) => {
                MozContextProperties(value.clone())
            }
            
            OffsetAnchor(ref value) => {
                OffsetAnchor(value.clone())
            }
            
            OffsetPath(ref value) => {
                OffsetPath(value.clone())
            }
            
            OffsetPosition(ref value) => {
                OffsetPosition(value.clone())
            }
            
            Page(ref value) => {
                Page(value.clone())
            }
            
            Perspective(ref value) => {
                Perspective(value.clone())
            }
            
            PositionAnchor(ref value) => {
                PositionAnchor(value.clone())
            }
            
            PositionTryOptions(ref value) => {
                PositionTryOptions(value.clone())
            }
            
            Quotes(ref value) => {
                Quotes(value.clone())
            }
            
            Rotate(ref value) => {
                Rotate(value.clone())
            }
            
            Scale(ref value) => {
                Scale(value.clone())
            }
            
            ScrollTimelineAxis(ref value) => {
                ScrollTimelineAxis(value.clone())
            }
            
            ScrollTimelineName(ref value) => {
                ScrollTimelineName(value.clone())
            }
            
            ScrollbarColor(ref value) => {
                ScrollbarColor(value.clone())
            }
            
            ShapeOutside(ref value) => {
                ShapeOutside(value.clone())
            }
            
            Size(ref value) => {
                Size(value.clone())
            }
            
            StrokeDasharray(ref value) => {
                StrokeDasharray(value.clone())
            }
            
            StrokeDashoffset(ref value) => {
                StrokeDashoffset(value.clone())
            }
            
            StrokeWidth(ref value) => {
                StrokeWidth(value.clone())
            }
            
            TabSize(ref value) => {
                TabSize(value.clone())
            }
            
            TextDecorationThickness(ref value) => {
                TextDecorationThickness(value.clone())
            }
            
            TextEmphasisStyle(ref value) => {
                TextEmphasisStyle(value.clone())
            }
            
            TextIndent(ref value) => {
                TextIndent(value.clone())
            }
            
            TextOverflow(ref value) => {
                TextOverflow(value.clone())
            }
            
            TextShadow(ref value) => {
                TextShadow(value.clone())
            }
            
            TransitionBehavior(ref value) => {
                TransitionBehavior(value.clone())
            }
            
            TransitionDelay(ref value) => {
                TransitionDelay(value.clone())
            }
            
            TransitionDuration(ref value) => {
                TransitionDuration(value.clone())
            }
            
            TransitionProperty(ref value) => {
                TransitionProperty(value.clone())
            }
            
            TransitionTimingFunction(ref value) => {
                TransitionTimingFunction(value.clone())
            }
            
            Translate(ref value) => {
                Translate(value.clone())
            }
            
            VerticalAlign(ref value) => {
                VerticalAlign(value.clone())
            }
            
            ViewTimelineAxis(ref value) => {
                ViewTimelineAxis(value.clone())
            }
            
            ViewTimelineInset(ref value) => {
                ViewTimelineInset(value.clone())
            }
            
            ViewTimelineName(ref value) => {
                ViewTimelineName(value.clone())
            }
            
            WebkitTextStrokeWidth(ref value) => {
                WebkitTextStrokeWidth(value.clone())
            }
            
            WillChange(ref value) => {
                WillChange(value.clone())
            }
            
            WordSpacing(ref value) => {
                WordSpacing(value.clone())
            }
            
            XLang(ref value) => {
                XLang(value.clone())
            }
            
            ObjectPosition(ref value) |
PerspectiveOrigin(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::Position>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Fill(ref value) |
Stroke(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::SVGPaint>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowTransformOrigin(ref value) |
TransformOrigin(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::TransformOrigin>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridTemplateColumns(ref value) |
GridTemplateRows(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::GridTemplateComponent>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderImageSource(ref value) |
ListStyleImage(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Image>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridAutoColumns(ref value) |
GridAutoRows(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::ImplicitGridTracks>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowTransform(ref value) |
Transform(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Transform>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            ColumnGap(ref value) |
RowGap(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MarkerEnd(ref value) |
MarkerMid(ref value) |
MarkerStart(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::url::UrlOrNone>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            ContainIntrinsicBlockSize(ref value) |
ContainIntrinsicHeight(ref value) |
ContainIntrinsicInlineSize(ref value) |
ContainIntrinsicWidth(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::ContainIntrinsicSize>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridColumnEnd(ref value) |
GridColumnStart(ref value) |
GridRowEnd(ref value) |
GridRowStart(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::GridLine>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MaxBlockSize(ref value) |
MaxHeight(ref value) |
MaxInlineSize(ref value) |
MaxWidth(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::MaxSize>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Cx(ref value) |
Cy(ref value) |
OffsetDistance(ref value) |
X(ref value) |
Y(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderBottomLeftRadius(ref value) |
BorderBottomRightRadius(ref value) |
BorderEndEndRadius(ref value) |
BorderEndStartRadius(ref value) |
BorderStartEndRadius(ref value) |
BorderStartStartRadius(ref value) |
BorderTopLeftRadius(ref value) |
BorderTopRightRadius(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderCornerRadius>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BlockSize(ref value) |
Height(ref value) |
InlineSize(ref value) |
MinBlockSize(ref value) |
MinHeight(ref value) |
MinInlineSize(ref value) |
MinWidth(ref value) |
Width(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Size>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderBlockEndWidth(ref value) |
BorderBlockStartWidth(ref value) |
BorderBottomWidth(ref value) |
BorderInlineEndWidth(ref value) |
BorderInlineStartWidth(ref value) |
BorderLeftWidth(ref value) |
BorderRightWidth(ref value) |
BorderTopWidth(ref value) |
ColumnRuleWidth(ref value) |
OutlineWidth(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BorderSideWidth>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            PaddingBlockEnd(ref value) |
PaddingBlockStart(ref value) |
PaddingBottom(ref value) |
PaddingInlineEnd(ref value) |
PaddingInlineStart(ref value) |
PaddingLeft(ref value) |
PaddingRight(ref value) |
PaddingTop(ref value) |
R(ref value) |
ShapeMargin(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Rx(ref value) |
Ry(ref value) |
ScrollPaddingBlockEnd(ref value) |
ScrollPaddingBlockStart(ref value) |
ScrollPaddingBottom(ref value) |
ScrollPaddingInlineEnd(ref value) |
ScrollPaddingInlineStart(ref value) |
ScrollPaddingLeft(ref value) |
ScrollPaddingRight(ref value) |
ScrollPaddingTop(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowInputRegionMargin(ref value) |
OutlineOffset(ref value) |
OverflowClipMargin(ref value) |
ScrollMarginBlockEnd(ref value) |
ScrollMarginBlockStart(ref value) |
ScrollMarginBottom(ref value) |
ScrollMarginInlineEnd(ref value) |
ScrollMarginInlineStart(ref value) |
ScrollMarginLeft(ref value) |
ScrollMarginRight(ref value) |
ScrollMarginTop(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Length>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Bottom(ref value) |
InsetBlockEnd(ref value) |
InsetBlockStart(ref value) |
InsetInlineEnd(ref value) |
InsetInlineStart(ref value) |
Left(ref value) |
MarginBlockEnd(ref value) |
MarginBlockStart(ref value) |
MarginBottom(ref value) |
MarginInlineEnd(ref value) |
MarginInlineStart(ref value) |
MarginLeft(ref value) |
MarginRight(ref value) |
MarginTop(ref value) |
Right(ref value) |
TextUnderlineOffset(ref value) |
Top(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BackgroundColor(ref value) |
BorderBlockEndColor(ref value) |
BorderBlockStartColor(ref value) |
BorderBottomColor(ref value) |
BorderInlineEndColor(ref value) |
BorderInlineStartColor(ref value) |
BorderLeftColor(ref value) |
BorderRightColor(ref value) |
BorderTopColor(ref value) |
ColumnRuleColor(ref value) |
FloodColor(ref value) |
LightingColor(ref value) |
OutlineColor(ref value) |
StopColor(ref value) |
TextDecorationColor(ref value) |
TextEmphasisColor(ref value) |
WebkitTextFillColor(ref value) |
WebkitTextStrokeColor(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Color>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            CSSWideKeyword(ref value) => {
                CSSWideKeyword(value.clone())
            }
            
            WithVariables(ref value) => {
                WithVariables(value.clone())
            }
            
            Custom(ref value) => {
                Custom(value.clone())
            }
        }
    }
}

impl PartialEq for PropertyDeclaration {
    #[inline]
    fn eq(&self, other: &Self) -> bool {
        use self::PropertyDeclaration::*;

        unsafe {
            let this_repr =
                &*(self as *const _ as *const PropertyDeclarationVariantRepr<()>);
            let other_repr =
                &*(other as *const _ as *const PropertyDeclarationVariantRepr<()>);
            if this_repr.tag != other_repr.tag {
                return false;
            }
            match *self {
                AlignContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AlignContent>);
                    *this == other_repr.value
                }
                AlignItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AlignItems>);
                    *this == other_repr.value
                }
                AlignSelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AlignSelf>);
                    *this == other_repr.value
                }
                AspectRatio(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AspectRatio>);
                    *this == other_repr.value
                }
                BackfaceVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::backface_visibility::SpecifiedValue>);
                    *this == other_repr.value
                }
                BaselineSource(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BaselineSource>);
                    *this == other_repr.value
                }
                BorderCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::border_collapse::SpecifiedValue>);
                    *this == other_repr.value
                }
                BorderImageRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BorderImageRepeat>);
                    *this == other_repr.value
                }
                BoxDecorationBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_decoration_break::SpecifiedValue>);
                    *this == other_repr.value
                }
                BoxSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_sizing::SpecifiedValue>);
                    *this == other_repr.value
                }
                BreakInside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BreakWithin>);
                    *this == other_repr.value
                }
                CaptionSide(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::table::CaptionSide>);
                    *this == other_repr.value
                }
                Clear(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Clear>);
                    *this == other_repr.value
                }
                ColorInterpolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColorInterpolationFilters(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation_filters::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColumnCount>);
                    *this == other_repr.value
                }
                ColumnFill(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_fill::SpecifiedValue>);
                    *this == other_repr.value
                }
                ColumnSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_span::SpecifiedValue>);
                    *this == other_repr.value
                }
                Contain(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Contain>);
                    *this == other_repr.value
                }
                ContainerType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ContainerType>);
                    *this == other_repr.value
                }
                ContentVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ContentVisibility>);
                    *this == other_repr.value
                }
                Direction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                Display(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Display>);
                    *this == other_repr.value
                }
                DominantBaseline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::dominant_baseline::SpecifiedValue>);
                    *this == other_repr.value
                }
                EmptyCells(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::empty_cells::SpecifiedValue>);
                    *this == other_repr.value
                }
                FlexDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                FlexWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_wrap::SpecifiedValue>);
                    *this == other_repr.value
                }
                Float(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Float>);
                    *this == other_repr.value
                }
                FontKerning(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_kerning::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontLanguageOverride(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontLanguageOverride>);
                    *this == other_repr.value
                }
                FontOpticalSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_optical_sizing::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontSizeAdjust>);
                    *this == other_repr.value
                }
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontStretch>);
                    *this == other_repr.value
                }
                FontStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontStyle>);
                    *this == other_repr.value
                }
                FontVariantCaps(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_caps::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontVariantEastAsian(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantEastAsian>);
                    *this == other_repr.value
                }
                FontVariantEmoji(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_emoji::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontVariantLigatures(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantLigatures>);
                    *this == other_repr.value
                }
                FontVariantNumeric(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantNumeric>);
                    *this == other_repr.value
                }
                FontVariantPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_position::SpecifiedValue>);
                    *this == other_repr.value
                }
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontWeight>);
                    *this == other_repr.value
                }
                ForcedColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ForcedColorAdjust>);
                    *this == other_repr.value
                }
                GridAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridAutoFlow>);
                    *this == other_repr.value
                }
                Hyphens(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::hyphens::SpecifiedValue>);
                    *this == other_repr.value
                }
                ImageOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::image_orientation::SpecifiedValue>);
                    *this == other_repr.value
                }
                ImageRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ImageRendering>);
                    *this == other_repr.value
                }
                ImeMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::ime_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                InitialLetter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::InitialLetter>);
                    *this == other_repr.value
                }
                InsetArea(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::InsetArea>);
                    *this == other_repr.value
                }
                Isolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::isolation::SpecifiedValue>);
                    *this == other_repr.value
                }
                JustifyContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::JustifyContent>);
                    *this == other_repr.value
                }
                JustifyItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::JustifyItems>);
                    *this == other_repr.value
                }
                JustifySelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::JustifySelf>);
                    *this == other_repr.value
                }
                LineBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineBreak>);
                    *this == other_repr.value
                }
                ListStylePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::list_style_position::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_type::SpecifiedValue>);
                    *this == other_repr.value
                }
                MasonryAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::MasonryAutoFlow>);
                    *this == other_repr.value
                }
                MathDepth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::MathDepth>);
                    *this == other_repr.value
                }
                MathStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::math_style::SpecifiedValue>);
                    *this == other_repr.value
                }
                MixBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mix_blend_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_align::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_collapse::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_orient::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozBoxPack(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_pack::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozControlCharacterVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::text::MozControlCharacterVisibility>);
                    *this == other_repr.value
                }
                MozFloatEdge(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_float_edge::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozInert(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_inert::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozMathVariant(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_math_variant::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozMinFontSizeRatio(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Percentage>);
                    *this == other_repr.value
                }
                MozOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_orient::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozOsxFontSmoothing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_osx_font_smoothing::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozTextSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_text_size_adjust::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozTheme(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ui::MozTheme>);
                    *this == other_repr.value
                }
                MozTopLayer(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_top_layer::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozUserFocus(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_focus::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozUserInput(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_input::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozUserModify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_modify::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozWindowDragging(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_dragging::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozWindowShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_shadow::SpecifiedValue>);
                    *this == other_repr.value
                }
                ObjectFit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::object_fit::SpecifiedValue>);
                    *this == other_repr.value
                }
                OffsetRotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OffsetRotate>);
                    *this == other_repr.value
                }
                OutlineStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OutlineStyle>);
                    *this == other_repr.value
                }
                OverflowAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverflowAnchor>);
                    *this == other_repr.value
                }
                OverflowWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverflowWrap>);
                    *this == other_repr.value
                }
                PageOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PageOrientation>);
                    *this == other_repr.value
                }
                PaintOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGPaintOrder>);
                    *this == other_repr.value
                }
                PointerEvents(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::pointer_events::SpecifiedValue>);
                    *this == other_repr.value
                }
                Position(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::position::SpecifiedValue>);
                    *this == other_repr.value
                }
                PositionTryOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionTryOrder>);
                    *this == other_repr.value
                }
                PositionVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionVisibility>);
                    *this == other_repr.value
                }
                PrintColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PrintColorAdjust>);
                    *this == other_repr.value
                }
                Resize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Resize>);
                    *this == other_repr.value
                }
                RubyAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::ruby_align::SpecifiedValue>);
                    *this == other_repr.value
                }
                RubyPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::RubyPosition>);
                    *this == other_repr.value
                }
                ScrollBehavior(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_behavior::SpecifiedValue>);
                    *this == other_repr.value
                }
                ScrollSnapAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollSnapAlign>);
                    *this == other_repr.value
                }
                ScrollSnapStop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollSnapStop>);
                    *this == other_repr.value
                }
                ScrollSnapType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollSnapType>);
                    *this == other_repr.value
                }
                ScrollbarGutter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollbarGutter>);
                    *this == other_repr.value
                }
                ScrollbarWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::scrollbar_width::SpecifiedValue>);
                    *this == other_repr.value
                }
                ShapeRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::shape_rendering::SpecifiedValue>);
                    *this == other_repr.value
                }
                StrokeLinecap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linecap::SpecifiedValue>);
                    *this == other_repr.value
                }
                StrokeLinejoin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linejoin::SpecifiedValue>);
                    *this == other_repr.value
                }
                TableLayout(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::table_layout::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextAlign>);
                    *this == other_repr.value
                }
                TextAlignLast(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextAlignLast>);
                    *this == other_repr.value
                }
                TextAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_anchor::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextCombineUpright(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_combine_upright::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextDecorationLine(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextDecorationLine>);
                    *this == other_repr.value
                }
                TextDecorationSkipInk(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextDecorationSkipInk>);
                    *this == other_repr.value
                }
                TextDecorationStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_decoration_style::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextEmphasisPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextEmphasisPosition>);
                    *this == other_repr.value
                }
                TextJustify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextJustify>);
                    *this == other_repr.value
                }
                TextOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_orientation::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_rendering::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextTransform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextTransform>);
                    *this == other_repr.value
                }
                TextUnderlinePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextUnderlinePosition>);
                    *this == other_repr.value
                }
                TextWrapMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_wrap_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                TextWrapStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_wrap_style::SpecifiedValue>);
                    *this == other_repr.value
                }
                TouchAction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TouchAction>);
                    *this == other_repr.value
                }
                TransformBox(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TransformBox>);
                    *this == other_repr.value
                }
                TransformStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TransformStyle>);
                    *this == other_repr.value
                }
                UnicodeBidi(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::unicode_bidi::SpecifiedValue>);
                    *this == other_repr.value
                }
                UserSelect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::UserSelect>);
                    *this == other_repr.value
                }
                VectorEffect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::vector_effect::SpecifiedValue>);
                    *this == other_repr.value
                }
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::visibility::SpecifiedValue>);
                    *this == other_repr.value
                }
                WebkitLineClamp(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineClamp>);
                    *this == other_repr.value
                }
                WebkitTextSecurity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::_webkit_text_security::SpecifiedValue>);
                    *this == other_repr.value
                }
                WhiteSpaceCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::white_space_collapse::SpecifiedValue>);
                    *this == other_repr.value
                }
                WordBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::WordBreak>);
                    *this == other_repr.value
                }
                WritingMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::writing_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                XTextScale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::XTextScale>);
                    *this == other_repr.value
                }
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ZIndex>);
                    *this == other_repr.value
                }
                Zoom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Zoom>);
                    *this == other_repr.value
                }
                Appearance(ref this) |
MozDefaultAppearance(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Appearance>);
                    *this == other_repr.value
                }
                MozForceBrokenImageIcon(ref this) |
MozSubtreeHiddenOnlyVisually(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BoolInteger>);
                    *this == other_repr.value
                }
                BreakAfter(ref this) |
BreakBefore(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BreakBetween>);
                    *this == other_repr.value
                }
                ClipRule(ref this) |
FillRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FillRule>);
                    *this == other_repr.value
                }
                OverflowClipBoxBlock(ref this) |
OverflowClipBoxInline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverflowClipBox>);
                    *this == other_repr.value
                }
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGOpacity>);
                    *this == other_repr.value
                }
                MozBoxOrdinalGroup(ref this) |
Order(ref this) |
XSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Integer>);
                    *this == other_repr.value
                }
                FontSynthesisPosition(ref this) |
FontSynthesisSmallCaps(ref this) |
FontSynthesisStyle(ref this) |
FontSynthesisWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontSynthesis>);
                    *this == other_repr.value
                }
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) |
StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeNumber>);
                    *this == other_repr.value
                }
                OverflowBlock(ref this) |
OverflowInline(ref this) |
OverflowX(ref this) |
OverflowY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Overflow>);
                    *this == other_repr.value
                }
                OverscrollBehaviorBlock(ref this) |
OverscrollBehaviorInline(ref this) |
OverscrollBehaviorX(ref this) |
OverscrollBehaviorY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverscrollBehavior>);
                    *this == other_repr.value
                }
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Opacity>);
                    *this == other_repr.value
                }
                BorderBlockEndStyle(ref this) |
BorderBlockStartStyle(ref this) |
BorderBottomStyle(ref this) |
BorderInlineEndStyle(ref this) |
BorderInlineStartStyle(ref this) |
BorderLeftStyle(ref this) |
BorderRightStyle(ref this) |
BorderTopStyle(ref this) |
ColumnRuleStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BorderStyle>);
                    *this == other_repr.value
                }
                AccentColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColorOrAuto>);
                    *this == other_repr.value
                }
                AnchorName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AnchorName>);
                    *this == other_repr.value
                }
                AnchorScope(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AnchorScope>);
                    *this == other_repr.value
                }
                AnimationComposition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_composition::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationDelay(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_delay::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_direction::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationDuration(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_duration::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationFillMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_fill_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationIterationCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_iteration_count::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_name::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationPlayState(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_play_state::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationTimeline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_timeline::SpecifiedValue>);
                    *this == other_repr.value
                }
                AnimationTimingFunction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::animation_timing_function::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackdropFilter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::backdrop_filter::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundAttachment(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_attachment::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_blend_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_clip::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_image::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_origin::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_x::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_y::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_repeat::SpecifiedValue>);
                    *this == other_repr.value
                }
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_size::SpecifiedValue>);
                    *this == other_repr.value
                }
                BorderImageOutset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::NonNegativeLengthOrNumberRect>>);
                    *this == other_repr.value
                }
                BorderImageSlice(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderImageSlice>>);
                    *this == other_repr.value
                }
                BorderImageWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderImageWidth>>);
                    *this == other_repr.value
                }
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderSpacing>>);
                    *this == other_repr.value
                }
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_shadow::SpecifiedValue>);
                    *this == other_repr.value
                }
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::color::CaretColor>);
                    *this == other_repr.value
                }
                Clip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::ClipRectOrAuto>>);
                    *this == other_repr.value
                }
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::basic_shape::ClipPath>);
                    *this == other_repr.value
                }
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColorPropertyValue>);
                    *this == other_repr.value
                }
                ColorScheme(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColorScheme>);
                    *this == other_repr.value
                }
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::length::NonNegativeLengthOrAuto>);
                    *this == other_repr.value
                }
                ContainerName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ContainerName>);
                    *this == other_repr.value
                }
                Content(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Content>);
                    *this == other_repr.value
                }
                CounterIncrement(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::CounterIncrement>);
                    *this == other_repr.value
                }
                CounterReset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::CounterReset>);
                    *this == other_repr.value
                }
                CounterSet(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::CounterSet>);
                    *this == other_repr.value
                }
                Cursor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Cursor>);
                    *this == other_repr.value
                }
                D(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::DProperty>);
                    *this == other_repr.value
                }
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::filter::SpecifiedValue>);
                    *this == other_repr.value
                }
                FlexBasis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::FlexBasis>>);
                    *this == other_repr.value
                }
                FontFamily(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontFamily>);
                    *this == other_repr.value
                }
                FontFeatureSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontFeatureSettings>);
                    *this == other_repr.value
                }
                FontPalette(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontPalette>);
                    *this == other_repr.value
                }
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontSize>);
                    *this == other_repr.value
                }
                FontVariantAlternates(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantAlternates>);
                    *this == other_repr.value
                }
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariationSettings>);
                    *this == other_repr.value
                }
                GridTemplateAreas(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridTemplateAreas>);
                    *this == other_repr.value
                }
                HyphenateCharacter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::HyphenateCharacter>);
                    *this == other_repr.value
                }
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LetterSpacing>);
                    *this == other_repr.value
                }
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineHeight>);
                    *this == other_repr.value
                }
                ListStyleType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ListStyleType>);
                    *this == other_repr.value
                }
                MaskClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_clip::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskComposite(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_composite::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_image::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_mode::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_origin::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_x::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_y::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_repeat::SpecifiedValue>);
                    *this == other_repr.value
                }
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_size::SpecifiedValue>);
                    *this == other_repr.value
                }
                MozContextProperties(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::MozContextProperties>);
                    *this == other_repr.value
                }
                OffsetAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::PositionOrAuto>>);
                    *this == other_repr.value
                }
                OffsetPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OffsetPath>);
                    *this == other_repr.value
                }
                OffsetPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::OffsetPosition>>);
                    *this == other_repr.value
                }
                Page(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PageName>);
                    *this == other_repr.value
                }
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Perspective>);
                    *this == other_repr.value
                }
                PositionAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionAnchor>);
                    *this == other_repr.value
                }
                PositionTryOptions(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionTryOptions>);
                    *this == other_repr.value
                }
                Quotes(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Quotes>);
                    *this == other_repr.value
                }
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Rotate>>);
                    *this == other_repr.value
                }
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Scale>>);
                    *this == other_repr.value
                }
                ScrollTimelineAxis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_timeline_axis::SpecifiedValue>);
                    *this == other_repr.value
                }
                ScrollTimelineName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_timeline_name::SpecifiedValue>);
                    *this == other_repr.value
                }
                ScrollbarColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::ui::ScrollbarColor>>);
                    *this == other_repr.value
                }
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::basic_shape::ShapeOutside>);
                    *this == other_repr.value
                }
                Size(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::PageSize>>);
                    *this == other_repr.value
                }
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGStrokeDashArray>);
                    *this == other_repr.value
                }
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGLength>);
                    *this == other_repr.value
                }
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGWidth>);
                    *this == other_repr.value
                }
                TabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthOrNumber>);
                    *this == other_repr.value
                }
                TextDecorationThickness(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextDecorationLength>);
                    *this == other_repr.value
                }
                TextEmphasisStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextEmphasisStyle>);
                    *this == other_repr.value
                }
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextIndent>);
                    *this == other_repr.value
                }
                TextOverflow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::TextOverflow>>);
                    *this == other_repr.value
                }
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_shadow::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionBehavior(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_behavior::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionDelay(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_delay::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionDuration(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_duration::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionProperty(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_property::SpecifiedValue>);
                    *this == other_repr.value
                }
                TransitionTimingFunction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::transition_timing_function::SpecifiedValue>);
                    *this == other_repr.value
                }
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Translate>>);
                    *this == other_repr.value
                }
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::VerticalAlign>);
                    *this == other_repr.value
                }
                ViewTimelineAxis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::view_timeline_axis::SpecifiedValue>);
                    *this == other_repr.value
                }
                ViewTimelineInset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::view_timeline_inset::SpecifiedValue>);
                    *this == other_repr.value
                }
                ViewTimelineName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<longhands::view_timeline_name::SpecifiedValue>);
                    *this == other_repr.value
                }
                WebkitTextStrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineWidth>);
                    *this == other_repr.value
                }
                WillChange(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::WillChange>);
                    *this == other_repr.value
                }
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::WordSpacing>);
                    *this == other_repr.value
                }
                XLang(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::XLang>);
                    *this == other_repr.value
                }
                ObjectPosition(ref this) |
PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Position>>);
                    *this == other_repr.value
                }
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::SVGPaint>>);
                    *this == other_repr.value
                }
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::TransformOrigin>>);
                    *this == other_repr.value
                }
                GridTemplateColumns(ref this) |
GridTemplateRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridTemplateComponent>);
                    *this == other_repr.value
                }
                BorderImageSource(ref this) |
ListStyleImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Image>);
                    *this == other_repr.value
                }
                GridAutoColumns(ref this) |
GridAutoRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ImplicitGridTracks>);
                    *this == other_repr.value
                }
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Transform>);
                    *this == other_repr.value
                }
                ColumnGap(ref this) |
RowGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>);
                    *this == other_repr.value
                }
                MarkerEnd(ref this) |
MarkerMid(ref this) |
MarkerStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::url::UrlOrNone>);
                    *this == other_repr.value
                }
                ContainIntrinsicBlockSize(ref this) |
ContainIntrinsicHeight(ref this) |
ContainIntrinsicInlineSize(ref this) |
ContainIntrinsicWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ContainIntrinsicSize>);
                    *this == other_repr.value
                }
                GridColumnEnd(ref this) |
GridColumnStart(ref this) |
GridRowEnd(ref this) |
GridRowStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridLine>);
                    *this == other_repr.value
                }
                MaxBlockSize(ref this) |
MaxHeight(ref this) |
MaxInlineSize(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::MaxSize>);
                    *this == other_repr.value
                }
                Cx(ref this) |
Cy(ref this) |
OffsetDistance(ref this) |
X(ref this) |
Y(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentage>);
                    *this == other_repr.value
                }
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderEndEndRadius(ref this) |
BorderEndStartRadius(ref this) |
BorderStartEndRadius(ref this) |
BorderStartStartRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderCornerRadius>>);
                    *this == other_repr.value
                }
                BlockSize(ref this) |
Height(ref this) |
InlineSize(ref this) |
MinBlockSize(ref this) |
MinHeight(ref this) |
MinInlineSize(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Size>);
                    *this == other_repr.value
                }
                BorderBlockEndWidth(ref this) |
BorderBlockStartWidth(ref this) |
BorderBottomWidth(ref this) |
BorderInlineEndWidth(ref this) |
BorderInlineStartWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BorderSideWidth>);
                    *this == other_repr.value
                }
                PaddingBlockEnd(ref this) |
PaddingBlockStart(ref this) |
PaddingBottom(ref this) |
PaddingInlineEnd(ref this) |
PaddingInlineStart(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) |
R(ref this) |
ShapeMargin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentage>);
                    *this == other_repr.value
                }
                Rx(ref this) |
Ry(ref this) |
ScrollPaddingBlockEnd(ref this) |
ScrollPaddingBlockStart(ref this) |
ScrollPaddingBottom(ref this) |
ScrollPaddingInlineEnd(ref this) |
ScrollPaddingInlineStart(ref this) |
ScrollPaddingLeft(ref this) |
ScrollPaddingRight(ref this) |
ScrollPaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentageOrAuto>);
                    *this == other_repr.value
                }
                MozWindowInputRegionMargin(ref this) |
OutlineOffset(ref this) |
OverflowClipMargin(ref this) |
ScrollMarginBlockEnd(ref this) |
ScrollMarginBlockStart(ref this) |
ScrollMarginBottom(ref this) |
ScrollMarginInlineEnd(ref this) |
ScrollMarginInlineStart(ref this) |
ScrollMarginLeft(ref this) |
ScrollMarginRight(ref this) |
ScrollMarginTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Length>);
                    *this == other_repr.value
                }
                Bottom(ref this) |
InsetBlockEnd(ref this) |
InsetBlockStart(ref this) |
InsetInlineEnd(ref this) |
InsetInlineStart(ref this) |
Left(ref this) |
MarginBlockEnd(ref this) |
MarginBlockStart(ref this) |
MarginBottom(ref this) |
MarginInlineEnd(ref this) |
MarginInlineStart(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
Right(ref this) |
TextUnderlineOffset(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentageOrAuto>);
                    *this == other_repr.value
                }
                BackgroundColor(ref this) |
BorderBlockEndColor(ref this) |
BorderBlockStartColor(ref this) |
BorderBottomColor(ref this) |
BorderInlineEndColor(ref this) |
BorderInlineStartColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
FloodColor(ref this) |
LightingColor(ref this) |
OutlineColor(ref this) |
StopColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Color>);
                    *this == other_repr.value
                }
                CSSWideKeyword(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<WideKeywordDeclaration>);
                    *this == other_repr.value
                }
                WithVariables(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<VariableDeclaration>);
                    *this == other_repr.value
                }
                Custom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const PropertyDeclarationVariantRepr<CustomDeclaration>);
                    *this == other_repr.value
                }
            }
        }
    }
}

impl MallocSizeOf for PropertyDeclaration {
    #[inline]
    fn size_of(&self, ops: &mut MallocSizeOfOps) -> usize {
        use self::PropertyDeclaration::*;

        match *self {
            AlignContent(ref value) => {
                value.size_of(ops)
            }
            AlignItems(ref value) => {
                value.size_of(ops)
            }
            AlignSelf(ref value) => {
                value.size_of(ops)
            }
            AspectRatio(ref value) => {
                value.size_of(ops)
            }
            BackfaceVisibility(ref value) => {
                value.size_of(ops)
            }
            BaselineSource(ref value) => {
                value.size_of(ops)
            }
            BorderCollapse(ref value) => {
                value.size_of(ops)
            }
            BorderImageRepeat(ref value) => {
                value.size_of(ops)
            }
            BoxDecorationBreak(ref value) => {
                value.size_of(ops)
            }
            BoxSizing(ref value) => {
                value.size_of(ops)
            }
            BreakInside(ref value) => {
                value.size_of(ops)
            }
            CaptionSide(ref value) => {
                value.size_of(ops)
            }
            Clear(ref value) => {
                value.size_of(ops)
            }
            ColorInterpolation(ref value) => {
                value.size_of(ops)
            }
            ColorInterpolationFilters(ref value) => {
                value.size_of(ops)
            }
            ColumnCount(ref value) => {
                value.size_of(ops)
            }
            ColumnFill(ref value) => {
                value.size_of(ops)
            }
            ColumnSpan(ref value) => {
                value.size_of(ops)
            }
            Contain(ref value) => {
                value.size_of(ops)
            }
            ContainerType(ref value) => {
                value.size_of(ops)
            }
            ContentVisibility(ref value) => {
                value.size_of(ops)
            }
            Direction(ref value) => {
                value.size_of(ops)
            }
            Display(ref value) => {
                value.size_of(ops)
            }
            DominantBaseline(ref value) => {
                value.size_of(ops)
            }
            EmptyCells(ref value) => {
                value.size_of(ops)
            }
            FlexDirection(ref value) => {
                value.size_of(ops)
            }
            FlexWrap(ref value) => {
                value.size_of(ops)
            }
            Float(ref value) => {
                value.size_of(ops)
            }
            FontKerning(ref value) => {
                value.size_of(ops)
            }
            FontLanguageOverride(ref value) => {
                value.size_of(ops)
            }
            FontOpticalSizing(ref value) => {
                value.size_of(ops)
            }
            FontSizeAdjust(ref value) => {
                value.size_of(ops)
            }
            FontStretch(ref value) => {
                value.size_of(ops)
            }
            FontStyle(ref value) => {
                value.size_of(ops)
            }
            FontVariantCaps(ref value) => {
                value.size_of(ops)
            }
            FontVariantEastAsian(ref value) => {
                value.size_of(ops)
            }
            FontVariantEmoji(ref value) => {
                value.size_of(ops)
            }
            FontVariantLigatures(ref value) => {
                value.size_of(ops)
            }
            FontVariantNumeric(ref value) => {
                value.size_of(ops)
            }
            FontVariantPosition(ref value) => {
                value.size_of(ops)
            }
            FontWeight(ref value) => {
                value.size_of(ops)
            }
            ForcedColorAdjust(ref value) => {
                value.size_of(ops)
            }
            GridAutoFlow(ref value) => {
                value.size_of(ops)
            }
            Hyphens(ref value) => {
                value.size_of(ops)
            }
            ImageOrientation(ref value) => {
                value.size_of(ops)
            }
            ImageRendering(ref value) => {
                value.size_of(ops)
            }
            ImeMode(ref value) => {
                value.size_of(ops)
            }
            InitialLetter(ref value) => {
                value.size_of(ops)
            }
            InsetArea(ref value) => {
                value.size_of(ops)
            }
            Isolation(ref value) => {
                value.size_of(ops)
            }
            JustifyContent(ref value) => {
                value.size_of(ops)
            }
            JustifyItems(ref value) => {
                value.size_of(ops)
            }
            JustifySelf(ref value) => {
                value.size_of(ops)
            }
            LineBreak(ref value) => {
                value.size_of(ops)
            }
            ListStylePosition(ref value) => {
                value.size_of(ops)
            }
            MaskType(ref value) => {
                value.size_of(ops)
            }
            MasonryAutoFlow(ref value) => {
                value.size_of(ops)
            }
            MathDepth(ref value) => {
                value.size_of(ops)
            }
            MathStyle(ref value) => {
                value.size_of(ops)
            }
            MixBlendMode(ref value) => {
                value.size_of(ops)
            }
            MozBoxAlign(ref value) => {
                value.size_of(ops)
            }
            MozBoxCollapse(ref value) => {
                value.size_of(ops)
            }
            MozBoxDirection(ref value) => {
                value.size_of(ops)
            }
            MozBoxOrient(ref value) => {
                value.size_of(ops)
            }
            MozBoxPack(ref value) => {
                value.size_of(ops)
            }
            MozControlCharacterVisibility(ref value) => {
                value.size_of(ops)
            }
            MozFloatEdge(ref value) => {
                value.size_of(ops)
            }
            MozInert(ref value) => {
                value.size_of(ops)
            }
            MozMathVariant(ref value) => {
                value.size_of(ops)
            }
            MozMinFontSizeRatio(ref value) => {
                value.size_of(ops)
            }
            MozOrient(ref value) => {
                value.size_of(ops)
            }
            MozOsxFontSmoothing(ref value) => {
                value.size_of(ops)
            }
            MozTextSizeAdjust(ref value) => {
                value.size_of(ops)
            }
            MozTheme(ref value) => {
                value.size_of(ops)
            }
            MozTopLayer(ref value) => {
                value.size_of(ops)
            }
            MozUserFocus(ref value) => {
                value.size_of(ops)
            }
            MozUserInput(ref value) => {
                value.size_of(ops)
            }
            MozUserModify(ref value) => {
                value.size_of(ops)
            }
            MozWindowDragging(ref value) => {
                value.size_of(ops)
            }
            MozWindowShadow(ref value) => {
                value.size_of(ops)
            }
            ObjectFit(ref value) => {
                value.size_of(ops)
            }
            OffsetRotate(ref value) => {
                value.size_of(ops)
            }
            OutlineStyle(ref value) => {
                value.size_of(ops)
            }
            OverflowAnchor(ref value) => {
                value.size_of(ops)
            }
            OverflowWrap(ref value) => {
                value.size_of(ops)
            }
            PageOrientation(ref value) => {
                value.size_of(ops)
            }
            PaintOrder(ref value) => {
                value.size_of(ops)
            }
            PointerEvents(ref value) => {
                value.size_of(ops)
            }
            Position(ref value) => {
                value.size_of(ops)
            }
            PositionTryOrder(ref value) => {
                value.size_of(ops)
            }
            PositionVisibility(ref value) => {
                value.size_of(ops)
            }
            PrintColorAdjust(ref value) => {
                value.size_of(ops)
            }
            Resize(ref value) => {
                value.size_of(ops)
            }
            RubyAlign(ref value) => {
                value.size_of(ops)
            }
            RubyPosition(ref value) => {
                value.size_of(ops)
            }
            ScrollBehavior(ref value) => {
                value.size_of(ops)
            }
            ScrollSnapAlign(ref value) => {
                value.size_of(ops)
            }
            ScrollSnapStop(ref value) => {
                value.size_of(ops)
            }
            ScrollSnapType(ref value) => {
                value.size_of(ops)
            }
            ScrollbarGutter(ref value) => {
                value.size_of(ops)
            }
            ScrollbarWidth(ref value) => {
                value.size_of(ops)
            }
            ShapeRendering(ref value) => {
                value.size_of(ops)
            }
            StrokeLinecap(ref value) => {
                value.size_of(ops)
            }
            StrokeLinejoin(ref value) => {
                value.size_of(ops)
            }
            TableLayout(ref value) => {
                value.size_of(ops)
            }
            TextAlign(ref value) => {
                value.size_of(ops)
            }
            TextAlignLast(ref value) => {
                value.size_of(ops)
            }
            TextAnchor(ref value) => {
                value.size_of(ops)
            }
            TextCombineUpright(ref value) => {
                value.size_of(ops)
            }
            TextDecorationLine(ref value) => {
                value.size_of(ops)
            }
            TextDecorationSkipInk(ref value) => {
                value.size_of(ops)
            }
            TextDecorationStyle(ref value) => {
                value.size_of(ops)
            }
            TextEmphasisPosition(ref value) => {
                value.size_of(ops)
            }
            TextJustify(ref value) => {
                value.size_of(ops)
            }
            TextOrientation(ref value) => {
                value.size_of(ops)
            }
            TextRendering(ref value) => {
                value.size_of(ops)
            }
            TextTransform(ref value) => {
                value.size_of(ops)
            }
            TextUnderlinePosition(ref value) => {
                value.size_of(ops)
            }
            TextWrapMode(ref value) => {
                value.size_of(ops)
            }
            TextWrapStyle(ref value) => {
                value.size_of(ops)
            }
            TouchAction(ref value) => {
                value.size_of(ops)
            }
            TransformBox(ref value) => {
                value.size_of(ops)
            }
            TransformStyle(ref value) => {
                value.size_of(ops)
            }
            UnicodeBidi(ref value) => {
                value.size_of(ops)
            }
            UserSelect(ref value) => {
                value.size_of(ops)
            }
            VectorEffect(ref value) => {
                value.size_of(ops)
            }
            Visibility(ref value) => {
                value.size_of(ops)
            }
            WebkitLineClamp(ref value) => {
                value.size_of(ops)
            }
            WebkitTextSecurity(ref value) => {
                value.size_of(ops)
            }
            WhiteSpaceCollapse(ref value) => {
                value.size_of(ops)
            }
            WordBreak(ref value) => {
                value.size_of(ops)
            }
            WritingMode(ref value) => {
                value.size_of(ops)
            }
            XTextScale(ref value) => {
                value.size_of(ops)
            }
            ZIndex(ref value) => {
                value.size_of(ops)
            }
            Zoom(ref value) => {
                value.size_of(ops)
            }
            Appearance(ref value) | MozDefaultAppearance(ref value) => {
                value.size_of(ops)
            }
            MozForceBrokenImageIcon(ref value) | MozSubtreeHiddenOnlyVisually(ref value) => {
                value.size_of(ops)
            }
            BreakAfter(ref value) | BreakBefore(ref value) => {
                value.size_of(ops)
            }
            ClipRule(ref value) | FillRule(ref value) => {
                value.size_of(ops)
            }
            OverflowClipBoxBlock(ref value) | OverflowClipBoxInline(ref value) => {
                value.size_of(ops)
            }
            FillOpacity(ref value) | StrokeOpacity(ref value) => {
                value.size_of(ops)
            }
            MozBoxOrdinalGroup(ref value) | Order(ref value) | XSpan(ref value) => {
                value.size_of(ops)
            }
            FontSynthesisPosition(ref value) | FontSynthesisSmallCaps(ref value) | FontSynthesisStyle(ref value) | FontSynthesisWeight(ref value) => {
                value.size_of(ops)
            }
            FlexGrow(ref value) | FlexShrink(ref value) | MozBoxFlex(ref value) | StrokeMiterlimit(ref value) => {
                value.size_of(ops)
            }
            OverflowBlock(ref value) | OverflowInline(ref value) | OverflowX(ref value) | OverflowY(ref value) => {
                value.size_of(ops)
            }
            OverscrollBehaviorBlock(ref value) | OverscrollBehaviorInline(ref value) | OverscrollBehaviorX(ref value) | OverscrollBehaviorY(ref value) => {
                value.size_of(ops)
            }
            FloodOpacity(ref value) | MozWindowOpacity(ref value) | Opacity(ref value) | ShapeImageThreshold(ref value) | StopOpacity(ref value) => {
                value.size_of(ops)
            }
            BorderBlockEndStyle(ref value) | BorderBlockStartStyle(ref value) | BorderBottomStyle(ref value) | BorderInlineEndStyle(ref value) | BorderInlineStartStyle(ref value) | BorderLeftStyle(ref value) | BorderRightStyle(ref value) | BorderTopStyle(ref value) | ColumnRuleStyle(ref value) => {
                value.size_of(ops)
            }
            AccentColor(ref value) => {
                value.size_of(ops)
            }
            AnchorName(ref value) => {
                value.size_of(ops)
            }
            AnchorScope(ref value) => {
                value.size_of(ops)
            }
            AnimationComposition(ref value) => {
                value.size_of(ops)
            }
            AnimationDelay(ref value) => {
                value.size_of(ops)
            }
            AnimationDirection(ref value) => {
                value.size_of(ops)
            }
            AnimationDuration(ref value) => {
                value.size_of(ops)
            }
            AnimationFillMode(ref value) => {
                value.size_of(ops)
            }
            AnimationIterationCount(ref value) => {
                value.size_of(ops)
            }
            AnimationName(ref value) => {
                value.size_of(ops)
            }
            AnimationPlayState(ref value) => {
                value.size_of(ops)
            }
            AnimationTimeline(ref value) => {
                value.size_of(ops)
            }
            AnimationTimingFunction(ref value) => {
                value.size_of(ops)
            }
            BackdropFilter(ref value) => {
                value.size_of(ops)
            }
            BackgroundAttachment(ref value) => {
                value.size_of(ops)
            }
            BackgroundBlendMode(ref value) => {
                value.size_of(ops)
            }
            BackgroundClip(ref value) => {
                value.size_of(ops)
            }
            BackgroundImage(ref value) => {
                value.size_of(ops)
            }
            BackgroundOrigin(ref value) => {
                value.size_of(ops)
            }
            BackgroundPositionX(ref value) => {
                value.size_of(ops)
            }
            BackgroundPositionY(ref value) => {
                value.size_of(ops)
            }
            BackgroundRepeat(ref value) => {
                value.size_of(ops)
            }
            BackgroundSize(ref value) => {
                value.size_of(ops)
            }
            BorderImageOutset(ref value) => {
                value.size_of(ops)
            }
            BorderImageSlice(ref value) => {
                value.size_of(ops)
            }
            BorderImageWidth(ref value) => {
                value.size_of(ops)
            }
            BorderSpacing(ref value) => {
                value.size_of(ops)
            }
            BoxShadow(ref value) => {
                value.size_of(ops)
            }
            CaretColor(ref value) => {
                value.size_of(ops)
            }
            Clip(ref value) => {
                value.size_of(ops)
            }
            ClipPath(ref value) => {
                value.size_of(ops)
            }
            Color(ref value) => {
                value.size_of(ops)
            }
            ColorScheme(ref value) => {
                value.size_of(ops)
            }
            ColumnWidth(ref value) => {
                value.size_of(ops)
            }
            ContainerName(ref value) => {
                value.size_of(ops)
            }
            Content(ref value) => {
                value.size_of(ops)
            }
            CounterIncrement(ref value) => {
                value.size_of(ops)
            }
            CounterReset(ref value) => {
                value.size_of(ops)
            }
            CounterSet(ref value) => {
                value.size_of(ops)
            }
            Cursor(ref value) => {
                value.size_of(ops)
            }
            D(ref value) => {
                value.size_of(ops)
            }
            Filter(ref value) => {
                value.size_of(ops)
            }
            FlexBasis(ref value) => {
                value.size_of(ops)
            }
            FontFamily(ref value) => {
                value.size_of(ops)
            }
            FontFeatureSettings(ref value) => {
                value.size_of(ops)
            }
            FontPalette(ref value) => {
                value.size_of(ops)
            }
            FontSize(ref value) => {
                value.size_of(ops)
            }
            FontVariantAlternates(ref value) => {
                value.size_of(ops)
            }
            FontVariationSettings(ref value) => {
                value.size_of(ops)
            }
            GridTemplateAreas(ref value) => {
                value.size_of(ops)
            }
            HyphenateCharacter(ref value) => {
                value.size_of(ops)
            }
            LetterSpacing(ref value) => {
                value.size_of(ops)
            }
            LineHeight(ref value) => {
                value.size_of(ops)
            }
            ListStyleType(ref value) => {
                value.size_of(ops)
            }
            MaskClip(ref value) => {
                value.size_of(ops)
            }
            MaskComposite(ref value) => {
                value.size_of(ops)
            }
            MaskImage(ref value) => {
                value.size_of(ops)
            }
            MaskMode(ref value) => {
                value.size_of(ops)
            }
            MaskOrigin(ref value) => {
                value.size_of(ops)
            }
            MaskPositionX(ref value) => {
                value.size_of(ops)
            }
            MaskPositionY(ref value) => {
                value.size_of(ops)
            }
            MaskRepeat(ref value) => {
                value.size_of(ops)
            }
            MaskSize(ref value) => {
                value.size_of(ops)
            }
            MozContextProperties(ref value) => {
                value.size_of(ops)
            }
            OffsetAnchor(ref value) => {
                value.size_of(ops)
            }
            OffsetPath(ref value) => {
                value.size_of(ops)
            }
            OffsetPosition(ref value) => {
                value.size_of(ops)
            }
            Page(ref value) => {
                value.size_of(ops)
            }
            Perspective(ref value) => {
                value.size_of(ops)
            }
            PositionAnchor(ref value) => {
                value.size_of(ops)
            }
            PositionTryOptions(ref value) => {
                value.size_of(ops)
            }
            Quotes(ref value) => {
                value.size_of(ops)
            }
            Rotate(ref value) => {
                value.size_of(ops)
            }
            Scale(ref value) => {
                value.size_of(ops)
            }
            ScrollTimelineAxis(ref value) => {
                value.size_of(ops)
            }
            ScrollTimelineName(ref value) => {
                value.size_of(ops)
            }
            ScrollbarColor(ref value) => {
                value.size_of(ops)
            }
            ShapeOutside(ref value) => {
                value.size_of(ops)
            }
            Size(ref value) => {
                value.size_of(ops)
            }
            StrokeDasharray(ref value) => {
                value.size_of(ops)
            }
            StrokeDashoffset(ref value) => {
                value.size_of(ops)
            }
            StrokeWidth(ref value) => {
                value.size_of(ops)
            }
            TabSize(ref value) => {
                value.size_of(ops)
            }
            TextDecorationThickness(ref value) => {
                value.size_of(ops)
            }
            TextEmphasisStyle(ref value) => {
                value.size_of(ops)
            }
            TextIndent(ref value) => {
                value.size_of(ops)
            }
            TextOverflow(ref value) => {
                value.size_of(ops)
            }
            TextShadow(ref value) => {
                value.size_of(ops)
            }
            TransitionBehavior(ref value) => {
                value.size_of(ops)
            }
            TransitionDelay(ref value) => {
                value.size_of(ops)
            }
            TransitionDuration(ref value) => {
                value.size_of(ops)
            }
            TransitionProperty(ref value) => {
                value.size_of(ops)
            }
            TransitionTimingFunction(ref value) => {
                value.size_of(ops)
            }
            Translate(ref value) => {
                value.size_of(ops)
            }
            VerticalAlign(ref value) => {
                value.size_of(ops)
            }
            ViewTimelineAxis(ref value) => {
                value.size_of(ops)
            }
            ViewTimelineInset(ref value) => {
                value.size_of(ops)
            }
            ViewTimelineName(ref value) => {
                value.size_of(ops)
            }
            WebkitTextStrokeWidth(ref value) => {
                value.size_of(ops)
            }
            WillChange(ref value) => {
                value.size_of(ops)
            }
            WordSpacing(ref value) => {
                value.size_of(ops)
            }
            XLang(ref value) => {
                value.size_of(ops)
            }
            ObjectPosition(ref value) | PerspectiveOrigin(ref value) => {
                value.size_of(ops)
            }
            Fill(ref value) | Stroke(ref value) => {
                value.size_of(ops)
            }
            MozWindowTransformOrigin(ref value) | TransformOrigin(ref value) => {
                value.size_of(ops)
            }
            GridTemplateColumns(ref value) | GridTemplateRows(ref value) => {
                value.size_of(ops)
            }
            BorderImageSource(ref value) | ListStyleImage(ref value) => {
                value.size_of(ops)
            }
            GridAutoColumns(ref value) | GridAutoRows(ref value) => {
                value.size_of(ops)
            }
            MozWindowTransform(ref value) | Transform(ref value) => {
                value.size_of(ops)
            }
            ColumnGap(ref value) | RowGap(ref value) => {
                value.size_of(ops)
            }
            MarkerEnd(ref value) | MarkerMid(ref value) | MarkerStart(ref value) => {
                value.size_of(ops)
            }
            ContainIntrinsicBlockSize(ref value) | ContainIntrinsicHeight(ref value) | ContainIntrinsicInlineSize(ref value) | ContainIntrinsicWidth(ref value) => {
                value.size_of(ops)
            }
            GridColumnEnd(ref value) | GridColumnStart(ref value) | GridRowEnd(ref value) | GridRowStart(ref value) => {
                value.size_of(ops)
            }
            MaxBlockSize(ref value) | MaxHeight(ref value) | MaxInlineSize(ref value) | MaxWidth(ref value) => {
                value.size_of(ops)
            }
            Cx(ref value) | Cy(ref value) | OffsetDistance(ref value) | X(ref value) | Y(ref value) => {
                value.size_of(ops)
            }
            BorderBottomLeftRadius(ref value) | BorderBottomRightRadius(ref value) | BorderEndEndRadius(ref value) | BorderEndStartRadius(ref value) | BorderStartEndRadius(ref value) | BorderStartStartRadius(ref value) | BorderTopLeftRadius(ref value) | BorderTopRightRadius(ref value) => {
                value.size_of(ops)
            }
            BlockSize(ref value) | Height(ref value) | InlineSize(ref value) | MinBlockSize(ref value) | MinHeight(ref value) | MinInlineSize(ref value) | MinWidth(ref value) | Width(ref value) => {
                value.size_of(ops)
            }
            BorderBlockEndWidth(ref value) | BorderBlockStartWidth(ref value) | BorderBottomWidth(ref value) | BorderInlineEndWidth(ref value) | BorderInlineStartWidth(ref value) | BorderLeftWidth(ref value) | BorderRightWidth(ref value) | BorderTopWidth(ref value) | ColumnRuleWidth(ref value) | OutlineWidth(ref value) => {
                value.size_of(ops)
            }
            PaddingBlockEnd(ref value) | PaddingBlockStart(ref value) | PaddingBottom(ref value) | PaddingInlineEnd(ref value) | PaddingInlineStart(ref value) | PaddingLeft(ref value) | PaddingRight(ref value) | PaddingTop(ref value) | R(ref value) | ShapeMargin(ref value) => {
                value.size_of(ops)
            }
            Rx(ref value) | Ry(ref value) | ScrollPaddingBlockEnd(ref value) | ScrollPaddingBlockStart(ref value) | ScrollPaddingBottom(ref value) | ScrollPaddingInlineEnd(ref value) | ScrollPaddingInlineStart(ref value) | ScrollPaddingLeft(ref value) | ScrollPaddingRight(ref value) | ScrollPaddingTop(ref value) => {
                value.size_of(ops)
            }
            MozWindowInputRegionMargin(ref value) | OutlineOffset(ref value) | OverflowClipMargin(ref value) | ScrollMarginBlockEnd(ref value) | ScrollMarginBlockStart(ref value) | ScrollMarginBottom(ref value) | ScrollMarginInlineEnd(ref value) | ScrollMarginInlineStart(ref value) | ScrollMarginLeft(ref value) | ScrollMarginRight(ref value) | ScrollMarginTop(ref value) => {
                value.size_of(ops)
            }
            Bottom(ref value) | InsetBlockEnd(ref value) | InsetBlockStart(ref value) | InsetInlineEnd(ref value) | InsetInlineStart(ref value) | Left(ref value) | MarginBlockEnd(ref value) | MarginBlockStart(ref value) | MarginBottom(ref value) | MarginInlineEnd(ref value) | MarginInlineStart(ref value) | MarginLeft(ref value) | MarginRight(ref value) | MarginTop(ref value) | Right(ref value) | TextUnderlineOffset(ref value) | Top(ref value) => {
                value.size_of(ops)
            }
            BackgroundColor(ref value) | BorderBlockEndColor(ref value) | BorderBlockStartColor(ref value) | BorderBottomColor(ref value) | BorderInlineEndColor(ref value) | BorderInlineStartColor(ref value) | BorderLeftColor(ref value) | BorderRightColor(ref value) | BorderTopColor(ref value) | ColumnRuleColor(ref value) | FloodColor(ref value) | LightingColor(ref value) | OutlineColor(ref value) | StopColor(ref value) | TextDecorationColor(ref value) | TextEmphasisColor(ref value) | WebkitTextFillColor(ref value) | WebkitTextStrokeColor(ref value) => {
                value.size_of(ops)
            }
            CSSWideKeyword(ref value) => {
                value.size_of(ops)
            }
            WithVariables(ref value) => {
                value.size_of(ops)
            }
            Custom(ref value) => {
                value.size_of(ops)
            }
        }
    }
}


impl PropertyDeclaration {
    /// Returns the given value for this declaration as a particular type.
    /// It's the caller's responsibility to guarantee that the longhand id has the right specified
    /// value representation.
    pub(crate) unsafe fn unchecked_value_as<T>(&self) -> &T {
        &(*(self as *const _ as *const PropertyDeclarationVariantRepr<T>)).value
    }

    /// Dumps the property declaration before crashing.
    #[cold]
    #[cfg(debug_assertions)]
    pub(crate) fn debug_crash(&self, reason: &str) {
        panic!("{}: {:?}", reason, self);
    }
    #[cfg(not(debug_assertions))]
    #[inline(always)]
    pub(crate) fn debug_crash(&self, _reason: &str) {}

    /// Returns whether this is a variant of the Longhand(Value) type, rather
    /// than one of the special variants in extra_variants.
    fn is_longhand_value(&self) -> bool {
        match *self {
            PropertyDeclaration::CSSWideKeyword(..) => false,
            PropertyDeclaration::WithVariables(..) => false,
            PropertyDeclaration::Custom(..) => false,
            _ => true,
        }
    }

    /// Like the method on ToCss, but without the type parameter to avoid
    /// accidentally monomorphizing this large function multiple times for
    /// different writers.
    pub fn to_css(&self, dest: &mut CssStringWriter) -> fmt::Result {
        use self::PropertyDeclaration::*;

        let mut dest = CssWriter::new(dest);
        match *self {
            AlignContent(ref value) => {
                value.to_css(&mut dest)
            }
            AlignItems(ref value) => {
                value.to_css(&mut dest)
            }
            AlignSelf(ref value) => {
                value.to_css(&mut dest)
            }
            AspectRatio(ref value) => {
                value.to_css(&mut dest)
            }
            BackfaceVisibility(ref value) => {
                value.to_css(&mut dest)
            }
            BaselineSource(ref value) => {
                value.to_css(&mut dest)
            }
            BorderCollapse(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageRepeat(ref value) => {
                value.to_css(&mut dest)
            }
            BoxDecorationBreak(ref value) => {
                value.to_css(&mut dest)
            }
            BoxSizing(ref value) => {
                value.to_css(&mut dest)
            }
            BreakInside(ref value) => {
                value.to_css(&mut dest)
            }
            CaptionSide(ref value) => {
                value.to_css(&mut dest)
            }
            Clear(ref value) => {
                value.to_css(&mut dest)
            }
            ColorInterpolation(ref value) => {
                value.to_css(&mut dest)
            }
            ColorInterpolationFilters(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnCount(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnFill(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnSpan(ref value) => {
                value.to_css(&mut dest)
            }
            Contain(ref value) => {
                value.to_css(&mut dest)
            }
            ContainerType(ref value) => {
                value.to_css(&mut dest)
            }
            ContentVisibility(ref value) => {
                value.to_css(&mut dest)
            }
            Direction(ref value) => {
                value.to_css(&mut dest)
            }
            Display(ref value) => {
                value.to_css(&mut dest)
            }
            DominantBaseline(ref value) => {
                value.to_css(&mut dest)
            }
            EmptyCells(ref value) => {
                value.to_css(&mut dest)
            }
            FlexDirection(ref value) => {
                value.to_css(&mut dest)
            }
            FlexWrap(ref value) => {
                value.to_css(&mut dest)
            }
            Float(ref value) => {
                value.to_css(&mut dest)
            }
            FontKerning(ref value) => {
                value.to_css(&mut dest)
            }
            FontLanguageOverride(ref value) => {
                value.to_css(&mut dest)
            }
            FontOpticalSizing(ref value) => {
                value.to_css(&mut dest)
            }
            FontSizeAdjust(ref value) => {
                value.to_css(&mut dest)
            }
            FontStretch(ref value) => {
                value.to_css(&mut dest)
            }
            FontStyle(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantCaps(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantEastAsian(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantEmoji(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantLigatures(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantNumeric(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantPosition(ref value) => {
                value.to_css(&mut dest)
            }
            FontWeight(ref value) => {
                value.to_css(&mut dest)
            }
            ForcedColorAdjust(ref value) => {
                value.to_css(&mut dest)
            }
            GridAutoFlow(ref value) => {
                value.to_css(&mut dest)
            }
            Hyphens(ref value) => {
                value.to_css(&mut dest)
            }
            ImageOrientation(ref value) => {
                value.to_css(&mut dest)
            }
            ImageRendering(ref value) => {
                value.to_css(&mut dest)
            }
            ImeMode(ref value) => {
                value.to_css(&mut dest)
            }
            InitialLetter(ref value) => {
                value.to_css(&mut dest)
            }
            InsetArea(ref value) => {
                value.to_css(&mut dest)
            }
            Isolation(ref value) => {
                value.to_css(&mut dest)
            }
            JustifyContent(ref value) => {
                value.to_css(&mut dest)
            }
            JustifyItems(ref value) => {
                value.to_css(&mut dest)
            }
            JustifySelf(ref value) => {
                value.to_css(&mut dest)
            }
            LineBreak(ref value) => {
                value.to_css(&mut dest)
            }
            ListStylePosition(ref value) => {
                value.to_css(&mut dest)
            }
            MaskType(ref value) => {
                value.to_css(&mut dest)
            }
            MasonryAutoFlow(ref value) => {
                value.to_css(&mut dest)
            }
            MathDepth(ref value) => {
                value.to_css(&mut dest)
            }
            MathStyle(ref value) => {
                value.to_css(&mut dest)
            }
            MixBlendMode(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxAlign(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxCollapse(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxDirection(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxOrient(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxPack(ref value) => {
                value.to_css(&mut dest)
            }
            MozControlCharacterVisibility(ref value) => {
                value.to_css(&mut dest)
            }
            MozFloatEdge(ref value) => {
                value.to_css(&mut dest)
            }
            MozInert(ref value) => {
                value.to_css(&mut dest)
            }
            MozMathVariant(ref value) => {
                value.to_css(&mut dest)
            }
            MozMinFontSizeRatio(ref value) => {
                value.to_css(&mut dest)
            }
            MozOrient(ref value) => {
                value.to_css(&mut dest)
            }
            MozOsxFontSmoothing(ref value) => {
                value.to_css(&mut dest)
            }
            MozTextSizeAdjust(ref value) => {
                value.to_css(&mut dest)
            }
            MozTheme(ref value) => {
                value.to_css(&mut dest)
            }
            MozTopLayer(ref value) => {
                value.to_css(&mut dest)
            }
            MozUserFocus(ref value) => {
                value.to_css(&mut dest)
            }
            MozUserInput(ref value) => {
                value.to_css(&mut dest)
            }
            MozUserModify(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowDragging(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowShadow(ref value) => {
                value.to_css(&mut dest)
            }
            ObjectFit(ref value) => {
                value.to_css(&mut dest)
            }
            OffsetRotate(ref value) => {
                value.to_css(&mut dest)
            }
            OutlineStyle(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowAnchor(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowWrap(ref value) => {
                value.to_css(&mut dest)
            }
            PageOrientation(ref value) => {
                value.to_css(&mut dest)
            }
            PaintOrder(ref value) => {
                value.to_css(&mut dest)
            }
            PointerEvents(ref value) => {
                value.to_css(&mut dest)
            }
            Position(ref value) => {
                value.to_css(&mut dest)
            }
            PositionTryOrder(ref value) => {
                value.to_css(&mut dest)
            }
            PositionVisibility(ref value) => {
                value.to_css(&mut dest)
            }
            PrintColorAdjust(ref value) => {
                value.to_css(&mut dest)
            }
            Resize(ref value) => {
                value.to_css(&mut dest)
            }
            RubyAlign(ref value) => {
                value.to_css(&mut dest)
            }
            RubyPosition(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollBehavior(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollSnapAlign(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollSnapStop(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollSnapType(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollbarGutter(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollbarWidth(ref value) => {
                value.to_css(&mut dest)
            }
            ShapeRendering(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeLinecap(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeLinejoin(ref value) => {
                value.to_css(&mut dest)
            }
            TableLayout(ref value) => {
                value.to_css(&mut dest)
            }
            TextAlign(ref value) => {
                value.to_css(&mut dest)
            }
            TextAlignLast(ref value) => {
                value.to_css(&mut dest)
            }
            TextAnchor(ref value) => {
                value.to_css(&mut dest)
            }
            TextCombineUpright(ref value) => {
                value.to_css(&mut dest)
            }
            TextDecorationLine(ref value) => {
                value.to_css(&mut dest)
            }
            TextDecorationSkipInk(ref value) => {
                value.to_css(&mut dest)
            }
            TextDecorationStyle(ref value) => {
                value.to_css(&mut dest)
            }
            TextEmphasisPosition(ref value) => {
                value.to_css(&mut dest)
            }
            TextJustify(ref value) => {
                value.to_css(&mut dest)
            }
            TextOrientation(ref value) => {
                value.to_css(&mut dest)
            }
            TextRendering(ref value) => {
                value.to_css(&mut dest)
            }
            TextTransform(ref value) => {
                value.to_css(&mut dest)
            }
            TextUnderlinePosition(ref value) => {
                value.to_css(&mut dest)
            }
            TextWrapMode(ref value) => {
                value.to_css(&mut dest)
            }
            TextWrapStyle(ref value) => {
                value.to_css(&mut dest)
            }
            TouchAction(ref value) => {
                value.to_css(&mut dest)
            }
            TransformBox(ref value) => {
                value.to_css(&mut dest)
            }
            TransformStyle(ref value) => {
                value.to_css(&mut dest)
            }
            UnicodeBidi(ref value) => {
                value.to_css(&mut dest)
            }
            UserSelect(ref value) => {
                value.to_css(&mut dest)
            }
            VectorEffect(ref value) => {
                value.to_css(&mut dest)
            }
            Visibility(ref value) => {
                value.to_css(&mut dest)
            }
            WebkitLineClamp(ref value) => {
                value.to_css(&mut dest)
            }
            WebkitTextSecurity(ref value) => {
                value.to_css(&mut dest)
            }
            WhiteSpaceCollapse(ref value) => {
                value.to_css(&mut dest)
            }
            WordBreak(ref value) => {
                value.to_css(&mut dest)
            }
            WritingMode(ref value) => {
                value.to_css(&mut dest)
            }
            XTextScale(ref value) => {
                value.to_css(&mut dest)
            }
            ZIndex(ref value) => {
                value.to_css(&mut dest)
            }
            Zoom(ref value) => {
                value.to_css(&mut dest)
            }
            Appearance(ref value) | MozDefaultAppearance(ref value) => {
                value.to_css(&mut dest)
            }
            MozForceBrokenImageIcon(ref value) | MozSubtreeHiddenOnlyVisually(ref value) => {
                value.to_css(&mut dest)
            }
            BreakAfter(ref value) | BreakBefore(ref value) => {
                value.to_css(&mut dest)
            }
            ClipRule(ref value) | FillRule(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowClipBoxBlock(ref value) | OverflowClipBoxInline(ref value) => {
                value.to_css(&mut dest)
            }
            FillOpacity(ref value) | StrokeOpacity(ref value) => {
                value.to_css(&mut dest)
            }
            MozBoxOrdinalGroup(ref value) | Order(ref value) | XSpan(ref value) => {
                value.to_css(&mut dest)
            }
            FontSynthesisPosition(ref value) | FontSynthesisSmallCaps(ref value) | FontSynthesisStyle(ref value) | FontSynthesisWeight(ref value) => {
                value.to_css(&mut dest)
            }
            FlexGrow(ref value) | FlexShrink(ref value) | MozBoxFlex(ref value) | StrokeMiterlimit(ref value) => {
                value.to_css(&mut dest)
            }
            OverflowBlock(ref value) | OverflowInline(ref value) | OverflowX(ref value) | OverflowY(ref value) => {
                value.to_css(&mut dest)
            }
            OverscrollBehaviorBlock(ref value) | OverscrollBehaviorInline(ref value) | OverscrollBehaviorX(ref value) | OverscrollBehaviorY(ref value) => {
                value.to_css(&mut dest)
            }
            FloodOpacity(ref value) | MozWindowOpacity(ref value) | Opacity(ref value) | ShapeImageThreshold(ref value) | StopOpacity(ref value) => {
                value.to_css(&mut dest)
            }
            BorderBlockEndStyle(ref value) | BorderBlockStartStyle(ref value) | BorderBottomStyle(ref value) | BorderInlineEndStyle(ref value) | BorderInlineStartStyle(ref value) | BorderLeftStyle(ref value) | BorderRightStyle(ref value) | BorderTopStyle(ref value) | ColumnRuleStyle(ref value) => {
                value.to_css(&mut dest)
            }
            AccentColor(ref value) => {
                value.to_css(&mut dest)
            }
            AnchorName(ref value) => {
                value.to_css(&mut dest)
            }
            AnchorScope(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationComposition(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationDelay(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationDirection(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationDuration(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationFillMode(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationIterationCount(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationName(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationPlayState(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationTimeline(ref value) => {
                value.to_css(&mut dest)
            }
            AnimationTimingFunction(ref value) => {
                value.to_css(&mut dest)
            }
            BackdropFilter(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundAttachment(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundBlendMode(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundClip(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundImage(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundPositionX(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundPositionY(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundRepeat(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundSize(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageOutset(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageSlice(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageWidth(ref value) => {
                value.to_css(&mut dest)
            }
            BorderSpacing(ref value) => {
                value.to_css(&mut dest)
            }
            BoxShadow(ref value) => {
                value.to_css(&mut dest)
            }
            CaretColor(ref value) => {
                value.to_css(&mut dest)
            }
            Clip(ref value) => {
                value.to_css(&mut dest)
            }
            ClipPath(ref value) => {
                value.to_css(&mut dest)
            }
            Color(ref value) => {
                value.to_css(&mut dest)
            }
            ColorScheme(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnWidth(ref value) => {
                value.to_css(&mut dest)
            }
            ContainerName(ref value) => {
                value.to_css(&mut dest)
            }
            Content(ref value) => {
                value.to_css(&mut dest)
            }
            CounterIncrement(ref value) => {
                value.to_css(&mut dest)
            }
            CounterReset(ref value) => {
                value.to_css(&mut dest)
            }
            CounterSet(ref value) => {
                value.to_css(&mut dest)
            }
            Cursor(ref value) => {
                value.to_css(&mut dest)
            }
            D(ref value) => {
                value.to_css(&mut dest)
            }
            Filter(ref value) => {
                value.to_css(&mut dest)
            }
            FlexBasis(ref value) => {
                value.to_css(&mut dest)
            }
            FontFamily(ref value) => {
                value.to_css(&mut dest)
            }
            FontFeatureSettings(ref value) => {
                value.to_css(&mut dest)
            }
            FontPalette(ref value) => {
                value.to_css(&mut dest)
            }
            FontSize(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariantAlternates(ref value) => {
                value.to_css(&mut dest)
            }
            FontVariationSettings(ref value) => {
                value.to_css(&mut dest)
            }
            GridTemplateAreas(ref value) => {
                value.to_css(&mut dest)
            }
            HyphenateCharacter(ref value) => {
                value.to_css(&mut dest)
            }
            LetterSpacing(ref value) => {
                value.to_css(&mut dest)
            }
            LineHeight(ref value) => {
                value.to_css(&mut dest)
            }
            ListStyleType(ref value) => {
                value.to_css(&mut dest)
            }
            MaskClip(ref value) => {
                value.to_css(&mut dest)
            }
            MaskComposite(ref value) => {
                value.to_css(&mut dest)
            }
            MaskImage(ref value) => {
                value.to_css(&mut dest)
            }
            MaskMode(ref value) => {
                value.to_css(&mut dest)
            }
            MaskOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            MaskPositionX(ref value) => {
                value.to_css(&mut dest)
            }
            MaskPositionY(ref value) => {
                value.to_css(&mut dest)
            }
            MaskRepeat(ref value) => {
                value.to_css(&mut dest)
            }
            MaskSize(ref value) => {
                value.to_css(&mut dest)
            }
            MozContextProperties(ref value) => {
                value.to_css(&mut dest)
            }
            OffsetAnchor(ref value) => {
                value.to_css(&mut dest)
            }
            OffsetPath(ref value) => {
                value.to_css(&mut dest)
            }
            OffsetPosition(ref value) => {
                value.to_css(&mut dest)
            }
            Page(ref value) => {
                value.to_css(&mut dest)
            }
            Perspective(ref value) => {
                value.to_css(&mut dest)
            }
            PositionAnchor(ref value) => {
                value.to_css(&mut dest)
            }
            PositionTryOptions(ref value) => {
                value.to_css(&mut dest)
            }
            Quotes(ref value) => {
                value.to_css(&mut dest)
            }
            Rotate(ref value) => {
                value.to_css(&mut dest)
            }
            Scale(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollTimelineAxis(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollTimelineName(ref value) => {
                value.to_css(&mut dest)
            }
            ScrollbarColor(ref value) => {
                value.to_css(&mut dest)
            }
            ShapeOutside(ref value) => {
                value.to_css(&mut dest)
            }
            Size(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeDasharray(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeDashoffset(ref value) => {
                value.to_css(&mut dest)
            }
            StrokeWidth(ref value) => {
                value.to_css(&mut dest)
            }
            TabSize(ref value) => {
                value.to_css(&mut dest)
            }
            TextDecorationThickness(ref value) => {
                value.to_css(&mut dest)
            }
            TextEmphasisStyle(ref value) => {
                value.to_css(&mut dest)
            }
            TextIndent(ref value) => {
                value.to_css(&mut dest)
            }
            TextOverflow(ref value) => {
                value.to_css(&mut dest)
            }
            TextShadow(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionBehavior(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionDelay(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionDuration(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionProperty(ref value) => {
                value.to_css(&mut dest)
            }
            TransitionTimingFunction(ref value) => {
                value.to_css(&mut dest)
            }
            Translate(ref value) => {
                value.to_css(&mut dest)
            }
            VerticalAlign(ref value) => {
                value.to_css(&mut dest)
            }
            ViewTimelineAxis(ref value) => {
                value.to_css(&mut dest)
            }
            ViewTimelineInset(ref value) => {
                value.to_css(&mut dest)
            }
            ViewTimelineName(ref value) => {
                value.to_css(&mut dest)
            }
            WebkitTextStrokeWidth(ref value) => {
                value.to_css(&mut dest)
            }
            WillChange(ref value) => {
                value.to_css(&mut dest)
            }
            WordSpacing(ref value) => {
                value.to_css(&mut dest)
            }
            XLang(ref value) => {
                value.to_css(&mut dest)
            }
            ObjectPosition(ref value) | PerspectiveOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            Fill(ref value) | Stroke(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowTransformOrigin(ref value) | TransformOrigin(ref value) => {
                value.to_css(&mut dest)
            }
            GridTemplateColumns(ref value) | GridTemplateRows(ref value) => {
                value.to_css(&mut dest)
            }
            BorderImageSource(ref value) | ListStyleImage(ref value) => {
                value.to_css(&mut dest)
            }
            GridAutoColumns(ref value) | GridAutoRows(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowTransform(ref value) | Transform(ref value) => {
                value.to_css(&mut dest)
            }
            ColumnGap(ref value) | RowGap(ref value) => {
                value.to_css(&mut dest)
            }
            MarkerEnd(ref value) | MarkerMid(ref value) | MarkerStart(ref value) => {
                value.to_css(&mut dest)
            }
            ContainIntrinsicBlockSize(ref value) | ContainIntrinsicHeight(ref value) | ContainIntrinsicInlineSize(ref value) | ContainIntrinsicWidth(ref value) => {
                value.to_css(&mut dest)
            }
            GridColumnEnd(ref value) | GridColumnStart(ref value) | GridRowEnd(ref value) | GridRowStart(ref value) => {
                value.to_css(&mut dest)
            }
            MaxBlockSize(ref value) | MaxHeight(ref value) | MaxInlineSize(ref value) | MaxWidth(ref value) => {
                value.to_css(&mut dest)
            }
            Cx(ref value) | Cy(ref value) | OffsetDistance(ref value) | X(ref value) | Y(ref value) => {
                value.to_css(&mut dest)
            }
            BorderBottomLeftRadius(ref value) | BorderBottomRightRadius(ref value) | BorderEndEndRadius(ref value) | BorderEndStartRadius(ref value) | BorderStartEndRadius(ref value) | BorderStartStartRadius(ref value) | BorderTopLeftRadius(ref value) | BorderTopRightRadius(ref value) => {
                value.to_css(&mut dest)
            }
            BlockSize(ref value) | Height(ref value) | InlineSize(ref value) | MinBlockSize(ref value) | MinHeight(ref value) | MinInlineSize(ref value) | MinWidth(ref value) | Width(ref value) => {
                value.to_css(&mut dest)
            }
            BorderBlockEndWidth(ref value) | BorderBlockStartWidth(ref value) | BorderBottomWidth(ref value) | BorderInlineEndWidth(ref value) | BorderInlineStartWidth(ref value) | BorderLeftWidth(ref value) | BorderRightWidth(ref value) | BorderTopWidth(ref value) | ColumnRuleWidth(ref value) | OutlineWidth(ref value) => {
                value.to_css(&mut dest)
            }
            PaddingBlockEnd(ref value) | PaddingBlockStart(ref value) | PaddingBottom(ref value) | PaddingInlineEnd(ref value) | PaddingInlineStart(ref value) | PaddingLeft(ref value) | PaddingRight(ref value) | PaddingTop(ref value) | R(ref value) | ShapeMargin(ref value) => {
                value.to_css(&mut dest)
            }
            Rx(ref value) | Ry(ref value) | ScrollPaddingBlockEnd(ref value) | ScrollPaddingBlockStart(ref value) | ScrollPaddingBottom(ref value) | ScrollPaddingInlineEnd(ref value) | ScrollPaddingInlineStart(ref value) | ScrollPaddingLeft(ref value) | ScrollPaddingRight(ref value) | ScrollPaddingTop(ref value) => {
                value.to_css(&mut dest)
            }
            MozWindowInputRegionMargin(ref value) | OutlineOffset(ref value) | OverflowClipMargin(ref value) | ScrollMarginBlockEnd(ref value) | ScrollMarginBlockStart(ref value) | ScrollMarginBottom(ref value) | ScrollMarginInlineEnd(ref value) | ScrollMarginInlineStart(ref value) | ScrollMarginLeft(ref value) | ScrollMarginRight(ref value) | ScrollMarginTop(ref value) => {
                value.to_css(&mut dest)
            }
            Bottom(ref value) | InsetBlockEnd(ref value) | InsetBlockStart(ref value) | InsetInlineEnd(ref value) | InsetInlineStart(ref value) | Left(ref value) | MarginBlockEnd(ref value) | MarginBlockStart(ref value) | MarginBottom(ref value) | MarginInlineEnd(ref value) | MarginInlineStart(ref value) | MarginLeft(ref value) | MarginRight(ref value) | MarginTop(ref value) | Right(ref value) | TextUnderlineOffset(ref value) | Top(ref value) => {
                value.to_css(&mut dest)
            }
            BackgroundColor(ref value) | BorderBlockEndColor(ref value) | BorderBlockStartColor(ref value) | BorderBottomColor(ref value) | BorderInlineEndColor(ref value) | BorderInlineStartColor(ref value) | BorderLeftColor(ref value) | BorderRightColor(ref value) | BorderTopColor(ref value) | ColumnRuleColor(ref value) | FloodColor(ref value) | LightingColor(ref value) | OutlineColor(ref value) | StopColor(ref value) | TextDecorationColor(ref value) | TextEmphasisColor(ref value) | WebkitTextFillColor(ref value) | WebkitTextStrokeColor(ref value) => {
                value.to_css(&mut dest)
            }
            CSSWideKeyword(ref value) => {
                value.to_css(&mut dest)
            }
            WithVariables(ref value) => {
                value.to_css(&mut dest)
            }
            Custom(ref value) => {
                value.to_css(&mut dest)
            }
        }
    }

    /// Returns the color value of a given property, for high-contrast-mode tweaks.
    pub(super) fn color_value(&self) -> Option<&crate::values::specified::Color> {
        
static COLOR_PROPERTIES: LonghandIdSet = LonghandIdSet {
    
    storage: [0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x3ffff00]
};

        
        let id = self.id().as_longhand()?;
        if !COLOR_PROPERTIES.contains(id) || !self.is_longhand_value() {
            return None;
        }
        let repr = self as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Color>;
        Some(unsafe { &(*repr).value })
    }
}

/// A module with all the code related to animated properties.
///
/// This needs to be "included" by mako at least after all longhand modules,
/// given they populate the global data.
pub mod animated_properties {
    /* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at https://mozilla.org/MPL/2.0/. */





#[cfg(feature = "gecko")] use crate::gecko_bindings::structs::nsCSSPropertyID;
use crate::properties::{
    longhands::{
        self, content_visibility::computed_value::T as ContentVisibility,
        visibility::computed_value::T as Visibility,
    },
    CSSWideKeyword, NonCustomPropertyId, LonghandId, NonCustomPropertyIterator,
    PropertyDeclaration, PropertyDeclarationId,
};
use std::ptr;
use std::mem;
use fxhash::FxHashMap;
use super::ComputedValues;
use crate::properties::OwnedPropertyDeclarationId;
use crate::values::animated::{Animate, Procedure, ToAnimatedValue, ToAnimatedZero};
use crate::values::animated::effects::AnimatedFilter;
#[cfg(feature = "gecko")] use crate::values::computed::TransitionProperty;
use crate::values::computed::{ClipRect, Context};
use crate::values::computed::ToComputedValue;
use crate::values::distance::{ComputeSquaredDistance, SquaredDistance};
use crate::values::generics::effects::Filter;
use void::{self, Void};
use crate::properties_and_values::value::CustomAnimatedValue;

/// Convert nsCSSPropertyID to TransitionProperty
#[cfg(feature = "gecko")]
#[allow(non_upper_case_globals)]
impl From<nsCSSPropertyID> for TransitionProperty {
    fn from(property: nsCSSPropertyID) -> TransitionProperty {
        TransitionProperty::NonCustom(NonCustomPropertyId::from_nscsspropertyid(property).unwrap())
    }
}

/// A collection of AnimationValue that were composed on an element.
/// This HashMap stores the values that are the last AnimationValue to be
/// composed for each TransitionProperty.
pub type AnimationValueMap = FxHashMap<OwnedPropertyDeclarationId, AnimationValue>;

/// An enum to represent a single computed value belonging to an animated
/// property in order to be interpolated with another one. When interpolating,
/// both values need to belong to the same property.
#[derive(Debug, MallocSizeOf)]
#[repr(u16)]
pub enum AnimationValue {
    /// `align-content`
    AlignContent(<crate::values::specified::AlignContent as ToComputedValue>::ComputedValue),
    /// `align-items`
    AlignItems(<crate::values::specified::AlignItems as ToComputedValue>::ComputedValue),
    /// `align-self`
    AlignSelf(<crate::values::specified::AlignSelf as ToComputedValue>::ComputedValue),
    /// `aspect-ratio`
    AspectRatio(<crate::values::specified::AspectRatio as ToComputedValue>::ComputedValue),
    /// `backface-visibility`
    BackfaceVisibility(<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `baseline-source`
    BaselineSource(<crate::values::specified::BaselineSource as ToComputedValue>::ComputedValue),
    /// `border-collapse`
    BorderCollapse(<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `border-image-repeat`
    BorderImageRepeat(<crate::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue),
    /// `box-decoration-break`
    BoxDecorationBreak(<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `box-sizing`
    BoxSizing(<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `break-inside`
    BreakInside(<crate::values::specified::BreakWithin as ToComputedValue>::ComputedValue),
    /// `caption-side`
    CaptionSide(<crate::values::specified::table::CaptionSide as ToComputedValue>::ComputedValue),
    /// `clear`
    Clear(<crate::values::specified::Clear as ToComputedValue>::ComputedValue),
    /// `color-interpolation`
    ColorInterpolation(<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `color-interpolation-filters`
    ColorInterpolationFilters(<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `column-count`
    ColumnCount(<<crate::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-fill`
    ColumnFill(<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `column-span`
    ColumnSpan(<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `contain`
    Contain(Void),
    /// `container-type`
    ContainerType(Void),
    /// `content-visibility`
    ContentVisibility(<crate::values::specified::ContentVisibility as ToComputedValue>::ComputedValue),
    /// `direction`
    Direction(Void),
    /// `display`
    Display(<crate::values::specified::Display as ToComputedValue>::ComputedValue),
    /// `dominant-baseline`
    DominantBaseline(<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `empty-cells`
    EmptyCells(<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `flex-direction`
    FlexDirection(<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `flex-wrap`
    FlexWrap(<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `float`
    Float(<crate::values::specified::Float as ToComputedValue>::ComputedValue),
    /// `font-kerning`
    FontKerning(<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-language-override`
    FontLanguageOverride(<crate::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue),
    /// `font-optical-sizing`
    FontOpticalSizing(<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-size-adjust`
    FontSizeAdjust(<<crate::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `font-stretch`
    FontStretch(<<crate::values::specified::FontStretch as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `font-style`
    FontStyle(<<crate::values::specified::FontStyle as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `font-variant-caps`
    FontVariantCaps(<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-variant-east-asian`
    FontVariantEastAsian(<crate::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue),
    /// `font-variant-emoji`
    FontVariantEmoji(<longhands::font_variant_emoji::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-variant-ligatures`
    FontVariantLigatures(<crate::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue),
    /// `font-variant-numeric`
    FontVariantNumeric(<crate::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue),
    /// `font-variant-position`
    FontVariantPosition(<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `font-weight`
    FontWeight(<<crate::values::specified::FontWeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `forced-color-adjust`
    ForcedColorAdjust(<crate::values::specified::ForcedColorAdjust as ToComputedValue>::ComputedValue),
    /// `grid-auto-flow`
    GridAutoFlow(<crate::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue),
    /// `hyphens`
    Hyphens(<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `image-orientation`
    ImageOrientation(<longhands::image_orientation::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `image-rendering`
    ImageRendering(<crate::values::specified::ImageRendering as ToComputedValue>::ComputedValue),
    /// `ime-mode`
    ImeMode(<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `initial-letter`
    InitialLetter(<crate::values::specified::InitialLetter as ToComputedValue>::ComputedValue),
    /// `inset-area`
    InsetArea(<crate::values::specified::InsetArea as ToComputedValue>::ComputedValue),
    /// `isolation`
    Isolation(<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `justify-content`
    JustifyContent(<crate::values::specified::JustifyContent as ToComputedValue>::ComputedValue),
    /// `justify-items`
    JustifyItems(<crate::values::specified::JustifyItems as ToComputedValue>::ComputedValue),
    /// `justify-self`
    JustifySelf(<crate::values::specified::JustifySelf as ToComputedValue>::ComputedValue),
    /// `line-break`
    LineBreak(<crate::values::specified::LineBreak as ToComputedValue>::ComputedValue),
    /// `list-style-position`
    ListStylePosition(<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-type`
    MaskType(<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `masonry-auto-flow`
    MasonryAutoFlow(<crate::values::specified::MasonryAutoFlow as ToComputedValue>::ComputedValue),
    /// `math-depth`
    MathDepth(Void),
    /// `math-style`
    MathStyle(Void),
    /// `mix-blend-mode`
    MixBlendMode(<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-align`
    MozBoxAlign(<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-collapse`
    MozBoxCollapse(Void),
    /// `-moz-box-direction`
    MozBoxDirection(<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-orient`
    MozBoxOrient(<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-box-pack`
    MozBoxPack(<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-control-character-visibility`
    MozControlCharacterVisibility(Void),
    /// `-moz-float-edge`
    MozFloatEdge(<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-inert`
    MozInert(<longhands::_moz_inert::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-math-variant`
    MozMathVariant(Void),
    /// `-moz-min-font-size-ratio`
    MozMinFontSizeRatio(Void),
    /// `-moz-orient`
    MozOrient(<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-osx-font-smoothing`
    MozOsxFontSmoothing(<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-text-size-adjust`
    MozTextSizeAdjust(<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-theme`
    MozTheme(<crate::values::specified::ui::MozTheme as ToComputedValue>::ComputedValue),
    /// `-moz-top-layer`
    MozTopLayer(Void),
    /// `-moz-user-focus`
    MozUserFocus(<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-user-input`
    MozUserInput(<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-user-modify`
    MozUserModify(<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-window-dragging`
    MozWindowDragging(<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-moz-window-shadow`
    MozWindowShadow(<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `object-fit`
    ObjectFit(<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `offset-rotate`
    OffsetRotate(<crate::values::specified::OffsetRotate as ToComputedValue>::ComputedValue),
    /// `outline-style`
    OutlineStyle(<crate::values::specified::OutlineStyle as ToComputedValue>::ComputedValue),
    /// `overflow-anchor`
    OverflowAnchor(<crate::values::specified::OverflowAnchor as ToComputedValue>::ComputedValue),
    /// `overflow-wrap`
    OverflowWrap(<crate::values::specified::OverflowWrap as ToComputedValue>::ComputedValue),
    /// `page-orientation`
    PageOrientation(Void),
    /// `paint-order`
    PaintOrder(<crate::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue),
    /// `pointer-events`
    PointerEvents(<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `position`
    Position(<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `position-try-order`
    PositionTryOrder(<crate::values::specified::PositionTryOrder as ToComputedValue>::ComputedValue),
    /// `position-visibility`
    PositionVisibility(<crate::values::specified::PositionVisibility as ToComputedValue>::ComputedValue),
    /// `print-color-adjust`
    PrintColorAdjust(<crate::values::specified::PrintColorAdjust as ToComputedValue>::ComputedValue),
    /// `resize`
    Resize(<crate::values::specified::Resize as ToComputedValue>::ComputedValue),
    /// `ruby-align`
    RubyAlign(<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `ruby-position`
    RubyPosition(<crate::values::specified::RubyPosition as ToComputedValue>::ComputedValue),
    /// `scroll-behavior`
    ScrollBehavior(<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `scroll-snap-align`
    ScrollSnapAlign(<crate::values::specified::ScrollSnapAlign as ToComputedValue>::ComputedValue),
    /// `scroll-snap-stop`
    ScrollSnapStop(<crate::values::specified::ScrollSnapStop as ToComputedValue>::ComputedValue),
    /// `scroll-snap-type`
    ScrollSnapType(<crate::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue),
    /// `scrollbar-gutter`
    ScrollbarGutter(<crate::values::specified::ScrollbarGutter as ToComputedValue>::ComputedValue),
    /// `scrollbar-width`
    ScrollbarWidth(<longhands::scrollbar_width::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `shape-rendering`
    ShapeRendering(<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `stroke-linecap`
    StrokeLinecap(<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `stroke-linejoin`
    StrokeLinejoin(<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `table-layout`
    TableLayout(<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-align`
    TextAlign(<crate::values::specified::TextAlign as ToComputedValue>::ComputedValue),
    /// `text-align-last`
    TextAlignLast(<crate::values::specified::TextAlignLast as ToComputedValue>::ComputedValue),
    /// `text-anchor`
    TextAnchor(<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-combine-upright`
    TextCombineUpright(Void),
    /// `text-decoration-line`
    TextDecorationLine(<crate::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue),
    /// `text-decoration-skip-ink`
    TextDecorationSkipInk(<crate::values::specified::TextDecorationSkipInk as ToComputedValue>::ComputedValue),
    /// `text-decoration-style`
    TextDecorationStyle(<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-emphasis-position`
    TextEmphasisPosition(<crate::values::specified::TextEmphasisPosition as ToComputedValue>::ComputedValue),
    /// `text-justify`
    TextJustify(<crate::values::specified::TextJustify as ToComputedValue>::ComputedValue),
    /// `text-orientation`
    TextOrientation(Void),
    /// `text-rendering`
    TextRendering(<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-transform`
    TextTransform(<crate::values::specified::TextTransform as ToComputedValue>::ComputedValue),
    /// `text-underline-position`
    TextUnderlinePosition(<crate::values::specified::TextUnderlinePosition as ToComputedValue>::ComputedValue),
    /// `text-wrap-mode`
    TextWrapMode(<longhands::text_wrap_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `text-wrap-style`
    TextWrapStyle(<longhands::text_wrap_style::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `touch-action`
    TouchAction(<crate::values::specified::TouchAction as ToComputedValue>::ComputedValue),
    /// `transform-box`
    TransformBox(<crate::values::specified::TransformBox as ToComputedValue>::ComputedValue),
    /// `transform-style`
    TransformStyle(<crate::values::specified::TransformStyle as ToComputedValue>::ComputedValue),
    /// `unicode-bidi`
    UnicodeBidi(Void),
    /// `user-select`
    UserSelect(<crate::values::specified::UserSelect as ToComputedValue>::ComputedValue),
    /// `vector-effect`
    VectorEffect(<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `visibility`
    Visibility(<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `-webkit-line-clamp`
    WebkitLineClamp(<crate::values::specified::LineClamp as ToComputedValue>::ComputedValue),
    /// `-webkit-text-security`
    WebkitTextSecurity(<longhands::_webkit_text_security::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `white-space-collapse`
    WhiteSpaceCollapse(<longhands::white_space_collapse::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `word-break`
    WordBreak(<crate::values::specified::WordBreak as ToComputedValue>::ComputedValue),
    /// `writing-mode`
    WritingMode(Void),
    /// `-x-text-scale`
    XTextScale(Void),
    /// `z-index`
    ZIndex(<crate::values::specified::ZIndex as ToComputedValue>::ComputedValue),
    /// `zoom`
    Zoom(<<crate::values::specified::Zoom as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `appearance`
    Appearance(<crate::values::specified::Appearance as ToComputedValue>::ComputedValue),
    /// `-moz-default-appearance`
    MozDefaultAppearance(Void),
    /// `-moz-force-broken-image-icon`
    MozForceBrokenImageIcon(<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue),
    /// `-moz-subtree-hidden-only-visually`
    MozSubtreeHiddenOnlyVisually(<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue),
    /// `break-after`
    BreakAfter(<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue),
    /// `break-before`
    BreakBefore(<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue),
    /// `clip-rule`
    ClipRule(<crate::values::specified::FillRule as ToComputedValue>::ComputedValue),
    /// `fill-rule`
    FillRule(<crate::values::specified::FillRule as ToComputedValue>::ComputedValue),
    /// `overflow-clip-box-block`
    OverflowClipBoxBlock(<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue),
    /// `overflow-clip-box-inline`
    OverflowClipBoxInline(<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue),
    /// `fill-opacity`
    FillOpacity(<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue),
    /// `stroke-opacity`
    StrokeOpacity(<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue),
    /// `-moz-box-ordinal-group`
    MozBoxOrdinalGroup(<crate::values::specified::Integer as ToComputedValue>::ComputedValue),
    /// `order`
    Order(<crate::values::specified::Integer as ToComputedValue>::ComputedValue),
    /// `-x-span`
    XSpan(Void),
    /// `font-synthesis-position`
    FontSynthesisPosition(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
    /// `font-synthesis-small-caps`
    FontSynthesisSmallCaps(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
    /// `font-synthesis-style`
    FontSynthesisStyle(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
    /// `font-synthesis-weight`
    FontSynthesisWeight(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
    /// `flex-grow`
    FlexGrow(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `flex-shrink`
    FlexShrink(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-box-flex`
    MozBoxFlex(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stroke-miterlimit`
    StrokeMiterlimit(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `overflow-block`
    OverflowBlock(Void),
    /// `overflow-inline`
    OverflowInline(Void),
    /// `overflow-x`
    OverflowX(<crate::values::specified::Overflow as ToComputedValue>::ComputedValue),
    /// `overflow-y`
    OverflowY(<crate::values::specified::Overflow as ToComputedValue>::ComputedValue),
    /// `overscroll-behavior-block`
    OverscrollBehaviorBlock(Void),
    /// `overscroll-behavior-inline`
    OverscrollBehaviorInline(Void),
    /// `overscroll-behavior-x`
    OverscrollBehaviorX(<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
    /// `overscroll-behavior-y`
    OverscrollBehaviorY(<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
    /// `flood-opacity`
    FloodOpacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `-moz-window-opacity`
    MozWindowOpacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `opacity`
    Opacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `shape-image-threshold`
    ShapeImageThreshold(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `stop-opacity`
    StopOpacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
    /// `border-block-end-style`
    BorderBlockEndStyle(Void),
    /// `border-block-start-style`
    BorderBlockStartStyle(Void),
    /// `border-bottom-style`
    BorderBottomStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `border-inline-end-style`
    BorderInlineEndStyle(Void),
    /// `border-inline-start-style`
    BorderInlineStartStyle(Void),
    /// `border-left-style`
    BorderLeftStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `border-right-style`
    BorderRightStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `border-top-style`
    BorderTopStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `column-rule-style`
    ColumnRuleStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
    /// `accent-color`
    AccentColor(<<crate::values::specified::ColorOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `anchor-name`
    AnchorName(<crate::values::specified::AnchorName as ToComputedValue>::ComputedValue),
    /// `anchor-scope`
    AnchorScope(<crate::values::specified::AnchorScope as ToComputedValue>::ComputedValue),
    /// `animation-composition`
    AnimationComposition(Void),
    /// `animation-delay`
    AnimationDelay(Void),
    /// `animation-direction`
    AnimationDirection(Void),
    /// `animation-duration`
    AnimationDuration(Void),
    /// `animation-fill-mode`
    AnimationFillMode(Void),
    /// `animation-iteration-count`
    AnimationIterationCount(Void),
    /// `animation-name`
    AnimationName(Void),
    /// `animation-play-state`
    AnimationPlayState(Void),
    /// `animation-timeline`
    AnimationTimeline(Void),
    /// `animation-timing-function`
    AnimationTimingFunction(Void),
    /// `backdrop-filter`
    BackdropFilter(<<longhands::backdrop_filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `background-attachment`
    BackgroundAttachment(<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-blend-mode`
    BackgroundBlendMode(<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-clip`
    BackgroundClip(<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-image`
    BackgroundImage(<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-origin`
    BackgroundOrigin(<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-position-x`
    BackgroundPositionX(<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-position-y`
    BackgroundPositionY(<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-repeat`
    BackgroundRepeat(<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `background-size`
    BackgroundSize(<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-image-outset`
    BorderImageOutset(<<crate::values::specified::NonNegativeLengthOrNumberRect as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-image-slice`
    BorderImageSlice(<<crate::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-image-width`
    BorderImageWidth(<<crate::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-spacing`
    BorderSpacing(<<crate::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `box-shadow`
    BoxShadow(<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `caret-color`
    CaretColor(<<crate::values::specified::color::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `clip`
    Clip(<crate::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue),
    /// `clip-path`
    ClipPath(<<crate::values::specified::basic_shape::ClipPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `color`
    Color(<<crate::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `color-scheme`
    ColorScheme(<crate::values::specified::ColorScheme as ToComputedValue>::ComputedValue),
    /// `column-width`
    ColumnWidth(<<crate::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `container-name`
    ContainerName(Void),
    /// `content`
    Content(<crate::values::specified::Content as ToComputedValue>::ComputedValue),
    /// `counter-increment`
    CounterIncrement(<crate::values::specified::CounterIncrement as ToComputedValue>::ComputedValue),
    /// `counter-reset`
    CounterReset(<crate::values::specified::CounterReset as ToComputedValue>::ComputedValue),
    /// `counter-set`
    CounterSet(<crate::values::specified::CounterSet as ToComputedValue>::ComputedValue),
    /// `cursor`
    Cursor(<crate::values::specified::Cursor as ToComputedValue>::ComputedValue),
    /// `d`
    D(<crate::values::specified::DProperty as ToComputedValue>::ComputedValue),
    /// `filter`
    Filter(<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `flex-basis`
    FlexBasis(<<crate::values::specified::FlexBasis as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `font-family`
    FontFamily(<crate::values::specified::FontFamily as ToComputedValue>::ComputedValue),
    /// `font-feature-settings`
    FontFeatureSettings(<crate::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue),
    /// `font-palette`
    FontPalette(<crate::values::specified::FontPalette as ToComputedValue>::ComputedValue),
    /// `font-size`
    FontSize(<<crate::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `font-variant-alternates`
    FontVariantAlternates(<crate::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue),
    /// `font-variation-settings`
    FontVariationSettings(<crate::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue),
    /// `grid-template-areas`
    GridTemplateAreas(<crate::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue),
    /// `hyphenate-character`
    HyphenateCharacter(<crate::values::specified::HyphenateCharacter as ToComputedValue>::ComputedValue),
    /// `letter-spacing`
    LetterSpacing(<crate::values::specified::LetterSpacing as ToComputedValue>::ComputedValue),
    /// `line-height`
    LineHeight(<<crate::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `list-style-type`
    ListStyleType(<crate::values::specified::ListStyleType as ToComputedValue>::ComputedValue),
    /// `mask-clip`
    MaskClip(<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-composite`
    MaskComposite(<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-image`
    MaskImage(<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-mode`
    MaskMode(<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-origin`
    MaskOrigin(<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-position-x`
    MaskPositionX(<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-position-y`
    MaskPositionY(<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-repeat`
    MaskRepeat(<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue),
    /// `mask-size`
    MaskSize(<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-context-properties`
    MozContextProperties(Void),
    /// `offset-anchor`
    OffsetAnchor(<crate::values::specified::PositionOrAuto as ToComputedValue>::ComputedValue),
    /// `offset-path`
    OffsetPath(<<crate::values::specified::OffsetPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `offset-position`
    OffsetPosition(<crate::values::specified::OffsetPosition as ToComputedValue>::ComputedValue),
    /// `page`
    Page(<crate::values::specified::PageName as ToComputedValue>::ComputedValue),
    /// `perspective`
    Perspective(<<crate::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `position-anchor`
    PositionAnchor(<crate::values::specified::PositionAnchor as ToComputedValue>::ComputedValue),
    /// `position-try-options`
    PositionTryOptions(<crate::values::specified::PositionTryOptions as ToComputedValue>::ComputedValue),
    /// `quotes`
    Quotes(<crate::values::specified::Quotes as ToComputedValue>::ComputedValue),
    /// `rotate`
    Rotate(<crate::values::specified::Rotate as ToComputedValue>::ComputedValue),
    /// `scale`
    Scale(<crate::values::specified::Scale as ToComputedValue>::ComputedValue),
    /// `scroll-timeline-axis`
    ScrollTimelineAxis(Void),
    /// `scroll-timeline-name`
    ScrollTimelineName(Void),
    /// `scrollbar-color`
    ScrollbarColor(<<crate::values::specified::ui::ScrollbarColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `shape-outside`
    ShapeOutside(<<crate::values::specified::basic_shape::ShapeOutside as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `size`
    Size(Void),
    /// `stroke-dasharray`
    StrokeDasharray(<<crate::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stroke-dashoffset`
    StrokeDashoffset(<crate::values::specified::SVGLength as ToComputedValue>::ComputedValue),
    /// `stroke-width`
    StrokeWidth(<<crate::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `tab-size`
    TabSize(<<crate::values::specified::NonNegativeLengthOrNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `text-decoration-thickness`
    TextDecorationThickness(<crate::values::specified::TextDecorationLength as ToComputedValue>::ComputedValue),
    /// `text-emphasis-style`
    TextEmphasisStyle(<crate::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue),
    /// `text-indent`
    TextIndent(<crate::values::specified::TextIndent as ToComputedValue>::ComputedValue),
    /// `text-overflow`
    TextOverflow(<crate::values::specified::TextOverflow as ToComputedValue>::ComputedValue),
    /// `text-shadow`
    TextShadow(<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `transition-behavior`
    TransitionBehavior(Void),
    /// `transition-delay`
    TransitionDelay(Void),
    /// `transition-duration`
    TransitionDuration(Void),
    /// `transition-property`
    TransitionProperty(Void),
    /// `transition-timing-function`
    TransitionTimingFunction(Void),
    /// `translate`
    Translate(<crate::values::specified::Translate as ToComputedValue>::ComputedValue),
    /// `vertical-align`
    VerticalAlign(<crate::values::specified::VerticalAlign as ToComputedValue>::ComputedValue),
    /// `view-timeline-axis`
    ViewTimelineAxis(Void),
    /// `view-timeline-inset`
    ViewTimelineInset(Void),
    /// `view-timeline-name`
    ViewTimelineName(Void),
    /// `-webkit-text-stroke-width`
    WebkitTextStrokeWidth(<crate::values::specified::LineWidth as ToComputedValue>::ComputedValue),
    /// `will-change`
    WillChange(Void),
    /// `word-spacing`
    WordSpacing(<crate::values::specified::WordSpacing as ToComputedValue>::ComputedValue),
    /// `-x-lang`
    XLang(Void),
    /// `object-position`
    ObjectPosition(<crate::values::specified::Position as ToComputedValue>::ComputedValue),
    /// `perspective-origin`
    PerspectiveOrigin(<crate::values::specified::Position as ToComputedValue>::ComputedValue),
    /// `fill`
    Fill(<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stroke`
    Stroke(<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-window-transform-origin`
    MozWindowTransformOrigin(<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue),
    /// `transform-origin`
    TransformOrigin(<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue),
    /// `grid-template-columns`
    GridTemplateColumns(<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue),
    /// `grid-template-rows`
    GridTemplateRows(<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue),
    /// `border-image-source`
    BorderImageSource(<crate::values::specified::Image as ToComputedValue>::ComputedValue),
    /// `list-style-image`
    ListStyleImage(<crate::values::specified::Image as ToComputedValue>::ComputedValue),
    /// `grid-auto-columns`
    GridAutoColumns(<crate::values::specified::ImplicitGridTracks as ToComputedValue>::ComputedValue),
    /// `grid-auto-rows`
    GridAutoRows(<crate::values::specified::ImplicitGridTracks as ToComputedValue>::ComputedValue),
    /// `-moz-window-transform`
    MozWindowTransform(<crate::values::specified::Transform as ToComputedValue>::ComputedValue),
    /// `transform`
    Transform(<crate::values::specified::Transform as ToComputedValue>::ComputedValue),
    /// `column-gap`
    ColumnGap(<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `row-gap`
    RowGap(<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `marker-end`
    MarkerEnd(<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue),
    /// `marker-mid`
    MarkerMid(<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue),
    /// `marker-start`
    MarkerStart(<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue),
    /// `contain-intrinsic-block-size`
    ContainIntrinsicBlockSize(Void),
    /// `contain-intrinsic-height`
    ContainIntrinsicHeight(<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `contain-intrinsic-inline-size`
    ContainIntrinsicInlineSize(Void),
    /// `contain-intrinsic-width`
    ContainIntrinsicWidth(<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `grid-column-end`
    GridColumnEnd(<crate::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `grid-column-start`
    GridColumnStart(<crate::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `grid-row-end`
    GridRowEnd(<crate::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `grid-row-start`
    GridRowStart(<crate::values::specified::GridLine as ToComputedValue>::ComputedValue),
    /// `max-block-size`
    MaxBlockSize(Void),
    /// `max-height`
    MaxHeight(<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `max-inline-size`
    MaxInlineSize(Void),
    /// `max-width`
    MaxWidth(<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `cx`
    Cx(<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue),
    /// `cy`
    Cy(<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue),
    /// `offset-distance`
    OffsetDistance(<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue),
    /// `x`
    X(<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue),
    /// `y`
    Y(<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue),
    /// `border-bottom-left-radius`
    BorderBottomLeftRadius(<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-bottom-right-radius`
    BorderBottomRightRadius(<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-end-end-radius`
    BorderEndEndRadius(Void),
    /// `border-end-start-radius`
    BorderEndStartRadius(Void),
    /// `border-start-end-radius`
    BorderStartEndRadius(Void),
    /// `border-start-start-radius`
    BorderStartStartRadius(Void),
    /// `border-top-left-radius`
    BorderTopLeftRadius(<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-top-right-radius`
    BorderTopRightRadius(<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `block-size`
    BlockSize(Void),
    /// `height`
    Height(<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `inline-size`
    InlineSize(Void),
    /// `min-block-size`
    MinBlockSize(Void),
    /// `min-height`
    MinHeight(<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `min-inline-size`
    MinInlineSize(Void),
    /// `min-width`
    MinWidth(<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `width`
    Width(<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-block-end-width`
    BorderBlockEndWidth(Void),
    /// `border-block-start-width`
    BorderBlockStartWidth(Void),
    /// `border-bottom-width`
    BorderBottomWidth(<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-inline-end-width`
    BorderInlineEndWidth(Void),
    /// `border-inline-start-width`
    BorderInlineStartWidth(Void),
    /// `border-left-width`
    BorderLeftWidth(<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-right-width`
    BorderRightWidth(<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-top-width`
    BorderTopWidth(<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-rule-width`
    ColumnRuleWidth(<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `outline-width`
    OutlineWidth(<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-block-end`
    PaddingBlockEnd(Void),
    /// `padding-block-start`
    PaddingBlockStart(Void),
    /// `padding-bottom`
    PaddingBottom(<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-inline-end`
    PaddingInlineEnd(Void),
    /// `padding-inline-start`
    PaddingInlineStart(Void),
    /// `padding-left`
    PaddingLeft(<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-right`
    PaddingRight(<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `padding-top`
    PaddingTop(<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `r`
    R(<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `shape-margin`
    ShapeMargin(<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `rx`
    Rx(<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `ry`
    Ry(<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `scroll-padding-block-end`
    ScrollPaddingBlockEnd(Void),
    /// `scroll-padding-block-start`
    ScrollPaddingBlockStart(Void),
    /// `scroll-padding-bottom`
    ScrollPaddingBottom(<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `scroll-padding-inline-end`
    ScrollPaddingInlineEnd(Void),
    /// `scroll-padding-inline-start`
    ScrollPaddingInlineStart(Void),
    /// `scroll-padding-left`
    ScrollPaddingLeft(<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `scroll-padding-right`
    ScrollPaddingRight(<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `scroll-padding-top`
    ScrollPaddingTop(<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-moz-window-input-region-margin`
    MozWindowInputRegionMargin(<crate::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `outline-offset`
    OutlineOffset(<crate::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `overflow-clip-margin`
    OverflowClipMargin(<crate::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `scroll-margin-block-end`
    ScrollMarginBlockEnd(Void),
    /// `scroll-margin-block-start`
    ScrollMarginBlockStart(Void),
    /// `scroll-margin-bottom`
    ScrollMarginBottom(<crate::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `scroll-margin-inline-end`
    ScrollMarginInlineEnd(Void),
    /// `scroll-margin-inline-start`
    ScrollMarginInlineStart(Void),
    /// `scroll-margin-left`
    ScrollMarginLeft(<crate::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `scroll-margin-right`
    ScrollMarginRight(<crate::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `scroll-margin-top`
    ScrollMarginTop(<crate::values::specified::Length as ToComputedValue>::ComputedValue),
    /// `bottom`
    Bottom(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `inset-block-end`
    InsetBlockEnd(Void),
    /// `inset-block-start`
    InsetBlockStart(Void),
    /// `inset-inline-end`
    InsetInlineEnd(Void),
    /// `inset-inline-start`
    InsetInlineStart(Void),
    /// `left`
    Left(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-block-end`
    MarginBlockEnd(Void),
    /// `margin-block-start`
    MarginBlockStart(Void),
    /// `margin-bottom`
    MarginBottom(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-inline-end`
    MarginInlineEnd(Void),
    /// `margin-inline-start`
    MarginInlineStart(Void),
    /// `margin-left`
    MarginLeft(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-right`
    MarginRight(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `margin-top`
    MarginTop(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `right`
    Right(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `text-underline-offset`
    TextUnderlineOffset(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `top`
    Top(<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue),
    /// `background-color`
    BackgroundColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-block-end-color`
    BorderBlockEndColor(Void),
    /// `border-block-start-color`
    BorderBlockStartColor(Void),
    /// `border-bottom-color`
    BorderBottomColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-inline-end-color`
    BorderInlineEndColor(Void),
    /// `border-inline-start-color`
    BorderInlineStartColor(Void),
    /// `border-left-color`
    BorderLeftColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-right-color`
    BorderRightColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `border-top-color`
    BorderTopColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `column-rule-color`
    ColumnRuleColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `flood-color`
    FloodColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `lighting-color`
    LightingColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `outline-color`
    OutlineColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `stop-color`
    StopColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `text-decoration-color`
    TextDecorationColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `text-emphasis-color`
    TextEmphasisColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-webkit-text-fill-color`
    WebkitTextFillColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// `-webkit-text-stroke-color`
    WebkitTextStrokeColor(<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
    /// A custom property.
    Custom(CustomAnimatedValue),
}



#[repr(C)]
struct AnimationValueVariantRepr<T> {
    tag: u16,
    value: T
}

impl Clone for AnimationValue {
    #[inline]
    fn clone(&self) -> Self {
        use self::AnimationValue::*;

        

        let self_tag = unsafe { *(self as *const _ as *const u16) };
        if self_tag <= LonghandId::ColumnRuleStyle as u16 {
            #[derive(Clone, Copy)]
            #[repr(u16)]
            enum CopyVariants {
                _AlignContent(<crate::values::specified::AlignContent as ToComputedValue>::ComputedValue),
                _AlignItems(<crate::values::specified::AlignItems as ToComputedValue>::ComputedValue),
                _AlignSelf(<crate::values::specified::AlignSelf as ToComputedValue>::ComputedValue),
                _AspectRatio(<crate::values::specified::AspectRatio as ToComputedValue>::ComputedValue),
                _BackfaceVisibility(<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
                _BaselineSource(<crate::values::specified::BaselineSource as ToComputedValue>::ComputedValue),
                _BorderCollapse(<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue),
                _BorderImageRepeat(<crate::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue),
                _BoxDecorationBreak(<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue),
                _BoxSizing(<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
                _BreakInside(<crate::values::specified::BreakWithin as ToComputedValue>::ComputedValue),
                _CaptionSide(<crate::values::specified::table::CaptionSide as ToComputedValue>::ComputedValue),
                _Clear(<crate::values::specified::Clear as ToComputedValue>::ComputedValue),
                _ColorInterpolation(<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColorInterpolationFilters(<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColumnCount(<<crate::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _ColumnFill(<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ColumnSpan(<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ContentVisibility(<crate::values::specified::ContentVisibility as ToComputedValue>::ComputedValue),
                _Display(<crate::values::specified::Display as ToComputedValue>::ComputedValue),
                _DominantBaseline(<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue),
                _EmptyCells(<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FlexDirection(<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FlexWrap(<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Float(<crate::values::specified::Float as ToComputedValue>::ComputedValue),
                _FontKerning(<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontLanguageOverride(<crate::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue),
                _FontOpticalSizing(<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontSizeAdjust(<<crate::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _FontStretch(<<crate::values::specified::FontStretch as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _FontStyle(<<crate::values::specified::FontStyle as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _FontVariantCaps(<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontVariantEastAsian(<crate::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue),
                _FontVariantEmoji(<longhands::font_variant_emoji::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontVariantLigatures(<crate::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue),
                _FontVariantNumeric(<crate::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue),
                _FontVariantPosition(<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue),
                _FontWeight(<<crate::values::specified::FontWeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _ForcedColorAdjust(<crate::values::specified::ForcedColorAdjust as ToComputedValue>::ComputedValue),
                _GridAutoFlow(<crate::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue),
                _Hyphens(<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ImageOrientation(<longhands::image_orientation::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ImageRendering(<crate::values::specified::ImageRendering as ToComputedValue>::ComputedValue),
                _ImeMode(<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
                _InitialLetter(<crate::values::specified::InitialLetter as ToComputedValue>::ComputedValue),
                _InsetArea(<crate::values::specified::InsetArea as ToComputedValue>::ComputedValue),
                _Isolation(<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue),
                _JustifyContent(<crate::values::specified::JustifyContent as ToComputedValue>::ComputedValue),
                _JustifyItems(<crate::values::specified::JustifyItems as ToComputedValue>::ComputedValue),
                _JustifySelf(<crate::values::specified::JustifySelf as ToComputedValue>::ComputedValue),
                _LineBreak(<crate::values::specified::LineBreak as ToComputedValue>::ComputedValue),
                _ListStylePosition(<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MaskType(<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MasonryAutoFlow(<crate::values::specified::MasonryAutoFlow as ToComputedValue>::ComputedValue),
                _MixBlendMode(<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxAlign(<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxDirection(<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxOrient(<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozBoxPack(<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozFloatEdge(<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozInert(<longhands::_moz_inert::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozOrient(<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozOsxFontSmoothing(<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozTextSizeAdjust(<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozTheme(<crate::values::specified::ui::MozTheme as ToComputedValue>::ComputedValue),
                _MozUserFocus(<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozUserInput(<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozUserModify(<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozWindowDragging(<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue),
                _MozWindowShadow(<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ObjectFit(<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue),
                _OffsetRotate(<crate::values::specified::OffsetRotate as ToComputedValue>::ComputedValue),
                _OutlineStyle(<crate::values::specified::OutlineStyle as ToComputedValue>::ComputedValue),
                _OverflowAnchor(<crate::values::specified::OverflowAnchor as ToComputedValue>::ComputedValue),
                _OverflowWrap(<crate::values::specified::OverflowWrap as ToComputedValue>::ComputedValue),
                _PaintOrder(<crate::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue),
                _PointerEvents(<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Position(<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue),
                _PositionTryOrder(<crate::values::specified::PositionTryOrder as ToComputedValue>::ComputedValue),
                _PositionVisibility(<crate::values::specified::PositionVisibility as ToComputedValue>::ComputedValue),
                _PrintColorAdjust(<crate::values::specified::PrintColorAdjust as ToComputedValue>::ComputedValue),
                _Resize(<crate::values::specified::Resize as ToComputedValue>::ComputedValue),
                _RubyAlign(<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue),
                _RubyPosition(<crate::values::specified::RubyPosition as ToComputedValue>::ComputedValue),
                _ScrollBehavior(<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ScrollSnapAlign(<crate::values::specified::ScrollSnapAlign as ToComputedValue>::ComputedValue),
                _ScrollSnapStop(<crate::values::specified::ScrollSnapStop as ToComputedValue>::ComputedValue),
                _ScrollSnapType(<crate::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue),
                _ScrollbarGutter(<crate::values::specified::ScrollbarGutter as ToComputedValue>::ComputedValue),
                _ScrollbarWidth(<longhands::scrollbar_width::SpecifiedValue as ToComputedValue>::ComputedValue),
                _ShapeRendering(<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
                _StrokeLinecap(<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue),
                _StrokeLinejoin(<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TableLayout(<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextAlign(<crate::values::specified::TextAlign as ToComputedValue>::ComputedValue),
                _TextAlignLast(<crate::values::specified::TextAlignLast as ToComputedValue>::ComputedValue),
                _TextAnchor(<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextDecorationLine(<crate::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue),
                _TextDecorationSkipInk(<crate::values::specified::TextDecorationSkipInk as ToComputedValue>::ComputedValue),
                _TextDecorationStyle(<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextEmphasisPosition(<crate::values::specified::TextEmphasisPosition as ToComputedValue>::ComputedValue),
                _TextJustify(<crate::values::specified::TextJustify as ToComputedValue>::ComputedValue),
                _TextRendering(<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextTransform(<crate::values::specified::TextTransform as ToComputedValue>::ComputedValue),
                _TextUnderlinePosition(<crate::values::specified::TextUnderlinePosition as ToComputedValue>::ComputedValue),
                _TextWrapMode(<longhands::text_wrap_mode::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TextWrapStyle(<longhands::text_wrap_style::SpecifiedValue as ToComputedValue>::ComputedValue),
                _TouchAction(<crate::values::specified::TouchAction as ToComputedValue>::ComputedValue),
                _TransformBox(<crate::values::specified::TransformBox as ToComputedValue>::ComputedValue),
                _TransformStyle(<crate::values::specified::TransformStyle as ToComputedValue>::ComputedValue),
                _UserSelect(<crate::values::specified::UserSelect as ToComputedValue>::ComputedValue),
                _VectorEffect(<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue),
                _Visibility(<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue),
                _WebkitLineClamp(<crate::values::specified::LineClamp as ToComputedValue>::ComputedValue),
                _WebkitTextSecurity(<longhands::_webkit_text_security::SpecifiedValue as ToComputedValue>::ComputedValue),
                _WhiteSpaceCollapse(<longhands::white_space_collapse::SpecifiedValue as ToComputedValue>::ComputedValue),
                _WordBreak(<crate::values::specified::WordBreak as ToComputedValue>::ComputedValue),
                _ZIndex(<crate::values::specified::ZIndex as ToComputedValue>::ComputedValue),
                _Zoom(<<crate::values::specified::Zoom as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _Appearance(<crate::values::specified::Appearance as ToComputedValue>::ComputedValue),
                _MozForceBrokenImageIcon(<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue),
                _MozSubtreeHiddenOnlyVisually(<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue),
                _BreakAfter(<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue),
                _BreakBefore(<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue),
                _ClipRule(<crate::values::specified::FillRule as ToComputedValue>::ComputedValue),
                _FillRule(<crate::values::specified::FillRule as ToComputedValue>::ComputedValue),
                _OverflowClipBoxBlock(<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue),
                _OverflowClipBoxInline(<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue),
                _FillOpacity(<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue),
                _StrokeOpacity(<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue),
                _MozBoxOrdinalGroup(<crate::values::specified::Integer as ToComputedValue>::ComputedValue),
                _Order(<crate::values::specified::Integer as ToComputedValue>::ComputedValue),
                _FontSynthesisPosition(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
                _FontSynthesisSmallCaps(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
                _FontSynthesisStyle(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
                _FontSynthesisWeight(<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue),
                _FlexGrow(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _FlexShrink(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _MozBoxFlex(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _StrokeMiterlimit(<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue),
                _OverflowX(<crate::values::specified::Overflow as ToComputedValue>::ComputedValue),
                _OverflowY(<crate::values::specified::Overflow as ToComputedValue>::ComputedValue),
                _OverscrollBehaviorX(<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
                _OverscrollBehaviorY(<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue),
                _FloodOpacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _MozWindowOpacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _Opacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _ShapeImageThreshold(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _StopOpacity(<crate::values::specified::Opacity as ToComputedValue>::ComputedValue),
                _BorderBottomStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
                _BorderLeftStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
                _BorderRightStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
                _BorderTopStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
                _ColumnRuleStyle(<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue),
            }

            unsafe {
                let mut out = mem::MaybeUninit::uninit();
                ptr::write(
                    out.as_mut_ptr() as *mut CopyVariants,
                    *(self as *const _ as *const CopyVariants),
                );
                return out.assume_init();
            }
        }

        match *self {
            
            AccentColor(ref value) => {
                AccentColor(value.clone())
            }
            
            AnchorName(ref value) => {
                AnchorName(value.clone())
            }
            
            AnchorScope(ref value) => {
                AnchorScope(value.clone())
            }
            
            BackdropFilter(ref value) => {
                BackdropFilter(value.clone())
            }
            
            BackgroundAttachment(ref value) => {
                BackgroundAttachment(value.clone())
            }
            
            BackgroundBlendMode(ref value) => {
                BackgroundBlendMode(value.clone())
            }
            
            BackgroundClip(ref value) => {
                BackgroundClip(value.clone())
            }
            
            BackgroundImage(ref value) => {
                BackgroundImage(value.clone())
            }
            
            BackgroundOrigin(ref value) => {
                BackgroundOrigin(value.clone())
            }
            
            BackgroundPositionX(ref value) => {
                BackgroundPositionX(value.clone())
            }
            
            BackgroundPositionY(ref value) => {
                BackgroundPositionY(value.clone())
            }
            
            BackgroundRepeat(ref value) => {
                BackgroundRepeat(value.clone())
            }
            
            BackgroundSize(ref value) => {
                BackgroundSize(value.clone())
            }
            
            BorderImageOutset(ref value) => {
                BorderImageOutset(value.clone())
            }
            
            BorderImageSlice(ref value) => {
                BorderImageSlice(value.clone())
            }
            
            BorderImageWidth(ref value) => {
                BorderImageWidth(value.clone())
            }
            
            BorderSpacing(ref value) => {
                BorderSpacing(value.clone())
            }
            
            BoxShadow(ref value) => {
                BoxShadow(value.clone())
            }
            
            CaretColor(ref value) => {
                CaretColor(value.clone())
            }
            
            Clip(ref value) => {
                Clip(value.clone())
            }
            
            ClipPath(ref value) => {
                ClipPath(value.clone())
            }
            
            Color(ref value) => {
                Color(value.clone())
            }
            
            ColorScheme(ref value) => {
                ColorScheme(value.clone())
            }
            
            ColumnWidth(ref value) => {
                ColumnWidth(value.clone())
            }
            
            Content(ref value) => {
                Content(value.clone())
            }
            
            CounterIncrement(ref value) => {
                CounterIncrement(value.clone())
            }
            
            CounterReset(ref value) => {
                CounterReset(value.clone())
            }
            
            CounterSet(ref value) => {
                CounterSet(value.clone())
            }
            
            Cursor(ref value) => {
                Cursor(value.clone())
            }
            
            D(ref value) => {
                D(value.clone())
            }
            
            Filter(ref value) => {
                Filter(value.clone())
            }
            
            FlexBasis(ref value) => {
                FlexBasis(value.clone())
            }
            
            FontFamily(ref value) => {
                FontFamily(value.clone())
            }
            
            FontFeatureSettings(ref value) => {
                FontFeatureSettings(value.clone())
            }
            
            FontPalette(ref value) => {
                FontPalette(value.clone())
            }
            
            FontSize(ref value) => {
                FontSize(value.clone())
            }
            
            FontVariantAlternates(ref value) => {
                FontVariantAlternates(value.clone())
            }
            
            FontVariationSettings(ref value) => {
                FontVariationSettings(value.clone())
            }
            
            GridTemplateAreas(ref value) => {
                GridTemplateAreas(value.clone())
            }
            
            HyphenateCharacter(ref value) => {
                HyphenateCharacter(value.clone())
            }
            
            LetterSpacing(ref value) => {
                LetterSpacing(value.clone())
            }
            
            LineHeight(ref value) => {
                LineHeight(value.clone())
            }
            
            ListStyleType(ref value) => {
                ListStyleType(value.clone())
            }
            
            MaskClip(ref value) => {
                MaskClip(value.clone())
            }
            
            MaskComposite(ref value) => {
                MaskComposite(value.clone())
            }
            
            MaskImage(ref value) => {
                MaskImage(value.clone())
            }
            
            MaskMode(ref value) => {
                MaskMode(value.clone())
            }
            
            MaskOrigin(ref value) => {
                MaskOrigin(value.clone())
            }
            
            MaskPositionX(ref value) => {
                MaskPositionX(value.clone())
            }
            
            MaskPositionY(ref value) => {
                MaskPositionY(value.clone())
            }
            
            MaskRepeat(ref value) => {
                MaskRepeat(value.clone())
            }
            
            MaskSize(ref value) => {
                MaskSize(value.clone())
            }
            
            OffsetAnchor(ref value) => {
                OffsetAnchor(value.clone())
            }
            
            OffsetPath(ref value) => {
                OffsetPath(value.clone())
            }
            
            OffsetPosition(ref value) => {
                OffsetPosition(value.clone())
            }
            
            Page(ref value) => {
                Page(value.clone())
            }
            
            Perspective(ref value) => {
                Perspective(value.clone())
            }
            
            PositionAnchor(ref value) => {
                PositionAnchor(value.clone())
            }
            
            PositionTryOptions(ref value) => {
                PositionTryOptions(value.clone())
            }
            
            Quotes(ref value) => {
                Quotes(value.clone())
            }
            
            Rotate(ref value) => {
                Rotate(value.clone())
            }
            
            Scale(ref value) => {
                Scale(value.clone())
            }
            
            ScrollbarColor(ref value) => {
                ScrollbarColor(value.clone())
            }
            
            ShapeOutside(ref value) => {
                ShapeOutside(value.clone())
            }
            
            StrokeDasharray(ref value) => {
                StrokeDasharray(value.clone())
            }
            
            StrokeDashoffset(ref value) => {
                StrokeDashoffset(value.clone())
            }
            
            StrokeWidth(ref value) => {
                StrokeWidth(value.clone())
            }
            
            TabSize(ref value) => {
                TabSize(value.clone())
            }
            
            TextDecorationThickness(ref value) => {
                TextDecorationThickness(value.clone())
            }
            
            TextEmphasisStyle(ref value) => {
                TextEmphasisStyle(value.clone())
            }
            
            TextIndent(ref value) => {
                TextIndent(value.clone())
            }
            
            TextOverflow(ref value) => {
                TextOverflow(value.clone())
            }
            
            TextShadow(ref value) => {
                TextShadow(value.clone())
            }
            
            Translate(ref value) => {
                Translate(value.clone())
            }
            
            VerticalAlign(ref value) => {
                VerticalAlign(value.clone())
            }
            
            WebkitTextStrokeWidth(ref value) => {
                WebkitTextStrokeWidth(value.clone())
            }
            
            WordSpacing(ref value) => {
                WordSpacing(value.clone())
            }
            
            ObjectPosition(ref value) |
PerspectiveOrigin(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Fill(ref value) |
Stroke(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowTransformOrigin(ref value) |
TransformOrigin(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridTemplateColumns(ref value) |
GridTemplateRows(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderImageSource(ref value) |
ListStyleImage(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Image as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridAutoColumns(ref value) |
GridAutoRows(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ImplicitGridTracks as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowTransform(ref value) |
Transform(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Transform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            ColumnGap(ref value) |
RowGap(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MarkerEnd(ref value) |
MarkerMid(ref value) |
MarkerStart(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            ContainIntrinsicHeight(ref value) |
ContainIntrinsicWidth(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridColumnEnd(ref value) |
GridColumnStart(ref value) |
GridRowEnd(ref value) |
GridRowStart(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MaxHeight(ref value) |
MaxWidth(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Cx(ref value) |
Cy(ref value) |
OffsetDistance(ref value) |
X(ref value) |
Y(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderBottomLeftRadius(ref value) |
BorderBottomRightRadius(ref value) |
BorderTopLeftRadius(ref value) |
BorderTopRightRadius(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Height(ref value) |
MinHeight(ref value) |
MinWidth(ref value) |
Width(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderBottomWidth(ref value) |
BorderLeftWidth(ref value) |
BorderRightWidth(ref value) |
BorderTopWidth(ref value) |
ColumnRuleWidth(ref value) |
OutlineWidth(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            PaddingBottom(ref value) |
PaddingLeft(ref value) |
PaddingRight(ref value) |
PaddingTop(ref value) |
R(ref value) |
ShapeMargin(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Rx(ref value) |
Ry(ref value) |
ScrollPaddingBottom(ref value) |
ScrollPaddingLeft(ref value) |
ScrollPaddingRight(ref value) |
ScrollPaddingTop(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowInputRegionMargin(ref value) |
OutlineOffset(ref value) |
OverflowClipMargin(ref value) |
ScrollMarginBottom(ref value) |
ScrollMarginLeft(ref value) |
ScrollMarginRight(ref value) |
ScrollMarginTop(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Length as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            Bottom(ref value) |
Left(ref value) |
MarginBottom(ref value) |
MarginLeft(ref value) |
MarginRight(ref value) |
MarginTop(ref value) |
Right(ref value) |
TextUnderlineOffset(ref value) |
Top(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            
            BackgroundColor(ref value) |
BorderBottomColor(ref value) |
BorderLeftColor(ref value) |
BorderRightColor(ref value) |
BorderTopColor(ref value) |
ColumnRuleColor(ref value) |
FloodColor(ref value) |
LightingColor(ref value) |
OutlineColor(ref value) |
StopColor(ref value) |
TextDecorationColor(ref value) |
TextEmphasisColor(ref value) |
WebkitTextFillColor(ref value) |
WebkitTextStrokeColor(ref value) => {
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value: value.clone(),
                        },
                    );
                    out.assume_init()
                }
            }
            Custom(ref animated_value) => Custom(animated_value.clone()),
            _ => unsafe { debug_unreachable!() }
        }
    }
}

impl PartialEq for AnimationValue {
    #[inline]
    fn eq(&self, other: &Self) -> bool {
        use self::AnimationValue::*;

        unsafe {
            let this_tag = *(self as *const _ as *const u16);
            let other_tag = *(other as *const _ as *const u16);
            if this_tag != other_tag {
                return false;
            }

            match *self {
                AlignContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AlignContent as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                AlignItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AlignItems as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                AlignSelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AlignSelf as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                AspectRatio(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AspectRatio as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackfaceVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BaselineSource(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BaselineSource as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderImageRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BoxDecorationBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BoxSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BreakInside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BreakWithin as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                CaptionSide(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::table::CaptionSide as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Clear(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Clear as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColorInterpolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColorInterpolationFilters(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ColumnFill(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColumnSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ContentVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ContentVisibility as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Display(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Display as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                DominantBaseline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                EmptyCells(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FlexDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FlexWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Float(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Float as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontKerning(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontLanguageOverride(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontOpticalSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontStretch as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FontStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontStyle as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FontVariantCaps(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantEastAsian(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantEmoji(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_emoji::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantLigatures(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantNumeric(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariantPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontWeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ForcedColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ForcedColorAdjust as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Hyphens(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ImageOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::image_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ImageRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ImageRendering as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ImeMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                InitialLetter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::InitialLetter as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                InsetArea(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::InsetArea as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Isolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                JustifyContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::JustifyContent as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                JustifyItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::JustifyItems as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                JustifySelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::JustifySelf as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                LineBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LineBreak as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ListStylePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MasonryAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::MasonryAutoFlow as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MixBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxPack(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozFloatEdge(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozInert(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_inert::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozOsxFontSmoothing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozTextSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozTheme(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ui::MozTheme as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozUserFocus(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozUserInput(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozUserModify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozWindowDragging(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozWindowShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ObjectFit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OffsetRotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OffsetRotate as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OutlineStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverflowAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverflowAnchor as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverflowWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverflowWrap as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PaintOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PointerEvents(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Position(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PositionTryOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionTryOrder as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PositionVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionVisibility as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PrintColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PrintColorAdjust as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Resize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Resize as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                RubyAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                RubyPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::RubyPosition as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollBehavior(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollSnapAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollSnapAlign as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollSnapStop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollSnapStop as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollSnapType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollbarGutter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollbarGutter as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollbarWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scrollbar_width::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ShapeRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                StrokeLinecap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                StrokeLinejoin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TableLayout(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextAlign as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextAlignLast(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextAlignLast as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextDecorationLine(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextDecorationSkipInk(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextDecorationSkipInk as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextDecorationStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextEmphasisPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextEmphasisPosition as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextJustify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextJustify as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextTransform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextTransform as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextUnderlinePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextUnderlinePosition as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextWrapMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_wrap_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextWrapStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_wrap_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TouchAction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TouchAction as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TransformBox(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TransformBox as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TransformStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TransformStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                UserSelect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::UserSelect as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                VectorEffect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WebkitLineClamp(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LineClamp as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WebkitTextSecurity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_webkit_text_security::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WhiteSpaceCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::white_space_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WordBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::WordBreak as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ZIndex as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Zoom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Zoom as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Appearance(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Appearance as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozForceBrokenImageIcon(ref this) |
MozSubtreeHiddenOnlyVisually(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BreakAfter(ref this) |
BreakBefore(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ClipRule(ref this) |
FillRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FillRule as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverflowClipBoxBlock(ref this) |
OverflowClipBoxInline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozBoxOrdinalGroup(ref this) |
Order(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Integer as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontSynthesisPosition(ref this) |
FontSynthesisSmallCaps(ref this) |
FontSynthesisStyle(ref this) |
FontSynthesisWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) |
StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                OverflowX(ref this) |
OverflowY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Overflow as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OverscrollBehaviorX(ref this) |
OverscrollBehaviorY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Opacity as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderBottomStyle(ref this) |
BorderLeftStyle(ref this) |
BorderRightStyle(ref this) |
BorderTopStyle(ref this) |
ColumnRuleStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                AccentColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColorOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                AnchorName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AnchorName as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                AnchorScope(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AnchorScope as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackdropFilter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::backdrop_filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BackgroundAttachment(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BorderImageOutset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumberRect as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BorderImageSlice(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BorderImageWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::color::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Clip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ClipPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ColorScheme(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ColorScheme as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Content(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Content as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                CounterIncrement(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                CounterReset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::CounterReset as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                CounterSet(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::CounterSet as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Cursor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Cursor as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                D(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::DProperty as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FlexBasis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FlexBasis as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FontFamily(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontFamily as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontFeatureSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontPalette(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontPalette as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                FontVariantAlternates(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridTemplateAreas(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                HyphenateCharacter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::HyphenateCharacter as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ListStyleType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ListStyleType as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskComposite(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                OffsetAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionOrAuto as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                OffsetPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::OffsetPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                OffsetPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OffsetPosition as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Page(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PageName as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                PositionAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionAnchor as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                PositionTryOptions(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionTryOptions as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Quotes(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Quotes as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Rotate as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Scale as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ScrollbarColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ui::ScrollbarColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ShapeOutside as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGLength as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                TabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                TextDecorationThickness(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextDecorationLength as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextEmphasisStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextIndent as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextOverflow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextOverflow as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Translate as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WebkitTextStrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LineWidth as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::WordSpacing as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ObjectPosition(ref this) |
PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Position as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridTemplateColumns(ref this) |
GridTemplateRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderImageSource(ref this) |
ListStyleImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Image as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                GridAutoColumns(ref this) |
GridAutoRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ImplicitGridTracks as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Transform as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ColumnGap(ref this) |
RowGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                MarkerEnd(ref this) |
MarkerMid(ref this) |
MarkerStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                ContainIntrinsicHeight(ref this) |
ContainIntrinsicWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                GridColumnEnd(ref this) |
GridColumnStart(ref this) |
GridRowEnd(ref this) |
GridRowStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridLine as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                MaxHeight(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Cx(ref this) |
Cy(ref this) |
OffsetDistance(ref this) |
X(ref this) |
Y(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Height(ref this) |
MinHeight(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                BorderBottomWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                PaddingBottom(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) |
R(ref this) |
ShapeMargin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Rx(ref this) |
Ry(ref this) |
ScrollPaddingBottom(ref this) |
ScrollPaddingLeft(ref this) |
ScrollPaddingRight(ref this) |
ScrollPaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                MozWindowInputRegionMargin(ref this) |
OutlineOffset(ref this) |
OverflowClipMargin(ref this) |
ScrollMarginBottom(ref this) |
ScrollMarginLeft(ref this) |
ScrollMarginRight(ref this) |
ScrollMarginTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Length as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                Bottom(ref this) |
Left(ref this) |
MarginBottom(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
Right(ref this) |
TextUnderlineOffset(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>);
                    *this == other_repr.value
                }
                BackgroundColor(ref this) |
BorderBottomColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
FloodColor(ref this) |
LightingColor(ref this) |
OutlineColor(ref this) |
StopColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    *this == other_repr.value
                }
                Contain(void) |
ContainerType(void) |
Direction(void) |
MathDepth(void) |
MathStyle(void) |
MozBoxCollapse(void) |
MozControlCharacterVisibility(void) |
MozMathVariant(void) |
MozMinFontSizeRatio(void) |
MozTopLayer(void) |
PageOrientation(void) |
TextCombineUpright(void) |
TextOrientation(void) |
UnicodeBidi(void) |
WritingMode(void) |
XTextScale(void) |
MozDefaultAppearance(void) |
XSpan(void) |
OverflowBlock(void) |
OverflowInline(void) |
OverscrollBehaviorBlock(void) |
OverscrollBehaviorInline(void) |
BorderBlockEndStyle(void) |
BorderBlockStartStyle(void) |
BorderInlineEndStyle(void) |
BorderInlineStartStyle(void) |
AnimationComposition(void) |
AnimationDelay(void) |
AnimationDirection(void) |
AnimationDuration(void) |
AnimationFillMode(void) |
AnimationIterationCount(void) |
AnimationName(void) |
AnimationPlayState(void) |
AnimationTimeline(void) |
AnimationTimingFunction(void) |
ContainerName(void) |
MozContextProperties(void) |
ScrollTimelineAxis(void) |
ScrollTimelineName(void) |
Size(void) |
TransitionBehavior(void) |
TransitionDelay(void) |
TransitionDuration(void) |
TransitionProperty(void) |
TransitionTimingFunction(void) |
ViewTimelineAxis(void) |
ViewTimelineInset(void) |
ViewTimelineName(void) |
WillChange(void) |
XLang(void) |
ContainIntrinsicBlockSize(void) |
ContainIntrinsicInlineSize(void) |
MaxBlockSize(void) |
MaxInlineSize(void) |
BorderEndEndRadius(void) |
BorderEndStartRadius(void) |
BorderStartEndRadius(void) |
BorderStartStartRadius(void) |
BlockSize(void) |
InlineSize(void) |
MinBlockSize(void) |
MinInlineSize(void) |
BorderBlockEndWidth(void) |
BorderBlockStartWidth(void) |
BorderInlineEndWidth(void) |
BorderInlineStartWidth(void) |
PaddingBlockEnd(void) |
PaddingBlockStart(void) |
PaddingInlineEnd(void) |
PaddingInlineStart(void) |
ScrollPaddingBlockEnd(void) |
ScrollPaddingBlockStart(void) |
ScrollPaddingInlineEnd(void) |
ScrollPaddingInlineStart(void) |
ScrollMarginBlockEnd(void) |
ScrollMarginBlockStart(void) |
ScrollMarginInlineEnd(void) |
ScrollMarginInlineStart(void) |
InsetBlockEnd(void) |
InsetBlockStart(void) |
InsetInlineEnd(void) |
InsetInlineStart(void) |
MarginBlockEnd(void) |
MarginBlockStart(void) |
MarginInlineEnd(void) |
MarginInlineStart(void) |
BorderBlockEndColor(void) |
BorderBlockStartColor(void) |
BorderInlineEndColor(void) |
BorderInlineStartColor(void) => {
                    void::unreachable(void)
                },
                AnimationValue::Custom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<CustomAnimatedValue>);
                    *this == other_repr.value
                },
            }
        }
    }
}

impl AnimationValue {
    /// Returns the longhand id this animated value corresponds to.
    #[inline]
    pub fn id(&self) -> PropertyDeclarationId {
        if let AnimationValue::Custom(animated_value) = self {
            return PropertyDeclarationId::Custom(&animated_value.name);
        }

        let id = unsafe { *(self as *const _ as *const LonghandId) };
        debug_assert_eq!(id, match *self {
            AnimationValue::AlignContent(..) => LonghandId::AlignContent,
            AnimationValue::AlignItems(..) => LonghandId::AlignItems,
            AnimationValue::AlignSelf(..) => LonghandId::AlignSelf,
            AnimationValue::AspectRatio(..) => LonghandId::AspectRatio,
            AnimationValue::BackfaceVisibility(..) => LonghandId::BackfaceVisibility,
            AnimationValue::BaselineSource(..) => LonghandId::BaselineSource,
            AnimationValue::BorderCollapse(..) => LonghandId::BorderCollapse,
            AnimationValue::BorderImageRepeat(..) => LonghandId::BorderImageRepeat,
            AnimationValue::BoxDecorationBreak(..) => LonghandId::BoxDecorationBreak,
            AnimationValue::BoxSizing(..) => LonghandId::BoxSizing,
            AnimationValue::BreakInside(..) => LonghandId::BreakInside,
            AnimationValue::CaptionSide(..) => LonghandId::CaptionSide,
            AnimationValue::Clear(..) => LonghandId::Clear,
            AnimationValue::ColorInterpolation(..) => LonghandId::ColorInterpolation,
            AnimationValue::ColorInterpolationFilters(..) => LonghandId::ColorInterpolationFilters,
            AnimationValue::ColumnCount(..) => LonghandId::ColumnCount,
            AnimationValue::ColumnFill(..) => LonghandId::ColumnFill,
            AnimationValue::ColumnSpan(..) => LonghandId::ColumnSpan,
            AnimationValue::Contain(void) => void::unreachable(void),
            AnimationValue::ContainerType(void) => void::unreachable(void),
            AnimationValue::ContentVisibility(..) => LonghandId::ContentVisibility,
            AnimationValue::Direction(void) => void::unreachable(void),
            AnimationValue::Display(..) => LonghandId::Display,
            AnimationValue::DominantBaseline(..) => LonghandId::DominantBaseline,
            AnimationValue::EmptyCells(..) => LonghandId::EmptyCells,
            AnimationValue::FlexDirection(..) => LonghandId::FlexDirection,
            AnimationValue::FlexWrap(..) => LonghandId::FlexWrap,
            AnimationValue::Float(..) => LonghandId::Float,
            AnimationValue::FontKerning(..) => LonghandId::FontKerning,
            AnimationValue::FontLanguageOverride(..) => LonghandId::FontLanguageOverride,
            AnimationValue::FontOpticalSizing(..) => LonghandId::FontOpticalSizing,
            AnimationValue::FontSizeAdjust(..) => LonghandId::FontSizeAdjust,
            AnimationValue::FontStretch(..) => LonghandId::FontStretch,
            AnimationValue::FontStyle(..) => LonghandId::FontStyle,
            AnimationValue::FontVariantCaps(..) => LonghandId::FontVariantCaps,
            AnimationValue::FontVariantEastAsian(..) => LonghandId::FontVariantEastAsian,
            AnimationValue::FontVariantEmoji(..) => LonghandId::FontVariantEmoji,
            AnimationValue::FontVariantLigatures(..) => LonghandId::FontVariantLigatures,
            AnimationValue::FontVariantNumeric(..) => LonghandId::FontVariantNumeric,
            AnimationValue::FontVariantPosition(..) => LonghandId::FontVariantPosition,
            AnimationValue::FontWeight(..) => LonghandId::FontWeight,
            AnimationValue::ForcedColorAdjust(..) => LonghandId::ForcedColorAdjust,
            AnimationValue::GridAutoFlow(..) => LonghandId::GridAutoFlow,
            AnimationValue::Hyphens(..) => LonghandId::Hyphens,
            AnimationValue::ImageOrientation(..) => LonghandId::ImageOrientation,
            AnimationValue::ImageRendering(..) => LonghandId::ImageRendering,
            AnimationValue::ImeMode(..) => LonghandId::ImeMode,
            AnimationValue::InitialLetter(..) => LonghandId::InitialLetter,
            AnimationValue::InsetArea(..) => LonghandId::InsetArea,
            AnimationValue::Isolation(..) => LonghandId::Isolation,
            AnimationValue::JustifyContent(..) => LonghandId::JustifyContent,
            AnimationValue::JustifyItems(..) => LonghandId::JustifyItems,
            AnimationValue::JustifySelf(..) => LonghandId::JustifySelf,
            AnimationValue::LineBreak(..) => LonghandId::LineBreak,
            AnimationValue::ListStylePosition(..) => LonghandId::ListStylePosition,
            AnimationValue::MaskType(..) => LonghandId::MaskType,
            AnimationValue::MasonryAutoFlow(..) => LonghandId::MasonryAutoFlow,
            AnimationValue::MathDepth(void) => void::unreachable(void),
            AnimationValue::MathStyle(void) => void::unreachable(void),
            AnimationValue::MixBlendMode(..) => LonghandId::MixBlendMode,
            AnimationValue::MozBoxAlign(..) => LonghandId::MozBoxAlign,
            AnimationValue::MozBoxCollapse(void) => void::unreachable(void),
            AnimationValue::MozBoxDirection(..) => LonghandId::MozBoxDirection,
            AnimationValue::MozBoxOrient(..) => LonghandId::MozBoxOrient,
            AnimationValue::MozBoxPack(..) => LonghandId::MozBoxPack,
            AnimationValue::MozControlCharacterVisibility(void) => void::unreachable(void),
            AnimationValue::MozFloatEdge(..) => LonghandId::MozFloatEdge,
            AnimationValue::MozInert(..) => LonghandId::MozInert,
            AnimationValue::MozMathVariant(void) => void::unreachable(void),
            AnimationValue::MozMinFontSizeRatio(void) => void::unreachable(void),
            AnimationValue::MozOrient(..) => LonghandId::MozOrient,
            AnimationValue::MozOsxFontSmoothing(..) => LonghandId::MozOsxFontSmoothing,
            AnimationValue::MozTextSizeAdjust(..) => LonghandId::MozTextSizeAdjust,
            AnimationValue::MozTheme(..) => LonghandId::MozTheme,
            AnimationValue::MozTopLayer(void) => void::unreachable(void),
            AnimationValue::MozUserFocus(..) => LonghandId::MozUserFocus,
            AnimationValue::MozUserInput(..) => LonghandId::MozUserInput,
            AnimationValue::MozUserModify(..) => LonghandId::MozUserModify,
            AnimationValue::MozWindowDragging(..) => LonghandId::MozWindowDragging,
            AnimationValue::MozWindowShadow(..) => LonghandId::MozWindowShadow,
            AnimationValue::ObjectFit(..) => LonghandId::ObjectFit,
            AnimationValue::OffsetRotate(..) => LonghandId::OffsetRotate,
            AnimationValue::OutlineStyle(..) => LonghandId::OutlineStyle,
            AnimationValue::OverflowAnchor(..) => LonghandId::OverflowAnchor,
            AnimationValue::OverflowWrap(..) => LonghandId::OverflowWrap,
            AnimationValue::PageOrientation(void) => void::unreachable(void),
            AnimationValue::PaintOrder(..) => LonghandId::PaintOrder,
            AnimationValue::PointerEvents(..) => LonghandId::PointerEvents,
            AnimationValue::Position(..) => LonghandId::Position,
            AnimationValue::PositionTryOrder(..) => LonghandId::PositionTryOrder,
            AnimationValue::PositionVisibility(..) => LonghandId::PositionVisibility,
            AnimationValue::PrintColorAdjust(..) => LonghandId::PrintColorAdjust,
            AnimationValue::Resize(..) => LonghandId::Resize,
            AnimationValue::RubyAlign(..) => LonghandId::RubyAlign,
            AnimationValue::RubyPosition(..) => LonghandId::RubyPosition,
            AnimationValue::ScrollBehavior(..) => LonghandId::ScrollBehavior,
            AnimationValue::ScrollSnapAlign(..) => LonghandId::ScrollSnapAlign,
            AnimationValue::ScrollSnapStop(..) => LonghandId::ScrollSnapStop,
            AnimationValue::ScrollSnapType(..) => LonghandId::ScrollSnapType,
            AnimationValue::ScrollbarGutter(..) => LonghandId::ScrollbarGutter,
            AnimationValue::ScrollbarWidth(..) => LonghandId::ScrollbarWidth,
            AnimationValue::ShapeRendering(..) => LonghandId::ShapeRendering,
            AnimationValue::StrokeLinecap(..) => LonghandId::StrokeLinecap,
            AnimationValue::StrokeLinejoin(..) => LonghandId::StrokeLinejoin,
            AnimationValue::TableLayout(..) => LonghandId::TableLayout,
            AnimationValue::TextAlign(..) => LonghandId::TextAlign,
            AnimationValue::TextAlignLast(..) => LonghandId::TextAlignLast,
            AnimationValue::TextAnchor(..) => LonghandId::TextAnchor,
            AnimationValue::TextCombineUpright(void) => void::unreachable(void),
            AnimationValue::TextDecorationLine(..) => LonghandId::TextDecorationLine,
            AnimationValue::TextDecorationSkipInk(..) => LonghandId::TextDecorationSkipInk,
            AnimationValue::TextDecorationStyle(..) => LonghandId::TextDecorationStyle,
            AnimationValue::TextEmphasisPosition(..) => LonghandId::TextEmphasisPosition,
            AnimationValue::TextJustify(..) => LonghandId::TextJustify,
            AnimationValue::TextOrientation(void) => void::unreachable(void),
            AnimationValue::TextRendering(..) => LonghandId::TextRendering,
            AnimationValue::TextTransform(..) => LonghandId::TextTransform,
            AnimationValue::TextUnderlinePosition(..) => LonghandId::TextUnderlinePosition,
            AnimationValue::TextWrapMode(..) => LonghandId::TextWrapMode,
            AnimationValue::TextWrapStyle(..) => LonghandId::TextWrapStyle,
            AnimationValue::TouchAction(..) => LonghandId::TouchAction,
            AnimationValue::TransformBox(..) => LonghandId::TransformBox,
            AnimationValue::TransformStyle(..) => LonghandId::TransformStyle,
            AnimationValue::UnicodeBidi(void) => void::unreachable(void),
            AnimationValue::UserSelect(..) => LonghandId::UserSelect,
            AnimationValue::VectorEffect(..) => LonghandId::VectorEffect,
            AnimationValue::Visibility(..) => LonghandId::Visibility,
            AnimationValue::WebkitLineClamp(..) => LonghandId::WebkitLineClamp,
            AnimationValue::WebkitTextSecurity(..) => LonghandId::WebkitTextSecurity,
            AnimationValue::WhiteSpaceCollapse(..) => LonghandId::WhiteSpaceCollapse,
            AnimationValue::WordBreak(..) => LonghandId::WordBreak,
            AnimationValue::WritingMode(void) => void::unreachable(void),
            AnimationValue::XTextScale(void) => void::unreachable(void),
            AnimationValue::ZIndex(..) => LonghandId::ZIndex,
            AnimationValue::Zoom(..) => LonghandId::Zoom,
            AnimationValue::Appearance(..) => LonghandId::Appearance,
            AnimationValue::MozDefaultAppearance(void) => void::unreachable(void),
            AnimationValue::MozForceBrokenImageIcon(..) => LonghandId::MozForceBrokenImageIcon,
            AnimationValue::MozSubtreeHiddenOnlyVisually(..) => LonghandId::MozSubtreeHiddenOnlyVisually,
            AnimationValue::BreakAfter(..) => LonghandId::BreakAfter,
            AnimationValue::BreakBefore(..) => LonghandId::BreakBefore,
            AnimationValue::ClipRule(..) => LonghandId::ClipRule,
            AnimationValue::FillRule(..) => LonghandId::FillRule,
            AnimationValue::OverflowClipBoxBlock(..) => LonghandId::OverflowClipBoxBlock,
            AnimationValue::OverflowClipBoxInline(..) => LonghandId::OverflowClipBoxInline,
            AnimationValue::FillOpacity(..) => LonghandId::FillOpacity,
            AnimationValue::StrokeOpacity(..) => LonghandId::StrokeOpacity,
            AnimationValue::MozBoxOrdinalGroup(..) => LonghandId::MozBoxOrdinalGroup,
            AnimationValue::Order(..) => LonghandId::Order,
            AnimationValue::XSpan(void) => void::unreachable(void),
            AnimationValue::FontSynthesisPosition(..) => LonghandId::FontSynthesisPosition,
            AnimationValue::FontSynthesisSmallCaps(..) => LonghandId::FontSynthesisSmallCaps,
            AnimationValue::FontSynthesisStyle(..) => LonghandId::FontSynthesisStyle,
            AnimationValue::FontSynthesisWeight(..) => LonghandId::FontSynthesisWeight,
            AnimationValue::FlexGrow(..) => LonghandId::FlexGrow,
            AnimationValue::FlexShrink(..) => LonghandId::FlexShrink,
            AnimationValue::MozBoxFlex(..) => LonghandId::MozBoxFlex,
            AnimationValue::StrokeMiterlimit(..) => LonghandId::StrokeMiterlimit,
            AnimationValue::OverflowBlock(void) => void::unreachable(void),
            AnimationValue::OverflowInline(void) => void::unreachable(void),
            AnimationValue::OverflowX(..) => LonghandId::OverflowX,
            AnimationValue::OverflowY(..) => LonghandId::OverflowY,
            AnimationValue::OverscrollBehaviorBlock(void) => void::unreachable(void),
            AnimationValue::OverscrollBehaviorInline(void) => void::unreachable(void),
            AnimationValue::OverscrollBehaviorX(..) => LonghandId::OverscrollBehaviorX,
            AnimationValue::OverscrollBehaviorY(..) => LonghandId::OverscrollBehaviorY,
            AnimationValue::FloodOpacity(..) => LonghandId::FloodOpacity,
            AnimationValue::MozWindowOpacity(..) => LonghandId::MozWindowOpacity,
            AnimationValue::Opacity(..) => LonghandId::Opacity,
            AnimationValue::ShapeImageThreshold(..) => LonghandId::ShapeImageThreshold,
            AnimationValue::StopOpacity(..) => LonghandId::StopOpacity,
            AnimationValue::BorderBlockEndStyle(void) => void::unreachable(void),
            AnimationValue::BorderBlockStartStyle(void) => void::unreachable(void),
            AnimationValue::BorderBottomStyle(..) => LonghandId::BorderBottomStyle,
            AnimationValue::BorderInlineEndStyle(void) => void::unreachable(void),
            AnimationValue::BorderInlineStartStyle(void) => void::unreachable(void),
            AnimationValue::BorderLeftStyle(..) => LonghandId::BorderLeftStyle,
            AnimationValue::BorderRightStyle(..) => LonghandId::BorderRightStyle,
            AnimationValue::BorderTopStyle(..) => LonghandId::BorderTopStyle,
            AnimationValue::ColumnRuleStyle(..) => LonghandId::ColumnRuleStyle,
            AnimationValue::AccentColor(..) => LonghandId::AccentColor,
            AnimationValue::AnchorName(..) => LonghandId::AnchorName,
            AnimationValue::AnchorScope(..) => LonghandId::AnchorScope,
            AnimationValue::AnimationComposition(void) => void::unreachable(void),
            AnimationValue::AnimationDelay(void) => void::unreachable(void),
            AnimationValue::AnimationDirection(void) => void::unreachable(void),
            AnimationValue::AnimationDuration(void) => void::unreachable(void),
            AnimationValue::AnimationFillMode(void) => void::unreachable(void),
            AnimationValue::AnimationIterationCount(void) => void::unreachable(void),
            AnimationValue::AnimationName(void) => void::unreachable(void),
            AnimationValue::AnimationPlayState(void) => void::unreachable(void),
            AnimationValue::AnimationTimeline(void) => void::unreachable(void),
            AnimationValue::AnimationTimingFunction(void) => void::unreachable(void),
            AnimationValue::BackdropFilter(..) => LonghandId::BackdropFilter,
            AnimationValue::BackgroundAttachment(..) => LonghandId::BackgroundAttachment,
            AnimationValue::BackgroundBlendMode(..) => LonghandId::BackgroundBlendMode,
            AnimationValue::BackgroundClip(..) => LonghandId::BackgroundClip,
            AnimationValue::BackgroundImage(..) => LonghandId::BackgroundImage,
            AnimationValue::BackgroundOrigin(..) => LonghandId::BackgroundOrigin,
            AnimationValue::BackgroundPositionX(..) => LonghandId::BackgroundPositionX,
            AnimationValue::BackgroundPositionY(..) => LonghandId::BackgroundPositionY,
            AnimationValue::BackgroundRepeat(..) => LonghandId::BackgroundRepeat,
            AnimationValue::BackgroundSize(..) => LonghandId::BackgroundSize,
            AnimationValue::BorderImageOutset(..) => LonghandId::BorderImageOutset,
            AnimationValue::BorderImageSlice(..) => LonghandId::BorderImageSlice,
            AnimationValue::BorderImageWidth(..) => LonghandId::BorderImageWidth,
            AnimationValue::BorderSpacing(..) => LonghandId::BorderSpacing,
            AnimationValue::BoxShadow(..) => LonghandId::BoxShadow,
            AnimationValue::CaretColor(..) => LonghandId::CaretColor,
            AnimationValue::Clip(..) => LonghandId::Clip,
            AnimationValue::ClipPath(..) => LonghandId::ClipPath,
            AnimationValue::Color(..) => LonghandId::Color,
            AnimationValue::ColorScheme(..) => LonghandId::ColorScheme,
            AnimationValue::ColumnWidth(..) => LonghandId::ColumnWidth,
            AnimationValue::ContainerName(void) => void::unreachable(void),
            AnimationValue::Content(..) => LonghandId::Content,
            AnimationValue::CounterIncrement(..) => LonghandId::CounterIncrement,
            AnimationValue::CounterReset(..) => LonghandId::CounterReset,
            AnimationValue::CounterSet(..) => LonghandId::CounterSet,
            AnimationValue::Cursor(..) => LonghandId::Cursor,
            AnimationValue::D(..) => LonghandId::D,
            AnimationValue::Filter(..) => LonghandId::Filter,
            AnimationValue::FlexBasis(..) => LonghandId::FlexBasis,
            AnimationValue::FontFamily(..) => LonghandId::FontFamily,
            AnimationValue::FontFeatureSettings(..) => LonghandId::FontFeatureSettings,
            AnimationValue::FontPalette(..) => LonghandId::FontPalette,
            AnimationValue::FontSize(..) => LonghandId::FontSize,
            AnimationValue::FontVariantAlternates(..) => LonghandId::FontVariantAlternates,
            AnimationValue::FontVariationSettings(..) => LonghandId::FontVariationSettings,
            AnimationValue::GridTemplateAreas(..) => LonghandId::GridTemplateAreas,
            AnimationValue::HyphenateCharacter(..) => LonghandId::HyphenateCharacter,
            AnimationValue::LetterSpacing(..) => LonghandId::LetterSpacing,
            AnimationValue::LineHeight(..) => LonghandId::LineHeight,
            AnimationValue::ListStyleType(..) => LonghandId::ListStyleType,
            AnimationValue::MaskClip(..) => LonghandId::MaskClip,
            AnimationValue::MaskComposite(..) => LonghandId::MaskComposite,
            AnimationValue::MaskImage(..) => LonghandId::MaskImage,
            AnimationValue::MaskMode(..) => LonghandId::MaskMode,
            AnimationValue::MaskOrigin(..) => LonghandId::MaskOrigin,
            AnimationValue::MaskPositionX(..) => LonghandId::MaskPositionX,
            AnimationValue::MaskPositionY(..) => LonghandId::MaskPositionY,
            AnimationValue::MaskRepeat(..) => LonghandId::MaskRepeat,
            AnimationValue::MaskSize(..) => LonghandId::MaskSize,
            AnimationValue::MozContextProperties(void) => void::unreachable(void),
            AnimationValue::OffsetAnchor(..) => LonghandId::OffsetAnchor,
            AnimationValue::OffsetPath(..) => LonghandId::OffsetPath,
            AnimationValue::OffsetPosition(..) => LonghandId::OffsetPosition,
            AnimationValue::Page(..) => LonghandId::Page,
            AnimationValue::Perspective(..) => LonghandId::Perspective,
            AnimationValue::PositionAnchor(..) => LonghandId::PositionAnchor,
            AnimationValue::PositionTryOptions(..) => LonghandId::PositionTryOptions,
            AnimationValue::Quotes(..) => LonghandId::Quotes,
            AnimationValue::Rotate(..) => LonghandId::Rotate,
            AnimationValue::Scale(..) => LonghandId::Scale,
            AnimationValue::ScrollTimelineAxis(void) => void::unreachable(void),
            AnimationValue::ScrollTimelineName(void) => void::unreachable(void),
            AnimationValue::ScrollbarColor(..) => LonghandId::ScrollbarColor,
            AnimationValue::ShapeOutside(..) => LonghandId::ShapeOutside,
            AnimationValue::Size(void) => void::unreachable(void),
            AnimationValue::StrokeDasharray(..) => LonghandId::StrokeDasharray,
            AnimationValue::StrokeDashoffset(..) => LonghandId::StrokeDashoffset,
            AnimationValue::StrokeWidth(..) => LonghandId::StrokeWidth,
            AnimationValue::TabSize(..) => LonghandId::TabSize,
            AnimationValue::TextDecorationThickness(..) => LonghandId::TextDecorationThickness,
            AnimationValue::TextEmphasisStyle(..) => LonghandId::TextEmphasisStyle,
            AnimationValue::TextIndent(..) => LonghandId::TextIndent,
            AnimationValue::TextOverflow(..) => LonghandId::TextOverflow,
            AnimationValue::TextShadow(..) => LonghandId::TextShadow,
            AnimationValue::TransitionBehavior(void) => void::unreachable(void),
            AnimationValue::TransitionDelay(void) => void::unreachable(void),
            AnimationValue::TransitionDuration(void) => void::unreachable(void),
            AnimationValue::TransitionProperty(void) => void::unreachable(void),
            AnimationValue::TransitionTimingFunction(void) => void::unreachable(void),
            AnimationValue::Translate(..) => LonghandId::Translate,
            AnimationValue::VerticalAlign(..) => LonghandId::VerticalAlign,
            AnimationValue::ViewTimelineAxis(void) => void::unreachable(void),
            AnimationValue::ViewTimelineInset(void) => void::unreachable(void),
            AnimationValue::ViewTimelineName(void) => void::unreachable(void),
            AnimationValue::WebkitTextStrokeWidth(..) => LonghandId::WebkitTextStrokeWidth,
            AnimationValue::WillChange(void) => void::unreachable(void),
            AnimationValue::WordSpacing(..) => LonghandId::WordSpacing,
            AnimationValue::XLang(void) => void::unreachable(void),
            AnimationValue::ObjectPosition(..) => LonghandId::ObjectPosition,
            AnimationValue::PerspectiveOrigin(..) => LonghandId::PerspectiveOrigin,
            AnimationValue::Fill(..) => LonghandId::Fill,
            AnimationValue::Stroke(..) => LonghandId::Stroke,
            AnimationValue::MozWindowTransformOrigin(..) => LonghandId::MozWindowTransformOrigin,
            AnimationValue::TransformOrigin(..) => LonghandId::TransformOrigin,
            AnimationValue::GridTemplateColumns(..) => LonghandId::GridTemplateColumns,
            AnimationValue::GridTemplateRows(..) => LonghandId::GridTemplateRows,
            AnimationValue::BorderImageSource(..) => LonghandId::BorderImageSource,
            AnimationValue::ListStyleImage(..) => LonghandId::ListStyleImage,
            AnimationValue::GridAutoColumns(..) => LonghandId::GridAutoColumns,
            AnimationValue::GridAutoRows(..) => LonghandId::GridAutoRows,
            AnimationValue::MozWindowTransform(..) => LonghandId::MozWindowTransform,
            AnimationValue::Transform(..) => LonghandId::Transform,
            AnimationValue::ColumnGap(..) => LonghandId::ColumnGap,
            AnimationValue::RowGap(..) => LonghandId::RowGap,
            AnimationValue::MarkerEnd(..) => LonghandId::MarkerEnd,
            AnimationValue::MarkerMid(..) => LonghandId::MarkerMid,
            AnimationValue::MarkerStart(..) => LonghandId::MarkerStart,
            AnimationValue::ContainIntrinsicBlockSize(void) => void::unreachable(void),
            AnimationValue::ContainIntrinsicHeight(..) => LonghandId::ContainIntrinsicHeight,
            AnimationValue::ContainIntrinsicInlineSize(void) => void::unreachable(void),
            AnimationValue::ContainIntrinsicWidth(..) => LonghandId::ContainIntrinsicWidth,
            AnimationValue::GridColumnEnd(..) => LonghandId::GridColumnEnd,
            AnimationValue::GridColumnStart(..) => LonghandId::GridColumnStart,
            AnimationValue::GridRowEnd(..) => LonghandId::GridRowEnd,
            AnimationValue::GridRowStart(..) => LonghandId::GridRowStart,
            AnimationValue::MaxBlockSize(void) => void::unreachable(void),
            AnimationValue::MaxHeight(..) => LonghandId::MaxHeight,
            AnimationValue::MaxInlineSize(void) => void::unreachable(void),
            AnimationValue::MaxWidth(..) => LonghandId::MaxWidth,
            AnimationValue::Cx(..) => LonghandId::Cx,
            AnimationValue::Cy(..) => LonghandId::Cy,
            AnimationValue::OffsetDistance(..) => LonghandId::OffsetDistance,
            AnimationValue::X(..) => LonghandId::X,
            AnimationValue::Y(..) => LonghandId::Y,
            AnimationValue::BorderBottomLeftRadius(..) => LonghandId::BorderBottomLeftRadius,
            AnimationValue::BorderBottomRightRadius(..) => LonghandId::BorderBottomRightRadius,
            AnimationValue::BorderEndEndRadius(void) => void::unreachable(void),
            AnimationValue::BorderEndStartRadius(void) => void::unreachable(void),
            AnimationValue::BorderStartEndRadius(void) => void::unreachable(void),
            AnimationValue::BorderStartStartRadius(void) => void::unreachable(void),
            AnimationValue::BorderTopLeftRadius(..) => LonghandId::BorderTopLeftRadius,
            AnimationValue::BorderTopRightRadius(..) => LonghandId::BorderTopRightRadius,
            AnimationValue::BlockSize(void) => void::unreachable(void),
            AnimationValue::Height(..) => LonghandId::Height,
            AnimationValue::InlineSize(void) => void::unreachable(void),
            AnimationValue::MinBlockSize(void) => void::unreachable(void),
            AnimationValue::MinHeight(..) => LonghandId::MinHeight,
            AnimationValue::MinInlineSize(void) => void::unreachable(void),
            AnimationValue::MinWidth(..) => LonghandId::MinWidth,
            AnimationValue::Width(..) => LonghandId::Width,
            AnimationValue::BorderBlockEndWidth(void) => void::unreachable(void),
            AnimationValue::BorderBlockStartWidth(void) => void::unreachable(void),
            AnimationValue::BorderBottomWidth(..) => LonghandId::BorderBottomWidth,
            AnimationValue::BorderInlineEndWidth(void) => void::unreachable(void),
            AnimationValue::BorderInlineStartWidth(void) => void::unreachable(void),
            AnimationValue::BorderLeftWidth(..) => LonghandId::BorderLeftWidth,
            AnimationValue::BorderRightWidth(..) => LonghandId::BorderRightWidth,
            AnimationValue::BorderTopWidth(..) => LonghandId::BorderTopWidth,
            AnimationValue::ColumnRuleWidth(..) => LonghandId::ColumnRuleWidth,
            AnimationValue::OutlineWidth(..) => LonghandId::OutlineWidth,
            AnimationValue::PaddingBlockEnd(void) => void::unreachable(void),
            AnimationValue::PaddingBlockStart(void) => void::unreachable(void),
            AnimationValue::PaddingBottom(..) => LonghandId::PaddingBottom,
            AnimationValue::PaddingInlineEnd(void) => void::unreachable(void),
            AnimationValue::PaddingInlineStart(void) => void::unreachable(void),
            AnimationValue::PaddingLeft(..) => LonghandId::PaddingLeft,
            AnimationValue::PaddingRight(..) => LonghandId::PaddingRight,
            AnimationValue::PaddingTop(..) => LonghandId::PaddingTop,
            AnimationValue::R(..) => LonghandId::R,
            AnimationValue::ShapeMargin(..) => LonghandId::ShapeMargin,
            AnimationValue::Rx(..) => LonghandId::Rx,
            AnimationValue::Ry(..) => LonghandId::Ry,
            AnimationValue::ScrollPaddingBlockEnd(void) => void::unreachable(void),
            AnimationValue::ScrollPaddingBlockStart(void) => void::unreachable(void),
            AnimationValue::ScrollPaddingBottom(..) => LonghandId::ScrollPaddingBottom,
            AnimationValue::ScrollPaddingInlineEnd(void) => void::unreachable(void),
            AnimationValue::ScrollPaddingInlineStart(void) => void::unreachable(void),
            AnimationValue::ScrollPaddingLeft(..) => LonghandId::ScrollPaddingLeft,
            AnimationValue::ScrollPaddingRight(..) => LonghandId::ScrollPaddingRight,
            AnimationValue::ScrollPaddingTop(..) => LonghandId::ScrollPaddingTop,
            AnimationValue::MozWindowInputRegionMargin(..) => LonghandId::MozWindowInputRegionMargin,
            AnimationValue::OutlineOffset(..) => LonghandId::OutlineOffset,
            AnimationValue::OverflowClipMargin(..) => LonghandId::OverflowClipMargin,
            AnimationValue::ScrollMarginBlockEnd(void) => void::unreachable(void),
            AnimationValue::ScrollMarginBlockStart(void) => void::unreachable(void),
            AnimationValue::ScrollMarginBottom(..) => LonghandId::ScrollMarginBottom,
            AnimationValue::ScrollMarginInlineEnd(void) => void::unreachable(void),
            AnimationValue::ScrollMarginInlineStart(void) => void::unreachable(void),
            AnimationValue::ScrollMarginLeft(..) => LonghandId::ScrollMarginLeft,
            AnimationValue::ScrollMarginRight(..) => LonghandId::ScrollMarginRight,
            AnimationValue::ScrollMarginTop(..) => LonghandId::ScrollMarginTop,
            AnimationValue::Bottom(..) => LonghandId::Bottom,
            AnimationValue::InsetBlockEnd(void) => void::unreachable(void),
            AnimationValue::InsetBlockStart(void) => void::unreachable(void),
            AnimationValue::InsetInlineEnd(void) => void::unreachable(void),
            AnimationValue::InsetInlineStart(void) => void::unreachable(void),
            AnimationValue::Left(..) => LonghandId::Left,
            AnimationValue::MarginBlockEnd(void) => void::unreachable(void),
            AnimationValue::MarginBlockStart(void) => void::unreachable(void),
            AnimationValue::MarginBottom(..) => LonghandId::MarginBottom,
            AnimationValue::MarginInlineEnd(void) => void::unreachable(void),
            AnimationValue::MarginInlineStart(void) => void::unreachable(void),
            AnimationValue::MarginLeft(..) => LonghandId::MarginLeft,
            AnimationValue::MarginRight(..) => LonghandId::MarginRight,
            AnimationValue::MarginTop(..) => LonghandId::MarginTop,
            AnimationValue::Right(..) => LonghandId::Right,
            AnimationValue::TextUnderlineOffset(..) => LonghandId::TextUnderlineOffset,
            AnimationValue::Top(..) => LonghandId::Top,
            AnimationValue::BackgroundColor(..) => LonghandId::BackgroundColor,
            AnimationValue::BorderBlockEndColor(void) => void::unreachable(void),
            AnimationValue::BorderBlockStartColor(void) => void::unreachable(void),
            AnimationValue::BorderBottomColor(..) => LonghandId::BorderBottomColor,
            AnimationValue::BorderInlineEndColor(void) => void::unreachable(void),
            AnimationValue::BorderInlineStartColor(void) => void::unreachable(void),
            AnimationValue::BorderLeftColor(..) => LonghandId::BorderLeftColor,
            AnimationValue::BorderRightColor(..) => LonghandId::BorderRightColor,
            AnimationValue::BorderTopColor(..) => LonghandId::BorderTopColor,
            AnimationValue::ColumnRuleColor(..) => LonghandId::ColumnRuleColor,
            AnimationValue::FloodColor(..) => LonghandId::FloodColor,
            AnimationValue::LightingColor(..) => LonghandId::LightingColor,
            AnimationValue::OutlineColor(..) => LonghandId::OutlineColor,
            AnimationValue::StopColor(..) => LonghandId::StopColor,
            AnimationValue::TextDecorationColor(..) => LonghandId::TextDecorationColor,
            AnimationValue::TextEmphasisColor(..) => LonghandId::TextEmphasisColor,
            AnimationValue::WebkitTextFillColor(..) => LonghandId::WebkitTextFillColor,
            AnimationValue::WebkitTextStrokeColor(..) => LonghandId::WebkitTextStrokeColor,
            AnimationValue::Custom(..) => unsafe { debug_unreachable!() },
        });
        PropertyDeclarationId::Longhand(id)
    }

    /// Returns whether this value is interpolable with another one.
    pub fn interpolable_with(&self, other: &Self) -> bool {
        self.animate(other, Procedure::Interpolate { progress: 0.5 }).is_ok()
    }

    /// "Uncompute" this animation value in order to be used inside the CSS
    /// cascade.
    pub fn uncompute(&self) -> PropertyDeclaration {
        use crate::properties::longhands;
        use self::AnimationValue::*;

        use super::PropertyDeclarationVariantRepr;

        match *self {
            
            
            AlignContent(ref value) => {
                let value = crate::values::specified::AlignContent::from_computed_value(&value);
                PropertyDeclaration::AlignContent(value)
            }
            
            AlignItems(ref value) => {
                let value = crate::values::specified::AlignItems::from_computed_value(&value);
                PropertyDeclaration::AlignItems(value)
            }
            
            AlignSelf(ref value) => {
                let value = crate::values::specified::AlignSelf::from_computed_value(&value);
                PropertyDeclaration::AlignSelf(value)
            }
            
            AspectRatio(ref value) => {
                let value = crate::values::specified::AspectRatio::from_computed_value(&value);
                PropertyDeclaration::AspectRatio(value)
            }
            
            BackfaceVisibility(ref value) => {
                let value = longhands::backface_visibility::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackfaceVisibility(value)
            }
            
            BaselineSource(ref value) => {
                let value = crate::values::specified::BaselineSource::from_computed_value(&value);
                PropertyDeclaration::BaselineSource(value)
            }
            
            BorderCollapse(ref value) => {
                let value = longhands::border_collapse::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BorderCollapse(value)
            }
            
            BorderImageRepeat(ref value) => {
                let value = crate::values::specified::BorderImageRepeat::from_computed_value(&value);
                PropertyDeclaration::BorderImageRepeat(value)
            }
            
            BoxDecorationBreak(ref value) => {
                let value = longhands::box_decoration_break::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BoxDecorationBreak(value)
            }
            
            BoxSizing(ref value) => {
                let value = longhands::box_sizing::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BoxSizing(value)
            }
            
            BreakInside(ref value) => {
                let value = crate::values::specified::BreakWithin::from_computed_value(&value);
                PropertyDeclaration::BreakInside(value)
            }
            
            CaptionSide(ref value) => {
                let value = crate::values::specified::table::CaptionSide::from_computed_value(&value);
                PropertyDeclaration::CaptionSide(value)
            }
            
            Clear(ref value) => {
                let value = crate::values::specified::Clear::from_computed_value(&value);
                PropertyDeclaration::Clear(value)
            }
            
            ColorInterpolation(ref value) => {
                let value = longhands::color_interpolation::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColorInterpolation(value)
            }
            
            ColorInterpolationFilters(ref value) => {
                let value = longhands::color_interpolation_filters::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColorInterpolationFilters(value)
            }
            
            ColumnCount(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::ColumnCount::from_computed_value(&value);
                PropertyDeclaration::ColumnCount(value)
            }
            
            ColumnFill(ref value) => {
                let value = longhands::column_fill::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColumnFill(value)
            }
            
            ColumnSpan(ref value) => {
                let value = longhands::column_span::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ColumnSpan(value)
            }
            
            ContentVisibility(ref value) => {
                let value = crate::values::specified::ContentVisibility::from_computed_value(&value);
                PropertyDeclaration::ContentVisibility(value)
            }
            
            Display(ref value) => {
                let value = crate::values::specified::Display::from_computed_value(&value);
                PropertyDeclaration::Display(value)
            }
            
            DominantBaseline(ref value) => {
                let value = longhands::dominant_baseline::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::DominantBaseline(value)
            }
            
            EmptyCells(ref value) => {
                let value = longhands::empty_cells::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::EmptyCells(value)
            }
            
            FlexDirection(ref value) => {
                let value = longhands::flex_direction::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FlexDirection(value)
            }
            
            FlexWrap(ref value) => {
                let value = longhands::flex_wrap::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FlexWrap(value)
            }
            
            Float(ref value) => {
                let value = crate::values::specified::Float::from_computed_value(&value);
                PropertyDeclaration::Float(value)
            }
            
            FontKerning(ref value) => {
                let value = longhands::font_kerning::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontKerning(value)
            }
            
            FontLanguageOverride(ref value) => {
                let value = crate::values::specified::FontLanguageOverride::from_computed_value(&value);
                PropertyDeclaration::FontLanguageOverride(value)
            }
            
            FontOpticalSizing(ref value) => {
                let value = longhands::font_optical_sizing::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontOpticalSizing(value)
            }
            
            FontSizeAdjust(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::FontSizeAdjust::from_computed_value(&value);
                PropertyDeclaration::FontSizeAdjust(value)
            }
            
            FontStretch(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::FontStretch::from_computed_value(&value);
                PropertyDeclaration::FontStretch(value)
            }
            
            FontStyle(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::FontStyle::from_computed_value(&value);
                PropertyDeclaration::FontStyle(value)
            }
            
            FontVariantCaps(ref value) => {
                let value = longhands::font_variant_caps::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontVariantCaps(value)
            }
            
            FontVariantEastAsian(ref value) => {
                let value = crate::values::specified::FontVariantEastAsian::from_computed_value(&value);
                PropertyDeclaration::FontVariantEastAsian(value)
            }
            
            FontVariantEmoji(ref value) => {
                let value = longhands::font_variant_emoji::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontVariantEmoji(value)
            }
            
            FontVariantLigatures(ref value) => {
                let value = crate::values::specified::FontVariantLigatures::from_computed_value(&value);
                PropertyDeclaration::FontVariantLigatures(value)
            }
            
            FontVariantNumeric(ref value) => {
                let value = crate::values::specified::FontVariantNumeric::from_computed_value(&value);
                PropertyDeclaration::FontVariantNumeric(value)
            }
            
            FontVariantPosition(ref value) => {
                let value = longhands::font_variant_position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::FontVariantPosition(value)
            }
            
            FontWeight(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::FontWeight::from_computed_value(&value);
                PropertyDeclaration::FontWeight(value)
            }
            
            ForcedColorAdjust(ref value) => {
                let value = crate::values::specified::ForcedColorAdjust::from_computed_value(&value);
                PropertyDeclaration::ForcedColorAdjust(value)
            }
            
            GridAutoFlow(ref value) => {
                let value = crate::values::specified::GridAutoFlow::from_computed_value(&value);
                PropertyDeclaration::GridAutoFlow(value)
            }
            
            Hyphens(ref value) => {
                let value = longhands::hyphens::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Hyphens(value)
            }
            
            ImageOrientation(ref value) => {
                let value = longhands::image_orientation::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ImageOrientation(value)
            }
            
            ImageRendering(ref value) => {
                let value = crate::values::specified::ImageRendering::from_computed_value(&value);
                PropertyDeclaration::ImageRendering(value)
            }
            
            ImeMode(ref value) => {
                let value = longhands::ime_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ImeMode(value)
            }
            
            InitialLetter(ref value) => {
                let value = crate::values::specified::InitialLetter::from_computed_value(&value);
                PropertyDeclaration::InitialLetter(value)
            }
            
            InsetArea(ref value) => {
                let value = crate::values::specified::InsetArea::from_computed_value(&value);
                PropertyDeclaration::InsetArea(value)
            }
            
            Isolation(ref value) => {
                let value = longhands::isolation::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Isolation(value)
            }
            
            JustifyContent(ref value) => {
                let value = crate::values::specified::JustifyContent::from_computed_value(&value);
                PropertyDeclaration::JustifyContent(value)
            }
            
            JustifyItems(ref value) => {
                let value = crate::values::specified::JustifyItems::from_computed_value(&value);
                PropertyDeclaration::JustifyItems(value)
            }
            
            JustifySelf(ref value) => {
                let value = crate::values::specified::JustifySelf::from_computed_value(&value);
                PropertyDeclaration::JustifySelf(value)
            }
            
            LineBreak(ref value) => {
                let value = crate::values::specified::LineBreak::from_computed_value(&value);
                PropertyDeclaration::LineBreak(value)
            }
            
            ListStylePosition(ref value) => {
                let value = longhands::list_style_position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ListStylePosition(value)
            }
            
            MaskType(ref value) => {
                let value = longhands::mask_type::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskType(value)
            }
            
            MasonryAutoFlow(ref value) => {
                let value = crate::values::specified::MasonryAutoFlow::from_computed_value(&value);
                PropertyDeclaration::MasonryAutoFlow(value)
            }
            
            MixBlendMode(ref value) => {
                let value = longhands::mix_blend_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MixBlendMode(value)
            }
            
            MozBoxAlign(ref value) => {
                let value = longhands::_moz_box_align::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxAlign(value)
            }
            
            MozBoxDirection(ref value) => {
                let value = longhands::_moz_box_direction::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxDirection(value)
            }
            
            MozBoxOrient(ref value) => {
                let value = longhands::_moz_box_orient::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxOrient(value)
            }
            
            MozBoxPack(ref value) => {
                let value = longhands::_moz_box_pack::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozBoxPack(value)
            }
            
            MozFloatEdge(ref value) => {
                let value = longhands::_moz_float_edge::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozFloatEdge(value)
            }
            
            MozInert(ref value) => {
                let value = longhands::_moz_inert::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozInert(value)
            }
            
            MozOrient(ref value) => {
                let value = longhands::_moz_orient::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozOrient(value)
            }
            
            MozOsxFontSmoothing(ref value) => {
                let value = longhands::_moz_osx_font_smoothing::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozOsxFontSmoothing(value)
            }
            
            MozTextSizeAdjust(ref value) => {
                let value = longhands::_moz_text_size_adjust::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozTextSizeAdjust(value)
            }
            
            MozTheme(ref value) => {
                let value = crate::values::specified::ui::MozTheme::from_computed_value(&value);
                PropertyDeclaration::MozTheme(value)
            }
            
            MozUserFocus(ref value) => {
                let value = longhands::_moz_user_focus::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozUserFocus(value)
            }
            
            MozUserInput(ref value) => {
                let value = longhands::_moz_user_input::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozUserInput(value)
            }
            
            MozUserModify(ref value) => {
                let value = longhands::_moz_user_modify::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozUserModify(value)
            }
            
            MozWindowDragging(ref value) => {
                let value = longhands::_moz_window_dragging::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozWindowDragging(value)
            }
            
            MozWindowShadow(ref value) => {
                let value = longhands::_moz_window_shadow::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MozWindowShadow(value)
            }
            
            ObjectFit(ref value) => {
                let value = longhands::object_fit::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ObjectFit(value)
            }
            
            OffsetRotate(ref value) => {
                let value = crate::values::specified::OffsetRotate::from_computed_value(&value);
                PropertyDeclaration::OffsetRotate(value)
            }
            
            OutlineStyle(ref value) => {
                let value = crate::values::specified::OutlineStyle::from_computed_value(&value);
                PropertyDeclaration::OutlineStyle(value)
            }
            
            OverflowAnchor(ref value) => {
                let value = crate::values::specified::OverflowAnchor::from_computed_value(&value);
                PropertyDeclaration::OverflowAnchor(value)
            }
            
            OverflowWrap(ref value) => {
                let value = crate::values::specified::OverflowWrap::from_computed_value(&value);
                PropertyDeclaration::OverflowWrap(value)
            }
            
            PaintOrder(ref value) => {
                let value = crate::values::specified::SVGPaintOrder::from_computed_value(&value);
                PropertyDeclaration::PaintOrder(value)
            }
            
            PointerEvents(ref value) => {
                let value = longhands::pointer_events::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::PointerEvents(value)
            }
            
            Position(ref value) => {
                let value = longhands::position::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Position(value)
            }
            
            PositionTryOrder(ref value) => {
                let value = crate::values::specified::PositionTryOrder::from_computed_value(&value);
                PropertyDeclaration::PositionTryOrder(value)
            }
            
            PositionVisibility(ref value) => {
                let value = crate::values::specified::PositionVisibility::from_computed_value(&value);
                PropertyDeclaration::PositionVisibility(value)
            }
            
            PrintColorAdjust(ref value) => {
                let value = crate::values::specified::PrintColorAdjust::from_computed_value(&value);
                PropertyDeclaration::PrintColorAdjust(value)
            }
            
            Resize(ref value) => {
                let value = crate::values::specified::Resize::from_computed_value(&value);
                PropertyDeclaration::Resize(value)
            }
            
            RubyAlign(ref value) => {
                let value = longhands::ruby_align::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::RubyAlign(value)
            }
            
            RubyPosition(ref value) => {
                let value = crate::values::specified::RubyPosition::from_computed_value(&value);
                PropertyDeclaration::RubyPosition(value)
            }
            
            ScrollBehavior(ref value) => {
                let value = longhands::scroll_behavior::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ScrollBehavior(value)
            }
            
            ScrollSnapAlign(ref value) => {
                let value = crate::values::specified::ScrollSnapAlign::from_computed_value(&value);
                PropertyDeclaration::ScrollSnapAlign(value)
            }
            
            ScrollSnapStop(ref value) => {
                let value = crate::values::specified::ScrollSnapStop::from_computed_value(&value);
                PropertyDeclaration::ScrollSnapStop(value)
            }
            
            ScrollSnapType(ref value) => {
                let value = crate::values::specified::ScrollSnapType::from_computed_value(&value);
                PropertyDeclaration::ScrollSnapType(value)
            }
            
            ScrollbarGutter(ref value) => {
                let value = crate::values::specified::ScrollbarGutter::from_computed_value(&value);
                PropertyDeclaration::ScrollbarGutter(value)
            }
            
            ScrollbarWidth(ref value) => {
                let value = longhands::scrollbar_width::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ScrollbarWidth(value)
            }
            
            ShapeRendering(ref value) => {
                let value = longhands::shape_rendering::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::ShapeRendering(value)
            }
            
            StrokeLinecap(ref value) => {
                let value = longhands::stroke_linecap::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::StrokeLinecap(value)
            }
            
            StrokeLinejoin(ref value) => {
                let value = longhands::stroke_linejoin::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::StrokeLinejoin(value)
            }
            
            TableLayout(ref value) => {
                let value = longhands::table_layout::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TableLayout(value)
            }
            
            TextAlign(ref value) => {
                let value = crate::values::specified::TextAlign::from_computed_value(&value);
                PropertyDeclaration::TextAlign(value)
            }
            
            TextAlignLast(ref value) => {
                let value = crate::values::specified::TextAlignLast::from_computed_value(&value);
                PropertyDeclaration::TextAlignLast(value)
            }
            
            TextAnchor(ref value) => {
                let value = longhands::text_anchor::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextAnchor(value)
            }
            
            TextDecorationLine(ref value) => {
                let value = crate::values::specified::TextDecorationLine::from_computed_value(&value);
                PropertyDeclaration::TextDecorationLine(value)
            }
            
            TextDecorationSkipInk(ref value) => {
                let value = crate::values::specified::TextDecorationSkipInk::from_computed_value(&value);
                PropertyDeclaration::TextDecorationSkipInk(value)
            }
            
            TextDecorationStyle(ref value) => {
                let value = longhands::text_decoration_style::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextDecorationStyle(value)
            }
            
            TextEmphasisPosition(ref value) => {
                let value = crate::values::specified::TextEmphasisPosition::from_computed_value(&value);
                PropertyDeclaration::TextEmphasisPosition(value)
            }
            
            TextJustify(ref value) => {
                let value = crate::values::specified::TextJustify::from_computed_value(&value);
                PropertyDeclaration::TextJustify(value)
            }
            
            TextRendering(ref value) => {
                let value = longhands::text_rendering::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextRendering(value)
            }
            
            TextTransform(ref value) => {
                let value = crate::values::specified::TextTransform::from_computed_value(&value);
                PropertyDeclaration::TextTransform(value)
            }
            
            TextUnderlinePosition(ref value) => {
                let value = crate::values::specified::TextUnderlinePosition::from_computed_value(&value);
                PropertyDeclaration::TextUnderlinePosition(value)
            }
            
            TextWrapMode(ref value) => {
                let value = longhands::text_wrap_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextWrapMode(value)
            }
            
            TextWrapStyle(ref value) => {
                let value = longhands::text_wrap_style::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextWrapStyle(value)
            }
            
            TouchAction(ref value) => {
                let value = crate::values::specified::TouchAction::from_computed_value(&value);
                PropertyDeclaration::TouchAction(value)
            }
            
            TransformBox(ref value) => {
                let value = crate::values::specified::TransformBox::from_computed_value(&value);
                PropertyDeclaration::TransformBox(value)
            }
            
            TransformStyle(ref value) => {
                let value = crate::values::specified::TransformStyle::from_computed_value(&value);
                PropertyDeclaration::TransformStyle(value)
            }
            
            UserSelect(ref value) => {
                let value = crate::values::specified::UserSelect::from_computed_value(&value);
                PropertyDeclaration::UserSelect(value)
            }
            
            VectorEffect(ref value) => {
                let value = longhands::vector_effect::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::VectorEffect(value)
            }
            
            Visibility(ref value) => {
                let value = longhands::visibility::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Visibility(value)
            }
            
            WebkitLineClamp(ref value) => {
                let value = crate::values::specified::LineClamp::from_computed_value(&value);
                PropertyDeclaration::WebkitLineClamp(value)
            }
            
            WebkitTextSecurity(ref value) => {
                let value = longhands::_webkit_text_security::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::WebkitTextSecurity(value)
            }
            
            WhiteSpaceCollapse(ref value) => {
                let value = longhands::white_space_collapse::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::WhiteSpaceCollapse(value)
            }
            
            WordBreak(ref value) => {
                let value = crate::values::specified::WordBreak::from_computed_value(&value);
                PropertyDeclaration::WordBreak(value)
            }
            
            ZIndex(ref value) => {
                let value = crate::values::specified::ZIndex::from_computed_value(&value);
                PropertyDeclaration::ZIndex(value)
            }
            
            Zoom(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::Zoom::from_computed_value(&value);
                PropertyDeclaration::Zoom(value)
            }
            
            Appearance(ref value) => {
                let value = crate::values::specified::Appearance::from_computed_value(&value);
                PropertyDeclaration::Appearance(value)
            }
            
            MozForceBrokenImageIcon(ref value) |
MozSubtreeHiddenOnlyVisually(ref value) => {
                let value = crate::values::specified::BoolInteger::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BoolInteger>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            BreakAfter(ref value) |
BreakBefore(ref value) => {
                let value = crate::values::specified::BreakBetween::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BreakBetween>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            ClipRule(ref value) |
FillRule(ref value) => {
                let value = crate::values::specified::FillRule::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::FillRule>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            OverflowClipBoxBlock(ref value) |
OverflowClipBoxInline(ref value) => {
                let value = crate::values::specified::OverflowClipBox::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::OverflowClipBox>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            FillOpacity(ref value) |
StrokeOpacity(ref value) => {
                let value = crate::values::specified::SVGOpacity::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::SVGOpacity>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozBoxOrdinalGroup(ref value) |
Order(ref value) => {
                let value = crate::values::specified::Integer::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Integer>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            FontSynthesisPosition(ref value) |
FontSynthesisSmallCaps(ref value) |
FontSynthesisStyle(ref value) |
FontSynthesisWeight(ref value) => {
                let value = crate::values::specified::FontSynthesis::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::FontSynthesis>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            FlexGrow(ref value) |
FlexShrink(ref value) |
MozBoxFlex(ref value) |
StrokeMiterlimit(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::NonNegativeNumber::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeNumber>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            OverflowX(ref value) |
OverflowY(ref value) => {
                let value = crate::values::specified::Overflow::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Overflow>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            OverscrollBehaviorX(ref value) |
OverscrollBehaviorY(ref value) => {
                let value = crate::values::specified::OverscrollBehavior::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::OverscrollBehavior>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            FloodOpacity(ref value) |
MozWindowOpacity(ref value) |
Opacity(ref value) |
ShapeImageThreshold(ref value) |
StopOpacity(ref value) => {
                let value = crate::values::specified::Opacity::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Opacity>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderBottomStyle(ref value) |
BorderLeftStyle(ref value) |
BorderRightStyle(ref value) |
BorderTopStyle(ref value) |
ColumnRuleStyle(ref value) => {
                let value = crate::values::specified::BorderStyle::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BorderStyle>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            AccentColor(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::ColorOrAuto::from_computed_value(&value);
                PropertyDeclaration::AccentColor(value)
            }
            
            AnchorName(ref value) => {
                let value = crate::values::specified::AnchorName::from_computed_value(&value);
                PropertyDeclaration::AnchorName(value)
            }
            
            AnchorScope(ref value) => {
                let value = crate::values::specified::AnchorScope::from_computed_value(&value);
                PropertyDeclaration::AnchorScope(value)
            }
            
            BackdropFilter(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::backdrop_filter::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackdropFilter(value)
            }
            
            BackgroundAttachment(ref value) => {
                let value = longhands::background_attachment::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundAttachment(value)
            }
            
            BackgroundBlendMode(ref value) => {
                let value = longhands::background_blend_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundBlendMode(value)
            }
            
            BackgroundClip(ref value) => {
                let value = longhands::background_clip::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundClip(value)
            }
            
            BackgroundImage(ref value) => {
                let value = longhands::background_image::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundImage(value)
            }
            
            BackgroundOrigin(ref value) => {
                let value = longhands::background_origin::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundOrigin(value)
            }
            
            BackgroundPositionX(ref value) => {
                let value = longhands::background_position_x::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundPositionX(value)
            }
            
            BackgroundPositionY(ref value) => {
                let value = longhands::background_position_y::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundPositionY(value)
            }
            
            BackgroundRepeat(ref value) => {
                let value = longhands::background_repeat::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundRepeat(value)
            }
            
            BackgroundSize(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::background_size::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BackgroundSize(value)
            }
            
            BorderImageOutset(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::NonNegativeLengthOrNumberRect::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderImageOutset(value)
            }
            
            BorderImageSlice(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::BorderImageSlice::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderImageSlice(value)
            }
            
            BorderImageWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::BorderImageWidth::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderImageWidth(value)
            }
            
            BorderSpacing(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::BorderSpacing::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::BorderSpacing(value)
            }
            
            BoxShadow(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::box_shadow::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::BoxShadow(value)
            }
            
            CaretColor(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::color::CaretColor::from_computed_value(&value);
                PropertyDeclaration::CaretColor(value)
            }
            
            Clip(ref value) => {
                let value = crate::values::specified::ClipRectOrAuto::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::Clip(value)
            }
            
            ClipPath(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::basic_shape::ClipPath::from_computed_value(&value);
                PropertyDeclaration::ClipPath(value)
            }
            
            Color(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::ColorPropertyValue::from_computed_value(&value);
                PropertyDeclaration::Color(value)
            }
            
            ColorScheme(ref value) => {
                let value = crate::values::specified::ColorScheme::from_computed_value(&value);
                PropertyDeclaration::ColorScheme(value)
            }
            
            ColumnWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::length::NonNegativeLengthOrAuto::from_computed_value(&value);
                PropertyDeclaration::ColumnWidth(value)
            }
            
            Content(ref value) => {
                let value = crate::values::specified::Content::from_computed_value(&value);
                PropertyDeclaration::Content(value)
            }
            
            CounterIncrement(ref value) => {
                let value = crate::values::specified::CounterIncrement::from_computed_value(&value);
                PropertyDeclaration::CounterIncrement(value)
            }
            
            CounterReset(ref value) => {
                let value = crate::values::specified::CounterReset::from_computed_value(&value);
                PropertyDeclaration::CounterReset(value)
            }
            
            CounterSet(ref value) => {
                let value = crate::values::specified::CounterSet::from_computed_value(&value);
                PropertyDeclaration::CounterSet(value)
            }
            
            Cursor(ref value) => {
                let value = crate::values::specified::Cursor::from_computed_value(&value);
                PropertyDeclaration::Cursor(value)
            }
            
            D(ref value) => {
                let value = crate::values::specified::DProperty::from_computed_value(&value);
                PropertyDeclaration::D(value)
            }
            
            Filter(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::filter::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::Filter(value)
            }
            
            FlexBasis(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::FlexBasis::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::FlexBasis(value)
            }
            
            FontFamily(ref value) => {
                let value = crate::values::specified::FontFamily::from_computed_value(&value);
                PropertyDeclaration::FontFamily(value)
            }
            
            FontFeatureSettings(ref value) => {
                let value = crate::values::specified::FontFeatureSettings::from_computed_value(&value);
                PropertyDeclaration::FontFeatureSettings(value)
            }
            
            FontPalette(ref value) => {
                let value = crate::values::specified::FontPalette::from_computed_value(&value);
                PropertyDeclaration::FontPalette(value)
            }
            
            FontSize(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::FontSize::from_computed_value(&value);
                PropertyDeclaration::FontSize(value)
            }
            
            FontVariantAlternates(ref value) => {
                let value = crate::values::specified::FontVariantAlternates::from_computed_value(&value);
                PropertyDeclaration::FontVariantAlternates(value)
            }
            
            FontVariationSettings(ref value) => {
                let value = crate::values::specified::FontVariationSettings::from_computed_value(&value);
                PropertyDeclaration::FontVariationSettings(value)
            }
            
            GridTemplateAreas(ref value) => {
                let value = crate::values::specified::GridTemplateAreas::from_computed_value(&value);
                PropertyDeclaration::GridTemplateAreas(value)
            }
            
            HyphenateCharacter(ref value) => {
                let value = crate::values::specified::HyphenateCharacter::from_computed_value(&value);
                PropertyDeclaration::HyphenateCharacter(value)
            }
            
            LetterSpacing(ref value) => {
                let value = crate::values::specified::LetterSpacing::from_computed_value(&value);
                PropertyDeclaration::LetterSpacing(value)
            }
            
            LineHeight(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::LineHeight::from_computed_value(&value);
                PropertyDeclaration::LineHeight(value)
            }
            
            ListStyleType(ref value) => {
                let value = crate::values::specified::ListStyleType::from_computed_value(&value);
                PropertyDeclaration::ListStyleType(value)
            }
            
            MaskClip(ref value) => {
                let value = longhands::mask_clip::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskClip(value)
            }
            
            MaskComposite(ref value) => {
                let value = longhands::mask_composite::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskComposite(value)
            }
            
            MaskImage(ref value) => {
                let value = longhands::mask_image::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskImage(value)
            }
            
            MaskMode(ref value) => {
                let value = longhands::mask_mode::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskMode(value)
            }
            
            MaskOrigin(ref value) => {
                let value = longhands::mask_origin::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskOrigin(value)
            }
            
            MaskPositionX(ref value) => {
                let value = longhands::mask_position_x::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskPositionX(value)
            }
            
            MaskPositionY(ref value) => {
                let value = longhands::mask_position_y::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskPositionY(value)
            }
            
            MaskRepeat(ref value) => {
                let value = longhands::mask_repeat::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskRepeat(value)
            }
            
            MaskSize(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::mask_size::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::MaskSize(value)
            }
            
            OffsetAnchor(ref value) => {
                let value = crate::values::specified::PositionOrAuto::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::OffsetAnchor(value)
            }
            
            OffsetPath(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::OffsetPath::from_computed_value(&value);
                PropertyDeclaration::OffsetPath(value)
            }
            
            OffsetPosition(ref value) => {
                let value = crate::values::specified::OffsetPosition::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::OffsetPosition(value)
            }
            
            Page(ref value) => {
                let value = crate::values::specified::PageName::from_computed_value(&value);
                PropertyDeclaration::Page(value)
            }
            
            Perspective(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::Perspective::from_computed_value(&value);
                PropertyDeclaration::Perspective(value)
            }
            
            PositionAnchor(ref value) => {
                let value = crate::values::specified::PositionAnchor::from_computed_value(&value);
                PropertyDeclaration::PositionAnchor(value)
            }
            
            PositionTryOptions(ref value) => {
                let value = crate::values::specified::PositionTryOptions::from_computed_value(&value);
                PropertyDeclaration::PositionTryOptions(value)
            }
            
            Quotes(ref value) => {
                let value = crate::values::specified::Quotes::from_computed_value(&value);
                PropertyDeclaration::Quotes(value)
            }
            
            Rotate(ref value) => {
                let value = crate::values::specified::Rotate::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::Rotate(value)
            }
            
            Scale(ref value) => {
                let value = crate::values::specified::Scale::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::Scale(value)
            }
            
            ScrollbarColor(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::ui::ScrollbarColor::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::ScrollbarColor(value)
            }
            
            ShapeOutside(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::basic_shape::ShapeOutside::from_computed_value(&value);
                PropertyDeclaration::ShapeOutside(value)
            }
            
            StrokeDasharray(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::SVGStrokeDashArray::from_computed_value(&value);
                PropertyDeclaration::StrokeDasharray(value)
            }
            
            StrokeDashoffset(ref value) => {
                let value = crate::values::specified::SVGLength::from_computed_value(&value);
                PropertyDeclaration::StrokeDashoffset(value)
            }
            
            StrokeWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::SVGWidth::from_computed_value(&value);
                PropertyDeclaration::StrokeWidth(value)
            }
            
            TabSize(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::NonNegativeLengthOrNumber::from_computed_value(&value);
                PropertyDeclaration::TabSize(value)
            }
            
            TextDecorationThickness(ref value) => {
                let value = crate::values::specified::TextDecorationLength::from_computed_value(&value);
                PropertyDeclaration::TextDecorationThickness(value)
            }
            
            TextEmphasisStyle(ref value) => {
                let value = crate::values::specified::TextEmphasisStyle::from_computed_value(&value);
                PropertyDeclaration::TextEmphasisStyle(value)
            }
            
            TextIndent(ref value) => {
                let value = crate::values::specified::TextIndent::from_computed_value(&value);
                PropertyDeclaration::TextIndent(value)
            }
            
            TextOverflow(ref value) => {
                let value = crate::values::specified::TextOverflow::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::TextOverflow(value)
            }
            
            TextShadow(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = longhands::text_shadow::SpecifiedValue::from_computed_value(&value);
                PropertyDeclaration::TextShadow(value)
            }
            
            Translate(ref value) => {
                let value = crate::values::specified::Translate::from_computed_value(&value);
                let value = Box::new(value);
                PropertyDeclaration::Translate(value)
            }
            
            VerticalAlign(ref value) => {
                let value = crate::values::specified::VerticalAlign::from_computed_value(&value);
                PropertyDeclaration::VerticalAlign(value)
            }
            
            WebkitTextStrokeWidth(ref value) => {
                let value = crate::values::specified::LineWidth::from_computed_value(&value);
                PropertyDeclaration::WebkitTextStrokeWidth(value)
            }
            
            WordSpacing(ref value) => {
                let value = crate::values::specified::WordSpacing::from_computed_value(&value);
                PropertyDeclaration::WordSpacing(value)
            }
            
            ObjectPosition(ref value) |
PerspectiveOrigin(ref value) => {
                let value = crate::values::specified::Position::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::Position>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            Fill(ref value) |
Stroke(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::SVGPaint::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::SVGPaint>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowTransformOrigin(ref value) |
TransformOrigin(ref value) => {
                let value = crate::values::specified::TransformOrigin::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::TransformOrigin>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridTemplateColumns(ref value) |
GridTemplateRows(ref value) => {
                let value = crate::values::specified::GridTemplateComponent::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::GridTemplateComponent>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderImageSource(ref value) |
ListStyleImage(ref value) => {
                let value = crate::values::specified::Image::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Image>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridAutoColumns(ref value) |
GridAutoRows(ref value) => {
                let value = crate::values::specified::ImplicitGridTracks::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::ImplicitGridTracks>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowTransform(ref value) |
Transform(ref value) => {
                let value = crate::values::specified::Transform::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Transform>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            ColumnGap(ref value) |
RowGap(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::length::NonNegativeLengthPercentageOrNormal::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            MarkerEnd(ref value) |
MarkerMid(ref value) |
MarkerStart(ref value) => {
                let value = crate::values::specified::url::UrlOrNone::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::url::UrlOrNone>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            ContainIntrinsicHeight(ref value) |
ContainIntrinsicWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::ContainIntrinsicSize::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::ContainIntrinsicSize>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            GridColumnEnd(ref value) |
GridColumnStart(ref value) |
GridRowEnd(ref value) |
GridRowStart(ref value) => {
                let value = crate::values::specified::GridLine::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::GridLine>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            MaxHeight(ref value) |
MaxWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::MaxSize::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::MaxSize>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            Cx(ref value) |
Cy(ref value) |
OffsetDistance(ref value) |
X(ref value) |
Y(ref value) => {
                let value = crate::values::specified::LengthPercentage::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderBottomLeftRadius(ref value) |
BorderBottomRightRadius(ref value) |
BorderTopLeftRadius(ref value) |
BorderTopRightRadius(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::BorderCornerRadius::from_computed_value(&value);
                let value = Box::new(value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderCornerRadius>>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            Height(ref value) |
MinHeight(ref value) |
MinWidth(ref value) |
Width(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::Size::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Size>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            BorderBottomWidth(ref value) |
BorderLeftWidth(ref value) |
BorderRightWidth(ref value) |
BorderTopWidth(ref value) |
ColumnRuleWidth(ref value) |
OutlineWidth(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::BorderSideWidth::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BorderSideWidth>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            PaddingBottom(ref value) |
PaddingLeft(ref value) |
PaddingRight(ref value) |
PaddingTop(ref value) |
R(ref value) |
ShapeMargin(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::NonNegativeLengthPercentage::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            Rx(ref value) |
Ry(ref value) |
ScrollPaddingBottom(ref value) |
ScrollPaddingLeft(ref value) |
ScrollPaddingRight(ref value) |
ScrollPaddingTop(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::NonNegativeLengthPercentageOrAuto::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            MozWindowInputRegionMargin(ref value) |
OutlineOffset(ref value) |
OverflowClipMargin(ref value) |
ScrollMarginBottom(ref value) |
ScrollMarginLeft(ref value) |
ScrollMarginRight(ref value) |
ScrollMarginTop(ref value) => {
                let value = crate::values::specified::Length::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Length>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            Bottom(ref value) |
Left(ref value) |
MarginBottom(ref value) |
MarginLeft(ref value) |
MarginRight(ref value) |
MarginTop(ref value) |
Right(ref value) |
TextUnderlineOffset(ref value) |
Top(ref value) => {
                let value = crate::values::specified::LengthPercentageOrAuto::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            
            BackgroundColor(ref value) |
BorderBottomColor(ref value) |
BorderLeftColor(ref value) |
BorderRightColor(ref value) |
BorderTopColor(ref value) |
ColumnRuleColor(ref value) |
FloodColor(ref value) |
LightingColor(ref value) |
OutlineColor(ref value) |
StopColor(ref value) |
TextDecorationColor(ref value) |
TextEmphasisColor(ref value) |
WebkitTextFillColor(ref value) |
WebkitTextStrokeColor(ref value) => {
                let ref value = ToAnimatedValue::from_animated_value(value.clone());
                let value = crate::values::specified::Color::from_computed_value(&value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Color>,
                        PropertyDeclarationVariantRepr {
                            tag: *(self as *const _ as *const u16),
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            Contain(void) |
ContainerType(void) |
Direction(void) |
MathDepth(void) |
MathStyle(void) |
MozBoxCollapse(void) |
MozControlCharacterVisibility(void) |
MozMathVariant(void) |
MozMinFontSizeRatio(void) |
MozTopLayer(void) |
PageOrientation(void) |
TextCombineUpright(void) |
TextOrientation(void) |
UnicodeBidi(void) |
WritingMode(void) |
XTextScale(void) |
MozDefaultAppearance(void) |
XSpan(void) |
OverflowBlock(void) |
OverflowInline(void) |
OverscrollBehaviorBlock(void) |
OverscrollBehaviorInline(void) |
BorderBlockEndStyle(void) |
BorderBlockStartStyle(void) |
BorderInlineEndStyle(void) |
BorderInlineStartStyle(void) |
AnimationComposition(void) |
AnimationDelay(void) |
AnimationDirection(void) |
AnimationDuration(void) |
AnimationFillMode(void) |
AnimationIterationCount(void) |
AnimationName(void) |
AnimationPlayState(void) |
AnimationTimeline(void) |
AnimationTimingFunction(void) |
ContainerName(void) |
MozContextProperties(void) |
ScrollTimelineAxis(void) |
ScrollTimelineName(void) |
Size(void) |
TransitionBehavior(void) |
TransitionDelay(void) |
TransitionDuration(void) |
TransitionProperty(void) |
TransitionTimingFunction(void) |
ViewTimelineAxis(void) |
ViewTimelineInset(void) |
ViewTimelineName(void) |
WillChange(void) |
XLang(void) |
ContainIntrinsicBlockSize(void) |
ContainIntrinsicInlineSize(void) |
MaxBlockSize(void) |
MaxInlineSize(void) |
BorderEndEndRadius(void) |
BorderEndStartRadius(void) |
BorderStartEndRadius(void) |
BorderStartStartRadius(void) |
BlockSize(void) |
InlineSize(void) |
MinBlockSize(void) |
MinInlineSize(void) |
BorderBlockEndWidth(void) |
BorderBlockStartWidth(void) |
BorderInlineEndWidth(void) |
BorderInlineStartWidth(void) |
PaddingBlockEnd(void) |
PaddingBlockStart(void) |
PaddingInlineEnd(void) |
PaddingInlineStart(void) |
ScrollPaddingBlockEnd(void) |
ScrollPaddingBlockStart(void) |
ScrollPaddingInlineEnd(void) |
ScrollPaddingInlineStart(void) |
ScrollMarginBlockEnd(void) |
ScrollMarginBlockStart(void) |
ScrollMarginInlineEnd(void) |
ScrollMarginInlineStart(void) |
InsetBlockEnd(void) |
InsetBlockStart(void) |
InsetInlineEnd(void) |
InsetInlineStart(void) |
MarginBlockEnd(void) |
MarginBlockStart(void) |
MarginInlineEnd(void) |
MarginInlineStart(void) |
BorderBlockEndColor(void) |
BorderBlockStartColor(void) |
BorderInlineEndColor(void) |
BorderInlineStartColor(void) => {
                void::unreachable(void)
            },
            Custom(ref animated_value) => animated_value.to_declaration(),
        }
    }

    /// Construct an AnimationValue from a property declaration.
    pub fn from_declaration(
        decl: &PropertyDeclaration,
        context: &mut Context,
        initial: &ComputedValues,
    ) -> Option<Self> {
        use super::PropertyDeclarationVariantRepr;

        

        let animatable = match *decl {
            PropertyDeclaration::AlignContent(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AlignContent>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AlignContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::AlignItems(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AlignItems>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AlignItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::AlignSelf(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AlignSelf>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AlignSelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::AspectRatio(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AspectRatio>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AspectRatio as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackfaceVisibility(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::backface_visibility::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BaselineSource(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BaselineSource>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BaselineSource as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderCollapse(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::border_collapse::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderImageRepeat(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BorderImageRepeat>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BoxDecorationBreak(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_decoration_break::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BoxSizing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_sizing::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BreakInside(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BreakWithin>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BreakWithin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::CaptionSide(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::table::CaptionSide>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::table::CaptionSide as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Clear(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Clear>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Clear as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColorInterpolation(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColorInterpolationFilters(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::color_interpolation_filters::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColumnCount(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColumnCount>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColumnFill(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_fill::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColumnSpan(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::column_span::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ContentVisibility(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ContentVisibility>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ContentVisibility as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Display(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Display>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Display as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::DominantBaseline(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::dominant_baseline::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::EmptyCells(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::empty_cells::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FlexDirection(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_direction::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FlexWrap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::flex_wrap::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Float(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Float>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Float as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontKerning(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_kerning::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontLanguageOverride(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontLanguageOverride>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontOpticalSizing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_optical_sizing::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontSizeAdjust(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontSizeAdjust>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontStretch(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontStretch>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontStretch as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontStyle>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontStyle as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariantCaps(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_caps::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariantEastAsian(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantEastAsian>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariantEmoji(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_emoji::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_variant_emoji::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariantLigatures(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantLigatures>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariantNumeric(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantNumeric>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariantPosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::font_variant_position::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontWeight(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontWeight>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontWeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ForcedColorAdjust(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ForcedColorAdjust>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ForcedColorAdjust as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::GridAutoFlow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridAutoFlow>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Hyphens(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::hyphens::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ImageOrientation(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::image_orientation::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::image_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ImageRendering(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ImageRendering>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ImageRendering as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ImeMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::ime_mode::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::InitialLetter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::InitialLetter>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::InitialLetter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::InsetArea(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::InsetArea>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::InsetArea as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Isolation(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::isolation::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::JustifyContent(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::JustifyContent>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::JustifyContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::JustifyItems(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::JustifyItems>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::JustifyItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::JustifySelf(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::JustifySelf>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::JustifySelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::LineBreak(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineBreak>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LineBreak as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ListStylePosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::list_style_position::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskType(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_type::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MasonryAutoFlow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::MasonryAutoFlow>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::MasonryAutoFlow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MixBlendMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mix_blend_mode::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozBoxAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_align::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozBoxDirection(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_direction::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozBoxOrient(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_orient::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozBoxPack(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_box_pack::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozFloatEdge(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_float_edge::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozInert(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_inert::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_inert::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozOrient(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_orient::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozOsxFontSmoothing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_osx_font_smoothing::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozTextSizeAdjust(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_text_size_adjust::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozTheme(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ui::MozTheme>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ui::MozTheme as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozUserFocus(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_focus::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozUserInput(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_input::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozUserModify(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_user_modify::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozWindowDragging(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_dragging::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozWindowShadow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_moz_window_shadow::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ObjectFit(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::object_fit::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OffsetRotate(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OffsetRotate>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OffsetRotate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OutlineStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OutlineStyle>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OverflowAnchor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverflowAnchor>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverflowAnchor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OverflowWrap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverflowWrap>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverflowWrap as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PaintOrder(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGPaintOrder>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PointerEvents(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::pointer_events::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Position(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::position::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PositionTryOrder(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionTryOrder>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionTryOrder as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PositionVisibility(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionVisibility>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionVisibility as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PrintColorAdjust(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PrintColorAdjust>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PrintColorAdjust as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Resize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Resize>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Resize as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::RubyAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::ruby_align::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::RubyPosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::RubyPosition>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::RubyPosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ScrollBehavior(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::scroll_behavior::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ScrollSnapAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollSnapAlign>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollSnapAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ScrollSnapStop(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollSnapStop>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollSnapStop as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ScrollSnapType(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollSnapType>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ScrollbarGutter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ScrollbarGutter>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollbarGutter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ScrollbarWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::scrollbar_width::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::scrollbar_width::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ShapeRendering(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::shape_rendering::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::StrokeLinecap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linecap::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::StrokeLinejoin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::stroke_linejoin::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TableLayout(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::table_layout::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextAlign>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextAlignLast(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextAlignLast>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextAlignLast as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextAnchor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_anchor::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextDecorationLine(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextDecorationLine>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextDecorationSkipInk(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextDecorationSkipInk>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextDecorationSkipInk as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextDecorationStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_decoration_style::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextEmphasisPosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextEmphasisPosition>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextEmphasisPosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextJustify(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextJustify>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextJustify as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextRendering(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_rendering::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextTransform(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextTransform>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextTransform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextUnderlinePosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextUnderlinePosition>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextUnderlinePosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextWrapMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_wrap_mode::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_wrap_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextWrapStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_wrap_style::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_wrap_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TouchAction(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TouchAction>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TouchAction as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TransformBox(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TransformBox>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TransformBox as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TransformStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TransformStyle>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TransformStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::UserSelect(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::UserSelect>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::UserSelect as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::VectorEffect(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::vector_effect::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Visibility(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::visibility::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::WebkitLineClamp(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineClamp>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LineClamp as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::WebkitTextSecurity(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::_webkit_text_security::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_webkit_text_security::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::WhiteSpaceCollapse(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::white_space_collapse::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::white_space_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::WordBreak(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::WordBreak>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::WordBreak as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ZIndex(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ZIndex>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ZIndex as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Zoom(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Zoom>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Zoom as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Appearance(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Appearance>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Appearance as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozForceBrokenImageIcon(ref value) |
PropertyDeclaration::MozSubtreeHiddenOnlyVisually(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BoolInteger>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BreakAfter(ref value) |
PropertyDeclaration::BreakBefore(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BreakBetween>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ClipRule(ref value) |
PropertyDeclaration::FillRule(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FillRule>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FillRule as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OverflowClipBoxBlock(ref value) |
PropertyDeclaration::OverflowClipBoxInline(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverflowClipBox>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FillOpacity(ref value) |
PropertyDeclaration::StrokeOpacity(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGOpacity>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozBoxOrdinalGroup(ref value) |
PropertyDeclaration::Order(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Integer>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Integer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontSynthesisPosition(ref value) |
PropertyDeclaration::FontSynthesisSmallCaps(ref value) |
PropertyDeclaration::FontSynthesisStyle(ref value) |
PropertyDeclaration::FontSynthesisWeight(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontSynthesis>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FlexGrow(ref value) |
PropertyDeclaration::FlexShrink(ref value) |
PropertyDeclaration::MozBoxFlex(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeNumber>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::StrokeMiterlimit(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeNumber>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OverflowBlock(ref value) |
PropertyDeclaration::OverflowInline(ref value) |
PropertyDeclaration::OverflowX(ref value) |
PropertyDeclaration::OverflowY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Overflow>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Overflow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OverscrollBehaviorBlock(ref value) |
PropertyDeclaration::OverscrollBehaviorInline(ref value) |
PropertyDeclaration::OverscrollBehaviorX(ref value) |
PropertyDeclaration::OverscrollBehaviorY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OverscrollBehavior>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FloodOpacity(ref value) |
PropertyDeclaration::MozWindowOpacity(ref value) |
PropertyDeclaration::Opacity(ref value) |
PropertyDeclaration::ShapeImageThreshold(ref value) |
PropertyDeclaration::StopOpacity(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Opacity>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Opacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderBottomStyle(ref value) |
PropertyDeclaration::BorderLeftStyle(ref value) |
PropertyDeclaration::BorderRightStyle(ref value) |
PropertyDeclaration::BorderTopStyle(ref value) |
PropertyDeclaration::ColumnRuleStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BorderStyle>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::AccentColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColorOrAuto>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ColorOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::AnchorName(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AnchorName>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AnchorName as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::AnchorScope(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::AnchorScope>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AnchorScope as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackdropFilter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::backdrop_filter::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::backdrop_filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundAttachment(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_attachment::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundBlendMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_blend_mode::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundClip(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_clip::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundImage(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_image::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_origin::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundPositionX(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_x::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundPositionY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_position_y::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundRepeat(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_repeat::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::background_size::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderImageOutset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::NonNegativeLengthOrNumberRect>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumberRect as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderImageSlice(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderImageSlice>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderImageWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderImageWidth>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderSpacing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderSpacing>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BoxShadow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::box_shadow::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::CaretColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::color::CaretColor>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::color::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Clip(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::ClipRectOrAuto>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ClipPath(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::basic_shape::ClipPath>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ClipPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Color(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColorPropertyValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColorScheme(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ColorScheme>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ColorScheme as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColumnWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::length::NonNegativeLengthOrAuto>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Content(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Content>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Content as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::CounterIncrement(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::CounterIncrement>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::CounterReset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::CounterReset>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::CounterReset as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::CounterSet(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::CounterSet>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::CounterSet as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Cursor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Cursor>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Cursor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::D(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::DProperty>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::DProperty as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Filter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::filter::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FlexBasis(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::FlexBasis>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FlexBasis as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontFamily(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontFamily>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontFamily as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontFeatureSettings(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontFeatureSettings>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontPalette(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontPalette>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontPalette as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontSize>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                if let Some(sf) = value.get_system() {
                    longhands::system_font::resolve_system_font(sf, context)
                }
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariantAlternates(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariantAlternates>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::FontVariationSettings(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::FontVariationSettings>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::GridTemplateAreas(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridTemplateAreas>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::HyphenateCharacter(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::HyphenateCharacter>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::HyphenateCharacter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::LetterSpacing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LetterSpacing>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::LineHeight(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineHeight>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ListStyleType(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ListStyleType>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ListStyleType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskClip(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_clip::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskComposite(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_composite::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskImage(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_image::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskMode(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_mode::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_origin::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskPositionX(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_x::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskPositionY(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_position_y::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskRepeat(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_repeat::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaskSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::mask_size::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OffsetAnchor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::PositionOrAuto>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OffsetPath(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::OffsetPath>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::OffsetPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::OffsetPosition(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::OffsetPosition>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OffsetPosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Page(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PageName>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PageName as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Perspective(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Perspective>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PositionAnchor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionAnchor>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionAnchor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PositionTryOptions(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::PositionTryOptions>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionTryOptions as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Quotes(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Quotes>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Quotes as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Rotate(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Rotate>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Rotate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Scale(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Scale>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Scale as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ScrollbarColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::ui::ScrollbarColor>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ui::ScrollbarColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ShapeOutside(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::basic_shape::ShapeOutside>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ShapeOutside as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::StrokeDasharray(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGStrokeDashArray>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::StrokeDashoffset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGLength>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::SVGLength as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::StrokeWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::SVGWidth>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TabSize(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthOrNumber>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextDecorationThickness(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextDecorationLength>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextDecorationLength as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextEmphasisStyle(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextEmphasisStyle>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextIndent(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::TextIndent>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextIndent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextOverflow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::TextOverflow>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextOverflow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextShadow(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<longhands::text_shadow::SpecifiedValue>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Translate(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Translate>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Translate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::VerticalAlign(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::VerticalAlign>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::WebkitTextStrokeWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LineWidth>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LineWidth as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::WordSpacing(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::WordSpacing>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::WordSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ObjectPosition(ref value) |
PropertyDeclaration::PerspectiveOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::Position>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Fill(ref value) |
PropertyDeclaration::Stroke(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::SVGPaint>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozWindowTransformOrigin(ref value) |
PropertyDeclaration::TransformOrigin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::TransformOrigin>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::GridTemplateColumns(ref value) |
PropertyDeclaration::GridTemplateRows(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridTemplateComponent>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderImageSource(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Image>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Image as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ListStyleImage(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Image>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Image as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::GridAutoColumns(ref value) |
PropertyDeclaration::GridAutoRows(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ImplicitGridTracks>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ImplicitGridTracks as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozWindowTransform(ref value) |
PropertyDeclaration::Transform(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Transform>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Transform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ColumnGap(ref value) |
PropertyDeclaration::RowGap(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MarkerEnd(ref value) |
PropertyDeclaration::MarkerMid(ref value) |
PropertyDeclaration::MarkerStart(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::url::UrlOrNone>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::ContainIntrinsicBlockSize(ref value) |
PropertyDeclaration::ContainIntrinsicHeight(ref value) |
PropertyDeclaration::ContainIntrinsicInlineSize(ref value) |
PropertyDeclaration::ContainIntrinsicWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::ContainIntrinsicSize>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::GridColumnEnd(ref value) |
PropertyDeclaration::GridColumnStart(ref value) |
PropertyDeclaration::GridRowEnd(ref value) |
PropertyDeclaration::GridRowStart(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::GridLine>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MaxBlockSize(ref value) |
PropertyDeclaration::MaxHeight(ref value) |
PropertyDeclaration::MaxInlineSize(ref value) |
PropertyDeclaration::MaxWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::MaxSize>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Cx(ref value) |
PropertyDeclaration::Cy(ref value) |
PropertyDeclaration::OffsetDistance(ref value) |
PropertyDeclaration::X(ref value) |
PropertyDeclaration::Y(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentage>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderBottomLeftRadius(ref value) |
PropertyDeclaration::BorderBottomRightRadius(ref value) |
PropertyDeclaration::BorderEndEndRadius(ref value) |
PropertyDeclaration::BorderEndStartRadius(ref value) |
PropertyDeclaration::BorderStartEndRadius(ref value) |
PropertyDeclaration::BorderStartStartRadius(ref value) |
PropertyDeclaration::BorderTopLeftRadius(ref value) |
PropertyDeclaration::BorderTopRightRadius(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderCornerRadius>>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = (**value).to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BlockSize(ref value) |
PropertyDeclaration::Height(ref value) |
PropertyDeclaration::InlineSize(ref value) |
PropertyDeclaration::MinBlockSize(ref value) |
PropertyDeclaration::MinHeight(ref value) |
PropertyDeclaration::MinInlineSize(ref value) |
PropertyDeclaration::MinWidth(ref value) |
PropertyDeclaration::Width(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Size>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BorderBlockEndWidth(ref value) |
PropertyDeclaration::BorderBlockStartWidth(ref value) |
PropertyDeclaration::BorderBottomWidth(ref value) |
PropertyDeclaration::BorderInlineEndWidth(ref value) |
PropertyDeclaration::BorderInlineStartWidth(ref value) |
PropertyDeclaration::BorderLeftWidth(ref value) |
PropertyDeclaration::BorderRightWidth(ref value) |
PropertyDeclaration::BorderTopWidth(ref value) |
PropertyDeclaration::ColumnRuleWidth(ref value) |
PropertyDeclaration::OutlineWidth(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::BorderSideWidth>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::PaddingBlockEnd(ref value) |
PropertyDeclaration::PaddingBlockStart(ref value) |
PropertyDeclaration::PaddingBottom(ref value) |
PropertyDeclaration::PaddingInlineEnd(ref value) |
PropertyDeclaration::PaddingInlineStart(ref value) |
PropertyDeclaration::PaddingLeft(ref value) |
PropertyDeclaration::PaddingRight(ref value) |
PropertyDeclaration::PaddingTop(ref value) |
PropertyDeclaration::R(ref value) |
PropertyDeclaration::ShapeMargin(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentage>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Rx(ref value) |
PropertyDeclaration::Ry(ref value) |
PropertyDeclaration::ScrollPaddingBlockEnd(ref value) |
PropertyDeclaration::ScrollPaddingBlockStart(ref value) |
PropertyDeclaration::ScrollPaddingBottom(ref value) |
PropertyDeclaration::ScrollPaddingInlineEnd(ref value) |
PropertyDeclaration::ScrollPaddingInlineStart(ref value) |
PropertyDeclaration::ScrollPaddingLeft(ref value) |
PropertyDeclaration::ScrollPaddingRight(ref value) |
PropertyDeclaration::ScrollPaddingTop(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentageOrAuto>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::MozWindowInputRegionMargin(ref value) |
PropertyDeclaration::OutlineOffset(ref value) |
PropertyDeclaration::OverflowClipMargin(ref value) |
PropertyDeclaration::ScrollMarginBlockEnd(ref value) |
PropertyDeclaration::ScrollMarginBlockStart(ref value) |
PropertyDeclaration::ScrollMarginBottom(ref value) |
PropertyDeclaration::ScrollMarginInlineEnd(ref value) |
PropertyDeclaration::ScrollMarginInlineStart(ref value) |
PropertyDeclaration::ScrollMarginLeft(ref value) |
PropertyDeclaration::ScrollMarginRight(ref value) |
PropertyDeclaration::ScrollMarginTop(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Length>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Length as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Bottom(ref value) |
PropertyDeclaration::InsetBlockEnd(ref value) |
PropertyDeclaration::InsetBlockStart(ref value) |
PropertyDeclaration::InsetInlineEnd(ref value) |
PropertyDeclaration::InsetInlineStart(ref value) |
PropertyDeclaration::Left(ref value) |
PropertyDeclaration::MarginBlockEnd(ref value) |
PropertyDeclaration::MarginBlockStart(ref value) |
PropertyDeclaration::MarginBottom(ref value) |
PropertyDeclaration::MarginInlineEnd(ref value) |
PropertyDeclaration::MarginInlineStart(ref value) |
PropertyDeclaration::MarginLeft(ref value) |
PropertyDeclaration::MarginRight(ref value) |
PropertyDeclaration::MarginTop(ref value) |
PropertyDeclaration::Right(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentageOrAuto>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextUnderlineOffset(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentageOrAuto>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::Top(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentageOrAuto>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::BackgroundColor(ref value) |
PropertyDeclaration::BorderBlockEndColor(ref value) |
PropertyDeclaration::BorderBlockStartColor(ref value) |
PropertyDeclaration::BorderBottomColor(ref value) |
PropertyDeclaration::BorderInlineEndColor(ref value) |
PropertyDeclaration::BorderInlineStartColor(ref value) |
PropertyDeclaration::BorderLeftColor(ref value) |
PropertyDeclaration::BorderRightColor(ref value) |
PropertyDeclaration::BorderTopColor(ref value) |
PropertyDeclaration::ColumnRuleColor(ref value) |
PropertyDeclaration::FloodColor(ref value) |
PropertyDeclaration::LightingColor(ref value) |
PropertyDeclaration::OutlineColor(ref value) |
PropertyDeclaration::StopColor(ref value) |
PropertyDeclaration::TextDecorationColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Color>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = true;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::TextEmphasisColor(ref value) |
PropertyDeclaration::WebkitTextFillColor(ref value) |
PropertyDeclaration::WebkitTextStrokeColor(ref value) => {
                let decl_repr = unsafe {
                    &*(decl as *const _ as *const PropertyDeclarationVariantRepr<crate::values::specified::Color>)
                };
                let longhand_id = unsafe {
                    *(&decl_repr.tag as *const u16 as *const LonghandId)
                };
                context.for_non_inherited_property = false;
                let value = value.to_computed_value(context);
                let value = value.to_animated_value();

                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: longhand_id.to_physical(context.builder.writing_mode) as u16,
                            value,
                        },
                    );
                    out.assume_init()
                }
            }
            PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                match declaration.id.to_physical(context.builder.writing_mode) {
                    // We put all the animatable properties first in the hopes
                    // that it might increase match locality.
                    LonghandId::AlignContent => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_align_content();

                        AnimationValue::AlignContent(computed)
                    },
                    LonghandId::AlignItems => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_align_items();

                        AnimationValue::AlignItems(computed)
                    },
                    LonghandId::AlignSelf => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_align_self();

                        AnimationValue::AlignSelf(computed)
                    },
                    LonghandId::AspectRatio => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_aspect_ratio();

                        AnimationValue::AspectRatio(computed)
                    },
                    LonghandId::BackfaceVisibility => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_backface_visibility();

                        AnimationValue::BackfaceVisibility(computed)
                    },
                    LonghandId::BaselineSource => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_baseline_source();

                        AnimationValue::BaselineSource(computed)
                    },
                    LonghandId::BorderCollapse => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_table()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_table()
                            },
                        };
                        let computed = style_struct
                            .clone_border_collapse();

                        AnimationValue::BorderCollapse(computed)
                    },
                    LonghandId::BorderImageRepeat => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_image_repeat();

                        AnimationValue::BorderImageRepeat(computed)
                    },
                    LonghandId::BoxDecorationBreak => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_box_decoration_break();

                        AnimationValue::BoxDecorationBreak(computed)
                    },
                    LonghandId::BoxSizing => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_box_sizing();

                        AnimationValue::BoxSizing(computed)
                    },
                    LonghandId::BreakInside => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_break_inside();

                        AnimationValue::BreakInside(computed)
                    },
                    LonghandId::CaptionSide => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_table()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_table()
                            },
                        };
                        let computed = style_struct
                            .clone_caption_side();

                        AnimationValue::CaptionSide(computed)
                    },
                    LonghandId::Clear => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_clear();

                        AnimationValue::Clear(computed)
                    },
                    LonghandId::ColorInterpolation => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_color_interpolation();

                        AnimationValue::ColorInterpolation(computed)
                    },
                    LonghandId::ColorInterpolationFilters => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_color_interpolation_filters();

                        AnimationValue::ColorInterpolationFilters(computed)
                    },
                    LonghandId::ColumnCount => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct
                            .clone_column_count();

                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnCount(computed)
                    },
                    LonghandId::ColumnFill => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct
                            .clone_column_fill();

                        AnimationValue::ColumnFill(computed)
                    },
                    LonghandId::ColumnSpan => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct
                            .clone_column_span();

                        AnimationValue::ColumnSpan(computed)
                    },
                    LonghandId::ContentVisibility => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_content_visibility();

                        AnimationValue::ContentVisibility(computed)
                    },
                    LonghandId::Display => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_display();

                        AnimationValue::Display(computed)
                    },
                    LonghandId::DominantBaseline => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_dominant_baseline();

                        AnimationValue::DominantBaseline(computed)
                    },
                    LonghandId::EmptyCells => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_table()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_table()
                            },
                        };
                        let computed = style_struct
                            .clone_empty_cells();

                        AnimationValue::EmptyCells(computed)
                    },
                    LonghandId::FlexDirection => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_flex_direction();

                        AnimationValue::FlexDirection(computed)
                    },
                    LonghandId::FlexWrap => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_flex_wrap();

                        AnimationValue::FlexWrap(computed)
                    },
                    LonghandId::Float => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_float();

                        AnimationValue::Float(computed)
                    },
                    LonghandId::FontKerning => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_kerning();

                        AnimationValue::FontKerning(computed)
                    },
                    LonghandId::FontLanguageOverride => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_language_override();

                        AnimationValue::FontLanguageOverride(computed)
                    },
                    LonghandId::FontOpticalSizing => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_optical_sizing();

                        AnimationValue::FontOpticalSizing(computed)
                    },
                    LonghandId::FontSizeAdjust => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_size_adjust();

                        let computed = computed.to_animated_value();
                        AnimationValue::FontSizeAdjust(computed)
                    },
                    LonghandId::FontStretch => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_stretch();

                        let computed = computed.to_animated_value();
                        AnimationValue::FontStretch(computed)
                    },
                    LonghandId::FontStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_style();

                        let computed = computed.to_animated_value();
                        AnimationValue::FontStyle(computed)
                    },
                    LonghandId::FontVariantCaps => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variant_caps();

                        AnimationValue::FontVariantCaps(computed)
                    },
                    LonghandId::FontVariantEastAsian => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variant_east_asian();

                        AnimationValue::FontVariantEastAsian(computed)
                    },
                    LonghandId::FontVariantEmoji => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variant_emoji();

                        AnimationValue::FontVariantEmoji(computed)
                    },
                    LonghandId::FontVariantLigatures => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variant_ligatures();

                        AnimationValue::FontVariantLigatures(computed)
                    },
                    LonghandId::FontVariantNumeric => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variant_numeric();

                        AnimationValue::FontVariantNumeric(computed)
                    },
                    LonghandId::FontVariantPosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variant_position();

                        AnimationValue::FontVariantPosition(computed)
                    },
                    LonghandId::FontWeight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_weight();

                        let computed = computed.to_animated_value();
                        AnimationValue::FontWeight(computed)
                    },
                    LonghandId::ForcedColorAdjust => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_forced_color_adjust();

                        AnimationValue::ForcedColorAdjust(computed)
                    },
                    LonghandId::GridAutoFlow => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_auto_flow();

                        AnimationValue::GridAutoFlow(computed)
                    },
                    LonghandId::Hyphens => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_hyphens();

                        AnimationValue::Hyphens(computed)
                    },
                    LonghandId::ImageOrientation => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_box()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_box()
                            },
                        };
                        let computed = style_struct
                            .clone_image_orientation();

                        AnimationValue::ImageOrientation(computed)
                    },
                    LonghandId::ImageRendering => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_box()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_box()
                            },
                        };
                        let computed = style_struct
                            .clone_image_rendering();

                        AnimationValue::ImageRendering(computed)
                    },
                    LonghandId::ImeMode => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_ime_mode();

                        AnimationValue::ImeMode(computed)
                    },
                    LonghandId::InitialLetter => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct
                            .clone_initial_letter();

                        AnimationValue::InitialLetter(computed)
                    },
                    LonghandId::InsetArea => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_inset_area();

                        AnimationValue::InsetArea(computed)
                    },
                    LonghandId::Isolation => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_isolation();

                        AnimationValue::Isolation(computed)
                    },
                    LonghandId::JustifyContent => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_justify_content();

                        AnimationValue::JustifyContent(computed)
                    },
                    LonghandId::JustifyItems => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_justify_items();

                        AnimationValue::JustifyItems(computed)
                    },
                    LonghandId::JustifySelf => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_justify_self();

                        AnimationValue::JustifySelf(computed)
                    },
                    LonghandId::LineBreak => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_line_break();

                        AnimationValue::LineBreak(computed)
                    },
                    LonghandId::ListStylePosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct
                            .clone_list_style_position();

                        AnimationValue::ListStylePosition(computed)
                    },
                    LonghandId::MaskType => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_type();

                        AnimationValue::MaskType(computed)
                    },
                    LonghandId::MasonryAutoFlow => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_masonry_auto_flow();

                        AnimationValue::MasonryAutoFlow(computed)
                    },
                    LonghandId::MixBlendMode => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct
                            .clone_mix_blend_mode();

                        AnimationValue::MixBlendMode(computed)
                    },
                    LonghandId::MozBoxAlign => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_box_align();

                        AnimationValue::MozBoxAlign(computed)
                    },
                    LonghandId::MozBoxDirection => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_box_direction();

                        AnimationValue::MozBoxDirection(computed)
                    },
                    LonghandId::MozBoxOrient => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_box_orient();

                        AnimationValue::MozBoxOrient(computed)
                    },
                    LonghandId::MozBoxPack => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_box_pack();

                        AnimationValue::MozBoxPack(computed)
                    },
                    LonghandId::MozFloatEdge => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_float_edge();

                        AnimationValue::MozFloatEdge(computed)
                    },
                    LonghandId::MozInert => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_inert();

                        AnimationValue::MozInert(computed)
                    },
                    LonghandId::MozOrient => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_orient();

                        AnimationValue::MozOrient(computed)
                    },
                    LonghandId::MozOsxFontSmoothing => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_osx_font_smoothing();

                        AnimationValue::MozOsxFontSmoothing(computed)
                    },
                    LonghandId::MozTextSizeAdjust => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_text_size_adjust();

                        AnimationValue::MozTextSizeAdjust(computed)
                    },
                    LonghandId::MozTheme => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_theme();

                        AnimationValue::MozTheme(computed)
                    },
                    LonghandId::MozUserFocus => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_user_focus();

                        AnimationValue::MozUserFocus(computed)
                    },
                    LonghandId::MozUserInput => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_user_input();

                        AnimationValue::MozUserInput(computed)
                    },
                    LonghandId::MozUserModify => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_user_modify();

                        AnimationValue::MozUserModify(computed)
                    },
                    LonghandId::MozWindowDragging => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_window_dragging();

                        AnimationValue::MozWindowDragging(computed)
                    },
                    LonghandId::MozWindowShadow => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_window_shadow();

                        AnimationValue::MozWindowShadow(computed)
                    },
                    LonghandId::ObjectFit => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_object_fit();

                        AnimationValue::ObjectFit(computed)
                    },
                    LonghandId::OffsetRotate => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_offset_rotate();

                        AnimationValue::OffsetRotate(computed)
                    },
                    LonghandId::OutlineStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct
                            .clone_outline_style();

                        AnimationValue::OutlineStyle(computed)
                    },
                    LonghandId::OverflowAnchor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_overflow_anchor();

                        AnimationValue::OverflowAnchor(computed)
                    },
                    LonghandId::OverflowWrap => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_overflow_wrap();

                        AnimationValue::OverflowWrap(computed)
                    },
                    LonghandId::PaintOrder => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_paint_order();

                        AnimationValue::PaintOrder(computed)
                    },
                    LonghandId::PointerEvents => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_pointer_events();

                        AnimationValue::PointerEvents(computed)
                    },
                    LonghandId::Position => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_position();

                        AnimationValue::Position(computed)
                    },
                    LonghandId::PositionTryOrder => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_position_try_order();

                        AnimationValue::PositionTryOrder(computed)
                    },
                    LonghandId::PositionVisibility => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_position_visibility();

                        AnimationValue::PositionVisibility(computed)
                    },
                    LonghandId::PrintColorAdjust => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_box()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_box()
                            },
                        };
                        let computed = style_struct
                            .clone_print_color_adjust();

                        AnimationValue::PrintColorAdjust(computed)
                    },
                    LonghandId::Resize => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_resize();

                        AnimationValue::Resize(computed)
                    },
                    LonghandId::RubyAlign => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_ruby_align();

                        AnimationValue::RubyAlign(computed)
                    },
                    LonghandId::RubyPosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_ruby_position();

                        AnimationValue::RubyPosition(computed)
                    },
                    LonghandId::ScrollBehavior => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_behavior();

                        AnimationValue::ScrollBehavior(computed)
                    },
                    LonghandId::ScrollSnapAlign => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_snap_align();

                        AnimationValue::ScrollSnapAlign(computed)
                    },
                    LonghandId::ScrollSnapStop => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_snap_stop();

                        AnimationValue::ScrollSnapStop(computed)
                    },
                    LonghandId::ScrollSnapType => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_snap_type();

                        AnimationValue::ScrollSnapType(computed)
                    },
                    LonghandId::ScrollbarGutter => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_scrollbar_gutter();

                        AnimationValue::ScrollbarGutter(computed)
                    },
                    LonghandId::ScrollbarWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_scrollbar_width();

                        AnimationValue::ScrollbarWidth(computed)
                    },
                    LonghandId::ShapeRendering => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_shape_rendering();

                        AnimationValue::ShapeRendering(computed)
                    },
                    LonghandId::StrokeLinecap => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke_linecap();

                        AnimationValue::StrokeLinecap(computed)
                    },
                    LonghandId::StrokeLinejoin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke_linejoin();

                        AnimationValue::StrokeLinejoin(computed)
                    },
                    LonghandId::TableLayout => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_table()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_table()
                            },
                        };
                        let computed = style_struct
                            .clone_table_layout();

                        AnimationValue::TableLayout(computed)
                    },
                    LonghandId::TextAlign => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_align();

                        AnimationValue::TextAlign(computed)
                    },
                    LonghandId::TextAlignLast => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_align_last();

                        AnimationValue::TextAlignLast(computed)
                    },
                    LonghandId::TextAnchor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_text_anchor();

                        AnimationValue::TextAnchor(computed)
                    },
                    LonghandId::TextDecorationLine => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_decoration_line();

                        AnimationValue::TextDecorationLine(computed)
                    },
                    LonghandId::TextDecorationSkipInk => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_decoration_skip_ink();

                        AnimationValue::TextDecorationSkipInk(computed)
                    },
                    LonghandId::TextDecorationStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_decoration_style();

                        AnimationValue::TextDecorationStyle(computed)
                    },
                    LonghandId::TextEmphasisPosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_emphasis_position();

                        AnimationValue::TextEmphasisPosition(computed)
                    },
                    LonghandId::TextJustify => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_justify();

                        AnimationValue::TextJustify(computed)
                    },
                    LonghandId::TextRendering => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_rendering();

                        AnimationValue::TextRendering(computed)
                    },
                    LonghandId::TextTransform => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_transform();

                        AnimationValue::TextTransform(computed)
                    },
                    LonghandId::TextUnderlinePosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_underline_position();

                        AnimationValue::TextUnderlinePosition(computed)
                    },
                    LonghandId::TextWrapMode => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_wrap_mode();

                        AnimationValue::TextWrapMode(computed)
                    },
                    LonghandId::TextWrapStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_wrap_style();

                        AnimationValue::TextWrapStyle(computed)
                    },
                    LonghandId::TouchAction => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_touch_action();

                        AnimationValue::TouchAction(computed)
                    },
                    LonghandId::TransformBox => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_transform_box();

                        AnimationValue::TransformBox(computed)
                    },
                    LonghandId::TransformStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_transform_style();

                        AnimationValue::TransformStyle(computed)
                    },
                    LonghandId::UserSelect => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_user_select();

                        AnimationValue::UserSelect(computed)
                    },
                    LonghandId::VectorEffect => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_vector_effect();

                        AnimationValue::VectorEffect(computed)
                    },
                    LonghandId::Visibility => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_box()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_box()
                            },
                        };
                        let computed = style_struct
                            .clone_visibility();

                        AnimationValue::Visibility(computed)
                    },
                    LonghandId::WebkitLineClamp => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone__webkit_line_clamp();

                        AnimationValue::WebkitLineClamp(computed)
                    },
                    LonghandId::WebkitTextSecurity => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone__webkit_text_security();

                        AnimationValue::WebkitTextSecurity(computed)
                    },
                    LonghandId::WhiteSpaceCollapse => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_white_space_collapse();

                        AnimationValue::WhiteSpaceCollapse(computed)
                    },
                    LonghandId::WordBreak => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_word_break();

                        AnimationValue::WordBreak(computed)
                    },
                    LonghandId::ZIndex => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_z_index();

                        AnimationValue::ZIndex(computed)
                    },
                    LonghandId::Zoom => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_zoom();

                        let computed = computed.to_animated_value();
                        AnimationValue::Zoom(computed)
                    },
                    LonghandId::Appearance => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_appearance();

                        AnimationValue::Appearance(computed)
                    },
                    LonghandId::MozForceBrokenImageIcon => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_force_broken_image_icon();

                        AnimationValue::MozForceBrokenImageIcon(computed)
                    },
                    LonghandId::MozSubtreeHiddenOnlyVisually => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_subtree_hidden_only_visually();

                        AnimationValue::MozSubtreeHiddenOnlyVisually(computed)
                    },
                    LonghandId::BreakAfter => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_break_after();

                        AnimationValue::BreakAfter(computed)
                    },
                    LonghandId::BreakBefore => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_break_before();

                        AnimationValue::BreakBefore(computed)
                    },
                    LonghandId::ClipRule => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_clip_rule();

                        AnimationValue::ClipRule(computed)
                    },
                    LonghandId::FillRule => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_fill_rule();

                        AnimationValue::FillRule(computed)
                    },
                    LonghandId::OverflowClipBoxBlock => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_overflow_clip_box_block();

                        AnimationValue::OverflowClipBoxBlock(computed)
                    },
                    LonghandId::OverflowClipBoxInline => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_overflow_clip_box_inline();

                        AnimationValue::OverflowClipBoxInline(computed)
                    },
                    LonghandId::FillOpacity => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_fill_opacity();

                        AnimationValue::FillOpacity(computed)
                    },
                    LonghandId::StrokeOpacity => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke_opacity();

                        AnimationValue::StrokeOpacity(computed)
                    },
                    LonghandId::MozBoxOrdinalGroup => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_box_ordinal_group();

                        AnimationValue::MozBoxOrdinalGroup(computed)
                    },
                    LonghandId::Order => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_order();

                        AnimationValue::Order(computed)
                    },
                    LonghandId::FontSynthesisPosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_synthesis_position();

                        AnimationValue::FontSynthesisPosition(computed)
                    },
                    LonghandId::FontSynthesisSmallCaps => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_synthesis_small_caps();

                        AnimationValue::FontSynthesisSmallCaps(computed)
                    },
                    LonghandId::FontSynthesisStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_synthesis_style();

                        AnimationValue::FontSynthesisStyle(computed)
                    },
                    LonghandId::FontSynthesisWeight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_synthesis_weight();

                        AnimationValue::FontSynthesisWeight(computed)
                    },
                    LonghandId::FlexGrow => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_flex_grow();

                        let computed = computed.to_animated_value();
                        AnimationValue::FlexGrow(computed)
                    },
                    LonghandId::FlexShrink => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_flex_shrink();

                        let computed = computed.to_animated_value();
                        AnimationValue::FlexShrink(computed)
                    },
                    LonghandId::MozBoxFlex => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_xul()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_xul()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_box_flex();

                        let computed = computed.to_animated_value();
                        AnimationValue::MozBoxFlex(computed)
                    },
                    LonghandId::StrokeMiterlimit => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke_miterlimit();

                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeMiterlimit(computed)
                    },
                    LonghandId::OverflowX => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_overflow_x();

                        AnimationValue::OverflowX(computed)
                    },
                    LonghandId::OverflowY => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_overflow_y();

                        AnimationValue::OverflowY(computed)
                    },
                    LonghandId::OverscrollBehaviorX => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_overscroll_behavior_x();

                        AnimationValue::OverscrollBehaviorX(computed)
                    },
                    LonghandId::OverscrollBehaviorY => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_overscroll_behavior_y();

                        AnimationValue::OverscrollBehaviorY(computed)
                    },
                    LonghandId::FloodOpacity => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_flood_opacity();

                        AnimationValue::FloodOpacity(computed)
                    },
                    LonghandId::MozWindowOpacity => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_window_opacity();

                        AnimationValue::MozWindowOpacity(computed)
                    },
                    LonghandId::Opacity => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct
                            .clone_opacity();

                        AnimationValue::Opacity(computed)
                    },
                    LonghandId::ShapeImageThreshold => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_shape_image_threshold();

                        AnimationValue::ShapeImageThreshold(computed)
                    },
                    LonghandId::StopOpacity => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stop_opacity();

                        AnimationValue::StopOpacity(computed)
                    },
                    LonghandId::BorderBottomStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_bottom_style();

                        AnimationValue::BorderBottomStyle(computed)
                    },
                    LonghandId::BorderLeftStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_left_style();

                        AnimationValue::BorderLeftStyle(computed)
                    },
                    LonghandId::BorderRightStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_right_style();

                        AnimationValue::BorderRightStyle(computed)
                    },
                    LonghandId::BorderTopStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_top_style();

                        AnimationValue::BorderTopStyle(computed)
                    },
                    LonghandId::ColumnRuleStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct
                            .clone_column_rule_style();

                        AnimationValue::ColumnRuleStyle(computed)
                    },
                    LonghandId::AccentColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_accent_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::AccentColor(computed)
                    },
                    LonghandId::AnchorName => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_anchor_name();

                        AnimationValue::AnchorName(computed)
                    },
                    LonghandId::AnchorScope => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_anchor_scope();

                        AnimationValue::AnchorScope(computed)
                    },
                    LonghandId::BackdropFilter => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct
                            .clone_backdrop_filter();

                        let computed = computed.to_animated_value();
                        AnimationValue::BackdropFilter(computed)
                    },
                    LonghandId::BackgroundAttachment => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_attachment();

                        AnimationValue::BackgroundAttachment(computed)
                    },
                    LonghandId::BackgroundBlendMode => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_blend_mode();

                        AnimationValue::BackgroundBlendMode(computed)
                    },
                    LonghandId::BackgroundClip => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_clip();

                        AnimationValue::BackgroundClip(computed)
                    },
                    LonghandId::BackgroundImage => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_image();

                        AnimationValue::BackgroundImage(computed)
                    },
                    LonghandId::BackgroundOrigin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_origin();

                        AnimationValue::BackgroundOrigin(computed)
                    },
                    LonghandId::BackgroundPositionX => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_position_x();

                        AnimationValue::BackgroundPositionX(computed)
                    },
                    LonghandId::BackgroundPositionY => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_position_y();

                        AnimationValue::BackgroundPositionY(computed)
                    },
                    LonghandId::BackgroundRepeat => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_repeat();

                        AnimationValue::BackgroundRepeat(computed)
                    },
                    LonghandId::BackgroundSize => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_size();

                        let computed = computed.to_animated_value();
                        AnimationValue::BackgroundSize(computed)
                    },
                    LonghandId::BorderImageOutset => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_image_outset();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderImageOutset(computed)
                    },
                    LonghandId::BorderImageSlice => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_image_slice();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderImageSlice(computed)
                    },
                    LonghandId::BorderImageWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_image_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderImageWidth(computed)
                    },
                    LonghandId::BorderSpacing => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_table()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_table()
                            },
                        };
                        let computed = style_struct
                            .clone_border_spacing();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderSpacing(computed)
                    },
                    LonghandId::BoxShadow => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct
                            .clone_box_shadow();

                        let computed = computed.to_animated_value();
                        AnimationValue::BoxShadow(computed)
                    },
                    LonghandId::CaretColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_caret_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::CaretColor(computed)
                    },
                    LonghandId::Clip => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct
                            .clone_clip();

                        AnimationValue::Clip(computed)
                    },
                    LonghandId::ClipPath => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_clip_path();

                        let computed = computed.to_animated_value();
                        AnimationValue::ClipPath(computed)
                    },
                    LonghandId::Color => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::Color(computed)
                    },
                    LonghandId::ColorScheme => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_color_scheme();

                        AnimationValue::ColorScheme(computed)
                    },
                    LonghandId::ColumnWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct
                            .clone_column_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnWidth(computed)
                    },
                    LonghandId::Content => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct
                            .clone_content();

                        AnimationValue::Content(computed)
                    },
                    LonghandId::CounterIncrement => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct
                            .clone_counter_increment();

                        AnimationValue::CounterIncrement(computed)
                    },
                    LonghandId::CounterReset => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct
                            .clone_counter_reset();

                        AnimationValue::CounterReset(computed)
                    },
                    LonghandId::CounterSet => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_counters()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_counters()
                            },
                        };
                        let computed = style_struct
                            .clone_counter_set();

                        AnimationValue::CounterSet(computed)
                    },
                    LonghandId::Cursor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_cursor();

                        AnimationValue::Cursor(computed)
                    },
                    LonghandId::D => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_d();

                        AnimationValue::D(computed)
                    },
                    LonghandId::Filter => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_effects()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_effects()
                            },
                        };
                        let computed = style_struct
                            .clone_filter();

                        let computed = computed.to_animated_value();
                        AnimationValue::Filter(computed)
                    },
                    LonghandId::FlexBasis => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_flex_basis();

                        let computed = computed.to_animated_value();
                        AnimationValue::FlexBasis(computed)
                    },
                    LonghandId::FontFamily => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_family();

                        AnimationValue::FontFamily(computed)
                    },
                    LonghandId::FontFeatureSettings => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_feature_settings();

                        AnimationValue::FontFeatureSettings(computed)
                    },
                    LonghandId::FontPalette => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_palette();

                        AnimationValue::FontPalette(computed)
                    },
                    LonghandId::FontSize => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_size();

                        let computed = computed.to_animated_value();
                        AnimationValue::FontSize(computed)
                    },
                    LonghandId::FontVariantAlternates => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variant_alternates();

                        AnimationValue::FontVariantAlternates(computed)
                    },
                    LonghandId::FontVariationSettings => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_font_variation_settings();

                        AnimationValue::FontVariationSettings(computed)
                    },
                    LonghandId::GridTemplateAreas => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_template_areas();

                        AnimationValue::GridTemplateAreas(computed)
                    },
                    LonghandId::HyphenateCharacter => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_hyphenate_character();

                        AnimationValue::HyphenateCharacter(computed)
                    },
                    LonghandId::LetterSpacing => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_letter_spacing();

                        AnimationValue::LetterSpacing(computed)
                    },
                    LonghandId::LineHeight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_font()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_font()
                            },
                        };
                        let computed = style_struct
                            .clone_line_height();

                        let computed = computed.to_animated_value();
                        AnimationValue::LineHeight(computed)
                    },
                    LonghandId::ListStyleType => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct
                            .clone_list_style_type();

                        AnimationValue::ListStyleType(computed)
                    },
                    LonghandId::MaskClip => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_clip();

                        AnimationValue::MaskClip(computed)
                    },
                    LonghandId::MaskComposite => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_composite();

                        AnimationValue::MaskComposite(computed)
                    },
                    LonghandId::MaskImage => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_image();

                        AnimationValue::MaskImage(computed)
                    },
                    LonghandId::MaskMode => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_mode();

                        AnimationValue::MaskMode(computed)
                    },
                    LonghandId::MaskOrigin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_origin();

                        AnimationValue::MaskOrigin(computed)
                    },
                    LonghandId::MaskPositionX => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_position_x();

                        AnimationValue::MaskPositionX(computed)
                    },
                    LonghandId::MaskPositionY => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_position_y();

                        AnimationValue::MaskPositionY(computed)
                    },
                    LonghandId::MaskRepeat => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_repeat();

                        AnimationValue::MaskRepeat(computed)
                    },
                    LonghandId::MaskSize => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_mask_size();

                        let computed = computed.to_animated_value();
                        AnimationValue::MaskSize(computed)
                    },
                    LonghandId::OffsetAnchor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_offset_anchor();

                        AnimationValue::OffsetAnchor(computed)
                    },
                    LonghandId::OffsetPath => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_offset_path();

                        let computed = computed.to_animated_value();
                        AnimationValue::OffsetPath(computed)
                    },
                    LonghandId::OffsetPosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_offset_position();

                        AnimationValue::OffsetPosition(computed)
                    },
                    LonghandId::Page => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_page()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_page()
                            },
                        };
                        let computed = style_struct
                            .clone_page();

                        AnimationValue::Page(computed)
                    },
                    LonghandId::Perspective => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_perspective();

                        let computed = computed.to_animated_value();
                        AnimationValue::Perspective(computed)
                    },
                    LonghandId::PositionAnchor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_position_anchor();

                        AnimationValue::PositionAnchor(computed)
                    },
                    LonghandId::PositionTryOptions => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_position_try_options();

                        AnimationValue::PositionTryOptions(computed)
                    },
                    LonghandId::Quotes => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct
                            .clone_quotes();

                        AnimationValue::Quotes(computed)
                    },
                    LonghandId::Rotate => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_rotate();

                        AnimationValue::Rotate(computed)
                    },
                    LonghandId::Scale => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_scale();

                        AnimationValue::Scale(computed)
                    },
                    LonghandId::ScrollbarColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_ui()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_ui()
                            },
                        };
                        let computed = style_struct
                            .clone_scrollbar_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::ScrollbarColor(computed)
                    },
                    LonghandId::ShapeOutside => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_shape_outside();

                        let computed = computed.to_animated_value();
                        AnimationValue::ShapeOutside(computed)
                    },
                    LonghandId::StrokeDasharray => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke_dasharray();

                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeDasharray(computed)
                    },
                    LonghandId::StrokeDashoffset => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke_dashoffset();

                        AnimationValue::StrokeDashoffset(computed)
                    },
                    LonghandId::StrokeWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::StrokeWidth(computed)
                    },
                    LonghandId::TabSize => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_tab_size();

                        let computed = computed.to_animated_value();
                        AnimationValue::TabSize(computed)
                    },
                    LonghandId::TextDecorationThickness => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_decoration_thickness();

                        AnimationValue::TextDecorationThickness(computed)
                    },
                    LonghandId::TextEmphasisStyle => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_emphasis_style();

                        AnimationValue::TextEmphasisStyle(computed)
                    },
                    LonghandId::TextIndent => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_indent();

                        AnimationValue::TextIndent(computed)
                    },
                    LonghandId::TextOverflow => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_overflow();

                        AnimationValue::TextOverflow(computed)
                    },
                    LonghandId::TextShadow => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_shadow();

                        let computed = computed.to_animated_value();
                        AnimationValue::TextShadow(computed)
                    },
                    LonghandId::Translate => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_translate();

                        AnimationValue::Translate(computed)
                    },
                    LonghandId::VerticalAlign => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_vertical_align();

                        AnimationValue::VerticalAlign(computed)
                    },
                    LonghandId::WebkitTextStrokeWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone__webkit_text_stroke_width();

                        AnimationValue::WebkitTextStrokeWidth(computed)
                    },
                    LonghandId::WordSpacing => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_word_spacing();

                        AnimationValue::WordSpacing(computed)
                    },
                    LonghandId::ObjectPosition => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_object_position();

                        AnimationValue::ObjectPosition(computed)
                    },
                    LonghandId::PerspectiveOrigin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_perspective_origin();

                        AnimationValue::PerspectiveOrigin(computed)
                    },
                    LonghandId::Fill => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_fill();

                        let computed = computed.to_animated_value();
                        AnimationValue::Fill(computed)
                    },
                    LonghandId::Stroke => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stroke();

                        let computed = computed.to_animated_value();
                        AnimationValue::Stroke(computed)
                    },
                    LonghandId::MozWindowTransformOrigin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_window_transform_origin();

                        AnimationValue::MozWindowTransformOrigin(computed)
                    },
                    LonghandId::TransformOrigin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_transform_origin();

                        AnimationValue::TransformOrigin(computed)
                    },
                    LonghandId::GridTemplateColumns => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_template_columns();

                        AnimationValue::GridTemplateColumns(computed)
                    },
                    LonghandId::GridTemplateRows => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_template_rows();

                        AnimationValue::GridTemplateRows(computed)
                    },
                    LonghandId::BorderImageSource => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_image_source();

                        AnimationValue::BorderImageSource(computed)
                    },
                    LonghandId::ListStyleImage => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_list()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_list()
                            },
                        };
                        let computed = style_struct
                            .clone_list_style_image();

                        AnimationValue::ListStyleImage(computed)
                    },
                    LonghandId::GridAutoColumns => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_auto_columns();

                        AnimationValue::GridAutoColumns(computed)
                    },
                    LonghandId::GridAutoRows => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_auto_rows();

                        AnimationValue::GridAutoRows(computed)
                    },
                    LonghandId::MozWindowTransform => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_window_transform();

                        AnimationValue::MozWindowTransform(computed)
                    },
                    LonghandId::Transform => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_transform();

                        AnimationValue::Transform(computed)
                    },
                    LonghandId::ColumnGap => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_column_gap();

                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnGap(computed)
                    },
                    LonghandId::RowGap => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_row_gap();

                        let computed = computed.to_animated_value();
                        AnimationValue::RowGap(computed)
                    },
                    LonghandId::MarkerEnd => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_marker_end();

                        AnimationValue::MarkerEnd(computed)
                    },
                    LonghandId::MarkerMid => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_marker_mid();

                        AnimationValue::MarkerMid(computed)
                    },
                    LonghandId::MarkerStart => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_svg()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_marker_start();

                        AnimationValue::MarkerStart(computed)
                    },
                    LonghandId::ContainIntrinsicHeight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_contain_intrinsic_height();

                        let computed = computed.to_animated_value();
                        AnimationValue::ContainIntrinsicHeight(computed)
                    },
                    LonghandId::ContainIntrinsicWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_contain_intrinsic_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::ContainIntrinsicWidth(computed)
                    },
                    LonghandId::GridColumnEnd => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_column_end();

                        AnimationValue::GridColumnEnd(computed)
                    },
                    LonghandId::GridColumnStart => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_column_start();

                        AnimationValue::GridColumnStart(computed)
                    },
                    LonghandId::GridRowEnd => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_row_end();

                        AnimationValue::GridRowEnd(computed)
                    },
                    LonghandId::GridRowStart => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_grid_row_start();

                        AnimationValue::GridRowStart(computed)
                    },
                    LonghandId::MaxHeight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_max_height();

                        let computed = computed.to_animated_value();
                        AnimationValue::MaxHeight(computed)
                    },
                    LonghandId::MaxWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_max_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::MaxWidth(computed)
                    },
                    LonghandId::Cx => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_cx();

                        AnimationValue::Cx(computed)
                    },
                    LonghandId::Cy => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_cy();

                        AnimationValue::Cy(computed)
                    },
                    LonghandId::OffsetDistance => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_offset_distance();

                        AnimationValue::OffsetDistance(computed)
                    },
                    LonghandId::X => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_x();

                        AnimationValue::X(computed)
                    },
                    LonghandId::Y => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_y();

                        AnimationValue::Y(computed)
                    },
                    LonghandId::BorderBottomLeftRadius => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_bottom_left_radius();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomLeftRadius(computed)
                    },
                    LonghandId::BorderBottomRightRadius => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_bottom_right_radius();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomRightRadius(computed)
                    },
                    LonghandId::BorderTopLeftRadius => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_top_left_radius();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopLeftRadius(computed)
                    },
                    LonghandId::BorderTopRightRadius => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_top_right_radius();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopRightRadius(computed)
                    },
                    LonghandId::Height => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_height();

                        let computed = computed.to_animated_value();
                        AnimationValue::Height(computed)
                    },
                    LonghandId::MinHeight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_min_height();

                        let computed = computed.to_animated_value();
                        AnimationValue::MinHeight(computed)
                    },
                    LonghandId::MinWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_min_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::MinWidth(computed)
                    },
                    LonghandId::Width => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::Width(computed)
                    },
                    LonghandId::BorderBottomWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_bottom_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomWidth(computed)
                    },
                    LonghandId::BorderLeftWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_left_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderLeftWidth(computed)
                    },
                    LonghandId::BorderRightWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_right_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderRightWidth(computed)
                    },
                    LonghandId::BorderTopWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_top_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopWidth(computed)
                    },
                    LonghandId::ColumnRuleWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct
                            .clone_column_rule_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnRuleWidth(computed)
                    },
                    LonghandId::OutlineWidth => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct
                            .clone_outline_width();

                        let computed = computed.to_animated_value();
                        AnimationValue::OutlineWidth(computed)
                    },
                    LonghandId::PaddingBottom => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_padding_bottom();

                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingBottom(computed)
                    },
                    LonghandId::PaddingLeft => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_padding_left();

                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingLeft(computed)
                    },
                    LonghandId::PaddingRight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_padding_right();

                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingRight(computed)
                    },
                    LonghandId::PaddingTop => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_padding_top();

                        let computed = computed.to_animated_value();
                        AnimationValue::PaddingTop(computed)
                    },
                    LonghandId::R => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_r();

                        let computed = computed.to_animated_value();
                        AnimationValue::R(computed)
                    },
                    LonghandId::ShapeMargin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_box()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_box()
                            },
                        };
                        let computed = style_struct
                            .clone_shape_margin();

                        let computed = computed.to_animated_value();
                        AnimationValue::ShapeMargin(computed)
                    },
                    LonghandId::Rx => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_rx();

                        let computed = computed.to_animated_value();
                        AnimationValue::Rx(computed)
                    },
                    LonghandId::Ry => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_ry();

                        let computed = computed.to_animated_value();
                        AnimationValue::Ry(computed)
                    },
                    LonghandId::ScrollPaddingBottom => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_padding_bottom();

                        let computed = computed.to_animated_value();
                        AnimationValue::ScrollPaddingBottom(computed)
                    },
                    LonghandId::ScrollPaddingLeft => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_padding_left();

                        let computed = computed.to_animated_value();
                        AnimationValue::ScrollPaddingLeft(computed)
                    },
                    LonghandId::ScrollPaddingRight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_padding_right();

                        let computed = computed.to_animated_value();
                        AnimationValue::ScrollPaddingRight(computed)
                    },
                    LonghandId::ScrollPaddingTop => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_padding()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_padding()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_padding_top();

                        let computed = computed.to_animated_value();
                        AnimationValue::ScrollPaddingTop(computed)
                    },
                    LonghandId::MozWindowInputRegionMargin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_ui()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_ui()
                            },
                        };
                        let computed = style_struct
                            .clone__moz_window_input_region_margin();

                        AnimationValue::MozWindowInputRegionMargin(computed)
                    },
                    LonghandId::OutlineOffset => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct
                            .clone_outline_offset();

                        AnimationValue::OutlineOffset(computed)
                    },
                    LonghandId::OverflowClipMargin => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_overflow_clip_margin();

                        AnimationValue::OverflowClipMargin(computed)
                    },
                    LonghandId::ScrollMarginBottom => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_margin_bottom();

                        AnimationValue::ScrollMarginBottom(computed)
                    },
                    LonghandId::ScrollMarginLeft => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_margin_left();

                        AnimationValue::ScrollMarginLeft(computed)
                    },
                    LonghandId::ScrollMarginRight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_margin_right();

                        AnimationValue::ScrollMarginRight(computed)
                    },
                    LonghandId::ScrollMarginTop => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_scroll_margin_top();

                        AnimationValue::ScrollMarginTop(computed)
                    },
                    LonghandId::Bottom => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_bottom();

                        AnimationValue::Bottom(computed)
                    },
                    LonghandId::Left => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_left();

                        AnimationValue::Left(computed)
                    },
                    LonghandId::MarginBottom => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_margin_bottom();

                        AnimationValue::MarginBottom(computed)
                    },
                    LonghandId::MarginLeft => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_margin_left();

                        AnimationValue::MarginLeft(computed)
                    },
                    LonghandId::MarginRight => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_margin_right();

                        AnimationValue::MarginRight(computed)
                    },
                    LonghandId::MarginTop => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_margin()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_margin()
                            },
                        };
                        let computed = style_struct
                            .clone_margin_top();

                        AnimationValue::MarginTop(computed)
                    },
                    LonghandId::Right => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_right();

                        AnimationValue::Right(computed)
                    },
                    LonghandId::TextUnderlineOffset => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_underline_offset();

                        AnimationValue::TextUnderlineOffset(computed)
                    },
                    LonghandId::Top => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_position()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_position()
                            },
                        };
                        let computed = style_struct
                            .clone_top();

                        AnimationValue::Top(computed)
                    },
                    LonghandId::BackgroundColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_background()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_background()
                            },
                        };
                        let computed = style_struct
                            .clone_background_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::BackgroundColor(computed)
                    },
                    LonghandId::BorderBottomColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_bottom_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderBottomColor(computed)
                    },
                    LonghandId::BorderLeftColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_left_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderLeftColor(computed)
                    },
                    LonghandId::BorderRightColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_right_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderRightColor(computed)
                    },
                    LonghandId::BorderTopColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_border()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_border()
                            },
                        };
                        let computed = style_struct
                            .clone_border_top_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::BorderTopColor(computed)
                    },
                    LonghandId::ColumnRuleColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_column()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_column()
                            },
                        };
                        let computed = style_struct
                            .clone_column_rule_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::ColumnRuleColor(computed)
                    },
                    LonghandId::FloodColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_flood_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::FloodColor(computed)
                    },
                    LonghandId::LightingColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_lighting_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::LightingColor(computed)
                    },
                    LonghandId::OutlineColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_outline()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_outline()
                            },
                        };
                        let computed = style_struct
                            .clone_outline_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::OutlineColor(computed)
                    },
                    LonghandId::StopColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_svg()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_svg()
                            },
                        };
                        let computed = style_struct
                            .clone_stop_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::StopColor(computed)
                    },
                    LonghandId::TextDecorationColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Initial => {
                                initial.get_text()
                            },
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_decoration_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::TextDecorationColor(computed)
                    },
                    LonghandId::TextEmphasisColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone_text_emphasis_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::TextEmphasisColor(computed)
                    },
                    LonghandId::WebkitTextFillColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone__webkit_text_fill_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::WebkitTextFillColor(computed)
                    },
                    LonghandId::WebkitTextStrokeColor => {
                        // FIXME(emilio, bug 1533327): I think revert (and
                        // revert-layer) handling is not fine here, but what to
                        // do instead?
                        //
                        // Seems we'd need the computed value as if it was
                        // revert, somehow. Treating it as `unset` seems fine
                        // for now...
                        let style_struct = match declaration.keyword {
                            CSSWideKeyword::Initial => {
                                initial.get_inherited_text()
                            },
                            CSSWideKeyword::Revert |
                            CSSWideKeyword::RevertLayer |
                            CSSWideKeyword::Unset |
                            CSSWideKeyword::Inherit => {
                                context.builder
                                       .get_parent_inherited_text()
                            },
                        };
                        let computed = style_struct
                            .clone__webkit_text_stroke_color();

                        let computed = computed.to_animated_value();
                        AnimationValue::WebkitTextStrokeColor(computed)
                    },
                    LonghandId::Contain => return None,
                    LonghandId::ContainerType => return None,
                    LonghandId::Direction => return None,
                    LonghandId::MathDepth => return None,
                    LonghandId::MathStyle => return None,
                    LonghandId::MozBoxCollapse => return None,
                    LonghandId::MozControlCharacterVisibility => return None,
                    LonghandId::MozMathVariant => return None,
                    LonghandId::MozMinFontSizeRatio => return None,
                    LonghandId::MozTopLayer => return None,
                    LonghandId::PageOrientation => return None,
                    LonghandId::TextCombineUpright => return None,
                    LonghandId::TextOrientation => return None,
                    LonghandId::UnicodeBidi => return None,
                    LonghandId::WritingMode => return None,
                    LonghandId::XTextScale => return None,
                    LonghandId::MozDefaultAppearance => return None,
                    LonghandId::XSpan => return None,
                    LonghandId::OverflowBlock => return None,
                    LonghandId::OverflowInline => return None,
                    LonghandId::OverscrollBehaviorBlock => return None,
                    LonghandId::OverscrollBehaviorInline => return None,
                    LonghandId::BorderBlockEndStyle => return None,
                    LonghandId::BorderBlockStartStyle => return None,
                    LonghandId::BorderInlineEndStyle => return None,
                    LonghandId::BorderInlineStartStyle => return None,
                    LonghandId::AnimationComposition => return None,
                    LonghandId::AnimationDelay => return None,
                    LonghandId::AnimationDirection => return None,
                    LonghandId::AnimationDuration => return None,
                    LonghandId::AnimationFillMode => return None,
                    LonghandId::AnimationIterationCount => return None,
                    LonghandId::AnimationName => return None,
                    LonghandId::AnimationPlayState => return None,
                    LonghandId::AnimationTimeline => return None,
                    LonghandId::AnimationTimingFunction => return None,
                    LonghandId::ContainerName => return None,
                    LonghandId::MozContextProperties => return None,
                    LonghandId::ScrollTimelineAxis => return None,
                    LonghandId::ScrollTimelineName => return None,
                    LonghandId::Size => return None,
                    LonghandId::TransitionBehavior => return None,
                    LonghandId::TransitionDelay => return None,
                    LonghandId::TransitionDuration => return None,
                    LonghandId::TransitionProperty => return None,
                    LonghandId::TransitionTimingFunction => return None,
                    LonghandId::ViewTimelineAxis => return None,
                    LonghandId::ViewTimelineInset => return None,
                    LonghandId::ViewTimelineName => return None,
                    LonghandId::WillChange => return None,
                    LonghandId::XLang => return None,
                    LonghandId::ContainIntrinsicBlockSize => return None,
                    LonghandId::ContainIntrinsicInlineSize => return None,
                    LonghandId::MaxBlockSize => return None,
                    LonghandId::MaxInlineSize => return None,
                    LonghandId::BorderEndEndRadius => return None,
                    LonghandId::BorderEndStartRadius => return None,
                    LonghandId::BorderStartEndRadius => return None,
                    LonghandId::BorderStartStartRadius => return None,
                    LonghandId::BlockSize => return None,
                    LonghandId::InlineSize => return None,
                    LonghandId::MinBlockSize => return None,
                    LonghandId::MinInlineSize => return None,
                    LonghandId::BorderBlockEndWidth => return None,
                    LonghandId::BorderBlockStartWidth => return None,
                    LonghandId::BorderInlineEndWidth => return None,
                    LonghandId::BorderInlineStartWidth => return None,
                    LonghandId::PaddingBlockEnd => return None,
                    LonghandId::PaddingBlockStart => return None,
                    LonghandId::PaddingInlineEnd => return None,
                    LonghandId::PaddingInlineStart => return None,
                    LonghandId::ScrollPaddingBlockEnd => return None,
                    LonghandId::ScrollPaddingBlockStart => return None,
                    LonghandId::ScrollPaddingInlineEnd => return None,
                    LonghandId::ScrollPaddingInlineStart => return None,
                    LonghandId::ScrollMarginBlockEnd => return None,
                    LonghandId::ScrollMarginBlockStart => return None,
                    LonghandId::ScrollMarginInlineEnd => return None,
                    LonghandId::ScrollMarginInlineStart => return None,
                    LonghandId::InsetBlockEnd => return None,
                    LonghandId::InsetBlockStart => return None,
                    LonghandId::InsetInlineEnd => return None,
                    LonghandId::InsetInlineStart => return None,
                    LonghandId::MarginBlockEnd => return None,
                    LonghandId::MarginBlockStart => return None,
                    LonghandId::MarginInlineEnd => return None,
                    LonghandId::MarginInlineStart => return None,
                    LonghandId::BorderBlockEndColor => return None,
                    LonghandId::BorderBlockStartColor => return None,
                    LonghandId::BorderInlineEndColor => return None,
                    LonghandId::BorderInlineStartColor => return None,
                }
            },
            PropertyDeclaration::WithVariables(ref declaration) => {
                let mut cache = Default::default();
                let substituted = {
                    let custom_properties = &context.style().custom_properties();

                    debug_assert!(
                        context.builder.stylist.is_some(),
                        "Need a Stylist to substitute variables!"
                    );
                    declaration.value.substitute_variables(
                        declaration.id,
                        custom_properties,
                        context.builder.stylist.unwrap(),
                        context,
                        &mut cache,
                    )
                };
                return AnimationValue::from_declaration(
                    &substituted,
                    context,
                    initial,
                )
            },
            PropertyDeclaration::Custom(ref declaration) => {
                AnimationValue::Custom(CustomAnimatedValue::from_declaration(
                    declaration,
                    context,
                    initial,
                )?)
            },
            _ => return None // non animatable properties will get included because of shorthands. ignore.
        };
        Some(animatable)
    }

    /// Get an AnimationValue for an declaration id from a given computed values.
    pub fn from_computed_values(
        property: PropertyDeclarationId,
        style: &ComputedValues,
    ) -> Option<Self> {
        let property = match property {
            PropertyDeclarationId::Longhand(id) => id,
            PropertyDeclarationId::Custom(ref name) => {
                // FIXME(bug 1869476): This should use a stylist to determine whether the name
                // corresponds to an inherited custom property and then choose the
                // inherited/non_inherited map accordingly.
                let p = &style.custom_properties();
                let value = p.inherited.get(*name).or_else(|| p.non_inherited.get(*name))?;
                return Some(AnimationValue::Custom(CustomAnimatedValue::from_computed(name, value)))
            }
        };

        Some(match property {
            LonghandId::AlignContent => {
                let computed = style.clone_align_content();
                AnimationValue::AlignContent(
                    computed
                )
            }
            LonghandId::AlignItems => {
                let computed = style.clone_align_items();
                AnimationValue::AlignItems(
                    computed
                )
            }
            LonghandId::AlignSelf => {
                let computed = style.clone_align_self();
                AnimationValue::AlignSelf(
                    computed
                )
            }
            LonghandId::AspectRatio => {
                let computed = style.clone_aspect_ratio();
                AnimationValue::AspectRatio(
                    computed
                )
            }
            LonghandId::BackfaceVisibility => {
                let computed = style.clone_backface_visibility();
                AnimationValue::BackfaceVisibility(
                    computed
                )
            }
            LonghandId::BaselineSource => {
                let computed = style.clone_baseline_source();
                AnimationValue::BaselineSource(
                    computed
                )
            }
            LonghandId::BorderCollapse => {
                let computed = style.clone_border_collapse();
                AnimationValue::BorderCollapse(
                    computed
                )
            }
            LonghandId::BorderImageRepeat => {
                let computed = style.clone_border_image_repeat();
                AnimationValue::BorderImageRepeat(
                    computed
                )
            }
            LonghandId::BoxDecorationBreak => {
                let computed = style.clone_box_decoration_break();
                AnimationValue::BoxDecorationBreak(
                    computed
                )
            }
            LonghandId::BoxSizing => {
                let computed = style.clone_box_sizing();
                AnimationValue::BoxSizing(
                    computed
                )
            }
            LonghandId::BreakInside => {
                let computed = style.clone_break_inside();
                AnimationValue::BreakInside(
                    computed
                )
            }
            LonghandId::CaptionSide => {
                let computed = style.clone_caption_side();
                AnimationValue::CaptionSide(
                    computed
                )
            }
            LonghandId::Clear => {
                let computed = style.clone_clear();
                AnimationValue::Clear(
                    computed
                )
            }
            LonghandId::ColorInterpolation => {
                let computed = style.clone_color_interpolation();
                AnimationValue::ColorInterpolation(
                    computed
                )
            }
            LonghandId::ColorInterpolationFilters => {
                let computed = style.clone_color_interpolation_filters();
                AnimationValue::ColorInterpolationFilters(
                    computed
                )
            }
            LonghandId::ColumnCount => {
                let computed = style.clone_column_count();
                AnimationValue::ColumnCount(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnFill => {
                let computed = style.clone_column_fill();
                AnimationValue::ColumnFill(
                    computed
                )
            }
            LonghandId::ColumnSpan => {
                let computed = style.clone_column_span();
                AnimationValue::ColumnSpan(
                    computed
                )
            }
            LonghandId::ContentVisibility => {
                let computed = style.clone_content_visibility();
                AnimationValue::ContentVisibility(
                    computed
                )
            }
            LonghandId::Display => {
                let computed = style.clone_display();
                AnimationValue::Display(
                    computed
                )
            }
            LonghandId::DominantBaseline => {
                let computed = style.clone_dominant_baseline();
                AnimationValue::DominantBaseline(
                    computed
                )
            }
            LonghandId::EmptyCells => {
                let computed = style.clone_empty_cells();
                AnimationValue::EmptyCells(
                    computed
                )
            }
            LonghandId::FlexDirection => {
                let computed = style.clone_flex_direction();
                AnimationValue::FlexDirection(
                    computed
                )
            }
            LonghandId::FlexWrap => {
                let computed = style.clone_flex_wrap();
                AnimationValue::FlexWrap(
                    computed
                )
            }
            LonghandId::Float => {
                let computed = style.clone_float();
                AnimationValue::Float(
                    computed
                )
            }
            LonghandId::FontKerning => {
                let computed = style.clone_font_kerning();
                AnimationValue::FontKerning(
                    computed
                )
            }
            LonghandId::FontLanguageOverride => {
                let computed = style.clone_font_language_override();
                AnimationValue::FontLanguageOverride(
                    computed
                )
            }
            LonghandId::FontOpticalSizing => {
                let computed = style.clone_font_optical_sizing();
                AnimationValue::FontOpticalSizing(
                    computed
                )
            }
            LonghandId::FontSizeAdjust => {
                let computed = style.clone_font_size_adjust();
                AnimationValue::FontSizeAdjust(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontStretch => {
                let computed = style.clone_font_stretch();
                AnimationValue::FontStretch(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontStyle => {
                let computed = style.clone_font_style();
                AnimationValue::FontStyle(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontVariantCaps => {
                let computed = style.clone_font_variant_caps();
                AnimationValue::FontVariantCaps(
                    computed
                )
            }
            LonghandId::FontVariantEastAsian => {
                let computed = style.clone_font_variant_east_asian();
                AnimationValue::FontVariantEastAsian(
                    computed
                )
            }
            LonghandId::FontVariantEmoji => {
                let computed = style.clone_font_variant_emoji();
                AnimationValue::FontVariantEmoji(
                    computed
                )
            }
            LonghandId::FontVariantLigatures => {
                let computed = style.clone_font_variant_ligatures();
                AnimationValue::FontVariantLigatures(
                    computed
                )
            }
            LonghandId::FontVariantNumeric => {
                let computed = style.clone_font_variant_numeric();
                AnimationValue::FontVariantNumeric(
                    computed
                )
            }
            LonghandId::FontVariantPosition => {
                let computed = style.clone_font_variant_position();
                AnimationValue::FontVariantPosition(
                    computed
                )
            }
            LonghandId::FontWeight => {
                let computed = style.clone_font_weight();
                AnimationValue::FontWeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::ForcedColorAdjust => {
                let computed = style.clone_forced_color_adjust();
                AnimationValue::ForcedColorAdjust(
                    computed
                )
            }
            LonghandId::GridAutoFlow => {
                let computed = style.clone_grid_auto_flow();
                AnimationValue::GridAutoFlow(
                    computed
                )
            }
            LonghandId::Hyphens => {
                let computed = style.clone_hyphens();
                AnimationValue::Hyphens(
                    computed
                )
            }
            LonghandId::ImageOrientation => {
                let computed = style.clone_image_orientation();
                AnimationValue::ImageOrientation(
                    computed
                )
            }
            LonghandId::ImageRendering => {
                let computed = style.clone_image_rendering();
                AnimationValue::ImageRendering(
                    computed
                )
            }
            LonghandId::ImeMode => {
                let computed = style.clone_ime_mode();
                AnimationValue::ImeMode(
                    computed
                )
            }
            LonghandId::InitialLetter => {
                let computed = style.clone_initial_letter();
                AnimationValue::InitialLetter(
                    computed
                )
            }
            LonghandId::InsetArea => {
                let computed = style.clone_inset_area();
                AnimationValue::InsetArea(
                    computed
                )
            }
            LonghandId::Isolation => {
                let computed = style.clone_isolation();
                AnimationValue::Isolation(
                    computed
                )
            }
            LonghandId::JustifyContent => {
                let computed = style.clone_justify_content();
                AnimationValue::JustifyContent(
                    computed
                )
            }
            LonghandId::JustifyItems => {
                let computed = style.clone_justify_items();
                AnimationValue::JustifyItems(
                    computed
                )
            }
            LonghandId::JustifySelf => {
                let computed = style.clone_justify_self();
                AnimationValue::JustifySelf(
                    computed
                )
            }
            LonghandId::LineBreak => {
                let computed = style.clone_line_break();
                AnimationValue::LineBreak(
                    computed
                )
            }
            LonghandId::ListStylePosition => {
                let computed = style.clone_list_style_position();
                AnimationValue::ListStylePosition(
                    computed
                )
            }
            LonghandId::MaskType => {
                let computed = style.clone_mask_type();
                AnimationValue::MaskType(
                    computed
                )
            }
            LonghandId::MasonryAutoFlow => {
                let computed = style.clone_masonry_auto_flow();
                AnimationValue::MasonryAutoFlow(
                    computed
                )
            }
            LonghandId::MixBlendMode => {
                let computed = style.clone_mix_blend_mode();
                AnimationValue::MixBlendMode(
                    computed
                )
            }
            LonghandId::MozBoxAlign => {
                let computed = style.clone__moz_box_align();
                AnimationValue::MozBoxAlign(
                    computed
                )
            }
            LonghandId::MozBoxDirection => {
                let computed = style.clone__moz_box_direction();
                AnimationValue::MozBoxDirection(
                    computed
                )
            }
            LonghandId::MozBoxOrient => {
                let computed = style.clone__moz_box_orient();
                AnimationValue::MozBoxOrient(
                    computed
                )
            }
            LonghandId::MozBoxPack => {
                let computed = style.clone__moz_box_pack();
                AnimationValue::MozBoxPack(
                    computed
                )
            }
            LonghandId::MozFloatEdge => {
                let computed = style.clone__moz_float_edge();
                AnimationValue::MozFloatEdge(
                    computed
                )
            }
            LonghandId::MozInert => {
                let computed = style.clone__moz_inert();
                AnimationValue::MozInert(
                    computed
                )
            }
            LonghandId::MozOrient => {
                let computed = style.clone__moz_orient();
                AnimationValue::MozOrient(
                    computed
                )
            }
            LonghandId::MozOsxFontSmoothing => {
                let computed = style.clone__moz_osx_font_smoothing();
                AnimationValue::MozOsxFontSmoothing(
                    computed
                )
            }
            LonghandId::MozTextSizeAdjust => {
                let computed = style.clone__moz_text_size_adjust();
                AnimationValue::MozTextSizeAdjust(
                    computed
                )
            }
            LonghandId::MozTheme => {
                let computed = style.clone__moz_theme();
                AnimationValue::MozTheme(
                    computed
                )
            }
            LonghandId::MozUserFocus => {
                let computed = style.clone__moz_user_focus();
                AnimationValue::MozUserFocus(
                    computed
                )
            }
            LonghandId::MozUserInput => {
                let computed = style.clone__moz_user_input();
                AnimationValue::MozUserInput(
                    computed
                )
            }
            LonghandId::MozUserModify => {
                let computed = style.clone__moz_user_modify();
                AnimationValue::MozUserModify(
                    computed
                )
            }
            LonghandId::MozWindowDragging => {
                let computed = style.clone__moz_window_dragging();
                AnimationValue::MozWindowDragging(
                    computed
                )
            }
            LonghandId::MozWindowShadow => {
                let computed = style.clone__moz_window_shadow();
                AnimationValue::MozWindowShadow(
                    computed
                )
            }
            LonghandId::ObjectFit => {
                let computed = style.clone_object_fit();
                AnimationValue::ObjectFit(
                    computed
                )
            }
            LonghandId::OffsetRotate => {
                let computed = style.clone_offset_rotate();
                AnimationValue::OffsetRotate(
                    computed
                )
            }
            LonghandId::OutlineStyle => {
                let computed = style.clone_outline_style();
                AnimationValue::OutlineStyle(
                    computed
                )
            }
            LonghandId::OverflowAnchor => {
                let computed = style.clone_overflow_anchor();
                AnimationValue::OverflowAnchor(
                    computed
                )
            }
            LonghandId::OverflowWrap => {
                let computed = style.clone_overflow_wrap();
                AnimationValue::OverflowWrap(
                    computed
                )
            }
            LonghandId::PaintOrder => {
                let computed = style.clone_paint_order();
                AnimationValue::PaintOrder(
                    computed
                )
            }
            LonghandId::PointerEvents => {
                let computed = style.clone_pointer_events();
                AnimationValue::PointerEvents(
                    computed
                )
            }
            LonghandId::Position => {
                let computed = style.clone_position();
                AnimationValue::Position(
                    computed
                )
            }
            LonghandId::PositionTryOrder => {
                let computed = style.clone_position_try_order();
                AnimationValue::PositionTryOrder(
                    computed
                )
            }
            LonghandId::PositionVisibility => {
                let computed = style.clone_position_visibility();
                AnimationValue::PositionVisibility(
                    computed
                )
            }
            LonghandId::PrintColorAdjust => {
                let computed = style.clone_print_color_adjust();
                AnimationValue::PrintColorAdjust(
                    computed
                )
            }
            LonghandId::Resize => {
                let computed = style.clone_resize();
                AnimationValue::Resize(
                    computed
                )
            }
            LonghandId::RubyAlign => {
                let computed = style.clone_ruby_align();
                AnimationValue::RubyAlign(
                    computed
                )
            }
            LonghandId::RubyPosition => {
                let computed = style.clone_ruby_position();
                AnimationValue::RubyPosition(
                    computed
                )
            }
            LonghandId::ScrollBehavior => {
                let computed = style.clone_scroll_behavior();
                AnimationValue::ScrollBehavior(
                    computed
                )
            }
            LonghandId::ScrollSnapAlign => {
                let computed = style.clone_scroll_snap_align();
                AnimationValue::ScrollSnapAlign(
                    computed
                )
            }
            LonghandId::ScrollSnapStop => {
                let computed = style.clone_scroll_snap_stop();
                AnimationValue::ScrollSnapStop(
                    computed
                )
            }
            LonghandId::ScrollSnapType => {
                let computed = style.clone_scroll_snap_type();
                AnimationValue::ScrollSnapType(
                    computed
                )
            }
            LonghandId::ScrollbarGutter => {
                let computed = style.clone_scrollbar_gutter();
                AnimationValue::ScrollbarGutter(
                    computed
                )
            }
            LonghandId::ScrollbarWidth => {
                let computed = style.clone_scrollbar_width();
                AnimationValue::ScrollbarWidth(
                    computed
                )
            }
            LonghandId::ShapeRendering => {
                let computed = style.clone_shape_rendering();
                AnimationValue::ShapeRendering(
                    computed
                )
            }
            LonghandId::StrokeLinecap => {
                let computed = style.clone_stroke_linecap();
                AnimationValue::StrokeLinecap(
                    computed
                )
            }
            LonghandId::StrokeLinejoin => {
                let computed = style.clone_stroke_linejoin();
                AnimationValue::StrokeLinejoin(
                    computed
                )
            }
            LonghandId::TableLayout => {
                let computed = style.clone_table_layout();
                AnimationValue::TableLayout(
                    computed
                )
            }
            LonghandId::TextAlign => {
                let computed = style.clone_text_align();
                AnimationValue::TextAlign(
                    computed
                )
            }
            LonghandId::TextAlignLast => {
                let computed = style.clone_text_align_last();
                AnimationValue::TextAlignLast(
                    computed
                )
            }
            LonghandId::TextAnchor => {
                let computed = style.clone_text_anchor();
                AnimationValue::TextAnchor(
                    computed
                )
            }
            LonghandId::TextDecorationLine => {
                let computed = style.clone_text_decoration_line();
                AnimationValue::TextDecorationLine(
                    computed
                )
            }
            LonghandId::TextDecorationSkipInk => {
                let computed = style.clone_text_decoration_skip_ink();
                AnimationValue::TextDecorationSkipInk(
                    computed
                )
            }
            LonghandId::TextDecorationStyle => {
                let computed = style.clone_text_decoration_style();
                AnimationValue::TextDecorationStyle(
                    computed
                )
            }
            LonghandId::TextEmphasisPosition => {
                let computed = style.clone_text_emphasis_position();
                AnimationValue::TextEmphasisPosition(
                    computed
                )
            }
            LonghandId::TextJustify => {
                let computed = style.clone_text_justify();
                AnimationValue::TextJustify(
                    computed
                )
            }
            LonghandId::TextRendering => {
                let computed = style.clone_text_rendering();
                AnimationValue::TextRendering(
                    computed
                )
            }
            LonghandId::TextTransform => {
                let computed = style.clone_text_transform();
                AnimationValue::TextTransform(
                    computed
                )
            }
            LonghandId::TextUnderlinePosition => {
                let computed = style.clone_text_underline_position();
                AnimationValue::TextUnderlinePosition(
                    computed
                )
            }
            LonghandId::TextWrapMode => {
                let computed = style.clone_text_wrap_mode();
                AnimationValue::TextWrapMode(
                    computed
                )
            }
            LonghandId::TextWrapStyle => {
                let computed = style.clone_text_wrap_style();
                AnimationValue::TextWrapStyle(
                    computed
                )
            }
            LonghandId::TouchAction => {
                let computed = style.clone_touch_action();
                AnimationValue::TouchAction(
                    computed
                )
            }
            LonghandId::TransformBox => {
                let computed = style.clone_transform_box();
                AnimationValue::TransformBox(
                    computed
                )
            }
            LonghandId::TransformStyle => {
                let computed = style.clone_transform_style();
                AnimationValue::TransformStyle(
                    computed
                )
            }
            LonghandId::UserSelect => {
                let computed = style.clone_user_select();
                AnimationValue::UserSelect(
                    computed
                )
            }
            LonghandId::VectorEffect => {
                let computed = style.clone_vector_effect();
                AnimationValue::VectorEffect(
                    computed
                )
            }
            LonghandId::Visibility => {
                let computed = style.clone_visibility();
                AnimationValue::Visibility(
                    computed
                )
            }
            LonghandId::WebkitLineClamp => {
                let computed = style.clone__webkit_line_clamp();
                AnimationValue::WebkitLineClamp(
                    computed
                )
            }
            LonghandId::WebkitTextSecurity => {
                let computed = style.clone__webkit_text_security();
                AnimationValue::WebkitTextSecurity(
                    computed
                )
            }
            LonghandId::WhiteSpaceCollapse => {
                let computed = style.clone_white_space_collapse();
                AnimationValue::WhiteSpaceCollapse(
                    computed
                )
            }
            LonghandId::WordBreak => {
                let computed = style.clone_word_break();
                AnimationValue::WordBreak(
                    computed
                )
            }
            LonghandId::ZIndex => {
                let computed = style.clone_z_index();
                AnimationValue::ZIndex(
                    computed
                )
            }
            LonghandId::Zoom => {
                let computed = style.clone_zoom();
                AnimationValue::Zoom(
                    computed.to_animated_value()
                )
            }
            LonghandId::Appearance => {
                let computed = style.clone_appearance();
                AnimationValue::Appearance(
                    computed
                )
            }
            LonghandId::MozForceBrokenImageIcon => {
                let computed = style.clone__moz_force_broken_image_icon();
                AnimationValue::MozForceBrokenImageIcon(
                    computed
                )
            }
            LonghandId::MozSubtreeHiddenOnlyVisually => {
                let computed = style.clone__moz_subtree_hidden_only_visually();
                AnimationValue::MozSubtreeHiddenOnlyVisually(
                    computed
                )
            }
            LonghandId::BreakAfter => {
                let computed = style.clone_break_after();
                AnimationValue::BreakAfter(
                    computed
                )
            }
            LonghandId::BreakBefore => {
                let computed = style.clone_break_before();
                AnimationValue::BreakBefore(
                    computed
                )
            }
            LonghandId::ClipRule => {
                let computed = style.clone_clip_rule();
                AnimationValue::ClipRule(
                    computed
                )
            }
            LonghandId::FillRule => {
                let computed = style.clone_fill_rule();
                AnimationValue::FillRule(
                    computed
                )
            }
            LonghandId::OverflowClipBoxBlock => {
                let computed = style.clone_overflow_clip_box_block();
                AnimationValue::OverflowClipBoxBlock(
                    computed
                )
            }
            LonghandId::OverflowClipBoxInline => {
                let computed = style.clone_overflow_clip_box_inline();
                AnimationValue::OverflowClipBoxInline(
                    computed
                )
            }
            LonghandId::FillOpacity => {
                let computed = style.clone_fill_opacity();
                AnimationValue::FillOpacity(
                    computed
                )
            }
            LonghandId::StrokeOpacity => {
                let computed = style.clone_stroke_opacity();
                AnimationValue::StrokeOpacity(
                    computed
                )
            }
            LonghandId::MozBoxOrdinalGroup => {
                let computed = style.clone__moz_box_ordinal_group();
                AnimationValue::MozBoxOrdinalGroup(
                    computed
                )
            }
            LonghandId::Order => {
                let computed = style.clone_order();
                AnimationValue::Order(
                    computed
                )
            }
            LonghandId::FontSynthesisPosition => {
                let computed = style.clone_font_synthesis_position();
                AnimationValue::FontSynthesisPosition(
                    computed
                )
            }
            LonghandId::FontSynthesisSmallCaps => {
                let computed = style.clone_font_synthesis_small_caps();
                AnimationValue::FontSynthesisSmallCaps(
                    computed
                )
            }
            LonghandId::FontSynthesisStyle => {
                let computed = style.clone_font_synthesis_style();
                AnimationValue::FontSynthesisStyle(
                    computed
                )
            }
            LonghandId::FontSynthesisWeight => {
                let computed = style.clone_font_synthesis_weight();
                AnimationValue::FontSynthesisWeight(
                    computed
                )
            }
            LonghandId::FlexGrow => {
                let computed = style.clone_flex_grow();
                AnimationValue::FlexGrow(
                    computed.to_animated_value()
                )
            }
            LonghandId::FlexShrink => {
                let computed = style.clone_flex_shrink();
                AnimationValue::FlexShrink(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozBoxFlex => {
                let computed = style.clone__moz_box_flex();
                AnimationValue::MozBoxFlex(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeMiterlimit => {
                let computed = style.clone_stroke_miterlimit();
                AnimationValue::StrokeMiterlimit(
                    computed.to_animated_value()
                )
            }
            LonghandId::OverflowX => {
                let computed = style.clone_overflow_x();
                AnimationValue::OverflowX(
                    computed
                )
            }
            LonghandId::OverflowY => {
                let computed = style.clone_overflow_y();
                AnimationValue::OverflowY(
                    computed
                )
            }
            LonghandId::OverscrollBehaviorX => {
                let computed = style.clone_overscroll_behavior_x();
                AnimationValue::OverscrollBehaviorX(
                    computed
                )
            }
            LonghandId::OverscrollBehaviorY => {
                let computed = style.clone_overscroll_behavior_y();
                AnimationValue::OverscrollBehaviorY(
                    computed
                )
            }
            LonghandId::FloodOpacity => {
                let computed = style.clone_flood_opacity();
                AnimationValue::FloodOpacity(
                    computed
                )
            }
            LonghandId::MozWindowOpacity => {
                let computed = style.clone__moz_window_opacity();
                AnimationValue::MozWindowOpacity(
                    computed
                )
            }
            LonghandId::Opacity => {
                let computed = style.clone_opacity();
                AnimationValue::Opacity(
                    computed
                )
            }
            LonghandId::ShapeImageThreshold => {
                let computed = style.clone_shape_image_threshold();
                AnimationValue::ShapeImageThreshold(
                    computed
                )
            }
            LonghandId::StopOpacity => {
                let computed = style.clone_stop_opacity();
                AnimationValue::StopOpacity(
                    computed
                )
            }
            LonghandId::BorderBottomStyle => {
                let computed = style.clone_border_bottom_style();
                AnimationValue::BorderBottomStyle(
                    computed
                )
            }
            LonghandId::BorderLeftStyle => {
                let computed = style.clone_border_left_style();
                AnimationValue::BorderLeftStyle(
                    computed
                )
            }
            LonghandId::BorderRightStyle => {
                let computed = style.clone_border_right_style();
                AnimationValue::BorderRightStyle(
                    computed
                )
            }
            LonghandId::BorderTopStyle => {
                let computed = style.clone_border_top_style();
                AnimationValue::BorderTopStyle(
                    computed
                )
            }
            LonghandId::ColumnRuleStyle => {
                let computed = style.clone_column_rule_style();
                AnimationValue::ColumnRuleStyle(
                    computed
                )
            }
            LonghandId::AccentColor => {
                let computed = style.clone_accent_color();
                AnimationValue::AccentColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::AnchorName => {
                let computed = style.clone_anchor_name();
                AnimationValue::AnchorName(
                    computed
                )
            }
            LonghandId::AnchorScope => {
                let computed = style.clone_anchor_scope();
                AnimationValue::AnchorScope(
                    computed
                )
            }
            LonghandId::BackdropFilter => {
                let computed = style.clone_backdrop_filter();
                AnimationValue::BackdropFilter(
                    computed.to_animated_value()
                )
            }
            LonghandId::BackgroundAttachment => {
                let computed = style.clone_background_attachment();
                AnimationValue::BackgroundAttachment(
                    computed
                )
            }
            LonghandId::BackgroundBlendMode => {
                let computed = style.clone_background_blend_mode();
                AnimationValue::BackgroundBlendMode(
                    computed
                )
            }
            LonghandId::BackgroundClip => {
                let computed = style.clone_background_clip();
                AnimationValue::BackgroundClip(
                    computed
                )
            }
            LonghandId::BackgroundImage => {
                let computed = style.clone_background_image();
                AnimationValue::BackgroundImage(
                    computed
                )
            }
            LonghandId::BackgroundOrigin => {
                let computed = style.clone_background_origin();
                AnimationValue::BackgroundOrigin(
                    computed
                )
            }
            LonghandId::BackgroundPositionX => {
                let computed = style.clone_background_position_x();
                AnimationValue::BackgroundPositionX(
                    computed
                )
            }
            LonghandId::BackgroundPositionY => {
                let computed = style.clone_background_position_y();
                AnimationValue::BackgroundPositionY(
                    computed
                )
            }
            LonghandId::BackgroundRepeat => {
                let computed = style.clone_background_repeat();
                AnimationValue::BackgroundRepeat(
                    computed
                )
            }
            LonghandId::BackgroundSize => {
                let computed = style.clone_background_size();
                AnimationValue::BackgroundSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderImageOutset => {
                let computed = style.clone_border_image_outset();
                AnimationValue::BorderImageOutset(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderImageSlice => {
                let computed = style.clone_border_image_slice();
                AnimationValue::BorderImageSlice(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderImageWidth => {
                let computed = style.clone_border_image_width();
                AnimationValue::BorderImageWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderSpacing => {
                let computed = style.clone_border_spacing();
                AnimationValue::BorderSpacing(
                    computed.to_animated_value()
                )
            }
            LonghandId::BoxShadow => {
                let computed = style.clone_box_shadow();
                AnimationValue::BoxShadow(
                    computed.to_animated_value()
                )
            }
            LonghandId::CaretColor => {
                let computed = style.clone_caret_color();
                AnimationValue::CaretColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::Clip => {
                let computed = style.clone_clip();
                AnimationValue::Clip(
                    computed
                )
            }
            LonghandId::ClipPath => {
                let computed = style.clone_clip_path();
                AnimationValue::ClipPath(
                    computed.to_animated_value()
                )
            }
            LonghandId::Color => {
                let computed = style.clone_color();
                AnimationValue::Color(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColorScheme => {
                let computed = style.clone_color_scheme();
                AnimationValue::ColorScheme(
                    computed
                )
            }
            LonghandId::ColumnWidth => {
                let computed = style.clone_column_width();
                AnimationValue::ColumnWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::Content => {
                let computed = style.clone_content();
                AnimationValue::Content(
                    computed
                )
            }
            LonghandId::CounterIncrement => {
                let computed = style.clone_counter_increment();
                AnimationValue::CounterIncrement(
                    computed
                )
            }
            LonghandId::CounterReset => {
                let computed = style.clone_counter_reset();
                AnimationValue::CounterReset(
                    computed
                )
            }
            LonghandId::CounterSet => {
                let computed = style.clone_counter_set();
                AnimationValue::CounterSet(
                    computed
                )
            }
            LonghandId::Cursor => {
                let computed = style.clone_cursor();
                AnimationValue::Cursor(
                    computed
                )
            }
            LonghandId::D => {
                let computed = style.clone_d();
                AnimationValue::D(
                    computed
                )
            }
            LonghandId::Filter => {
                let computed = style.clone_filter();
                AnimationValue::Filter(
                    computed.to_animated_value()
                )
            }
            LonghandId::FlexBasis => {
                let computed = style.clone_flex_basis();
                AnimationValue::FlexBasis(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontFamily => {
                let computed = style.clone_font_family();
                AnimationValue::FontFamily(
                    computed
                )
            }
            LonghandId::FontFeatureSettings => {
                let computed = style.clone_font_feature_settings();
                AnimationValue::FontFeatureSettings(
                    computed
                )
            }
            LonghandId::FontPalette => {
                let computed = style.clone_font_palette();
                AnimationValue::FontPalette(
                    computed
                )
            }
            LonghandId::FontSize => {
                let computed = style.clone_font_size();
                AnimationValue::FontSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::FontVariantAlternates => {
                let computed = style.clone_font_variant_alternates();
                AnimationValue::FontVariantAlternates(
                    computed
                )
            }
            LonghandId::FontVariationSettings => {
                let computed = style.clone_font_variation_settings();
                AnimationValue::FontVariationSettings(
                    computed
                )
            }
            LonghandId::GridTemplateAreas => {
                let computed = style.clone_grid_template_areas();
                AnimationValue::GridTemplateAreas(
                    computed
                )
            }
            LonghandId::HyphenateCharacter => {
                let computed = style.clone_hyphenate_character();
                AnimationValue::HyphenateCharacter(
                    computed
                )
            }
            LonghandId::LetterSpacing => {
                let computed = style.clone_letter_spacing();
                AnimationValue::LetterSpacing(
                    computed
                )
            }
            LonghandId::LineHeight => {
                let computed = style.clone_line_height();
                AnimationValue::LineHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::ListStyleType => {
                let computed = style.clone_list_style_type();
                AnimationValue::ListStyleType(
                    computed
                )
            }
            LonghandId::MaskClip => {
                let computed = style.clone_mask_clip();
                AnimationValue::MaskClip(
                    computed
                )
            }
            LonghandId::MaskComposite => {
                let computed = style.clone_mask_composite();
                AnimationValue::MaskComposite(
                    computed
                )
            }
            LonghandId::MaskImage => {
                let computed = style.clone_mask_image();
                AnimationValue::MaskImage(
                    computed
                )
            }
            LonghandId::MaskMode => {
                let computed = style.clone_mask_mode();
                AnimationValue::MaskMode(
                    computed
                )
            }
            LonghandId::MaskOrigin => {
                let computed = style.clone_mask_origin();
                AnimationValue::MaskOrigin(
                    computed
                )
            }
            LonghandId::MaskPositionX => {
                let computed = style.clone_mask_position_x();
                AnimationValue::MaskPositionX(
                    computed
                )
            }
            LonghandId::MaskPositionY => {
                let computed = style.clone_mask_position_y();
                AnimationValue::MaskPositionY(
                    computed
                )
            }
            LonghandId::MaskRepeat => {
                let computed = style.clone_mask_repeat();
                AnimationValue::MaskRepeat(
                    computed
                )
            }
            LonghandId::MaskSize => {
                let computed = style.clone_mask_size();
                AnimationValue::MaskSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::OffsetAnchor => {
                let computed = style.clone_offset_anchor();
                AnimationValue::OffsetAnchor(
                    computed
                )
            }
            LonghandId::OffsetPath => {
                let computed = style.clone_offset_path();
                AnimationValue::OffsetPath(
                    computed.to_animated_value()
                )
            }
            LonghandId::OffsetPosition => {
                let computed = style.clone_offset_position();
                AnimationValue::OffsetPosition(
                    computed
                )
            }
            LonghandId::Page => {
                let computed = style.clone_page();
                AnimationValue::Page(
                    computed
                )
            }
            LonghandId::Perspective => {
                let computed = style.clone_perspective();
                AnimationValue::Perspective(
                    computed.to_animated_value()
                )
            }
            LonghandId::PositionAnchor => {
                let computed = style.clone_position_anchor();
                AnimationValue::PositionAnchor(
                    computed
                )
            }
            LonghandId::PositionTryOptions => {
                let computed = style.clone_position_try_options();
                AnimationValue::PositionTryOptions(
                    computed
                )
            }
            LonghandId::Quotes => {
                let computed = style.clone_quotes();
                AnimationValue::Quotes(
                    computed
                )
            }
            LonghandId::Rotate => {
                let computed = style.clone_rotate();
                AnimationValue::Rotate(
                    computed
                )
            }
            LonghandId::Scale => {
                let computed = style.clone_scale();
                AnimationValue::Scale(
                    computed
                )
            }
            LonghandId::ScrollbarColor => {
                let computed = style.clone_scrollbar_color();
                AnimationValue::ScrollbarColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::ShapeOutside => {
                let computed = style.clone_shape_outside();
                AnimationValue::ShapeOutside(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeDasharray => {
                let computed = style.clone_stroke_dasharray();
                AnimationValue::StrokeDasharray(
                    computed.to_animated_value()
                )
            }
            LonghandId::StrokeDashoffset => {
                let computed = style.clone_stroke_dashoffset();
                AnimationValue::StrokeDashoffset(
                    computed
                )
            }
            LonghandId::StrokeWidth => {
                let computed = style.clone_stroke_width();
                AnimationValue::StrokeWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::TabSize => {
                let computed = style.clone_tab_size();
                AnimationValue::TabSize(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextDecorationThickness => {
                let computed = style.clone_text_decoration_thickness();
                AnimationValue::TextDecorationThickness(
                    computed
                )
            }
            LonghandId::TextEmphasisStyle => {
                let computed = style.clone_text_emphasis_style();
                AnimationValue::TextEmphasisStyle(
                    computed
                )
            }
            LonghandId::TextIndent => {
                let computed = style.clone_text_indent();
                AnimationValue::TextIndent(
                    computed
                )
            }
            LonghandId::TextOverflow => {
                let computed = style.clone_text_overflow();
                AnimationValue::TextOverflow(
                    computed
                )
            }
            LonghandId::TextShadow => {
                let computed = style.clone_text_shadow();
                AnimationValue::TextShadow(
                    computed.to_animated_value()
                )
            }
            LonghandId::Translate => {
                let computed = style.clone_translate();
                AnimationValue::Translate(
                    computed
                )
            }
            LonghandId::VerticalAlign => {
                let computed = style.clone_vertical_align();
                AnimationValue::VerticalAlign(
                    computed
                )
            }
            LonghandId::WebkitTextStrokeWidth => {
                let computed = style.clone__webkit_text_stroke_width();
                AnimationValue::WebkitTextStrokeWidth(
                    computed
                )
            }
            LonghandId::WordSpacing => {
                let computed = style.clone_word_spacing();
                AnimationValue::WordSpacing(
                    computed
                )
            }
            LonghandId::ObjectPosition => {
                let computed = style.clone_object_position();
                AnimationValue::ObjectPosition(
                    computed
                )
            }
            LonghandId::PerspectiveOrigin => {
                let computed = style.clone_perspective_origin();
                AnimationValue::PerspectiveOrigin(
                    computed
                )
            }
            LonghandId::Fill => {
                let computed = style.clone_fill();
                AnimationValue::Fill(
                    computed.to_animated_value()
                )
            }
            LonghandId::Stroke => {
                let computed = style.clone_stroke();
                AnimationValue::Stroke(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozWindowTransformOrigin => {
                let computed = style.clone__moz_window_transform_origin();
                AnimationValue::MozWindowTransformOrigin(
                    computed
                )
            }
            LonghandId::TransformOrigin => {
                let computed = style.clone_transform_origin();
                AnimationValue::TransformOrigin(
                    computed
                )
            }
            LonghandId::GridTemplateColumns => {
                let computed = style.clone_grid_template_columns();
                AnimationValue::GridTemplateColumns(
                    computed
                )
            }
            LonghandId::GridTemplateRows => {
                let computed = style.clone_grid_template_rows();
                AnimationValue::GridTemplateRows(
                    computed
                )
            }
            LonghandId::BorderImageSource => {
                let computed = style.clone_border_image_source();
                AnimationValue::BorderImageSource(
                    computed
                )
            }
            LonghandId::ListStyleImage => {
                let computed = style.clone_list_style_image();
                AnimationValue::ListStyleImage(
                    computed
                )
            }
            LonghandId::GridAutoColumns => {
                let computed = style.clone_grid_auto_columns();
                AnimationValue::GridAutoColumns(
                    computed
                )
            }
            LonghandId::GridAutoRows => {
                let computed = style.clone_grid_auto_rows();
                AnimationValue::GridAutoRows(
                    computed
                )
            }
            LonghandId::MozWindowTransform => {
                let computed = style.clone__moz_window_transform();
                AnimationValue::MozWindowTransform(
                    computed
                )
            }
            LonghandId::Transform => {
                let computed = style.clone_transform();
                AnimationValue::Transform(
                    computed
                )
            }
            LonghandId::ColumnGap => {
                let computed = style.clone_column_gap();
                AnimationValue::ColumnGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::RowGap => {
                let computed = style.clone_row_gap();
                AnimationValue::RowGap(
                    computed.to_animated_value()
                )
            }
            LonghandId::MarkerEnd => {
                let computed = style.clone_marker_end();
                AnimationValue::MarkerEnd(
                    computed
                )
            }
            LonghandId::MarkerMid => {
                let computed = style.clone_marker_mid();
                AnimationValue::MarkerMid(
                    computed
                )
            }
            LonghandId::MarkerStart => {
                let computed = style.clone_marker_start();
                AnimationValue::MarkerStart(
                    computed
                )
            }
            LonghandId::ContainIntrinsicHeight => {
                let computed = style.clone_contain_intrinsic_height();
                AnimationValue::ContainIntrinsicHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::ContainIntrinsicWidth => {
                let computed = style.clone_contain_intrinsic_width();
                AnimationValue::ContainIntrinsicWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::GridColumnEnd => {
                let computed = style.clone_grid_column_end();
                AnimationValue::GridColumnEnd(
                    computed
                )
            }
            LonghandId::GridColumnStart => {
                let computed = style.clone_grid_column_start();
                AnimationValue::GridColumnStart(
                    computed
                )
            }
            LonghandId::GridRowEnd => {
                let computed = style.clone_grid_row_end();
                AnimationValue::GridRowEnd(
                    computed
                )
            }
            LonghandId::GridRowStart => {
                let computed = style.clone_grid_row_start();
                AnimationValue::GridRowStart(
                    computed
                )
            }
            LonghandId::MaxHeight => {
                let computed = style.clone_max_height();
                AnimationValue::MaxHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::MaxWidth => {
                let computed = style.clone_max_width();
                AnimationValue::MaxWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::Cx => {
                let computed = style.clone_cx();
                AnimationValue::Cx(
                    computed
                )
            }
            LonghandId::Cy => {
                let computed = style.clone_cy();
                AnimationValue::Cy(
                    computed
                )
            }
            LonghandId::OffsetDistance => {
                let computed = style.clone_offset_distance();
                AnimationValue::OffsetDistance(
                    computed
                )
            }
            LonghandId::X => {
                let computed = style.clone_x();
                AnimationValue::X(
                    computed
                )
            }
            LonghandId::Y => {
                let computed = style.clone_y();
                AnimationValue::Y(
                    computed
                )
            }
            LonghandId::BorderBottomLeftRadius => {
                let computed = style.clone_border_bottom_left_radius();
                AnimationValue::BorderBottomLeftRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomRightRadius => {
                let computed = style.clone_border_bottom_right_radius();
                AnimationValue::BorderBottomRightRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopLeftRadius => {
                let computed = style.clone_border_top_left_radius();
                AnimationValue::BorderTopLeftRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopRightRadius => {
                let computed = style.clone_border_top_right_radius();
                AnimationValue::BorderTopRightRadius(
                    computed.to_animated_value()
                )
            }
            LonghandId::Height => {
                let computed = style.clone_height();
                AnimationValue::Height(
                    computed.to_animated_value()
                )
            }
            LonghandId::MinHeight => {
                let computed = style.clone_min_height();
                AnimationValue::MinHeight(
                    computed.to_animated_value()
                )
            }
            LonghandId::MinWidth => {
                let computed = style.clone_min_width();
                AnimationValue::MinWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::Width => {
                let computed = style.clone_width();
                AnimationValue::Width(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomWidth => {
                let computed = style.clone_border_bottom_width();
                AnimationValue::BorderBottomWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderLeftWidth => {
                let computed = style.clone_border_left_width();
                AnimationValue::BorderLeftWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderRightWidth => {
                let computed = style.clone_border_right_width();
                AnimationValue::BorderRightWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopWidth => {
                let computed = style.clone_border_top_width();
                AnimationValue::BorderTopWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnRuleWidth => {
                let computed = style.clone_column_rule_width();
                AnimationValue::ColumnRuleWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::OutlineWidth => {
                let computed = style.clone_outline_width();
                AnimationValue::OutlineWidth(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingBottom => {
                let computed = style.clone_padding_bottom();
                AnimationValue::PaddingBottom(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingLeft => {
                let computed = style.clone_padding_left();
                AnimationValue::PaddingLeft(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingRight => {
                let computed = style.clone_padding_right();
                AnimationValue::PaddingRight(
                    computed.to_animated_value()
                )
            }
            LonghandId::PaddingTop => {
                let computed = style.clone_padding_top();
                AnimationValue::PaddingTop(
                    computed.to_animated_value()
                )
            }
            LonghandId::R => {
                let computed = style.clone_r();
                AnimationValue::R(
                    computed.to_animated_value()
                )
            }
            LonghandId::ShapeMargin => {
                let computed = style.clone_shape_margin();
                AnimationValue::ShapeMargin(
                    computed.to_animated_value()
                )
            }
            LonghandId::Rx => {
                let computed = style.clone_rx();
                AnimationValue::Rx(
                    computed.to_animated_value()
                )
            }
            LonghandId::Ry => {
                let computed = style.clone_ry();
                AnimationValue::Ry(
                    computed.to_animated_value()
                )
            }
            LonghandId::ScrollPaddingBottom => {
                let computed = style.clone_scroll_padding_bottom();
                AnimationValue::ScrollPaddingBottom(
                    computed.to_animated_value()
                )
            }
            LonghandId::ScrollPaddingLeft => {
                let computed = style.clone_scroll_padding_left();
                AnimationValue::ScrollPaddingLeft(
                    computed.to_animated_value()
                )
            }
            LonghandId::ScrollPaddingRight => {
                let computed = style.clone_scroll_padding_right();
                AnimationValue::ScrollPaddingRight(
                    computed.to_animated_value()
                )
            }
            LonghandId::ScrollPaddingTop => {
                let computed = style.clone_scroll_padding_top();
                AnimationValue::ScrollPaddingTop(
                    computed.to_animated_value()
                )
            }
            LonghandId::MozWindowInputRegionMargin => {
                let computed = style.clone__moz_window_input_region_margin();
                AnimationValue::MozWindowInputRegionMargin(
                    computed
                )
            }
            LonghandId::OutlineOffset => {
                let computed = style.clone_outline_offset();
                AnimationValue::OutlineOffset(
                    computed
                )
            }
            LonghandId::OverflowClipMargin => {
                let computed = style.clone_overflow_clip_margin();
                AnimationValue::OverflowClipMargin(
                    computed
                )
            }
            LonghandId::ScrollMarginBottom => {
                let computed = style.clone_scroll_margin_bottom();
                AnimationValue::ScrollMarginBottom(
                    computed
                )
            }
            LonghandId::ScrollMarginLeft => {
                let computed = style.clone_scroll_margin_left();
                AnimationValue::ScrollMarginLeft(
                    computed
                )
            }
            LonghandId::ScrollMarginRight => {
                let computed = style.clone_scroll_margin_right();
                AnimationValue::ScrollMarginRight(
                    computed
                )
            }
            LonghandId::ScrollMarginTop => {
                let computed = style.clone_scroll_margin_top();
                AnimationValue::ScrollMarginTop(
                    computed
                )
            }
            LonghandId::Bottom => {
                let computed = style.clone_bottom();
                AnimationValue::Bottom(
                    computed
                )
            }
            LonghandId::Left => {
                let computed = style.clone_left();
                AnimationValue::Left(
                    computed
                )
            }
            LonghandId::MarginBottom => {
                let computed = style.clone_margin_bottom();
                AnimationValue::MarginBottom(
                    computed
                )
            }
            LonghandId::MarginLeft => {
                let computed = style.clone_margin_left();
                AnimationValue::MarginLeft(
                    computed
                )
            }
            LonghandId::MarginRight => {
                let computed = style.clone_margin_right();
                AnimationValue::MarginRight(
                    computed
                )
            }
            LonghandId::MarginTop => {
                let computed = style.clone_margin_top();
                AnimationValue::MarginTop(
                    computed
                )
            }
            LonghandId::Right => {
                let computed = style.clone_right();
                AnimationValue::Right(
                    computed
                )
            }
            LonghandId::TextUnderlineOffset => {
                let computed = style.clone_text_underline_offset();
                AnimationValue::TextUnderlineOffset(
                    computed
                )
            }
            LonghandId::Top => {
                let computed = style.clone_top();
                AnimationValue::Top(
                    computed
                )
            }
            LonghandId::BackgroundColor => {
                let computed = style.clone_background_color();
                AnimationValue::BackgroundColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderBottomColor => {
                let computed = style.clone_border_bottom_color();
                AnimationValue::BorderBottomColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderLeftColor => {
                let computed = style.clone_border_left_color();
                AnimationValue::BorderLeftColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderRightColor => {
                let computed = style.clone_border_right_color();
                AnimationValue::BorderRightColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::BorderTopColor => {
                let computed = style.clone_border_top_color();
                AnimationValue::BorderTopColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::ColumnRuleColor => {
                let computed = style.clone_column_rule_color();
                AnimationValue::ColumnRuleColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::FloodColor => {
                let computed = style.clone_flood_color();
                AnimationValue::FloodColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::LightingColor => {
                let computed = style.clone_lighting_color();
                AnimationValue::LightingColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::OutlineColor => {
                let computed = style.clone_outline_color();
                AnimationValue::OutlineColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::StopColor => {
                let computed = style.clone_stop_color();
                AnimationValue::StopColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextDecorationColor => {
                let computed = style.clone_text_decoration_color();
                AnimationValue::TextDecorationColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::TextEmphasisColor => {
                let computed = style.clone_text_emphasis_color();
                AnimationValue::TextEmphasisColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextFillColor => {
                let computed = style.clone__webkit_text_fill_color();
                AnimationValue::WebkitTextFillColor(
                    computed.to_animated_value()
                )
            }
            LonghandId::WebkitTextStrokeColor => {
                let computed = style.clone__webkit_text_stroke_color();
                AnimationValue::WebkitTextStrokeColor(
                    computed.to_animated_value()
                )
            }
            _ => return None,
        })
    }

    /// Update `style` with the value of this `AnimationValue`.
    ///
    /// SERVO ONLY: This doesn't properly handle things like updating 'em' units
    /// when animated font-size.
    #[cfg(feature = "servo")]
    pub fn set_in_style_for_servo(&self, style: &mut ComputedValues) {
        match self {
            AnimationValue::AlignContent(ref value) => {
                    style.mutate_position().set_align_content(value.clone());
            }
            AnimationValue::AlignItems(ref value) => {
                    style.mutate_position().set_align_items(value.clone());
            }
            AnimationValue::AlignSelf(ref value) => {
                    style.mutate_position().set_align_self(value.clone());
            }
            AnimationValue::AspectRatio(ref value) => {
                    style.mutate_position().set_aspect_ratio(value.clone());
            }
            AnimationValue::BackfaceVisibility(ref value) => {
                    style.mutate_box().set_backface_visibility(value.clone());
            }
            AnimationValue::BaselineSource(ref value) => {
                    style.mutate_box().set_baseline_source(value.clone());
            }
            AnimationValue::BorderCollapse(ref value) => {
                    style.mutate_inherited_table().set_border_collapse(value.clone());
            }
            AnimationValue::BorderImageRepeat(ref value) => {
                    style.mutate_border().set_border_image_repeat(value.clone());
            }
            AnimationValue::BoxDecorationBreak(ref value) => {
                    style.mutate_border().set_box_decoration_break(value.clone());
            }
            AnimationValue::BoxSizing(ref value) => {
                    style.mutate_position().set_box_sizing(value.clone());
            }
            AnimationValue::BreakInside(ref value) => {
                    style.mutate_box().set_break_inside(value.clone());
            }
            AnimationValue::CaptionSide(ref value) => {
                    style.mutate_inherited_table().set_caption_side(value.clone());
            }
            AnimationValue::Clear(ref value) => {
                    style.mutate_box().set_clear(value.clone());
            }
            AnimationValue::ColorInterpolation(ref value) => {
                    style.mutate_inherited_svg().set_color_interpolation(value.clone());
            }
            AnimationValue::ColorInterpolationFilters(ref value) => {
                    style.mutate_inherited_svg().set_color_interpolation_filters(value.clone());
            }
            AnimationValue::ColumnCount(ref value) => {
                let value: longhands::column_count::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_column().set_column_count(value);
            }
            AnimationValue::ColumnFill(ref value) => {
                    style.mutate_column().set_column_fill(value.clone());
            }
            AnimationValue::ColumnSpan(ref value) => {
                    style.mutate_column().set_column_span(value.clone());
            }
            AnimationValue::Contain(..) => unreachable!(),
            AnimationValue::ContainerType(..) => unreachable!(),
            AnimationValue::ContentVisibility(ref value) => {
                    style.mutate_box().set_content_visibility(value.clone());
            }
            AnimationValue::Direction(..) => unreachable!(),
            AnimationValue::Display(ref value) => {
                    style.mutate_box().set_display(value.clone());
            }
            AnimationValue::DominantBaseline(ref value) => {
                    style.mutate_inherited_svg().set_dominant_baseline(value.clone());
            }
            AnimationValue::EmptyCells(ref value) => {
                    style.mutate_inherited_table().set_empty_cells(value.clone());
            }
            AnimationValue::FlexDirection(ref value) => {
                    style.mutate_position().set_flex_direction(value.clone());
            }
            AnimationValue::FlexWrap(ref value) => {
                    style.mutate_position().set_flex_wrap(value.clone());
            }
            AnimationValue::Float(ref value) => {
                    style.mutate_box().set_float(value.clone());
            }
            AnimationValue::FontKerning(ref value) => {
                    style.mutate_font().set_font_kerning(value.clone());
            }
            AnimationValue::FontLanguageOverride(ref value) => {
                    style.mutate_font().set_font_language_override(value.clone());
            }
            AnimationValue::FontOpticalSizing(ref value) => {
                    style.mutate_font().set_font_optical_sizing(value.clone());
            }
            AnimationValue::FontSizeAdjust(ref value) => {
                let value: longhands::font_size_adjust::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_font().set_font_size_adjust(value);
            }
            AnimationValue::FontStretch(ref value) => {
                let value: longhands::font_stretch::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_font().set_font_stretch(value);
            }
            AnimationValue::FontStyle(ref value) => {
                let value: longhands::font_style::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_font().set_font_style(value);
            }
            AnimationValue::FontVariantCaps(ref value) => {
                    style.mutate_font().set_font_variant_caps(value.clone());
            }
            AnimationValue::FontVariantEastAsian(ref value) => {
                    style.mutate_font().set_font_variant_east_asian(value.clone());
            }
            AnimationValue::FontVariantEmoji(ref value) => {
                    style.mutate_font().set_font_variant_emoji(value.clone());
            }
            AnimationValue::FontVariantLigatures(ref value) => {
                    style.mutate_font().set_font_variant_ligatures(value.clone());
            }
            AnimationValue::FontVariantNumeric(ref value) => {
                    style.mutate_font().set_font_variant_numeric(value.clone());
            }
            AnimationValue::FontVariantPosition(ref value) => {
                    style.mutate_font().set_font_variant_position(value.clone());
            }
            AnimationValue::FontWeight(ref value) => {
                let value: longhands::font_weight::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_font().set_font_weight(value);
            }
            AnimationValue::ForcedColorAdjust(ref value) => {
                    style.mutate_inherited_text().set_forced_color_adjust(value.clone());
            }
            AnimationValue::GridAutoFlow(ref value) => {
                    style.mutate_position().set_grid_auto_flow(value.clone());
            }
            AnimationValue::Hyphens(ref value) => {
                    style.mutate_inherited_text().set_hyphens(value.clone());
            }
            AnimationValue::ImageOrientation(ref value) => {
                    style.mutate_inherited_box().set_image_orientation(value.clone());
            }
            AnimationValue::ImageRendering(ref value) => {
                    style.mutate_inherited_box().set_image_rendering(value.clone());
            }
            AnimationValue::ImeMode(ref value) => {
                    style.mutate_ui().set_ime_mode(value.clone());
            }
            AnimationValue::InitialLetter(ref value) => {
                    style.mutate_text().set_initial_letter(value.clone());
            }
            AnimationValue::InsetArea(ref value) => {
                    style.mutate_position().set_inset_area(value.clone());
            }
            AnimationValue::Isolation(ref value) => {
                    style.mutate_box().set_isolation(value.clone());
            }
            AnimationValue::JustifyContent(ref value) => {
                    style.mutate_position().set_justify_content(value.clone());
            }
            AnimationValue::JustifyItems(ref value) => {
                    style.mutate_position().set_justify_items(value.clone());
            }
            AnimationValue::JustifySelf(ref value) => {
                    style.mutate_position().set_justify_self(value.clone());
            }
            AnimationValue::LineBreak(ref value) => {
                    style.mutate_inherited_text().set_line_break(value.clone());
            }
            AnimationValue::ListStylePosition(ref value) => {
                    style.mutate_list().set_list_style_position(value.clone());
            }
            AnimationValue::MaskType(ref value) => {
                    style.mutate_svg().set_mask_type(value.clone());
            }
            AnimationValue::MasonryAutoFlow(ref value) => {
                    style.mutate_position().set_masonry_auto_flow(value.clone());
            }
            AnimationValue::MathDepth(..) => unreachable!(),
            AnimationValue::MathStyle(..) => unreachable!(),
            AnimationValue::MixBlendMode(ref value) => {
                    style.mutate_effects().set_mix_blend_mode(value.clone());
            }
            AnimationValue::MozBoxAlign(ref value) => {
                    style.mutate_xul().set__moz_box_align(value.clone());
            }
            AnimationValue::MozBoxCollapse(..) => unreachable!(),
            AnimationValue::MozBoxDirection(ref value) => {
                    style.mutate_xul().set__moz_box_direction(value.clone());
            }
            AnimationValue::MozBoxOrient(ref value) => {
                    style.mutate_xul().set__moz_box_orient(value.clone());
            }
            AnimationValue::MozBoxPack(ref value) => {
                    style.mutate_xul().set__moz_box_pack(value.clone());
            }
            AnimationValue::MozControlCharacterVisibility(..) => unreachable!(),
            AnimationValue::MozFloatEdge(ref value) => {
                    style.mutate_border().set__moz_float_edge(value.clone());
            }
            AnimationValue::MozInert(ref value) => {
                    style.mutate_inherited_ui().set__moz_inert(value.clone());
            }
            AnimationValue::MozMathVariant(..) => unreachable!(),
            AnimationValue::MozMinFontSizeRatio(..) => unreachable!(),
            AnimationValue::MozOrient(ref value) => {
                    style.mutate_box().set__moz_orient(value.clone());
            }
            AnimationValue::MozOsxFontSmoothing(ref value) => {
                    style.mutate_font().set__moz_osx_font_smoothing(value.clone());
            }
            AnimationValue::MozTextSizeAdjust(ref value) => {
                    style.mutate_inherited_text().set__moz_text_size_adjust(value.clone());
            }
            AnimationValue::MozTheme(ref value) => {
                    style.mutate_inherited_ui().set__moz_theme(value.clone());
            }
            AnimationValue::MozTopLayer(..) => unreachable!(),
            AnimationValue::MozUserFocus(ref value) => {
                    style.mutate_inherited_ui().set__moz_user_focus(value.clone());
            }
            AnimationValue::MozUserInput(ref value) => {
                    style.mutate_inherited_ui().set__moz_user_input(value.clone());
            }
            AnimationValue::MozUserModify(ref value) => {
                    style.mutate_inherited_ui().set__moz_user_modify(value.clone());
            }
            AnimationValue::MozWindowDragging(ref value) => {
                    style.mutate_ui().set__moz_window_dragging(value.clone());
            }
            AnimationValue::MozWindowShadow(ref value) => {
                    style.mutate_ui().set__moz_window_shadow(value.clone());
            }
            AnimationValue::ObjectFit(ref value) => {
                    style.mutate_position().set_object_fit(value.clone());
            }
            AnimationValue::OffsetRotate(ref value) => {
                    style.mutate_box().set_offset_rotate(value.clone());
            }
            AnimationValue::OutlineStyle(ref value) => {
                    style.mutate_outline().set_outline_style(value.clone());
            }
            AnimationValue::OverflowAnchor(ref value) => {
                    style.mutate_box().set_overflow_anchor(value.clone());
            }
            AnimationValue::OverflowWrap(ref value) => {
                    style.mutate_inherited_text().set_overflow_wrap(value.clone());
            }
            AnimationValue::PageOrientation(..) => unreachable!(),
            AnimationValue::PaintOrder(ref value) => {
                    style.mutate_inherited_svg().set_paint_order(value.clone());
            }
            AnimationValue::PointerEvents(ref value) => {
                    style.mutate_inherited_ui().set_pointer_events(value.clone());
            }
            AnimationValue::Position(ref value) => {
                    style.mutate_box().set_position(value.clone());
            }
            AnimationValue::PositionTryOrder(ref value) => {
                    style.mutate_position().set_position_try_order(value.clone());
            }
            AnimationValue::PositionVisibility(ref value) => {
                    style.mutate_position().set_position_visibility(value.clone());
            }
            AnimationValue::PrintColorAdjust(ref value) => {
                    style.mutate_inherited_box().set_print_color_adjust(value.clone());
            }
            AnimationValue::Resize(ref value) => {
                    style.mutate_box().set_resize(value.clone());
            }
            AnimationValue::RubyAlign(ref value) => {
                    style.mutate_inherited_text().set_ruby_align(value.clone());
            }
            AnimationValue::RubyPosition(ref value) => {
                    style.mutate_inherited_text().set_ruby_position(value.clone());
            }
            AnimationValue::ScrollBehavior(ref value) => {
                    style.mutate_box().set_scroll_behavior(value.clone());
            }
            AnimationValue::ScrollSnapAlign(ref value) => {
                    style.mutate_box().set_scroll_snap_align(value.clone());
            }
            AnimationValue::ScrollSnapStop(ref value) => {
                    style.mutate_box().set_scroll_snap_stop(value.clone());
            }
            AnimationValue::ScrollSnapType(ref value) => {
                    style.mutate_box().set_scroll_snap_type(value.clone());
            }
            AnimationValue::ScrollbarGutter(ref value) => {
                    style.mutate_box().set_scrollbar_gutter(value.clone());
            }
            AnimationValue::ScrollbarWidth(ref value) => {
                    style.mutate_ui().set_scrollbar_width(value.clone());
            }
            AnimationValue::ShapeRendering(ref value) => {
                    style.mutate_inherited_svg().set_shape_rendering(value.clone());
            }
            AnimationValue::StrokeLinecap(ref value) => {
                    style.mutate_inherited_svg().set_stroke_linecap(value.clone());
            }
            AnimationValue::StrokeLinejoin(ref value) => {
                    style.mutate_inherited_svg().set_stroke_linejoin(value.clone());
            }
            AnimationValue::TableLayout(ref value) => {
                    style.mutate_table().set_table_layout(value.clone());
            }
            AnimationValue::TextAlign(ref value) => {
                    style.mutate_inherited_text().set_text_align(value.clone());
            }
            AnimationValue::TextAlignLast(ref value) => {
                    style.mutate_inherited_text().set_text_align_last(value.clone());
            }
            AnimationValue::TextAnchor(ref value) => {
                    style.mutate_inherited_svg().set_text_anchor(value.clone());
            }
            AnimationValue::TextCombineUpright(..) => unreachable!(),
            AnimationValue::TextDecorationLine(ref value) => {
                    style.mutate_text().set_text_decoration_line(value.clone());
            }
            AnimationValue::TextDecorationSkipInk(ref value) => {
                    style.mutate_inherited_text().set_text_decoration_skip_ink(value.clone());
            }
            AnimationValue::TextDecorationStyle(ref value) => {
                    style.mutate_text().set_text_decoration_style(value.clone());
            }
            AnimationValue::TextEmphasisPosition(ref value) => {
                    style.mutate_inherited_text().set_text_emphasis_position(value.clone());
            }
            AnimationValue::TextJustify(ref value) => {
                    style.mutate_inherited_text().set_text_justify(value.clone());
            }
            AnimationValue::TextOrientation(..) => unreachable!(),
            AnimationValue::TextRendering(ref value) => {
                    style.mutate_inherited_text().set_text_rendering(value.clone());
            }
            AnimationValue::TextTransform(ref value) => {
                    style.mutate_inherited_text().set_text_transform(value.clone());
            }
            AnimationValue::TextUnderlinePosition(ref value) => {
                    style.mutate_inherited_text().set_text_underline_position(value.clone());
            }
            AnimationValue::TextWrapMode(ref value) => {
                    style.mutate_inherited_text().set_text_wrap_mode(value.clone());
            }
            AnimationValue::TextWrapStyle(ref value) => {
                    style.mutate_inherited_text().set_text_wrap_style(value.clone());
            }
            AnimationValue::TouchAction(ref value) => {
                    style.mutate_box().set_touch_action(value.clone());
            }
            AnimationValue::TransformBox(ref value) => {
                    style.mutate_box().set_transform_box(value.clone());
            }
            AnimationValue::TransformStyle(ref value) => {
                    style.mutate_box().set_transform_style(value.clone());
            }
            AnimationValue::UnicodeBidi(..) => unreachable!(),
            AnimationValue::UserSelect(ref value) => {
                    style.mutate_ui().set_user_select(value.clone());
            }
            AnimationValue::VectorEffect(ref value) => {
                    style.mutate_svg().set_vector_effect(value.clone());
            }
            AnimationValue::Visibility(ref value) => {
                    style.mutate_inherited_box().set_visibility(value.clone());
            }
            AnimationValue::WebkitLineClamp(ref value) => {
                    style.mutate_box().set__webkit_line_clamp(value.clone());
            }
            AnimationValue::WebkitTextSecurity(ref value) => {
                    style.mutate_inherited_text().set__webkit_text_security(value.clone());
            }
            AnimationValue::WhiteSpaceCollapse(ref value) => {
                    style.mutate_inherited_text().set_white_space_collapse(value.clone());
            }
            AnimationValue::WordBreak(ref value) => {
                    style.mutate_inherited_text().set_word_break(value.clone());
            }
            AnimationValue::WritingMode(..) => unreachable!(),
            AnimationValue::XTextScale(..) => unreachable!(),
            AnimationValue::ZIndex(ref value) => {
                    style.mutate_position().set_z_index(value.clone());
            }
            AnimationValue::Zoom(ref value) => {
                let value: longhands::zoom::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_box().set_zoom(value);
            }
            AnimationValue::Appearance(ref value) => {
                    style.mutate_box().set_appearance(value.clone());
            }
            AnimationValue::MozDefaultAppearance(..) => unreachable!(),
            AnimationValue::MozForceBrokenImageIcon(ref value) => {
                    style.mutate_ui().set__moz_force_broken_image_icon(value.clone());
            }
            AnimationValue::MozSubtreeHiddenOnlyVisually(ref value) => {
                    style.mutate_ui().set__moz_subtree_hidden_only_visually(value.clone());
            }
            AnimationValue::BreakAfter(ref value) => {
                    style.mutate_box().set_break_after(value.clone());
            }
            AnimationValue::BreakBefore(ref value) => {
                    style.mutate_box().set_break_before(value.clone());
            }
            AnimationValue::ClipRule(ref value) => {
                    style.mutate_inherited_svg().set_clip_rule(value.clone());
            }
            AnimationValue::FillRule(ref value) => {
                    style.mutate_inherited_svg().set_fill_rule(value.clone());
            }
            AnimationValue::OverflowClipBoxBlock(ref value) => {
                    style.mutate_box().set_overflow_clip_box_block(value.clone());
            }
            AnimationValue::OverflowClipBoxInline(ref value) => {
                    style.mutate_box().set_overflow_clip_box_inline(value.clone());
            }
            AnimationValue::FillOpacity(ref value) => {
                    style.mutate_inherited_svg().set_fill_opacity(value.clone());
            }
            AnimationValue::StrokeOpacity(ref value) => {
                    style.mutate_inherited_svg().set_stroke_opacity(value.clone());
            }
            AnimationValue::MozBoxOrdinalGroup(ref value) => {
                    style.mutate_xul().set__moz_box_ordinal_group(value.clone());
            }
            AnimationValue::Order(ref value) => {
                    style.mutate_position().set_order(value.clone());
            }
            AnimationValue::XSpan(..) => unreachable!(),
            AnimationValue::FontSynthesisPosition(ref value) => {
                    style.mutate_font().set_font_synthesis_position(value.clone());
            }
            AnimationValue::FontSynthesisSmallCaps(ref value) => {
                    style.mutate_font().set_font_synthesis_small_caps(value.clone());
            }
            AnimationValue::FontSynthesisStyle(ref value) => {
                    style.mutate_font().set_font_synthesis_style(value.clone());
            }
            AnimationValue::FontSynthesisWeight(ref value) => {
                    style.mutate_font().set_font_synthesis_weight(value.clone());
            }
            AnimationValue::FlexGrow(ref value) => {
                let value: longhands::flex_grow::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_flex_grow(value);
            }
            AnimationValue::FlexShrink(ref value) => {
                let value: longhands::flex_shrink::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_flex_shrink(value);
            }
            AnimationValue::MozBoxFlex(ref value) => {
                let value: longhands::_moz_box_flex::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_xul().set__moz_box_flex(value);
            }
            AnimationValue::StrokeMiterlimit(ref value) => {
                let value: longhands::stroke_miterlimit::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_svg().set_stroke_miterlimit(value);
            }
            AnimationValue::OverflowBlock(..) => unreachable!(),
            AnimationValue::OverflowInline(..) => unreachable!(),
            AnimationValue::OverflowX(ref value) => {
                    style.mutate_box().set_overflow_x(value.clone());
            }
            AnimationValue::OverflowY(ref value) => {
                    style.mutate_box().set_overflow_y(value.clone());
            }
            AnimationValue::OverscrollBehaviorBlock(..) => unreachable!(),
            AnimationValue::OverscrollBehaviorInline(..) => unreachable!(),
            AnimationValue::OverscrollBehaviorX(ref value) => {
                    style.mutate_box().set_overscroll_behavior_x(value.clone());
            }
            AnimationValue::OverscrollBehaviorY(ref value) => {
                    style.mutate_box().set_overscroll_behavior_y(value.clone());
            }
            AnimationValue::FloodOpacity(ref value) => {
                    style.mutate_svg().set_flood_opacity(value.clone());
            }
            AnimationValue::MozWindowOpacity(ref value) => {
                    style.mutate_ui().set__moz_window_opacity(value.clone());
            }
            AnimationValue::Opacity(ref value) => {
                    style.mutate_effects().set_opacity(value.clone());
            }
            AnimationValue::ShapeImageThreshold(ref value) => {
                    style.mutate_box().set_shape_image_threshold(value.clone());
            }
            AnimationValue::StopOpacity(ref value) => {
                    style.mutate_svg().set_stop_opacity(value.clone());
            }
            AnimationValue::BorderBlockEndStyle(..) => unreachable!(),
            AnimationValue::BorderBlockStartStyle(..) => unreachable!(),
            AnimationValue::BorderBottomStyle(ref value) => {
                    style.mutate_border().set_border_bottom_style(value.clone());
            }
            AnimationValue::BorderInlineEndStyle(..) => unreachable!(),
            AnimationValue::BorderInlineStartStyle(..) => unreachable!(),
            AnimationValue::BorderLeftStyle(ref value) => {
                    style.mutate_border().set_border_left_style(value.clone());
            }
            AnimationValue::BorderRightStyle(ref value) => {
                    style.mutate_border().set_border_right_style(value.clone());
            }
            AnimationValue::BorderTopStyle(ref value) => {
                    style.mutate_border().set_border_top_style(value.clone());
            }
            AnimationValue::ColumnRuleStyle(ref value) => {
                    style.mutate_column().set_column_rule_style(value.clone());
            }
            AnimationValue::AccentColor(ref value) => {
                let value: longhands::accent_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_ui().set_accent_color(value);
            }
            AnimationValue::AnchorName(ref value) => {
                    style.mutate_box().set_anchor_name(value.clone());
            }
            AnimationValue::AnchorScope(ref value) => {
                    style.mutate_box().set_anchor_scope(value.clone());
            }
            AnimationValue::AnimationComposition(..) => unreachable!(),
            AnimationValue::AnimationDelay(..) => unreachable!(),
            AnimationValue::AnimationDirection(..) => unreachable!(),
            AnimationValue::AnimationDuration(..) => unreachable!(),
            AnimationValue::AnimationFillMode(..) => unreachable!(),
            AnimationValue::AnimationIterationCount(..) => unreachable!(),
            AnimationValue::AnimationName(..) => unreachable!(),
            AnimationValue::AnimationPlayState(..) => unreachable!(),
            AnimationValue::AnimationTimeline(..) => unreachable!(),
            AnimationValue::AnimationTimingFunction(..) => unreachable!(),
            AnimationValue::BackdropFilter(ref value) => {
                let value: longhands::backdrop_filter::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_effects().set_backdrop_filter(value);
            }
            AnimationValue::BackgroundAttachment(ref value) => {
                    style.mutate_background().set_background_attachment(value.clone());
            }
            AnimationValue::BackgroundBlendMode(ref value) => {
                    style.mutate_background().set_background_blend_mode(value.clone());
            }
            AnimationValue::BackgroundClip(ref value) => {
                    style.mutate_background().set_background_clip(value.clone());
            }
            AnimationValue::BackgroundImage(ref value) => {
                    style.mutate_background().set_background_image(value.clone());
            }
            AnimationValue::BackgroundOrigin(ref value) => {
                    style.mutate_background().set_background_origin(value.clone());
            }
            AnimationValue::BackgroundPositionX(ref value) => {
                    style.mutate_background().set_background_position_x(value.clone());
            }
            AnimationValue::BackgroundPositionY(ref value) => {
                    style.mutate_background().set_background_position_y(value.clone());
            }
            AnimationValue::BackgroundRepeat(ref value) => {
                    style.mutate_background().set_background_repeat(value.clone());
            }
            AnimationValue::BackgroundSize(ref value) => {
                let value: longhands::background_size::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_background().set_background_size(value);
            }
            AnimationValue::BorderImageOutset(ref value) => {
                let value: longhands::border_image_outset::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_image_outset(value);
            }
            AnimationValue::BorderImageSlice(ref value) => {
                let value: longhands::border_image_slice::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_image_slice(value);
            }
            AnimationValue::BorderImageWidth(ref value) => {
                let value: longhands::border_image_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_image_width(value);
            }
            AnimationValue::BorderSpacing(ref value) => {
                let value: longhands::border_spacing::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_table().set_border_spacing(value);
            }
            AnimationValue::BoxShadow(ref value) => {
                let value: longhands::box_shadow::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_effects().set_box_shadow(value);
            }
            AnimationValue::CaretColor(ref value) => {
                let value: longhands::caret_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_ui().set_caret_color(value);
            }
            AnimationValue::Clip(ref value) => {
                    style.mutate_effects().set_clip(value.clone());
            }
            AnimationValue::ClipPath(ref value) => {
                let value: longhands::clip_path::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_clip_path(value);
            }
            AnimationValue::Color(ref value) => {
                let value: longhands::color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_text().set_color(value);
            }
            AnimationValue::ColorScheme(ref value) => {
                    style.mutate_inherited_ui().set_color_scheme(value.clone());
            }
            AnimationValue::ColumnWidth(ref value) => {
                let value: longhands::column_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_column().set_column_width(value);
            }
            AnimationValue::ContainerName(..) => unreachable!(),
            AnimationValue::Content(ref value) => {
                    style.mutate_counters().set_content(value.clone());
            }
            AnimationValue::CounterIncrement(ref value) => {
                    style.mutate_counters().set_counter_increment(value.clone());
            }
            AnimationValue::CounterReset(ref value) => {
                    style.mutate_counters().set_counter_reset(value.clone());
            }
            AnimationValue::CounterSet(ref value) => {
                    style.mutate_counters().set_counter_set(value.clone());
            }
            AnimationValue::Cursor(ref value) => {
                    style.mutate_inherited_ui().set_cursor(value.clone());
            }
            AnimationValue::D(ref value) => {
                    style.mutate_svg().set_d(value.clone());
            }
            AnimationValue::Filter(ref value) => {
                let value: longhands::filter::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_effects().set_filter(value);
            }
            AnimationValue::FlexBasis(ref value) => {
                let value: longhands::flex_basis::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_flex_basis(value);
            }
            AnimationValue::FontFamily(ref value) => {
                    style.mutate_font().set_font_family(value.clone());
            }
            AnimationValue::FontFeatureSettings(ref value) => {
                    style.mutate_font().set_font_feature_settings(value.clone());
            }
            AnimationValue::FontPalette(ref value) => {
                    style.mutate_font().set_font_palette(value.clone());
            }
            AnimationValue::FontSize(ref value) => {
                let value: longhands::font_size::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_font().set_font_size(value);
            }
            AnimationValue::FontVariantAlternates(ref value) => {
                    style.mutate_font().set_font_variant_alternates(value.clone());
            }
            AnimationValue::FontVariationSettings(ref value) => {
                    style.mutate_font().set_font_variation_settings(value.clone());
            }
            AnimationValue::GridTemplateAreas(ref value) => {
                    style.mutate_position().set_grid_template_areas(value.clone());
            }
            AnimationValue::HyphenateCharacter(ref value) => {
                    style.mutate_inherited_text().set_hyphenate_character(value.clone());
            }
            AnimationValue::LetterSpacing(ref value) => {
                    style.mutate_inherited_text().set_letter_spacing(value.clone());
            }
            AnimationValue::LineHeight(ref value) => {
                let value: longhands::line_height::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_font().set_line_height(value);
            }
            AnimationValue::ListStyleType(ref value) => {
                    style.mutate_list().set_list_style_type(value.clone());
            }
            AnimationValue::MaskClip(ref value) => {
                    style.mutate_svg().set_mask_clip(value.clone());
            }
            AnimationValue::MaskComposite(ref value) => {
                    style.mutate_svg().set_mask_composite(value.clone());
            }
            AnimationValue::MaskImage(ref value) => {
                    style.mutate_svg().set_mask_image(value.clone());
            }
            AnimationValue::MaskMode(ref value) => {
                    style.mutate_svg().set_mask_mode(value.clone());
            }
            AnimationValue::MaskOrigin(ref value) => {
                    style.mutate_svg().set_mask_origin(value.clone());
            }
            AnimationValue::MaskPositionX(ref value) => {
                    style.mutate_svg().set_mask_position_x(value.clone());
            }
            AnimationValue::MaskPositionY(ref value) => {
                    style.mutate_svg().set_mask_position_y(value.clone());
            }
            AnimationValue::MaskRepeat(ref value) => {
                    style.mutate_svg().set_mask_repeat(value.clone());
            }
            AnimationValue::MaskSize(ref value) => {
                let value: longhands::mask_size::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_mask_size(value);
            }
            AnimationValue::MozContextProperties(..) => unreachable!(),
            AnimationValue::OffsetAnchor(ref value) => {
                    style.mutate_box().set_offset_anchor(value.clone());
            }
            AnimationValue::OffsetPath(ref value) => {
                let value: longhands::offset_path::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_box().set_offset_path(value);
            }
            AnimationValue::OffsetPosition(ref value) => {
                    style.mutate_box().set_offset_position(value.clone());
            }
            AnimationValue::Page(ref value) => {
                    style.mutate_page().set_page(value.clone());
            }
            AnimationValue::Perspective(ref value) => {
                let value: longhands::perspective::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_box().set_perspective(value);
            }
            AnimationValue::PositionAnchor(ref value) => {
                    style.mutate_position().set_position_anchor(value.clone());
            }
            AnimationValue::PositionTryOptions(ref value) => {
                    style.mutate_position().set_position_try_options(value.clone());
            }
            AnimationValue::Quotes(ref value) => {
                    style.mutate_list().set_quotes(value.clone());
            }
            AnimationValue::Rotate(ref value) => {
                    style.mutate_box().set_rotate(value.clone());
            }
            AnimationValue::Scale(ref value) => {
                    style.mutate_box().set_scale(value.clone());
            }
            AnimationValue::ScrollTimelineAxis(..) => unreachable!(),
            AnimationValue::ScrollTimelineName(..) => unreachable!(),
            AnimationValue::ScrollbarColor(ref value) => {
                let value: longhands::scrollbar_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_ui().set_scrollbar_color(value);
            }
            AnimationValue::ShapeOutside(ref value) => {
                let value: longhands::shape_outside::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_box().set_shape_outside(value);
            }
            AnimationValue::Size(..) => unreachable!(),
            AnimationValue::StrokeDasharray(ref value) => {
                let value: longhands::stroke_dasharray::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_svg().set_stroke_dasharray(value);
            }
            AnimationValue::StrokeDashoffset(ref value) => {
                    style.mutate_inherited_svg().set_stroke_dashoffset(value.clone());
            }
            AnimationValue::StrokeWidth(ref value) => {
                let value: longhands::stroke_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_svg().set_stroke_width(value);
            }
            AnimationValue::TabSize(ref value) => {
                let value: longhands::tab_size::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_text().set_tab_size(value);
            }
            AnimationValue::TextDecorationThickness(ref value) => {
                    style.mutate_text().set_text_decoration_thickness(value.clone());
            }
            AnimationValue::TextEmphasisStyle(ref value) => {
                    style.mutate_inherited_text().set_text_emphasis_style(value.clone());
            }
            AnimationValue::TextIndent(ref value) => {
                    style.mutate_inherited_text().set_text_indent(value.clone());
            }
            AnimationValue::TextOverflow(ref value) => {
                    style.mutate_text().set_text_overflow(value.clone());
            }
            AnimationValue::TextShadow(ref value) => {
                let value: longhands::text_shadow::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_text().set_text_shadow(value);
            }
            AnimationValue::TransitionBehavior(..) => unreachable!(),
            AnimationValue::TransitionDelay(..) => unreachable!(),
            AnimationValue::TransitionDuration(..) => unreachable!(),
            AnimationValue::TransitionProperty(..) => unreachable!(),
            AnimationValue::TransitionTimingFunction(..) => unreachable!(),
            AnimationValue::Translate(ref value) => {
                    style.mutate_box().set_translate(value.clone());
            }
            AnimationValue::VerticalAlign(ref value) => {
                    style.mutate_box().set_vertical_align(value.clone());
            }
            AnimationValue::ViewTimelineAxis(..) => unreachable!(),
            AnimationValue::ViewTimelineInset(..) => unreachable!(),
            AnimationValue::ViewTimelineName(..) => unreachable!(),
            AnimationValue::WebkitTextStrokeWidth(ref value) => {
                    style.mutate_inherited_text().set__webkit_text_stroke_width(value.clone());
            }
            AnimationValue::WillChange(..) => unreachable!(),
            AnimationValue::WordSpacing(ref value) => {
                    style.mutate_inherited_text().set_word_spacing(value.clone());
            }
            AnimationValue::XLang(..) => unreachable!(),
            AnimationValue::ObjectPosition(ref value) => {
                    style.mutate_position().set_object_position(value.clone());
            }
            AnimationValue::PerspectiveOrigin(ref value) => {
                    style.mutate_box().set_perspective_origin(value.clone());
            }
            AnimationValue::Fill(ref value) => {
                let value: longhands::fill::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_svg().set_fill(value);
            }
            AnimationValue::Stroke(ref value) => {
                let value: longhands::stroke::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_svg().set_stroke(value);
            }
            AnimationValue::MozWindowTransformOrigin(ref value) => {
                    style.mutate_ui().set__moz_window_transform_origin(value.clone());
            }
            AnimationValue::TransformOrigin(ref value) => {
                    style.mutate_box().set_transform_origin(value.clone());
            }
            AnimationValue::GridTemplateColumns(ref value) => {
                    style.mutate_position().set_grid_template_columns(value.clone());
            }
            AnimationValue::GridTemplateRows(ref value) => {
                    style.mutate_position().set_grid_template_rows(value.clone());
            }
            AnimationValue::BorderImageSource(ref value) => {
                    style.mutate_border().set_border_image_source(value.clone());
            }
            AnimationValue::ListStyleImage(ref value) => {
                    style.mutate_list().set_list_style_image(value.clone());
            }
            AnimationValue::GridAutoColumns(ref value) => {
                    style.mutate_position().set_grid_auto_columns(value.clone());
            }
            AnimationValue::GridAutoRows(ref value) => {
                    style.mutate_position().set_grid_auto_rows(value.clone());
            }
            AnimationValue::MozWindowTransform(ref value) => {
                    style.mutate_ui().set__moz_window_transform(value.clone());
            }
            AnimationValue::Transform(ref value) => {
                    style.mutate_box().set_transform(value.clone());
            }
            AnimationValue::ColumnGap(ref value) => {
                let value: longhands::column_gap::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_column_gap(value);
            }
            AnimationValue::RowGap(ref value) => {
                let value: longhands::row_gap::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_row_gap(value);
            }
            AnimationValue::MarkerEnd(ref value) => {
                    style.mutate_inherited_svg().set_marker_end(value.clone());
            }
            AnimationValue::MarkerMid(ref value) => {
                    style.mutate_inherited_svg().set_marker_mid(value.clone());
            }
            AnimationValue::MarkerStart(ref value) => {
                    style.mutate_inherited_svg().set_marker_start(value.clone());
            }
            AnimationValue::ContainIntrinsicBlockSize(..) => unreachable!(),
            AnimationValue::ContainIntrinsicHeight(ref value) => {
                let value: longhands::contain_intrinsic_height::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_contain_intrinsic_height(value);
            }
            AnimationValue::ContainIntrinsicInlineSize(..) => unreachable!(),
            AnimationValue::ContainIntrinsicWidth(ref value) => {
                let value: longhands::contain_intrinsic_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_contain_intrinsic_width(value);
            }
            AnimationValue::GridColumnEnd(ref value) => {
                    style.mutate_position().set_grid_column_end(value.clone());
            }
            AnimationValue::GridColumnStart(ref value) => {
                    style.mutate_position().set_grid_column_start(value.clone());
            }
            AnimationValue::GridRowEnd(ref value) => {
                    style.mutate_position().set_grid_row_end(value.clone());
            }
            AnimationValue::GridRowStart(ref value) => {
                    style.mutate_position().set_grid_row_start(value.clone());
            }
            AnimationValue::MaxBlockSize(..) => unreachable!(),
            AnimationValue::MaxHeight(ref value) => {
                let value: longhands::max_height::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_max_height(value);
            }
            AnimationValue::MaxInlineSize(..) => unreachable!(),
            AnimationValue::MaxWidth(ref value) => {
                let value: longhands::max_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_max_width(value);
            }
            AnimationValue::Cx(ref value) => {
                    style.mutate_svg().set_cx(value.clone());
            }
            AnimationValue::Cy(ref value) => {
                    style.mutate_svg().set_cy(value.clone());
            }
            AnimationValue::OffsetDistance(ref value) => {
                    style.mutate_box().set_offset_distance(value.clone());
            }
            AnimationValue::X(ref value) => {
                    style.mutate_svg().set_x(value.clone());
            }
            AnimationValue::Y(ref value) => {
                    style.mutate_svg().set_y(value.clone());
            }
            AnimationValue::BorderBottomLeftRadius(ref value) => {
                let value: longhands::border_bottom_left_radius::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_bottom_left_radius(value);
            }
            AnimationValue::BorderBottomRightRadius(ref value) => {
                let value: longhands::border_bottom_right_radius::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_bottom_right_radius(value);
            }
            AnimationValue::BorderEndEndRadius(..) => unreachable!(),
            AnimationValue::BorderEndStartRadius(..) => unreachable!(),
            AnimationValue::BorderStartEndRadius(..) => unreachable!(),
            AnimationValue::BorderStartStartRadius(..) => unreachable!(),
            AnimationValue::BorderTopLeftRadius(ref value) => {
                let value: longhands::border_top_left_radius::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_top_left_radius(value);
            }
            AnimationValue::BorderTopRightRadius(ref value) => {
                let value: longhands::border_top_right_radius::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_top_right_radius(value);
            }
            AnimationValue::BlockSize(..) => unreachable!(),
            AnimationValue::Height(ref value) => {
                let value: longhands::height::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_height(value);
            }
            AnimationValue::InlineSize(..) => unreachable!(),
            AnimationValue::MinBlockSize(..) => unreachable!(),
            AnimationValue::MinHeight(ref value) => {
                let value: longhands::min_height::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_min_height(value);
            }
            AnimationValue::MinInlineSize(..) => unreachable!(),
            AnimationValue::MinWidth(ref value) => {
                let value: longhands::min_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_min_width(value);
            }
            AnimationValue::Width(ref value) => {
                let value: longhands::width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_position().set_width(value);
            }
            AnimationValue::BorderBlockEndWidth(..) => unreachable!(),
            AnimationValue::BorderBlockStartWidth(..) => unreachable!(),
            AnimationValue::BorderBottomWidth(ref value) => {
                let value: longhands::border_bottom_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_bottom_width(value);
            }
            AnimationValue::BorderInlineEndWidth(..) => unreachable!(),
            AnimationValue::BorderInlineStartWidth(..) => unreachable!(),
            AnimationValue::BorderLeftWidth(ref value) => {
                let value: longhands::border_left_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_left_width(value);
            }
            AnimationValue::BorderRightWidth(ref value) => {
                let value: longhands::border_right_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_right_width(value);
            }
            AnimationValue::BorderTopWidth(ref value) => {
                let value: longhands::border_top_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_top_width(value);
            }
            AnimationValue::ColumnRuleWidth(ref value) => {
                let value: longhands::column_rule_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_column().set_column_rule_width(value);
            }
            AnimationValue::OutlineWidth(ref value) => {
                let value: longhands::outline_width::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_outline().set_outline_width(value);
            }
            AnimationValue::PaddingBlockEnd(..) => unreachable!(),
            AnimationValue::PaddingBlockStart(..) => unreachable!(),
            AnimationValue::PaddingBottom(ref value) => {
                let value: longhands::padding_bottom::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_padding_bottom(value);
            }
            AnimationValue::PaddingInlineEnd(..) => unreachable!(),
            AnimationValue::PaddingInlineStart(..) => unreachable!(),
            AnimationValue::PaddingLeft(ref value) => {
                let value: longhands::padding_left::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_padding_left(value);
            }
            AnimationValue::PaddingRight(ref value) => {
                let value: longhands::padding_right::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_padding_right(value);
            }
            AnimationValue::PaddingTop(ref value) => {
                let value: longhands::padding_top::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_padding_top(value);
            }
            AnimationValue::R(ref value) => {
                let value: longhands::r::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_r(value);
            }
            AnimationValue::ShapeMargin(ref value) => {
                let value: longhands::shape_margin::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_box().set_shape_margin(value);
            }
            AnimationValue::Rx(ref value) => {
                let value: longhands::rx::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_rx(value);
            }
            AnimationValue::Ry(ref value) => {
                let value: longhands::ry::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_ry(value);
            }
            AnimationValue::ScrollPaddingBlockEnd(..) => unreachable!(),
            AnimationValue::ScrollPaddingBlockStart(..) => unreachable!(),
            AnimationValue::ScrollPaddingBottom(ref value) => {
                let value: longhands::scroll_padding_bottom::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_scroll_padding_bottom(value);
            }
            AnimationValue::ScrollPaddingInlineEnd(..) => unreachable!(),
            AnimationValue::ScrollPaddingInlineStart(..) => unreachable!(),
            AnimationValue::ScrollPaddingLeft(ref value) => {
                let value: longhands::scroll_padding_left::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_scroll_padding_left(value);
            }
            AnimationValue::ScrollPaddingRight(ref value) => {
                let value: longhands::scroll_padding_right::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_scroll_padding_right(value);
            }
            AnimationValue::ScrollPaddingTop(ref value) => {
                let value: longhands::scroll_padding_top::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_padding().set_scroll_padding_top(value);
            }
            AnimationValue::MozWindowInputRegionMargin(ref value) => {
                    style.mutate_ui().set__moz_window_input_region_margin(value.clone());
            }
            AnimationValue::OutlineOffset(ref value) => {
                    style.mutate_outline().set_outline_offset(value.clone());
            }
            AnimationValue::OverflowClipMargin(ref value) => {
                    style.mutate_margin().set_overflow_clip_margin(value.clone());
            }
            AnimationValue::ScrollMarginBlockEnd(..) => unreachable!(),
            AnimationValue::ScrollMarginBlockStart(..) => unreachable!(),
            AnimationValue::ScrollMarginBottom(ref value) => {
                    style.mutate_margin().set_scroll_margin_bottom(value.clone());
            }
            AnimationValue::ScrollMarginInlineEnd(..) => unreachable!(),
            AnimationValue::ScrollMarginInlineStart(..) => unreachable!(),
            AnimationValue::ScrollMarginLeft(ref value) => {
                    style.mutate_margin().set_scroll_margin_left(value.clone());
            }
            AnimationValue::ScrollMarginRight(ref value) => {
                    style.mutate_margin().set_scroll_margin_right(value.clone());
            }
            AnimationValue::ScrollMarginTop(ref value) => {
                    style.mutate_margin().set_scroll_margin_top(value.clone());
            }
            AnimationValue::Bottom(ref value) => {
                    style.mutate_position().set_bottom(value.clone());
            }
            AnimationValue::InsetBlockEnd(..) => unreachable!(),
            AnimationValue::InsetBlockStart(..) => unreachable!(),
            AnimationValue::InsetInlineEnd(..) => unreachable!(),
            AnimationValue::InsetInlineStart(..) => unreachable!(),
            AnimationValue::Left(ref value) => {
                    style.mutate_position().set_left(value.clone());
            }
            AnimationValue::MarginBlockEnd(..) => unreachable!(),
            AnimationValue::MarginBlockStart(..) => unreachable!(),
            AnimationValue::MarginBottom(ref value) => {
                    style.mutate_margin().set_margin_bottom(value.clone());
            }
            AnimationValue::MarginInlineEnd(..) => unreachable!(),
            AnimationValue::MarginInlineStart(..) => unreachable!(),
            AnimationValue::MarginLeft(ref value) => {
                    style.mutate_margin().set_margin_left(value.clone());
            }
            AnimationValue::MarginRight(ref value) => {
                    style.mutate_margin().set_margin_right(value.clone());
            }
            AnimationValue::MarginTop(ref value) => {
                    style.mutate_margin().set_margin_top(value.clone());
            }
            AnimationValue::Right(ref value) => {
                    style.mutate_position().set_right(value.clone());
            }
            AnimationValue::TextUnderlineOffset(ref value) => {
                    style.mutate_inherited_text().set_text_underline_offset(value.clone());
            }
            AnimationValue::Top(ref value) => {
                    style.mutate_position().set_top(value.clone());
            }
            AnimationValue::BackgroundColor(ref value) => {
                let value: longhands::background_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_background().set_background_color(value);
            }
            AnimationValue::BorderBlockEndColor(..) => unreachable!(),
            AnimationValue::BorderBlockStartColor(..) => unreachable!(),
            AnimationValue::BorderBottomColor(ref value) => {
                let value: longhands::border_bottom_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_bottom_color(value);
            }
            AnimationValue::BorderInlineEndColor(..) => unreachable!(),
            AnimationValue::BorderInlineStartColor(..) => unreachable!(),
            AnimationValue::BorderLeftColor(ref value) => {
                let value: longhands::border_left_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_left_color(value);
            }
            AnimationValue::BorderRightColor(ref value) => {
                let value: longhands::border_right_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_right_color(value);
            }
            AnimationValue::BorderTopColor(ref value) => {
                let value: longhands::border_top_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_border().set_border_top_color(value);
            }
            AnimationValue::ColumnRuleColor(ref value) => {
                let value: longhands::column_rule_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_column().set_column_rule_color(value);
            }
            AnimationValue::FloodColor(ref value) => {
                let value: longhands::flood_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_flood_color(value);
            }
            AnimationValue::LightingColor(ref value) => {
                let value: longhands::lighting_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_lighting_color(value);
            }
            AnimationValue::OutlineColor(ref value) => {
                let value: longhands::outline_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_outline().set_outline_color(value);
            }
            AnimationValue::StopColor(ref value) => {
                let value: longhands::stop_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_svg().set_stop_color(value);
            }
            AnimationValue::TextDecorationColor(ref value) => {
                let value: longhands::text_decoration_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_text().set_text_decoration_color(value);
            }
            AnimationValue::TextEmphasisColor(ref value) => {
                let value: longhands::text_emphasis_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_text().set_text_emphasis_color(value);
            }
            AnimationValue::WebkitTextFillColor(ref value) => {
                let value: longhands::_webkit_text_fill_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_text().set__webkit_text_fill_color(value);
            }
            AnimationValue::WebkitTextStrokeColor(ref value) => {
                let value: longhands::_webkit_text_stroke_color::computed_value::T =
                    ToAnimatedValue::from_animated_value(value.clone());
                    style.mutate_inherited_text().set__webkit_text_stroke_color(value);
            }
            AnimationValue::Custom(..) => unreachable!(),
        }
    }

    /// As above, but a stub for Gecko.
    #[cfg(feature = "gecko")]
    pub fn set_in_style_for_servo(&self, _: &mut ComputedValues) {
    }
}

fn animate_discrete<T: Clone>(this: &T, other: &T, procedure: Procedure) -> Result<T, ()> {
    if let Procedure::Interpolate { progress } = procedure {
        Ok(if progress < 0.5 { this.clone() } else { other.clone() })
    } else {
        Err(())
    }
}

impl Animate for AnimationValue {
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        Ok(unsafe {
            use self::AnimationValue::*;

            let this_tag = *(self as *const _ as *const u16);
            let other_tag = *(other as *const _ as *const u16);
            if this_tag != other_tag {
                panic!("Unexpected AnimationValue::animate call");
            }

            match *self {
                
                AlignContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AlignContent as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AlignContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                AlignItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AlignItems as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AlignItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                AlignSelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AlignSelf as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AlignSelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                AspectRatio(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AspectRatio as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AspectRatio as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackfaceVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::backface_visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BaselineSource(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BaselineSource as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BaselineSource as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::border_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderImageRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BorderImageRepeat as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BoxDecorationBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::box_decoration_break::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BoxSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::box_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BreakInside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BreakWithin as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BreakWithin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                CaptionSide(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::table::CaptionSide as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::table::CaptionSide as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Clear(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Clear as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Clear as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColorInterpolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::color_interpolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColorInterpolationFilters(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::color_interpolation_filters::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColumnFill(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::column_fill::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColumnSpan(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::column_span::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ContentVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ContentVisibility as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ContentVisibility as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Display(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Display as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Display as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                DominantBaseline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::dominant_baseline::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                EmptyCells(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::empty_cells::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FlexDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::flex_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FlexWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::flex_wrap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Float(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Float as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Float as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontKerning(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_kerning::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontLanguageOverride(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontLanguageOverride as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontOpticalSizing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_optical_sizing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontStretch as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontStretch as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontStyle as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontStyle as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariantCaps(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_variant_caps::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariantEastAsian(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantEastAsian as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariantEmoji(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_emoji::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_variant_emoji::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariantLigatures(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantLigatures as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariantNumeric(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantNumeric as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariantPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::font_variant_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontWeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontWeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ForcedColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ForcedColorAdjust as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ForcedColorAdjust as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                GridAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridAutoFlow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Hyphens(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::hyphens::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ImageOrientation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::image_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::image_orientation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ImageRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ImageRendering as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ImageRendering as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ImeMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::ime_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                InitialLetter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::InitialLetter as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::InitialLetter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                InsetArea(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::InsetArea as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::InsetArea as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Isolation(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::isolation::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                JustifyContent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::JustifyContent as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::JustifyContent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                JustifyItems(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::JustifyItems as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::JustifyItems as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                JustifySelf(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::JustifySelf as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::JustifySelf as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                LineBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LineBreak as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LineBreak as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ListStylePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::list_style_position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_type::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MasonryAutoFlow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::MasonryAutoFlow as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::MasonryAutoFlow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MixBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mix_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozBoxAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozBoxDirection(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_direction::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozBoxOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozBoxPack(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_box_pack::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozFloatEdge(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_float_edge::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozInert(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_inert::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_inert::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozOrient(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_orient::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozOsxFontSmoothing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_osx_font_smoothing::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozTextSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_text_size_adjust::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozTheme(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ui::MozTheme as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ui::MozTheme as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozUserFocus(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_user_focus::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozUserInput(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_user_input::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozUserModify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_user_modify::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozWindowDragging(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_window_dragging::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozWindowShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_moz_window_shadow::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ObjectFit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::object_fit::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OffsetRotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OffsetRotate as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OffsetRotate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OutlineStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OutlineStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OverflowAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverflowAnchor as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverflowAnchor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OverflowWrap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverflowWrap as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverflowWrap as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PaintOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::SVGPaintOrder as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PointerEvents(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::pointer_events::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Position(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::position::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PositionTryOrder(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionTryOrder as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionTryOrder as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PositionVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionVisibility as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionVisibility as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PrintColorAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PrintColorAdjust as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PrintColorAdjust as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Resize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Resize as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Resize as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                RubyAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::ruby_align::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                RubyPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::RubyPosition as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::RubyPosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ScrollBehavior(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::scroll_behavior::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ScrollSnapAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollSnapAlign as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollSnapAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ScrollSnapStop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollSnapStop as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollSnapStop as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ScrollSnapType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollSnapType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ScrollbarGutter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ScrollbarGutter as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ScrollbarGutter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ScrollbarWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::scrollbar_width::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::scrollbar_width::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ShapeRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::shape_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                StrokeLinecap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::stroke_linecap::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                StrokeLinejoin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::stroke_linejoin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TableLayout(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::table_layout::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextAlign as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextAlignLast(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextAlignLast as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextAlignLast as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_anchor::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextDecorationLine(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextDecorationLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextDecorationSkipInk(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextDecorationSkipInk as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextDecorationSkipInk as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextDecorationStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_decoration_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextEmphasisPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextEmphasisPosition as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextEmphasisPosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextJustify(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextJustify as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextJustify as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextRendering(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_rendering::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextTransform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextTransform as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextTransform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextUnderlinePosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextUnderlinePosition as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextUnderlinePosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextWrapMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_wrap_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_wrap_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextWrapStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::text_wrap_style::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::text_wrap_style::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TouchAction(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TouchAction as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TouchAction as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TransformBox(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TransformBox as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TransformBox as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TransformStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TransformStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TransformStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                UserSelect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::UserSelect as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::UserSelect as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                VectorEffect(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::vector_effect::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                WebkitLineClamp(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LineClamp as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LineClamp as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                WebkitTextSecurity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::_webkit_text_security::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::_webkit_text_security::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                WhiteSpaceCollapse(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::white_space_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::white_space_collapse::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                WordBreak(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::WordBreak as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::WordBreak as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ZIndex as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ZIndex as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Zoom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Zoom as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Zoom as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Appearance(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Appearance as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Appearance as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozForceBrokenImageIcon(ref this) |
MozSubtreeHiddenOnlyVisually(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BoolInteger as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BreakAfter(ref this) |
BreakBefore(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BreakBetween as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ClipRule(ref this) |
FillRule(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FillRule as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FillRule as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OverflowClipBoxBlock(ref this) |
OverflowClipBoxInline(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverflowClipBox as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozBoxOrdinalGroup(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Integer as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Integer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Order(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Integer as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Integer as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontSynthesisPosition(ref this) |
FontSynthesisSmallCaps(ref this) |
FontSynthesisStyle(ref this) |
FontSynthesisWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontSynthesis as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) |
StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OverflowX(ref this) |
OverflowY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Overflow as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Overflow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OverscrollBehaviorX(ref this) |
OverscrollBehaviorY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OverscrollBehavior as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Opacity as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Opacity as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderBottomStyle(ref this) |
BorderLeftStyle(ref this) |
BorderRightStyle(ref this) |
BorderTopStyle(ref this) |
ColumnRuleStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::BorderStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                AccentColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColorOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ColorOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                AnchorName(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AnchorName as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AnchorName as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                AnchorScope(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AnchorScope as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::AnchorScope as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackdropFilter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::backdrop_filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::backdrop_filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundAttachment(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_attachment::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundBlendMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_blend_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::background_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderImageOutset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumberRect as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumberRect as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderImageSlice(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderImageWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::color::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::color::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Clip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ClipPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ClipPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColorScheme(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ColorScheme as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ColorScheme as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Content(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Content as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Content as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                CounterIncrement(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::CounterIncrement as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                CounterReset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::CounterReset as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::CounterReset as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                CounterSet(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::CounterSet as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::CounterSet as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Cursor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Cursor as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Cursor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                D(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::DProperty as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::DProperty as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FlexBasis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FlexBasis as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FlexBasis as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontFamily(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontFamily as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontFamily as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontFeatureSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontFeatureSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontPalette(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontPalette as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontPalette as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariantAlternates(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariantAlternates as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                GridTemplateAreas(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridTemplateAreas as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                HyphenateCharacter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::HyphenateCharacter as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::HyphenateCharacter as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ListStyleType(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ListStyleType as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ListStyleType as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskClip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_clip::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskComposite(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_composite::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_image::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskMode(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_mode::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_origin::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskRepeat(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<longhands::mask_repeat::SpecifiedValue as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OffsetAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionOrAuto as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OffsetPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::OffsetPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::OffsetPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                OffsetPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OffsetPosition as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::OffsetPosition as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Page(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PageName as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PageName as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PositionAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionAnchor as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionAnchor as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PositionTryOptions(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionTryOptions as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::PositionTryOptions as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Quotes(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Quotes as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Quotes as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Rotate as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Rotate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Scale as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Scale as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ScrollbarColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ui::ScrollbarColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ui::ScrollbarColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ShapeOutside as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ShapeOutside as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGLength as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::SVGLength as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextDecorationThickness(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextDecorationLength as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextDecorationLength as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextEmphasisStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextEmphasisStyle as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextIndent as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextIndent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextOverflow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextOverflow as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TextOverflow as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Translate as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Translate as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                WebkitTextStrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LineWidth as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LineWidth as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::WordSpacing as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::WordSpacing as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ObjectPosition(ref this) |
PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Position as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Position as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                GridTemplateColumns(ref this) |
GridTemplateRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderImageSource(ref this) |
ListStyleImage(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Image as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Image as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                GridAutoColumns(ref this) |
GridAutoRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ImplicitGridTracks as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::ImplicitGridTracks as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Transform as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Transform as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ColumnGap(ref this) |
RowGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MarkerEnd(ref this) |
MarkerMid(ref this) |
MarkerStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::url::UrlOrNone as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                ContainIntrinsicHeight(ref this) |
ContainIntrinsicWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                GridColumnEnd(ref this) |
GridColumnStart(ref this) |
GridRowEnd(ref this) |
GridRowStart(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridLine as ToComputedValue>::ComputedValue>);
                    let value = animate_discrete(this, &other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::GridLine as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MaxHeight(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Cx(ref this) |
Cy(ref this) |
OffsetDistance(ref this) |
X(ref this) |
Y(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Height(ref this) |
MinHeight(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BorderBottomWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                PaddingBottom(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) |
R(ref this) |
ShapeMargin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Rx(ref this) |
Ry(ref this) |
ScrollPaddingBottom(ref this) |
ScrollPaddingLeft(ref this) |
ScrollPaddingRight(ref this) |
ScrollPaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                MozWindowInputRegionMargin(ref this) |
OutlineOffset(ref this) |
OverflowClipMargin(ref this) |
ScrollMarginBottom(ref this) |
ScrollMarginLeft(ref this) |
ScrollMarginRight(ref this) |
ScrollMarginTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Length as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::Length as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Bottom(ref this) |
Left(ref this) |
MarginBottom(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
Right(ref this) |
TextUnderlineOffset(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                BackgroundColor(ref this) |
BorderBottomColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
FloodColor(ref this) |
LightingColor(ref this) |
OutlineColor(ref this) |
StopColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);
                    let value = this.animate(&other_repr.value, procedure)?;

                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut AnimationValueVariantRepr<<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>,
                        AnimationValueVariantRepr {
                            tag: this_tag,
                            value,
                        },
                    );
                    out.assume_init()
                },
                Contain(void) |
ContainerType(void) |
Direction(void) |
MathDepth(void) |
MathStyle(void) |
MozBoxCollapse(void) |
MozControlCharacterVisibility(void) |
MozMathVariant(void) |
MozMinFontSizeRatio(void) |
MozTopLayer(void) |
PageOrientation(void) |
TextCombineUpright(void) |
TextOrientation(void) |
UnicodeBidi(void) |
WritingMode(void) |
XTextScale(void) |
MozDefaultAppearance(void) |
XSpan(void) |
OverflowBlock(void) |
OverflowInline(void) |
OverscrollBehaviorBlock(void) |
OverscrollBehaviorInline(void) |
BorderBlockEndStyle(void) |
BorderBlockStartStyle(void) |
BorderInlineEndStyle(void) |
BorderInlineStartStyle(void) |
AnimationComposition(void) |
AnimationDelay(void) |
AnimationDirection(void) |
AnimationDuration(void) |
AnimationFillMode(void) |
AnimationIterationCount(void) |
AnimationName(void) |
AnimationPlayState(void) |
AnimationTimeline(void) |
AnimationTimingFunction(void) |
ContainerName(void) |
MozContextProperties(void) |
ScrollTimelineAxis(void) |
ScrollTimelineName(void) |
Size(void) |
TransitionBehavior(void) |
TransitionDelay(void) |
TransitionDuration(void) |
TransitionProperty(void) |
TransitionTimingFunction(void) |
ViewTimelineAxis(void) |
ViewTimelineInset(void) |
ViewTimelineName(void) |
WillChange(void) |
XLang(void) |
ContainIntrinsicBlockSize(void) |
ContainIntrinsicInlineSize(void) |
MaxBlockSize(void) |
MaxInlineSize(void) |
BorderEndEndRadius(void) |
BorderEndStartRadius(void) |
BorderStartEndRadius(void) |
BorderStartStartRadius(void) |
BlockSize(void) |
InlineSize(void) |
MinBlockSize(void) |
MinInlineSize(void) |
BorderBlockEndWidth(void) |
BorderBlockStartWidth(void) |
BorderInlineEndWidth(void) |
BorderInlineStartWidth(void) |
PaddingBlockEnd(void) |
PaddingBlockStart(void) |
PaddingInlineEnd(void) |
PaddingInlineStart(void) |
ScrollPaddingBlockEnd(void) |
ScrollPaddingBlockStart(void) |
ScrollPaddingInlineEnd(void) |
ScrollPaddingInlineStart(void) |
ScrollMarginBlockEnd(void) |
ScrollMarginBlockStart(void) |
ScrollMarginInlineEnd(void) |
ScrollMarginInlineStart(void) |
InsetBlockEnd(void) |
InsetBlockStart(void) |
InsetInlineEnd(void) |
InsetInlineStart(void) |
MarginBlockEnd(void) |
MarginBlockStart(void) |
MarginInlineEnd(void) |
MarginInlineStart(void) |
BorderBlockEndColor(void) |
BorderBlockStartColor(void) |
BorderInlineEndColor(void) |
BorderInlineStartColor(void) => {
                    void::unreachable(void)
                },
                Custom(ref self_value) => {
                    let Custom(ref other_value) = *other else { unreachable!() };
                    Custom(self_value.animate(other_value, procedure)?)
                },
            }
        })
    }
}



impl ComputeSquaredDistance for AnimationValue {
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        unsafe {
            use self::AnimationValue::*;

            let this_tag = *(self as *const _ as *const u16);
            let other_tag = *(other as *const _ as *const u16);
            if this_tag != other_tag {
                panic!("Unexpected AnimationValue::compute_squared_distance call");
            }

            match *self {
                AspectRatio(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::AspectRatio as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ColumnCount(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColumnCount as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ContentVisibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ContentVisibility as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontSizeAdjust(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontSizeAdjust as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontStretch(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontStretch as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontStyle(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontStyle as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontWeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontWeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                OffsetRotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OffsetRotate as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Visibility(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::visibility::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                WebkitLineClamp(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LineClamp as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ZIndex(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ZIndex as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Zoom(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Zoom as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FillOpacity(ref this) |
StrokeOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGOpacity as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Order(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Integer as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FlexGrow(ref this) |
FlexShrink(ref this) |
MozBoxFlex(ref this) |
StrokeMiterlimit(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FloodOpacity(ref this) |
MozWindowOpacity(ref this) |
Opacity(ref this) |
ShapeImageThreshold(ref this) |
StopOpacity(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Opacity as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                AccentColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColorOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackdropFilter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::backdrop_filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::background_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::background_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderImageOutset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumberRect as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderImageSlice(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderImageSlice as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderImageWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderImageWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderSpacing as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BoxShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::box_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                CaretColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::color::CaretColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Clip(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::ClipRectOrAuto as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ClipPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ClipPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Color(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ColorPropertyValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ColumnWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                D(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::DProperty as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Filter(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::filter::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FlexBasis(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FlexBasis as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::FontSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                FontVariationSettings(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::FontVariationSettings as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                LetterSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LetterSpacing as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                LineHeight(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::LineHeight as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaskPositionX(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_x::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaskPositionY(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<longhands::mask_position_y::SpecifiedValue as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaskSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::mask_size::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                OffsetAnchor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::PositionOrAuto as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                OffsetPath(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::OffsetPath as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                OffsetPosition(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::OffsetPosition as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Perspective(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Perspective as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Rotate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Rotate as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Scale(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Scale as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ScrollbarColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ui::ScrollbarColor as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ShapeOutside(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::basic_shape::ShapeOutside as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                StrokeDasharray(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGStrokeDashArray as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                StrokeDashoffset(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::SVGLength as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                StrokeWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                TabSize(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthOrNumber as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                TextDecorationThickness(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextDecorationLength as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                TextIndent(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TextIndent as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                TextShadow(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<longhands::text_shadow::SpecifiedValue as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Translate(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Translate as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                VerticalAlign(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::VerticalAlign as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                WordSpacing(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::WordSpacing as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ObjectPosition(ref this) |
PerspectiveOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Position as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Fill(ref this) |
Stroke(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::SVGPaint as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MozWindowTransformOrigin(ref this) |
TransformOrigin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::TransformOrigin as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                GridTemplateColumns(ref this) |
GridTemplateRows(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::GridTemplateComponent as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MozWindowTransform(ref this) |
Transform(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Transform as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ColumnGap(ref this) |
RowGap(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::length::NonNegativeLengthPercentageOrNormal as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                ContainIntrinsicHeight(ref this) |
ContainIntrinsicWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::ContainIntrinsicSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MaxHeight(ref this) |
MaxWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::MaxSize as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Cx(ref this) |
Cy(ref this) |
OffsetDistance(ref this) |
X(ref this) |
Y(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LengthPercentage as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderBottomLeftRadius(ref this) |
BorderBottomRightRadius(ref this) |
BorderTopLeftRadius(ref this) |
BorderTopRightRadius(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderCornerRadius as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Height(ref this) |
MinHeight(ref this) |
MinWidth(ref this) |
Width(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Size as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BorderBottomWidth(ref this) |
BorderLeftWidth(ref this) |
BorderRightWidth(ref this) |
BorderTopWidth(ref this) |
ColumnRuleWidth(ref this) |
OutlineWidth(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::BorderSideWidth as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                PaddingBottom(ref this) |
PaddingLeft(ref this) |
PaddingRight(ref this) |
PaddingTop(ref this) |
R(ref this) |
ShapeMargin(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentage as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Rx(ref this) |
Ry(ref this) |
ScrollPaddingBottom(ref this) |
ScrollPaddingLeft(ref this) |
ScrollPaddingRight(ref this) |
ScrollPaddingTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::NonNegativeLengthPercentageOrAuto as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                MozWindowInputRegionMargin(ref this) |
OutlineOffset(ref this) |
OverflowClipMargin(ref this) |
ScrollMarginBottom(ref this) |
ScrollMarginLeft(ref this) |
ScrollMarginRight(ref this) |
ScrollMarginTop(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::Length as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                Bottom(ref this) |
Left(ref this) |
MarginBottom(ref this) |
MarginLeft(ref this) |
MarginRight(ref this) |
MarginTop(ref this) |
Right(ref this) |
TextUnderlineOffset(ref this) |
Top(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<crate::values::specified::LengthPercentageOrAuto as ToComputedValue>::ComputedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                BackgroundColor(ref this) |
BorderBottomColor(ref this) |
BorderLeftColor(ref this) |
BorderRightColor(ref this) |
BorderTopColor(ref this) |
ColumnRuleColor(ref this) |
FloodColor(ref this) |
LightingColor(ref this) |
OutlineColor(ref this) |
StopColor(ref this) |
TextDecorationColor(ref this) |
TextEmphasisColor(ref this) |
WebkitTextFillColor(ref this) |
WebkitTextStrokeColor(ref this) => {
                    let other_repr =
                        &*(other as *const _ as *const AnimationValueVariantRepr<<<crate::values::specified::Color as ToComputedValue>::ComputedValue as ToAnimatedValue>::AnimatedValue>);

                    this.compute_squared_distance(&other_repr.value)
                }
                _ => Err(()),
            }
        }
    }
}

impl ToAnimatedZero for AnimationValue {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            AnimationValue::AspectRatio(ref base) => {
                Ok(AnimationValue::AspectRatio(base.to_animated_zero()?))
            },
            AnimationValue::ColumnCount(ref base) => {
                Ok(AnimationValue::ColumnCount(base.to_animated_zero()?))
            },
            AnimationValue::ContentVisibility(ref base) => {
                Ok(AnimationValue::ContentVisibility(base.to_animated_zero()?))
            },
            AnimationValue::FontSizeAdjust(ref base) => {
                Ok(AnimationValue::FontSizeAdjust(base.to_animated_zero()?))
            },
            AnimationValue::FontStretch(ref base) => {
                Ok(AnimationValue::FontStretch(base.to_animated_zero()?))
            },
            AnimationValue::FontStyle(ref base) => {
                Ok(AnimationValue::FontStyle(base.to_animated_zero()?))
            },
            AnimationValue::FontWeight(ref base) => {
                Ok(AnimationValue::FontWeight(base.to_animated_zero()?))
            },
            AnimationValue::OffsetRotate(ref base) => {
                Ok(AnimationValue::OffsetRotate(base.to_animated_zero()?))
            },
            AnimationValue::Visibility(ref base) => {
                Ok(AnimationValue::Visibility(base.to_animated_zero()?))
            },
            AnimationValue::WebkitLineClamp(ref base) => {
                Ok(AnimationValue::WebkitLineClamp(base.to_animated_zero()?))
            },
            AnimationValue::ZIndex(ref base) => {
                Ok(AnimationValue::ZIndex(base.to_animated_zero()?))
            },
            AnimationValue::Zoom(ref base) => {
                Ok(AnimationValue::Zoom(base.to_animated_zero()?))
            },
            AnimationValue::FillOpacity(ref base) => {
                Ok(AnimationValue::FillOpacity(base.to_animated_zero()?))
            },
            AnimationValue::StrokeOpacity(ref base) => {
                Ok(AnimationValue::StrokeOpacity(base.to_animated_zero()?))
            },
            AnimationValue::Order(ref base) => {
                Ok(AnimationValue::Order(base.to_animated_zero()?))
            },
            AnimationValue::FlexGrow(ref base) => {
                Ok(AnimationValue::FlexGrow(base.to_animated_zero()?))
            },
            AnimationValue::FlexShrink(ref base) => {
                Ok(AnimationValue::FlexShrink(base.to_animated_zero()?))
            },
            AnimationValue::MozBoxFlex(ref base) => {
                Ok(AnimationValue::MozBoxFlex(base.to_animated_zero()?))
            },
            AnimationValue::StrokeMiterlimit(ref base) => {
                Ok(AnimationValue::StrokeMiterlimit(base.to_animated_zero()?))
            },
            AnimationValue::FloodOpacity(ref base) => {
                Ok(AnimationValue::FloodOpacity(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowOpacity(ref base) => {
                Ok(AnimationValue::MozWindowOpacity(base.to_animated_zero()?))
            },
            AnimationValue::Opacity(ref base) => {
                Ok(AnimationValue::Opacity(base.to_animated_zero()?))
            },
            AnimationValue::ShapeImageThreshold(ref base) => {
                Ok(AnimationValue::ShapeImageThreshold(base.to_animated_zero()?))
            },
            AnimationValue::StopOpacity(ref base) => {
                Ok(AnimationValue::StopOpacity(base.to_animated_zero()?))
            },
            AnimationValue::AccentColor(ref base) => {
                Ok(AnimationValue::AccentColor(base.to_animated_zero()?))
            },
            AnimationValue::BackdropFilter(ref base) => {
                Ok(AnimationValue::BackdropFilter(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundPositionX(ref base) => {
                Ok(AnimationValue::BackgroundPositionX(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundPositionY(ref base) => {
                Ok(AnimationValue::BackgroundPositionY(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundSize(ref base) => {
                Ok(AnimationValue::BackgroundSize(base.to_animated_zero()?))
            },
            AnimationValue::BorderImageOutset(ref base) => {
                Ok(AnimationValue::BorderImageOutset(base.to_animated_zero()?))
            },
            AnimationValue::BorderImageSlice(ref base) => {
                Ok(AnimationValue::BorderImageSlice(base.to_animated_zero()?))
            },
            AnimationValue::BorderImageWidth(ref base) => {
                Ok(AnimationValue::BorderImageWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderSpacing(ref base) => {
                Ok(AnimationValue::BorderSpacing(base.to_animated_zero()?))
            },
            AnimationValue::BoxShadow(ref base) => {
                Ok(AnimationValue::BoxShadow(base.to_animated_zero()?))
            },
            AnimationValue::CaretColor(ref base) => {
                Ok(AnimationValue::CaretColor(base.to_animated_zero()?))
            },
            AnimationValue::Clip(ref base) => {
                Ok(AnimationValue::Clip(base.to_animated_zero()?))
            },
            AnimationValue::ClipPath(ref base) => {
                Ok(AnimationValue::ClipPath(base.to_animated_zero()?))
            },
            AnimationValue::Color(ref base) => {
                Ok(AnimationValue::Color(base.to_animated_zero()?))
            },
            AnimationValue::ColumnWidth(ref base) => {
                Ok(AnimationValue::ColumnWidth(base.to_animated_zero()?))
            },
            AnimationValue::D(ref base) => {
                Ok(AnimationValue::D(base.to_animated_zero()?))
            },
            AnimationValue::Filter(ref base) => {
                Ok(AnimationValue::Filter(base.to_animated_zero()?))
            },
            AnimationValue::FlexBasis(ref base) => {
                Ok(AnimationValue::FlexBasis(base.to_animated_zero()?))
            },
            AnimationValue::FontSize(ref base) => {
                Ok(AnimationValue::FontSize(base.to_animated_zero()?))
            },
            AnimationValue::FontVariationSettings(ref base) => {
                Ok(AnimationValue::FontVariationSettings(base.to_animated_zero()?))
            },
            AnimationValue::LetterSpacing(ref base) => {
                Ok(AnimationValue::LetterSpacing(base.to_animated_zero()?))
            },
            AnimationValue::LineHeight(ref base) => {
                Ok(AnimationValue::LineHeight(base.to_animated_zero()?))
            },
            AnimationValue::MaskPositionX(ref base) => {
                Ok(AnimationValue::MaskPositionX(base.to_animated_zero()?))
            },
            AnimationValue::MaskPositionY(ref base) => {
                Ok(AnimationValue::MaskPositionY(base.to_animated_zero()?))
            },
            AnimationValue::MaskSize(ref base) => {
                Ok(AnimationValue::MaskSize(base.to_animated_zero()?))
            },
            AnimationValue::OffsetAnchor(ref base) => {
                Ok(AnimationValue::OffsetAnchor(base.to_animated_zero()?))
            },
            AnimationValue::OffsetPath(ref base) => {
                Ok(AnimationValue::OffsetPath(base.to_animated_zero()?))
            },
            AnimationValue::OffsetPosition(ref base) => {
                Ok(AnimationValue::OffsetPosition(base.to_animated_zero()?))
            },
            AnimationValue::Perspective(ref base) => {
                Ok(AnimationValue::Perspective(base.to_animated_zero()?))
            },
            AnimationValue::Rotate(ref base) => {
                Ok(AnimationValue::Rotate(base.to_animated_zero()?))
            },
            AnimationValue::Scale(ref base) => {
                Ok(AnimationValue::Scale(base.to_animated_zero()?))
            },
            AnimationValue::ScrollbarColor(ref base) => {
                Ok(AnimationValue::ScrollbarColor(base.to_animated_zero()?))
            },
            AnimationValue::ShapeOutside(ref base) => {
                Ok(AnimationValue::ShapeOutside(base.to_animated_zero()?))
            },
            AnimationValue::StrokeDasharray(ref base) => {
                Ok(AnimationValue::StrokeDasharray(base.to_animated_zero()?))
            },
            AnimationValue::StrokeDashoffset(ref base) => {
                Ok(AnimationValue::StrokeDashoffset(base.to_animated_zero()?))
            },
            AnimationValue::StrokeWidth(ref base) => {
                Ok(AnimationValue::StrokeWidth(base.to_animated_zero()?))
            },
            AnimationValue::TabSize(ref base) => {
                Ok(AnimationValue::TabSize(base.to_animated_zero()?))
            },
            AnimationValue::TextDecorationThickness(ref base) => {
                Ok(AnimationValue::TextDecorationThickness(base.to_animated_zero()?))
            },
            AnimationValue::TextIndent(ref base) => {
                Ok(AnimationValue::TextIndent(base.to_animated_zero()?))
            },
            AnimationValue::TextShadow(ref base) => {
                Ok(AnimationValue::TextShadow(base.to_animated_zero()?))
            },
            AnimationValue::Translate(ref base) => {
                Ok(AnimationValue::Translate(base.to_animated_zero()?))
            },
            AnimationValue::VerticalAlign(ref base) => {
                Ok(AnimationValue::VerticalAlign(base.to_animated_zero()?))
            },
            AnimationValue::WordSpacing(ref base) => {
                Ok(AnimationValue::WordSpacing(base.to_animated_zero()?))
            },
            AnimationValue::ObjectPosition(ref base) => {
                Ok(AnimationValue::ObjectPosition(base.to_animated_zero()?))
            },
            AnimationValue::PerspectiveOrigin(ref base) => {
                Ok(AnimationValue::PerspectiveOrigin(base.to_animated_zero()?))
            },
            AnimationValue::Fill(ref base) => {
                Ok(AnimationValue::Fill(base.to_animated_zero()?))
            },
            AnimationValue::Stroke(ref base) => {
                Ok(AnimationValue::Stroke(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowTransformOrigin(ref base) => {
                Ok(AnimationValue::MozWindowTransformOrigin(base.to_animated_zero()?))
            },
            AnimationValue::TransformOrigin(ref base) => {
                Ok(AnimationValue::TransformOrigin(base.to_animated_zero()?))
            },
            AnimationValue::GridTemplateColumns(ref base) => {
                Ok(AnimationValue::GridTemplateColumns(base.to_animated_zero()?))
            },
            AnimationValue::GridTemplateRows(ref base) => {
                Ok(AnimationValue::GridTemplateRows(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowTransform(ref base) => {
                Ok(AnimationValue::MozWindowTransform(base.to_animated_zero()?))
            },
            AnimationValue::Transform(ref base) => {
                Ok(AnimationValue::Transform(base.to_animated_zero()?))
            },
            AnimationValue::ColumnGap(ref base) => {
                Ok(AnimationValue::ColumnGap(base.to_animated_zero()?))
            },
            AnimationValue::RowGap(ref base) => {
                Ok(AnimationValue::RowGap(base.to_animated_zero()?))
            },
            AnimationValue::ContainIntrinsicHeight(ref base) => {
                Ok(AnimationValue::ContainIntrinsicHeight(base.to_animated_zero()?))
            },
            AnimationValue::ContainIntrinsicWidth(ref base) => {
                Ok(AnimationValue::ContainIntrinsicWidth(base.to_animated_zero()?))
            },
            AnimationValue::MaxHeight(ref base) => {
                Ok(AnimationValue::MaxHeight(base.to_animated_zero()?))
            },
            AnimationValue::MaxWidth(ref base) => {
                Ok(AnimationValue::MaxWidth(base.to_animated_zero()?))
            },
            AnimationValue::Cx(ref base) => {
                Ok(AnimationValue::Cx(base.to_animated_zero()?))
            },
            AnimationValue::Cy(ref base) => {
                Ok(AnimationValue::Cy(base.to_animated_zero()?))
            },
            AnimationValue::OffsetDistance(ref base) => {
                Ok(AnimationValue::OffsetDistance(base.to_animated_zero()?))
            },
            AnimationValue::X(ref base) => {
                Ok(AnimationValue::X(base.to_animated_zero()?))
            },
            AnimationValue::Y(ref base) => {
                Ok(AnimationValue::Y(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomLeftRadius(ref base) => {
                Ok(AnimationValue::BorderBottomLeftRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomRightRadius(ref base) => {
                Ok(AnimationValue::BorderBottomRightRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopLeftRadius(ref base) => {
                Ok(AnimationValue::BorderTopLeftRadius(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopRightRadius(ref base) => {
                Ok(AnimationValue::BorderTopRightRadius(base.to_animated_zero()?))
            },
            AnimationValue::Height(ref base) => {
                Ok(AnimationValue::Height(base.to_animated_zero()?))
            },
            AnimationValue::MinHeight(ref base) => {
                Ok(AnimationValue::MinHeight(base.to_animated_zero()?))
            },
            AnimationValue::MinWidth(ref base) => {
                Ok(AnimationValue::MinWidth(base.to_animated_zero()?))
            },
            AnimationValue::Width(ref base) => {
                Ok(AnimationValue::Width(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomWidth(ref base) => {
                Ok(AnimationValue::BorderBottomWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderLeftWidth(ref base) => {
                Ok(AnimationValue::BorderLeftWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderRightWidth(ref base) => {
                Ok(AnimationValue::BorderRightWidth(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopWidth(ref base) => {
                Ok(AnimationValue::BorderTopWidth(base.to_animated_zero()?))
            },
            AnimationValue::ColumnRuleWidth(ref base) => {
                Ok(AnimationValue::ColumnRuleWidth(base.to_animated_zero()?))
            },
            AnimationValue::OutlineWidth(ref base) => {
                Ok(AnimationValue::OutlineWidth(base.to_animated_zero()?))
            },
            AnimationValue::PaddingBottom(ref base) => {
                Ok(AnimationValue::PaddingBottom(base.to_animated_zero()?))
            },
            AnimationValue::PaddingLeft(ref base) => {
                Ok(AnimationValue::PaddingLeft(base.to_animated_zero()?))
            },
            AnimationValue::PaddingRight(ref base) => {
                Ok(AnimationValue::PaddingRight(base.to_animated_zero()?))
            },
            AnimationValue::PaddingTop(ref base) => {
                Ok(AnimationValue::PaddingTop(base.to_animated_zero()?))
            },
            AnimationValue::R(ref base) => {
                Ok(AnimationValue::R(base.to_animated_zero()?))
            },
            AnimationValue::ShapeMargin(ref base) => {
                Ok(AnimationValue::ShapeMargin(base.to_animated_zero()?))
            },
            AnimationValue::Rx(ref base) => {
                Ok(AnimationValue::Rx(base.to_animated_zero()?))
            },
            AnimationValue::Ry(ref base) => {
                Ok(AnimationValue::Ry(base.to_animated_zero()?))
            },
            AnimationValue::ScrollPaddingBottom(ref base) => {
                Ok(AnimationValue::ScrollPaddingBottom(base.to_animated_zero()?))
            },
            AnimationValue::ScrollPaddingLeft(ref base) => {
                Ok(AnimationValue::ScrollPaddingLeft(base.to_animated_zero()?))
            },
            AnimationValue::ScrollPaddingRight(ref base) => {
                Ok(AnimationValue::ScrollPaddingRight(base.to_animated_zero()?))
            },
            AnimationValue::ScrollPaddingTop(ref base) => {
                Ok(AnimationValue::ScrollPaddingTop(base.to_animated_zero()?))
            },
            AnimationValue::MozWindowInputRegionMargin(ref base) => {
                Ok(AnimationValue::MozWindowInputRegionMargin(base.to_animated_zero()?))
            },
            AnimationValue::OutlineOffset(ref base) => {
                Ok(AnimationValue::OutlineOffset(base.to_animated_zero()?))
            },
            AnimationValue::OverflowClipMargin(ref base) => {
                Ok(AnimationValue::OverflowClipMargin(base.to_animated_zero()?))
            },
            AnimationValue::ScrollMarginBottom(ref base) => {
                Ok(AnimationValue::ScrollMarginBottom(base.to_animated_zero()?))
            },
            AnimationValue::ScrollMarginLeft(ref base) => {
                Ok(AnimationValue::ScrollMarginLeft(base.to_animated_zero()?))
            },
            AnimationValue::ScrollMarginRight(ref base) => {
                Ok(AnimationValue::ScrollMarginRight(base.to_animated_zero()?))
            },
            AnimationValue::ScrollMarginTop(ref base) => {
                Ok(AnimationValue::ScrollMarginTop(base.to_animated_zero()?))
            },
            AnimationValue::Bottom(ref base) => {
                Ok(AnimationValue::Bottom(base.to_animated_zero()?))
            },
            AnimationValue::Left(ref base) => {
                Ok(AnimationValue::Left(base.to_animated_zero()?))
            },
            AnimationValue::MarginBottom(ref base) => {
                Ok(AnimationValue::MarginBottom(base.to_animated_zero()?))
            },
            AnimationValue::MarginLeft(ref base) => {
                Ok(AnimationValue::MarginLeft(base.to_animated_zero()?))
            },
            AnimationValue::MarginRight(ref base) => {
                Ok(AnimationValue::MarginRight(base.to_animated_zero()?))
            },
            AnimationValue::MarginTop(ref base) => {
                Ok(AnimationValue::MarginTop(base.to_animated_zero()?))
            },
            AnimationValue::Right(ref base) => {
                Ok(AnimationValue::Right(base.to_animated_zero()?))
            },
            AnimationValue::TextUnderlineOffset(ref base) => {
                Ok(AnimationValue::TextUnderlineOffset(base.to_animated_zero()?))
            },
            AnimationValue::Top(ref base) => {
                Ok(AnimationValue::Top(base.to_animated_zero()?))
            },
            AnimationValue::BackgroundColor(ref base) => {
                Ok(AnimationValue::BackgroundColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderBottomColor(ref base) => {
                Ok(AnimationValue::BorderBottomColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderLeftColor(ref base) => {
                Ok(AnimationValue::BorderLeftColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderRightColor(ref base) => {
                Ok(AnimationValue::BorderRightColor(base.to_animated_zero()?))
            },
            AnimationValue::BorderTopColor(ref base) => {
                Ok(AnimationValue::BorderTopColor(base.to_animated_zero()?))
            },
            AnimationValue::ColumnRuleColor(ref base) => {
                Ok(AnimationValue::ColumnRuleColor(base.to_animated_zero()?))
            },
            AnimationValue::FloodColor(ref base) => {
                Ok(AnimationValue::FloodColor(base.to_animated_zero()?))
            },
            AnimationValue::LightingColor(ref base) => {
                Ok(AnimationValue::LightingColor(base.to_animated_zero()?))
            },
            AnimationValue::OutlineColor(ref base) => {
                Ok(AnimationValue::OutlineColor(base.to_animated_zero()?))
            },
            AnimationValue::StopColor(ref base) => {
                Ok(AnimationValue::StopColor(base.to_animated_zero()?))
            },
            AnimationValue::TextDecorationColor(ref base) => {
                Ok(AnimationValue::TextDecorationColor(base.to_animated_zero()?))
            },
            AnimationValue::TextEmphasisColor(ref base) => {
                Ok(AnimationValue::TextEmphasisColor(base.to_animated_zero()?))
            },
            AnimationValue::WebkitTextFillColor(ref base) => {
                Ok(AnimationValue::WebkitTextFillColor(base.to_animated_zero()?))
            },
            AnimationValue::WebkitTextStrokeColor(ref base) => {
                Ok(AnimationValue::WebkitTextStrokeColor(base.to_animated_zero()?))
            },
            AnimationValue::Custom(..) => {
                // TODO(bug 1869185): For some non-universal registered custom properties, it may make sense to implement this.
                Err(())
            },
            _ => Err(()),
        }
    }
}

/// <https://drafts.csswg.org/web-animations-1/#animating-visibility>
impl Animate for Visibility {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match procedure {
            Procedure::Interpolate { .. } => {
                let (this_weight, other_weight) = procedure.weights();
                match (*self, *other) {
                    (Visibility::Visible, _) => {
                        Ok(if this_weight > 0.0 { *self } else { *other })
                    },
                    (_, Visibility::Visible) => {
                        Ok(if other_weight > 0.0 { *other } else { *self })
                    },
                    _ => Err(()),
                }
            },
            _ => Err(()),
        }
    }
}

impl ComputeSquaredDistance for Visibility {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        Ok(SquaredDistance::from_sqrt(if *self == *other { 0. } else { 1. }))
    }
}

impl ToAnimatedZero for Visibility {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Err(())
    }
}

/// <https://drafts.csswg.org/css-contain-3/#content-visibility-animation>
impl Animate for ContentVisibility {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        match procedure {
            Procedure::Interpolate { .. } => {
                let (this_weight, other_weight) = procedure.weights();
                match (*self, *other) {
                    (ContentVisibility::Hidden, _) => {
                        Ok(if other_weight > 0.0 { *other } else { *self })
                    },
                    (_, ContentVisibility::Hidden) => {
                        Ok(if this_weight > 0.0 { *self } else { *other })
                    },
                    _ => Err(()),
                }
            },
            _ => Err(()),
        }
    }
}

impl ComputeSquaredDistance for ContentVisibility {
    #[inline]
    fn compute_squared_distance(&self, other: &Self) -> Result<SquaredDistance, ()> {
        Ok(SquaredDistance::from_sqrt(if *self == *other { 0. } else { 1. }))
    }
}

impl ToAnimatedZero for ContentVisibility {
    #[inline]
    fn to_animated_zero(&self) -> Result<Self, ()> {
        Err(())
    }
}

/// <https://drafts.csswg.org/css-transitions/#animtype-rect>
impl Animate for ClipRect {
    #[inline]
    fn animate(&self, other: &Self, procedure: Procedure) -> Result<Self, ()> {
        use crate::values::computed::LengthOrAuto;
        let animate_component = |this: &LengthOrAuto, other: &LengthOrAuto| {
            let result = this.animate(other, procedure)?;
            if let Procedure::Interpolate { .. } = procedure {
                return Ok(result);
            }
            if result.is_auto() {
                // FIXME(emilio): Why? A couple SMIL tests fail without this,
                // but it seems extremely fishy.
                return Err(());
            }
            Ok(result)
        };

        Ok(ClipRect {
            top: animate_component(&self.top, &other.top)?,
            right: animate_component(&self.right, &other.right)?,
            bottom: animate_component(&self.bottom, &other.bottom)?,
            left: animate_component(&self.left, &other.left)?,
        })
    }
}



/// <https://drafts.fxtf.org/filters/#animation-of-filters>
impl Animate for AnimatedFilter {
    fn animate(
        &self,
        other: &Self,
        procedure: Procedure,
    ) -> Result<Self, ()> {
        use crate::values::animated::animate_multiplicative_factor;
        match (self, other) {
            (&Filter::Blur(ref this), &Filter::Blur(ref other)) => {
                Ok(Filter::Blur(this.animate(other, procedure)?))
            },
            (&Filter::Grayscale(ref this), &Filter::Grayscale(ref other)) => {
                Ok(Filter::Grayscale(this.animate(other, procedure)?))
            },
            (&Filter::HueRotate(ref this), &Filter::HueRotate(ref other)) => {
                Ok(Filter::HueRotate(this.animate(other, procedure)?))
            },
            (&Filter::Invert(ref this), &Filter::Invert(ref other)) => {
                Ok(Filter::Invert(this.animate(other, procedure)?))
            },
            (&Filter::Sepia(ref this), &Filter::Sepia(ref other)) => {
                Ok(Filter::Sepia(this.animate(other, procedure)?))
            },
            (&Filter::Brightness(this), &Filter::Brightness(other)) => {
                Ok(Filter::Brightness(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::Contrast(this), &Filter::Contrast(other)) => {
                Ok(Filter::Contrast(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::Opacity(this), &Filter::Opacity(other)) => {
                Ok(Filter::Opacity(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::Saturate(this), &Filter::Saturate(other)) => {
                Ok(Filter::Saturate(animate_multiplicative_factor(this, other, procedure)?))
            },
            (&Filter::DropShadow(ref this), &Filter::DropShadow(ref other)) => {
                Ok(Filter::DropShadow(this.animate(other, procedure)?))
            },
            _ => Err(()),
        }
    }
}

/// <http://dev.w3.org/csswg/css-transforms/#none-transform-animation>
impl ToAnimatedZero for AnimatedFilter {
    fn to_animated_zero(&self) -> Result<Self, ()> {
        match *self {
            Filter::Blur(ref this) => Ok(Filter::Blur(this.to_animated_zero()?)),
            Filter::Grayscale(ref this) => Ok(Filter::Grayscale(this.to_animated_zero()?)),
            Filter::HueRotate(ref this) => Ok(Filter::HueRotate(this.to_animated_zero()?)),
            Filter::Invert(ref this) => Ok(Filter::Invert(this.to_animated_zero()?)),
            Filter::Sepia(ref this) => Ok(Filter::Sepia(this.to_animated_zero()?)),
            Filter::Brightness(_) => Ok(Filter::Brightness(1.)),
            Filter::Contrast(_) => Ok(Filter::Contrast(1.)),
            Filter::Opacity(_) => Ok(Filter::Opacity(1.)),
            Filter::Saturate(_) => Ok(Filter::Saturate(1.)),
            Filter::DropShadow(ref this) => Ok(Filter::DropShadow(this.to_animated_zero()?)),
            _ => Err(()),
        }
    }
}

/// An iterator over all the properties that transition on a given style.
pub struct TransitionPropertyIterator<'a> {
    style: &'a ComputedValues,
    index_range: core::ops::Range<usize>,
    longhand_iterator: Option<NonCustomPropertyIterator<LonghandId>>,
}

impl<'a> TransitionPropertyIterator<'a> {
    /// Create a `TransitionPropertyIterator` for the given style.
    pub fn from_style(style: &'a ComputedValues) -> Self {
        Self {
            style,
            index_range: 0..style.get_ui().transition_property_count(),
            longhand_iterator: None,
        }
    }
}

/// A single iteration of the TransitionPropertyIterator.
pub struct TransitionPropertyIteration {
    /// The id of the longhand for this property.
    pub property: OwnedPropertyDeclarationId,

    /// The index of this property in the list of transition properties for this
    /// iterator's style.
    pub index: usize,
}

impl<'a> Iterator for TransitionPropertyIterator<'a> {
    type Item = TransitionPropertyIteration;

    fn next(&mut self) -> Option<Self::Item> {
        use crate::values::computed::TransitionProperty;
        loop {
            if let Some(ref mut longhand_iterator) = self.longhand_iterator {
                if let Some(longhand_id) = longhand_iterator.next() {
                    return Some(TransitionPropertyIteration {
                        property: OwnedPropertyDeclarationId::Longhand(longhand_id),
                        index: self.index_range.start - 1,
                    });
                }
                self.longhand_iterator = None;
            }

            let index = self.index_range.next()?;
            match self.style.get_ui().transition_property_at(index) {
                TransitionProperty::NonCustom(id) => {
                    match id.longhand_or_shorthand() {
                        Ok(longhand_id) => {
                            return Some(TransitionPropertyIteration {
                                property: OwnedPropertyDeclarationId::Longhand(longhand_id),
                                index,
                            });
                        },
                        Err(shorthand_id) => {
                            // In the other cases, we set up our state so that we are ready to
                            // compute the next value of the iterator and then loop (equivalent
                            // to calling self.next()).
                            self.longhand_iterator = Some(shorthand_id.longhands());
                        },
                    }
                }
                TransitionProperty::Custom(name) => {
                    return Some(TransitionPropertyIteration {
                        property: OwnedPropertyDeclarationId::Custom(name),
                        index,
                    })
                },
                TransitionProperty::Unsupported(..) => {},
            }
        }
    }
}

}

/// A module to group various interesting property counts.
pub mod property_counts {
    /// The number of (non-alias) longhand properties.
    pub const LONGHANDS: usize = 410;
    /// The number of (non-alias) shorthand properties.
    pub const SHORTHANDS: usize = 79;
    /// The number of aliases.
    pub const ALIASES: usize = 110;
    /// The number of counted unknown properties.
    pub const COUNTED_UNKNOWN: usize = 103;
    /// The number of (non-alias) longhands and shorthands.
    pub const LONGHANDS_AND_SHORTHANDS: usize = LONGHANDS + SHORTHANDS;
    /// The number of non-custom properties.
    pub const NON_CUSTOM: usize = LONGHANDS_AND_SHORTHANDS + ALIASES;
    /// The number of prioritary properties that we have.
    pub const PRIORITARY: usize = 17;
    /// The max number of longhands that a shorthand other than "all" expands to.
    pub const MAX_SHORTHAND_EXPANDED: usize =
        19;
    /// The max amount of longhands that the `all` shorthand will ever contain.
    pub const ALL_SHORTHAND_EXPANDED: usize = 389;
    /// The number of animatable properties.
    pub const ANIMATABLE: usize = 363;
}

#[allow(dead_code)]
unsafe fn static_assert_nscsspropertyid() {
    std::mem::transmute::<[u8; 0], [u8; nsCSSPropertyID::eCSSProperty_align_content as usize]>([0; 0]); // align-content
    std::mem::transmute::<[u8; 1], [u8; nsCSSPropertyID::eCSSProperty_align_items as usize]>([0; 1]); // align-items
    std::mem::transmute::<[u8; 2], [u8; nsCSSPropertyID::eCSSProperty_align_self as usize]>([0; 2]); // align-self
    std::mem::transmute::<[u8; 3], [u8; nsCSSPropertyID::eCSSProperty_aspect_ratio as usize]>([0; 3]); // aspect-ratio
    std::mem::transmute::<[u8; 4], [u8; nsCSSPropertyID::eCSSProperty_backface_visibility as usize]>([0; 4]); // backface-visibility
    std::mem::transmute::<[u8; 5], [u8; nsCSSPropertyID::eCSSProperty_baseline_source as usize]>([0; 5]); // baseline-source
    std::mem::transmute::<[u8; 6], [u8; nsCSSPropertyID::eCSSProperty_border_collapse as usize]>([0; 6]); // border-collapse
    std::mem::transmute::<[u8; 7], [u8; nsCSSPropertyID::eCSSProperty_border_image_repeat as usize]>([0; 7]); // border-image-repeat
    std::mem::transmute::<[u8; 8], [u8; nsCSSPropertyID::eCSSProperty_box_decoration_break as usize]>([0; 8]); // box-decoration-break
    std::mem::transmute::<[u8; 9], [u8; nsCSSPropertyID::eCSSProperty_box_sizing as usize]>([0; 9]); // box-sizing
    std::mem::transmute::<[u8; 10], [u8; nsCSSPropertyID::eCSSProperty_break_inside as usize]>([0; 10]); // break-inside
    std::mem::transmute::<[u8; 11], [u8; nsCSSPropertyID::eCSSProperty_caption_side as usize]>([0; 11]); // caption-side
    std::mem::transmute::<[u8; 12], [u8; nsCSSPropertyID::eCSSProperty_clear as usize]>([0; 12]); // clear
    std::mem::transmute::<[u8; 13], [u8; nsCSSPropertyID::eCSSProperty_color_interpolation as usize]>([0; 13]); // color-interpolation
    std::mem::transmute::<[u8; 14], [u8; nsCSSPropertyID::eCSSProperty_color_interpolation_filters as usize]>([0; 14]); // color-interpolation-filters
    std::mem::transmute::<[u8; 15], [u8; nsCSSPropertyID::eCSSProperty_column_count as usize]>([0; 15]); // column-count
    std::mem::transmute::<[u8; 16], [u8; nsCSSPropertyID::eCSSProperty_column_fill as usize]>([0; 16]); // column-fill
    std::mem::transmute::<[u8; 17], [u8; nsCSSPropertyID::eCSSProperty_column_span as usize]>([0; 17]); // column-span
    std::mem::transmute::<[u8; 18], [u8; nsCSSPropertyID::eCSSProperty_contain as usize]>([0; 18]); // contain
    std::mem::transmute::<[u8; 19], [u8; nsCSSPropertyID::eCSSProperty_container_type as usize]>([0; 19]); // container-type
    std::mem::transmute::<[u8; 20], [u8; nsCSSPropertyID::eCSSProperty_content_visibility as usize]>([0; 20]); // content-visibility
    std::mem::transmute::<[u8; 21], [u8; nsCSSPropertyID::eCSSProperty_direction as usize]>([0; 21]); // direction
    std::mem::transmute::<[u8; 22], [u8; nsCSSPropertyID::eCSSProperty_display as usize]>([0; 22]); // display
    std::mem::transmute::<[u8; 23], [u8; nsCSSPropertyID::eCSSProperty_dominant_baseline as usize]>([0; 23]); // dominant-baseline
    std::mem::transmute::<[u8; 24], [u8; nsCSSPropertyID::eCSSProperty_empty_cells as usize]>([0; 24]); // empty-cells
    std::mem::transmute::<[u8; 25], [u8; nsCSSPropertyID::eCSSProperty_flex_direction as usize]>([0; 25]); // flex-direction
    std::mem::transmute::<[u8; 26], [u8; nsCSSPropertyID::eCSSProperty_flex_wrap as usize]>([0; 26]); // flex-wrap
    std::mem::transmute::<[u8; 27], [u8; nsCSSPropertyID::eCSSProperty_float as usize]>([0; 27]); // float
    std::mem::transmute::<[u8; 28], [u8; nsCSSPropertyID::eCSSProperty_font_kerning as usize]>([0; 28]); // font-kerning
    std::mem::transmute::<[u8; 29], [u8; nsCSSPropertyID::eCSSProperty_font_language_override as usize]>([0; 29]); // font-language-override
    std::mem::transmute::<[u8; 30], [u8; nsCSSPropertyID::eCSSProperty_font_optical_sizing as usize]>([0; 30]); // font-optical-sizing
    std::mem::transmute::<[u8; 31], [u8; nsCSSPropertyID::eCSSProperty_font_size_adjust as usize]>([0; 31]); // font-size-adjust
    std::mem::transmute::<[u8; 32], [u8; nsCSSPropertyID::eCSSProperty_font_stretch as usize]>([0; 32]); // font-stretch
    std::mem::transmute::<[u8; 33], [u8; nsCSSPropertyID::eCSSProperty_font_style as usize]>([0; 33]); // font-style
    std::mem::transmute::<[u8; 34], [u8; nsCSSPropertyID::eCSSProperty_font_variant_caps as usize]>([0; 34]); // font-variant-caps
    std::mem::transmute::<[u8; 35], [u8; nsCSSPropertyID::eCSSProperty_font_variant_east_asian as usize]>([0; 35]); // font-variant-east-asian
    std::mem::transmute::<[u8; 36], [u8; nsCSSPropertyID::eCSSProperty_font_variant_emoji as usize]>([0; 36]); // font-variant-emoji
    std::mem::transmute::<[u8; 37], [u8; nsCSSPropertyID::eCSSProperty_font_variant_ligatures as usize]>([0; 37]); // font-variant-ligatures
    std::mem::transmute::<[u8; 38], [u8; nsCSSPropertyID::eCSSProperty_font_variant_numeric as usize]>([0; 38]); // font-variant-numeric
    std::mem::transmute::<[u8; 39], [u8; nsCSSPropertyID::eCSSProperty_font_variant_position as usize]>([0; 39]); // font-variant-position
    std::mem::transmute::<[u8; 40], [u8; nsCSSPropertyID::eCSSProperty_font_weight as usize]>([0; 40]); // font-weight
    std::mem::transmute::<[u8; 41], [u8; nsCSSPropertyID::eCSSProperty_forced_color_adjust as usize]>([0; 41]); // forced-color-adjust
    std::mem::transmute::<[u8; 42], [u8; nsCSSPropertyID::eCSSProperty_grid_auto_flow as usize]>([0; 42]); // grid-auto-flow
    std::mem::transmute::<[u8; 43], [u8; nsCSSPropertyID::eCSSProperty_hyphens as usize]>([0; 43]); // hyphens
    std::mem::transmute::<[u8; 44], [u8; nsCSSPropertyID::eCSSProperty_image_orientation as usize]>([0; 44]); // image-orientation
    std::mem::transmute::<[u8; 45], [u8; nsCSSPropertyID::eCSSProperty_image_rendering as usize]>([0; 45]); // image-rendering
    std::mem::transmute::<[u8; 46], [u8; nsCSSPropertyID::eCSSProperty_ime_mode as usize]>([0; 46]); // ime-mode
    std::mem::transmute::<[u8; 47], [u8; nsCSSPropertyID::eCSSProperty_initial_letter as usize]>([0; 47]); // initial-letter
    std::mem::transmute::<[u8; 48], [u8; nsCSSPropertyID::eCSSProperty_inset_area as usize]>([0; 48]); // inset-area
    std::mem::transmute::<[u8; 49], [u8; nsCSSPropertyID::eCSSProperty_isolation as usize]>([0; 49]); // isolation
    std::mem::transmute::<[u8; 50], [u8; nsCSSPropertyID::eCSSProperty_justify_content as usize]>([0; 50]); // justify-content
    std::mem::transmute::<[u8; 51], [u8; nsCSSPropertyID::eCSSProperty_justify_items as usize]>([0; 51]); // justify-items
    std::mem::transmute::<[u8; 52], [u8; nsCSSPropertyID::eCSSProperty_justify_self as usize]>([0; 52]); // justify-self
    std::mem::transmute::<[u8; 53], [u8; nsCSSPropertyID::eCSSProperty_line_break as usize]>([0; 53]); // line-break
    std::mem::transmute::<[u8; 54], [u8; nsCSSPropertyID::eCSSProperty_list_style_position as usize]>([0; 54]); // list-style-position
    std::mem::transmute::<[u8; 55], [u8; nsCSSPropertyID::eCSSProperty_mask_type as usize]>([0; 55]); // mask-type
    std::mem::transmute::<[u8; 56], [u8; nsCSSPropertyID::eCSSProperty_masonry_auto_flow as usize]>([0; 56]); // masonry-auto-flow
    std::mem::transmute::<[u8; 57], [u8; nsCSSPropertyID::eCSSProperty_math_depth as usize]>([0; 57]); // math-depth
    std::mem::transmute::<[u8; 58], [u8; nsCSSPropertyID::eCSSProperty_math_style as usize]>([0; 58]); // math-style
    std::mem::transmute::<[u8; 59], [u8; nsCSSPropertyID::eCSSProperty_mix_blend_mode as usize]>([0; 59]); // mix-blend-mode
    std::mem::transmute::<[u8; 60], [u8; nsCSSPropertyID::eCSSProperty__moz_box_align as usize]>([0; 60]); // -moz-box-align
    std::mem::transmute::<[u8; 61], [u8; nsCSSPropertyID::eCSSProperty__moz_box_collapse as usize]>([0; 61]); // -moz-box-collapse
    std::mem::transmute::<[u8; 62], [u8; nsCSSPropertyID::eCSSProperty__moz_box_direction as usize]>([0; 62]); // -moz-box-direction
    std::mem::transmute::<[u8; 63], [u8; nsCSSPropertyID::eCSSProperty__moz_box_orient as usize]>([0; 63]); // -moz-box-orient
    std::mem::transmute::<[u8; 64], [u8; nsCSSPropertyID::eCSSProperty__moz_box_pack as usize]>([0; 64]); // -moz-box-pack
    std::mem::transmute::<[u8; 65], [u8; nsCSSPropertyID::eCSSProperty__moz_control_character_visibility as usize]>([0; 65]); // -moz-control-character-visibility
    std::mem::transmute::<[u8; 66], [u8; nsCSSPropertyID::eCSSProperty__moz_float_edge as usize]>([0; 66]); // -moz-float-edge
    std::mem::transmute::<[u8; 67], [u8; nsCSSPropertyID::eCSSProperty__moz_inert as usize]>([0; 67]); // -moz-inert
    std::mem::transmute::<[u8; 68], [u8; nsCSSPropertyID::eCSSProperty__moz_math_variant as usize]>([0; 68]); // -moz-math-variant
    std::mem::transmute::<[u8; 69], [u8; nsCSSPropertyID::eCSSProperty__moz_min_font_size_ratio as usize]>([0; 69]); // -moz-min-font-size-ratio
    std::mem::transmute::<[u8; 70], [u8; nsCSSPropertyID::eCSSProperty__moz_orient as usize]>([0; 70]); // -moz-orient
    std::mem::transmute::<[u8; 71], [u8; nsCSSPropertyID::eCSSProperty__moz_osx_font_smoothing as usize]>([0; 71]); // -moz-osx-font-smoothing
    std::mem::transmute::<[u8; 72], [u8; nsCSSPropertyID::eCSSProperty__moz_text_size_adjust as usize]>([0; 72]); // -moz-text-size-adjust
    std::mem::transmute::<[u8; 73], [u8; nsCSSPropertyID::eCSSProperty__moz_theme as usize]>([0; 73]); // -moz-theme
    std::mem::transmute::<[u8; 74], [u8; nsCSSPropertyID::eCSSProperty__moz_top_layer as usize]>([0; 74]); // -moz-top-layer
    std::mem::transmute::<[u8; 75], [u8; nsCSSPropertyID::eCSSProperty__moz_user_focus as usize]>([0; 75]); // -moz-user-focus
    std::mem::transmute::<[u8; 76], [u8; nsCSSPropertyID::eCSSProperty__moz_user_input as usize]>([0; 76]); // -moz-user-input
    std::mem::transmute::<[u8; 77], [u8; nsCSSPropertyID::eCSSProperty__moz_user_modify as usize]>([0; 77]); // -moz-user-modify
    std::mem::transmute::<[u8; 78], [u8; nsCSSPropertyID::eCSSProperty__moz_window_dragging as usize]>([0; 78]); // -moz-window-dragging
    std::mem::transmute::<[u8; 79], [u8; nsCSSPropertyID::eCSSProperty__moz_window_shadow as usize]>([0; 79]); // -moz-window-shadow
    std::mem::transmute::<[u8; 80], [u8; nsCSSPropertyID::eCSSProperty_object_fit as usize]>([0; 80]); // object-fit
    std::mem::transmute::<[u8; 81], [u8; nsCSSPropertyID::eCSSProperty_offset_rotate as usize]>([0; 81]); // offset-rotate
    std::mem::transmute::<[u8; 82], [u8; nsCSSPropertyID::eCSSProperty_outline_style as usize]>([0; 82]); // outline-style
    std::mem::transmute::<[u8; 83], [u8; nsCSSPropertyID::eCSSProperty_overflow_anchor as usize]>([0; 83]); // overflow-anchor
    std::mem::transmute::<[u8; 84], [u8; nsCSSPropertyID::eCSSProperty_overflow_wrap as usize]>([0; 84]); // overflow-wrap
    std::mem::transmute::<[u8; 85], [u8; nsCSSPropertyID::eCSSProperty_page_orientation as usize]>([0; 85]); // page-orientation
    std::mem::transmute::<[u8; 86], [u8; nsCSSPropertyID::eCSSProperty_paint_order as usize]>([0; 86]); // paint-order
    std::mem::transmute::<[u8; 87], [u8; nsCSSPropertyID::eCSSProperty_pointer_events as usize]>([0; 87]); // pointer-events
    std::mem::transmute::<[u8; 88], [u8; nsCSSPropertyID::eCSSProperty_position as usize]>([0; 88]); // position
    std::mem::transmute::<[u8; 89], [u8; nsCSSPropertyID::eCSSProperty_position_try_order as usize]>([0; 89]); // position-try-order
    std::mem::transmute::<[u8; 90], [u8; nsCSSPropertyID::eCSSProperty_position_visibility as usize]>([0; 90]); // position-visibility
    std::mem::transmute::<[u8; 91], [u8; nsCSSPropertyID::eCSSProperty_print_color_adjust as usize]>([0; 91]); // print-color-adjust
    std::mem::transmute::<[u8; 92], [u8; nsCSSPropertyID::eCSSProperty_resize as usize]>([0; 92]); // resize
    std::mem::transmute::<[u8; 93], [u8; nsCSSPropertyID::eCSSProperty_ruby_align as usize]>([0; 93]); // ruby-align
    std::mem::transmute::<[u8; 94], [u8; nsCSSPropertyID::eCSSProperty_ruby_position as usize]>([0; 94]); // ruby-position
    std::mem::transmute::<[u8; 95], [u8; nsCSSPropertyID::eCSSProperty_scroll_behavior as usize]>([0; 95]); // scroll-behavior
    std::mem::transmute::<[u8; 96], [u8; nsCSSPropertyID::eCSSProperty_scroll_snap_align as usize]>([0; 96]); // scroll-snap-align
    std::mem::transmute::<[u8; 97], [u8; nsCSSPropertyID::eCSSProperty_scroll_snap_stop as usize]>([0; 97]); // scroll-snap-stop
    std::mem::transmute::<[u8; 98], [u8; nsCSSPropertyID::eCSSProperty_scroll_snap_type as usize]>([0; 98]); // scroll-snap-type
    std::mem::transmute::<[u8; 99], [u8; nsCSSPropertyID::eCSSProperty_scrollbar_gutter as usize]>([0; 99]); // scrollbar-gutter
    std::mem::transmute::<[u8; 100], [u8; nsCSSPropertyID::eCSSProperty_scrollbar_width as usize]>([0; 100]); // scrollbar-width
    std::mem::transmute::<[u8; 101], [u8; nsCSSPropertyID::eCSSProperty_shape_rendering as usize]>([0; 101]); // shape-rendering
    std::mem::transmute::<[u8; 102], [u8; nsCSSPropertyID::eCSSProperty_stroke_linecap as usize]>([0; 102]); // stroke-linecap
    std::mem::transmute::<[u8; 103], [u8; nsCSSPropertyID::eCSSProperty_stroke_linejoin as usize]>([0; 103]); // stroke-linejoin
    std::mem::transmute::<[u8; 104], [u8; nsCSSPropertyID::eCSSProperty_table_layout as usize]>([0; 104]); // table-layout
    std::mem::transmute::<[u8; 105], [u8; nsCSSPropertyID::eCSSProperty_text_align as usize]>([0; 105]); // text-align
    std::mem::transmute::<[u8; 106], [u8; nsCSSPropertyID::eCSSProperty_text_align_last as usize]>([0; 106]); // text-align-last
    std::mem::transmute::<[u8; 107], [u8; nsCSSPropertyID::eCSSProperty_text_anchor as usize]>([0; 107]); // text-anchor
    std::mem::transmute::<[u8; 108], [u8; nsCSSPropertyID::eCSSProperty_text_combine_upright as usize]>([0; 108]); // text-combine-upright
    std::mem::transmute::<[u8; 109], [u8; nsCSSPropertyID::eCSSProperty_text_decoration_line as usize]>([0; 109]); // text-decoration-line
    std::mem::transmute::<[u8; 110], [u8; nsCSSPropertyID::eCSSProperty_text_decoration_skip_ink as usize]>([0; 110]); // text-decoration-skip-ink
    std::mem::transmute::<[u8; 111], [u8; nsCSSPropertyID::eCSSProperty_text_decoration_style as usize]>([0; 111]); // text-decoration-style
    std::mem::transmute::<[u8; 112], [u8; nsCSSPropertyID::eCSSProperty_text_emphasis_position as usize]>([0; 112]); // text-emphasis-position
    std::mem::transmute::<[u8; 113], [u8; nsCSSPropertyID::eCSSProperty_text_justify as usize]>([0; 113]); // text-justify
    std::mem::transmute::<[u8; 114], [u8; nsCSSPropertyID::eCSSProperty_text_orientation as usize]>([0; 114]); // text-orientation
    std::mem::transmute::<[u8; 115], [u8; nsCSSPropertyID::eCSSProperty_text_rendering as usize]>([0; 115]); // text-rendering
    std::mem::transmute::<[u8; 116], [u8; nsCSSPropertyID::eCSSProperty_text_transform as usize]>([0; 116]); // text-transform
    std::mem::transmute::<[u8; 117], [u8; nsCSSPropertyID::eCSSProperty_text_underline_position as usize]>([0; 117]); // text-underline-position
    std::mem::transmute::<[u8; 118], [u8; nsCSSPropertyID::eCSSProperty_text_wrap_mode as usize]>([0; 118]); // text-wrap-mode
    std::mem::transmute::<[u8; 119], [u8; nsCSSPropertyID::eCSSProperty_text_wrap_style as usize]>([0; 119]); // text-wrap-style
    std::mem::transmute::<[u8; 120], [u8; nsCSSPropertyID::eCSSProperty_touch_action as usize]>([0; 120]); // touch-action
    std::mem::transmute::<[u8; 121], [u8; nsCSSPropertyID::eCSSProperty_transform_box as usize]>([0; 121]); // transform-box
    std::mem::transmute::<[u8; 122], [u8; nsCSSPropertyID::eCSSProperty_transform_style as usize]>([0; 122]); // transform-style
    std::mem::transmute::<[u8; 123], [u8; nsCSSPropertyID::eCSSProperty_unicode_bidi as usize]>([0; 123]); // unicode-bidi
    std::mem::transmute::<[u8; 124], [u8; nsCSSPropertyID::eCSSProperty_user_select as usize]>([0; 124]); // user-select
    std::mem::transmute::<[u8; 125], [u8; nsCSSPropertyID::eCSSProperty_vector_effect as usize]>([0; 125]); // vector-effect
    std::mem::transmute::<[u8; 126], [u8; nsCSSPropertyID::eCSSProperty_visibility as usize]>([0; 126]); // visibility
    std::mem::transmute::<[u8; 127], [u8; nsCSSPropertyID::eCSSProperty__webkit_line_clamp as usize]>([0; 127]); // -webkit-line-clamp
    std::mem::transmute::<[u8; 128], [u8; nsCSSPropertyID::eCSSProperty__webkit_text_security as usize]>([0; 128]); // -webkit-text-security
    std::mem::transmute::<[u8; 129], [u8; nsCSSPropertyID::eCSSProperty_white_space_collapse as usize]>([0; 129]); // white-space-collapse
    std::mem::transmute::<[u8; 130], [u8; nsCSSPropertyID::eCSSProperty_word_break as usize]>([0; 130]); // word-break
    std::mem::transmute::<[u8; 131], [u8; nsCSSPropertyID::eCSSProperty_writing_mode as usize]>([0; 131]); // writing-mode
    std::mem::transmute::<[u8; 132], [u8; nsCSSPropertyID::eCSSProperty__x_text_scale as usize]>([0; 132]); // -x-text-scale
    std::mem::transmute::<[u8; 133], [u8; nsCSSPropertyID::eCSSProperty_z_index as usize]>([0; 133]); // z-index
    std::mem::transmute::<[u8; 134], [u8; nsCSSPropertyID::eCSSProperty_zoom as usize]>([0; 134]); // zoom
    std::mem::transmute::<[u8; 135], [u8; nsCSSPropertyID::eCSSProperty_appearance as usize]>([0; 135]); // appearance
    std::mem::transmute::<[u8; 136], [u8; nsCSSPropertyID::eCSSProperty__moz_default_appearance as usize]>([0; 136]); // -moz-default-appearance
    std::mem::transmute::<[u8; 137], [u8; nsCSSPropertyID::eCSSProperty__moz_force_broken_image_icon as usize]>([0; 137]); // -moz-force-broken-image-icon
    std::mem::transmute::<[u8; 138], [u8; nsCSSPropertyID::eCSSProperty__moz_subtree_hidden_only_visually as usize]>([0; 138]); // -moz-subtree-hidden-only-visually
    std::mem::transmute::<[u8; 139], [u8; nsCSSPropertyID::eCSSProperty_break_after as usize]>([0; 139]); // break-after
    std::mem::transmute::<[u8; 140], [u8; nsCSSPropertyID::eCSSProperty_break_before as usize]>([0; 140]); // break-before
    std::mem::transmute::<[u8; 141], [u8; nsCSSPropertyID::eCSSProperty_clip_rule as usize]>([0; 141]); // clip-rule
    std::mem::transmute::<[u8; 142], [u8; nsCSSPropertyID::eCSSProperty_fill_rule as usize]>([0; 142]); // fill-rule
    std::mem::transmute::<[u8; 143], [u8; nsCSSPropertyID::eCSSProperty_overflow_clip_box_block as usize]>([0; 143]); // overflow-clip-box-block
    std::mem::transmute::<[u8; 144], [u8; nsCSSPropertyID::eCSSProperty_overflow_clip_box_inline as usize]>([0; 144]); // overflow-clip-box-inline
    std::mem::transmute::<[u8; 145], [u8; nsCSSPropertyID::eCSSProperty_fill_opacity as usize]>([0; 145]); // fill-opacity
    std::mem::transmute::<[u8; 146], [u8; nsCSSPropertyID::eCSSProperty_stroke_opacity as usize]>([0; 146]); // stroke-opacity
    std::mem::transmute::<[u8; 147], [u8; nsCSSPropertyID::eCSSProperty__moz_box_ordinal_group as usize]>([0; 147]); // -moz-box-ordinal-group
    std::mem::transmute::<[u8; 148], [u8; nsCSSPropertyID::eCSSProperty_order as usize]>([0; 148]); // order
    std::mem::transmute::<[u8; 149], [u8; nsCSSPropertyID::eCSSProperty__x_span as usize]>([0; 149]); // -x-span
    std::mem::transmute::<[u8; 150], [u8; nsCSSPropertyID::eCSSProperty_font_synthesis_position as usize]>([0; 150]); // font-synthesis-position
    std::mem::transmute::<[u8; 151], [u8; nsCSSPropertyID::eCSSProperty_font_synthesis_small_caps as usize]>([0; 151]); // font-synthesis-small-caps
    std::mem::transmute::<[u8; 152], [u8; nsCSSPropertyID::eCSSProperty_font_synthesis_style as usize]>([0; 152]); // font-synthesis-style
    std::mem::transmute::<[u8; 153], [u8; nsCSSPropertyID::eCSSProperty_font_synthesis_weight as usize]>([0; 153]); // font-synthesis-weight
    std::mem::transmute::<[u8; 154], [u8; nsCSSPropertyID::eCSSProperty_flex_grow as usize]>([0; 154]); // flex-grow
    std::mem::transmute::<[u8; 155], [u8; nsCSSPropertyID::eCSSProperty_flex_shrink as usize]>([0; 155]); // flex-shrink
    std::mem::transmute::<[u8; 156], [u8; nsCSSPropertyID::eCSSProperty__moz_box_flex as usize]>([0; 156]); // -moz-box-flex
    std::mem::transmute::<[u8; 157], [u8; nsCSSPropertyID::eCSSProperty_stroke_miterlimit as usize]>([0; 157]); // stroke-miterlimit
    std::mem::transmute::<[u8; 158], [u8; nsCSSPropertyID::eCSSProperty_overflow_block as usize]>([0; 158]); // overflow-block
    std::mem::transmute::<[u8; 159], [u8; nsCSSPropertyID::eCSSProperty_overflow_inline as usize]>([0; 159]); // overflow-inline
    std::mem::transmute::<[u8; 160], [u8; nsCSSPropertyID::eCSSProperty_overflow_x as usize]>([0; 160]); // overflow-x
    std::mem::transmute::<[u8; 161], [u8; nsCSSPropertyID::eCSSProperty_overflow_y as usize]>([0; 161]); // overflow-y
    std::mem::transmute::<[u8; 162], [u8; nsCSSPropertyID::eCSSProperty_overscroll_behavior_block as usize]>([0; 162]); // overscroll-behavior-block
    std::mem::transmute::<[u8; 163], [u8; nsCSSPropertyID::eCSSProperty_overscroll_behavior_inline as usize]>([0; 163]); // overscroll-behavior-inline
    std::mem::transmute::<[u8; 164], [u8; nsCSSPropertyID::eCSSProperty_overscroll_behavior_x as usize]>([0; 164]); // overscroll-behavior-x
    std::mem::transmute::<[u8; 165], [u8; nsCSSPropertyID::eCSSProperty_overscroll_behavior_y as usize]>([0; 165]); // overscroll-behavior-y
    std::mem::transmute::<[u8; 166], [u8; nsCSSPropertyID::eCSSProperty_flood_opacity as usize]>([0; 166]); // flood-opacity
    std::mem::transmute::<[u8; 167], [u8; nsCSSPropertyID::eCSSProperty__moz_window_opacity as usize]>([0; 167]); // -moz-window-opacity
    std::mem::transmute::<[u8; 168], [u8; nsCSSPropertyID::eCSSProperty_opacity as usize]>([0; 168]); // opacity
    std::mem::transmute::<[u8; 169], [u8; nsCSSPropertyID::eCSSProperty_shape_image_threshold as usize]>([0; 169]); // shape-image-threshold
    std::mem::transmute::<[u8; 170], [u8; nsCSSPropertyID::eCSSProperty_stop_opacity as usize]>([0; 170]); // stop-opacity
    std::mem::transmute::<[u8; 171], [u8; nsCSSPropertyID::eCSSProperty_border_block_end_style as usize]>([0; 171]); // border-block-end-style
    std::mem::transmute::<[u8; 172], [u8; nsCSSPropertyID::eCSSProperty_border_block_start_style as usize]>([0; 172]); // border-block-start-style
    std::mem::transmute::<[u8; 173], [u8; nsCSSPropertyID::eCSSProperty_border_bottom_style as usize]>([0; 173]); // border-bottom-style
    std::mem::transmute::<[u8; 174], [u8; nsCSSPropertyID::eCSSProperty_border_inline_end_style as usize]>([0; 174]); // border-inline-end-style
    std::mem::transmute::<[u8; 175], [u8; nsCSSPropertyID::eCSSProperty_border_inline_start_style as usize]>([0; 175]); // border-inline-start-style
    std::mem::transmute::<[u8; 176], [u8; nsCSSPropertyID::eCSSProperty_border_left_style as usize]>([0; 176]); // border-left-style
    std::mem::transmute::<[u8; 177], [u8; nsCSSPropertyID::eCSSProperty_border_right_style as usize]>([0; 177]); // border-right-style
    std::mem::transmute::<[u8; 178], [u8; nsCSSPropertyID::eCSSProperty_border_top_style as usize]>([0; 178]); // border-top-style
    std::mem::transmute::<[u8; 179], [u8; nsCSSPropertyID::eCSSProperty_column_rule_style as usize]>([0; 179]); // column-rule-style
    std::mem::transmute::<[u8; 180], [u8; nsCSSPropertyID::eCSSProperty_accent_color as usize]>([0; 180]); // accent-color
    std::mem::transmute::<[u8; 181], [u8; nsCSSPropertyID::eCSSProperty_anchor_name as usize]>([0; 181]); // anchor-name
    std::mem::transmute::<[u8; 182], [u8; nsCSSPropertyID::eCSSProperty_anchor_scope as usize]>([0; 182]); // anchor-scope
    std::mem::transmute::<[u8; 183], [u8; nsCSSPropertyID::eCSSProperty_animation_composition as usize]>([0; 183]); // animation-composition
    std::mem::transmute::<[u8; 184], [u8; nsCSSPropertyID::eCSSProperty_animation_delay as usize]>([0; 184]); // animation-delay
    std::mem::transmute::<[u8; 185], [u8; nsCSSPropertyID::eCSSProperty_animation_direction as usize]>([0; 185]); // animation-direction
    std::mem::transmute::<[u8; 186], [u8; nsCSSPropertyID::eCSSProperty_animation_duration as usize]>([0; 186]); // animation-duration
    std::mem::transmute::<[u8; 187], [u8; nsCSSPropertyID::eCSSProperty_animation_fill_mode as usize]>([0; 187]); // animation-fill-mode
    std::mem::transmute::<[u8; 188], [u8; nsCSSPropertyID::eCSSProperty_animation_iteration_count as usize]>([0; 188]); // animation-iteration-count
    std::mem::transmute::<[u8; 189], [u8; nsCSSPropertyID::eCSSProperty_animation_name as usize]>([0; 189]); // animation-name
    std::mem::transmute::<[u8; 190], [u8; nsCSSPropertyID::eCSSProperty_animation_play_state as usize]>([0; 190]); // animation-play-state
    std::mem::transmute::<[u8; 191], [u8; nsCSSPropertyID::eCSSProperty_animation_timeline as usize]>([0; 191]); // animation-timeline
    std::mem::transmute::<[u8; 192], [u8; nsCSSPropertyID::eCSSProperty_animation_timing_function as usize]>([0; 192]); // animation-timing-function
    std::mem::transmute::<[u8; 193], [u8; nsCSSPropertyID::eCSSProperty_backdrop_filter as usize]>([0; 193]); // backdrop-filter
    std::mem::transmute::<[u8; 194], [u8; nsCSSPropertyID::eCSSProperty_background_attachment as usize]>([0; 194]); // background-attachment
    std::mem::transmute::<[u8; 195], [u8; nsCSSPropertyID::eCSSProperty_background_blend_mode as usize]>([0; 195]); // background-blend-mode
    std::mem::transmute::<[u8; 196], [u8; nsCSSPropertyID::eCSSProperty_background_clip as usize]>([0; 196]); // background-clip
    std::mem::transmute::<[u8; 197], [u8; nsCSSPropertyID::eCSSProperty_background_image as usize]>([0; 197]); // background-image
    std::mem::transmute::<[u8; 198], [u8; nsCSSPropertyID::eCSSProperty_background_origin as usize]>([0; 198]); // background-origin
    std::mem::transmute::<[u8; 199], [u8; nsCSSPropertyID::eCSSProperty_background_position_x as usize]>([0; 199]); // background-position-x
    std::mem::transmute::<[u8; 200], [u8; nsCSSPropertyID::eCSSProperty_background_position_y as usize]>([0; 200]); // background-position-y
    std::mem::transmute::<[u8; 201], [u8; nsCSSPropertyID::eCSSProperty_background_repeat as usize]>([0; 201]); // background-repeat
    std::mem::transmute::<[u8; 202], [u8; nsCSSPropertyID::eCSSProperty_background_size as usize]>([0; 202]); // background-size
    std::mem::transmute::<[u8; 203], [u8; nsCSSPropertyID::eCSSProperty_border_image_outset as usize]>([0; 203]); // border-image-outset
    std::mem::transmute::<[u8; 204], [u8; nsCSSPropertyID::eCSSProperty_border_image_slice as usize]>([0; 204]); // border-image-slice
    std::mem::transmute::<[u8; 205], [u8; nsCSSPropertyID::eCSSProperty_border_image_width as usize]>([0; 205]); // border-image-width
    std::mem::transmute::<[u8; 206], [u8; nsCSSPropertyID::eCSSProperty_border_spacing as usize]>([0; 206]); // border-spacing
    std::mem::transmute::<[u8; 207], [u8; nsCSSPropertyID::eCSSProperty_box_shadow as usize]>([0; 207]); // box-shadow
    std::mem::transmute::<[u8; 208], [u8; nsCSSPropertyID::eCSSProperty_caret_color as usize]>([0; 208]); // caret-color
    std::mem::transmute::<[u8; 209], [u8; nsCSSPropertyID::eCSSProperty_clip as usize]>([0; 209]); // clip
    std::mem::transmute::<[u8; 210], [u8; nsCSSPropertyID::eCSSProperty_clip_path as usize]>([0; 210]); // clip-path
    std::mem::transmute::<[u8; 211], [u8; nsCSSPropertyID::eCSSProperty_color as usize]>([0; 211]); // color
    std::mem::transmute::<[u8; 212], [u8; nsCSSPropertyID::eCSSProperty_color_scheme as usize]>([0; 212]); // color-scheme
    std::mem::transmute::<[u8; 213], [u8; nsCSSPropertyID::eCSSProperty_column_width as usize]>([0; 213]); // column-width
    std::mem::transmute::<[u8; 214], [u8; nsCSSPropertyID::eCSSProperty_container_name as usize]>([0; 214]); // container-name
    std::mem::transmute::<[u8; 215], [u8; nsCSSPropertyID::eCSSProperty_content as usize]>([0; 215]); // content
    std::mem::transmute::<[u8; 216], [u8; nsCSSPropertyID::eCSSProperty_counter_increment as usize]>([0; 216]); // counter-increment
    std::mem::transmute::<[u8; 217], [u8; nsCSSPropertyID::eCSSProperty_counter_reset as usize]>([0; 217]); // counter-reset
    std::mem::transmute::<[u8; 218], [u8; nsCSSPropertyID::eCSSProperty_counter_set as usize]>([0; 218]); // counter-set
    std::mem::transmute::<[u8; 219], [u8; nsCSSPropertyID::eCSSProperty_cursor as usize]>([0; 219]); // cursor
    std::mem::transmute::<[u8; 220], [u8; nsCSSPropertyID::eCSSProperty_d as usize]>([0; 220]); // d
    std::mem::transmute::<[u8; 221], [u8; nsCSSPropertyID::eCSSProperty_filter as usize]>([0; 221]); // filter
    std::mem::transmute::<[u8; 222], [u8; nsCSSPropertyID::eCSSProperty_flex_basis as usize]>([0; 222]); // flex-basis
    std::mem::transmute::<[u8; 223], [u8; nsCSSPropertyID::eCSSProperty_font_family as usize]>([0; 223]); // font-family
    std::mem::transmute::<[u8; 224], [u8; nsCSSPropertyID::eCSSProperty_font_feature_settings as usize]>([0; 224]); // font-feature-settings
    std::mem::transmute::<[u8; 225], [u8; nsCSSPropertyID::eCSSProperty_font_palette as usize]>([0; 225]); // font-palette
    std::mem::transmute::<[u8; 226], [u8; nsCSSPropertyID::eCSSProperty_font_size as usize]>([0; 226]); // font-size
    std::mem::transmute::<[u8; 227], [u8; nsCSSPropertyID::eCSSProperty_font_variant_alternates as usize]>([0; 227]); // font-variant-alternates
    std::mem::transmute::<[u8; 228], [u8; nsCSSPropertyID::eCSSProperty_font_variation_settings as usize]>([0; 228]); // font-variation-settings
    std::mem::transmute::<[u8; 229], [u8; nsCSSPropertyID::eCSSProperty_grid_template_areas as usize]>([0; 229]); // grid-template-areas
    std::mem::transmute::<[u8; 230], [u8; nsCSSPropertyID::eCSSProperty_hyphenate_character as usize]>([0; 230]); // hyphenate-character
    std::mem::transmute::<[u8; 231], [u8; nsCSSPropertyID::eCSSProperty_letter_spacing as usize]>([0; 231]); // letter-spacing
    std::mem::transmute::<[u8; 232], [u8; nsCSSPropertyID::eCSSProperty_line_height as usize]>([0; 232]); // line-height
    std::mem::transmute::<[u8; 233], [u8; nsCSSPropertyID::eCSSProperty_list_style_type as usize]>([0; 233]); // list-style-type
    std::mem::transmute::<[u8; 234], [u8; nsCSSPropertyID::eCSSProperty_mask_clip as usize]>([0; 234]); // mask-clip
    std::mem::transmute::<[u8; 235], [u8; nsCSSPropertyID::eCSSProperty_mask_composite as usize]>([0; 235]); // mask-composite
    std::mem::transmute::<[u8; 236], [u8; nsCSSPropertyID::eCSSProperty_mask_image as usize]>([0; 236]); // mask-image
    std::mem::transmute::<[u8; 237], [u8; nsCSSPropertyID::eCSSProperty_mask_mode as usize]>([0; 237]); // mask-mode
    std::mem::transmute::<[u8; 238], [u8; nsCSSPropertyID::eCSSProperty_mask_origin as usize]>([0; 238]); // mask-origin
    std::mem::transmute::<[u8; 239], [u8; nsCSSPropertyID::eCSSProperty_mask_position_x as usize]>([0; 239]); // mask-position-x
    std::mem::transmute::<[u8; 240], [u8; nsCSSPropertyID::eCSSProperty_mask_position_y as usize]>([0; 240]); // mask-position-y
    std::mem::transmute::<[u8; 241], [u8; nsCSSPropertyID::eCSSProperty_mask_repeat as usize]>([0; 241]); // mask-repeat
    std::mem::transmute::<[u8; 242], [u8; nsCSSPropertyID::eCSSProperty_mask_size as usize]>([0; 242]); // mask-size
    std::mem::transmute::<[u8; 243], [u8; nsCSSPropertyID::eCSSProperty__moz_context_properties as usize]>([0; 243]); // -moz-context-properties
    std::mem::transmute::<[u8; 244], [u8; nsCSSPropertyID::eCSSProperty_offset_anchor as usize]>([0; 244]); // offset-anchor
    std::mem::transmute::<[u8; 245], [u8; nsCSSPropertyID::eCSSProperty_offset_path as usize]>([0; 245]); // offset-path
    std::mem::transmute::<[u8; 246], [u8; nsCSSPropertyID::eCSSProperty_offset_position as usize]>([0; 246]); // offset-position
    std::mem::transmute::<[u8; 247], [u8; nsCSSPropertyID::eCSSProperty_page as usize]>([0; 247]); // page
    std::mem::transmute::<[u8; 248], [u8; nsCSSPropertyID::eCSSProperty_perspective as usize]>([0; 248]); // perspective
    std::mem::transmute::<[u8; 249], [u8; nsCSSPropertyID::eCSSProperty_position_anchor as usize]>([0; 249]); // position-anchor
    std::mem::transmute::<[u8; 250], [u8; nsCSSPropertyID::eCSSProperty_position_try_options as usize]>([0; 250]); // position-try-options
    std::mem::transmute::<[u8; 251], [u8; nsCSSPropertyID::eCSSProperty_quotes as usize]>([0; 251]); // quotes
    std::mem::transmute::<[u8; 252], [u8; nsCSSPropertyID::eCSSProperty_rotate as usize]>([0; 252]); // rotate
    std::mem::transmute::<[u8; 253], [u8; nsCSSPropertyID::eCSSProperty_scale as usize]>([0; 253]); // scale
    std::mem::transmute::<[u8; 254], [u8; nsCSSPropertyID::eCSSProperty_scroll_timeline_axis as usize]>([0; 254]); // scroll-timeline-axis
    std::mem::transmute::<[u8; 255], [u8; nsCSSPropertyID::eCSSProperty_scroll_timeline_name as usize]>([0; 255]); // scroll-timeline-name
    std::mem::transmute::<[u8; 256], [u8; nsCSSPropertyID::eCSSProperty_scrollbar_color as usize]>([0; 256]); // scrollbar-color
    std::mem::transmute::<[u8; 257], [u8; nsCSSPropertyID::eCSSProperty_shape_outside as usize]>([0; 257]); // shape-outside
    std::mem::transmute::<[u8; 258], [u8; nsCSSPropertyID::eCSSProperty_size as usize]>([0; 258]); // size
    std::mem::transmute::<[u8; 259], [u8; nsCSSPropertyID::eCSSProperty_stroke_dasharray as usize]>([0; 259]); // stroke-dasharray
    std::mem::transmute::<[u8; 260], [u8; nsCSSPropertyID::eCSSProperty_stroke_dashoffset as usize]>([0; 260]); // stroke-dashoffset
    std::mem::transmute::<[u8; 261], [u8; nsCSSPropertyID::eCSSProperty_stroke_width as usize]>([0; 261]); // stroke-width
    std::mem::transmute::<[u8; 262], [u8; nsCSSPropertyID::eCSSProperty_tab_size as usize]>([0; 262]); // tab-size
    std::mem::transmute::<[u8; 263], [u8; nsCSSPropertyID::eCSSProperty_text_decoration_thickness as usize]>([0; 263]); // text-decoration-thickness
    std::mem::transmute::<[u8; 264], [u8; nsCSSPropertyID::eCSSProperty_text_emphasis_style as usize]>([0; 264]); // text-emphasis-style
    std::mem::transmute::<[u8; 265], [u8; nsCSSPropertyID::eCSSProperty_text_indent as usize]>([0; 265]); // text-indent
    std::mem::transmute::<[u8; 266], [u8; nsCSSPropertyID::eCSSProperty_text_overflow as usize]>([0; 266]); // text-overflow
    std::mem::transmute::<[u8; 267], [u8; nsCSSPropertyID::eCSSProperty_text_shadow as usize]>([0; 267]); // text-shadow
    std::mem::transmute::<[u8; 268], [u8; nsCSSPropertyID::eCSSProperty_transition_behavior as usize]>([0; 268]); // transition-behavior
    std::mem::transmute::<[u8; 269], [u8; nsCSSPropertyID::eCSSProperty_transition_delay as usize]>([0; 269]); // transition-delay
    std::mem::transmute::<[u8; 270], [u8; nsCSSPropertyID::eCSSProperty_transition_duration as usize]>([0; 270]); // transition-duration
    std::mem::transmute::<[u8; 271], [u8; nsCSSPropertyID::eCSSProperty_transition_property as usize]>([0; 271]); // transition-property
    std::mem::transmute::<[u8; 272], [u8; nsCSSPropertyID::eCSSProperty_transition_timing_function as usize]>([0; 272]); // transition-timing-function
    std::mem::transmute::<[u8; 273], [u8; nsCSSPropertyID::eCSSProperty_translate as usize]>([0; 273]); // translate
    std::mem::transmute::<[u8; 274], [u8; nsCSSPropertyID::eCSSProperty_vertical_align as usize]>([0; 274]); // vertical-align
    std::mem::transmute::<[u8; 275], [u8; nsCSSPropertyID::eCSSProperty_view_timeline_axis as usize]>([0; 275]); // view-timeline-axis
    std::mem::transmute::<[u8; 276], [u8; nsCSSPropertyID::eCSSProperty_view_timeline_inset as usize]>([0; 276]); // view-timeline-inset
    std::mem::transmute::<[u8; 277], [u8; nsCSSPropertyID::eCSSProperty_view_timeline_name as usize]>([0; 277]); // view-timeline-name
    std::mem::transmute::<[u8; 278], [u8; nsCSSPropertyID::eCSSProperty__webkit_text_stroke_width as usize]>([0; 278]); // -webkit-text-stroke-width
    std::mem::transmute::<[u8; 279], [u8; nsCSSPropertyID::eCSSProperty_will_change as usize]>([0; 279]); // will-change
    std::mem::transmute::<[u8; 280], [u8; nsCSSPropertyID::eCSSProperty_word_spacing as usize]>([0; 280]); // word-spacing
    std::mem::transmute::<[u8; 281], [u8; nsCSSPropertyID::eCSSProperty__x_lang as usize]>([0; 281]); // -x-lang
    std::mem::transmute::<[u8; 282], [u8; nsCSSPropertyID::eCSSProperty_object_position as usize]>([0; 282]); // object-position
    std::mem::transmute::<[u8; 283], [u8; nsCSSPropertyID::eCSSProperty_perspective_origin as usize]>([0; 283]); // perspective-origin
    std::mem::transmute::<[u8; 284], [u8; nsCSSPropertyID::eCSSProperty_fill as usize]>([0; 284]); // fill
    std::mem::transmute::<[u8; 285], [u8; nsCSSPropertyID::eCSSProperty_stroke as usize]>([0; 285]); // stroke
    std::mem::transmute::<[u8; 286], [u8; nsCSSPropertyID::eCSSProperty__moz_window_transform_origin as usize]>([0; 286]); // -moz-window-transform-origin
    std::mem::transmute::<[u8; 287], [u8; nsCSSPropertyID::eCSSProperty_transform_origin as usize]>([0; 287]); // transform-origin
    std::mem::transmute::<[u8; 288], [u8; nsCSSPropertyID::eCSSProperty_grid_template_columns as usize]>([0; 288]); // grid-template-columns
    std::mem::transmute::<[u8; 289], [u8; nsCSSPropertyID::eCSSProperty_grid_template_rows as usize]>([0; 289]); // grid-template-rows
    std::mem::transmute::<[u8; 290], [u8; nsCSSPropertyID::eCSSProperty_border_image_source as usize]>([0; 290]); // border-image-source
    std::mem::transmute::<[u8; 291], [u8; nsCSSPropertyID::eCSSProperty_list_style_image as usize]>([0; 291]); // list-style-image
    std::mem::transmute::<[u8; 292], [u8; nsCSSPropertyID::eCSSProperty_grid_auto_columns as usize]>([0; 292]); // grid-auto-columns
    std::mem::transmute::<[u8; 293], [u8; nsCSSPropertyID::eCSSProperty_grid_auto_rows as usize]>([0; 293]); // grid-auto-rows
    std::mem::transmute::<[u8; 294], [u8; nsCSSPropertyID::eCSSProperty__moz_window_transform as usize]>([0; 294]); // -moz-window-transform
    std::mem::transmute::<[u8; 295], [u8; nsCSSPropertyID::eCSSProperty_transform as usize]>([0; 295]); // transform
    std::mem::transmute::<[u8; 296], [u8; nsCSSPropertyID::eCSSProperty_column_gap as usize]>([0; 296]); // column-gap
    std::mem::transmute::<[u8; 297], [u8; nsCSSPropertyID::eCSSProperty_row_gap as usize]>([0; 297]); // row-gap
    std::mem::transmute::<[u8; 298], [u8; nsCSSPropertyID::eCSSProperty_marker_end as usize]>([0; 298]); // marker-end
    std::mem::transmute::<[u8; 299], [u8; nsCSSPropertyID::eCSSProperty_marker_mid as usize]>([0; 299]); // marker-mid
    std::mem::transmute::<[u8; 300], [u8; nsCSSPropertyID::eCSSProperty_marker_start as usize]>([0; 300]); // marker-start
    std::mem::transmute::<[u8; 301], [u8; nsCSSPropertyID::eCSSProperty_contain_intrinsic_block_size as usize]>([0; 301]); // contain-intrinsic-block-size
    std::mem::transmute::<[u8; 302], [u8; nsCSSPropertyID::eCSSProperty_contain_intrinsic_height as usize]>([0; 302]); // contain-intrinsic-height
    std::mem::transmute::<[u8; 303], [u8; nsCSSPropertyID::eCSSProperty_contain_intrinsic_inline_size as usize]>([0; 303]); // contain-intrinsic-inline-size
    std::mem::transmute::<[u8; 304], [u8; nsCSSPropertyID::eCSSProperty_contain_intrinsic_width as usize]>([0; 304]); // contain-intrinsic-width
    std::mem::transmute::<[u8; 305], [u8; nsCSSPropertyID::eCSSProperty_grid_column_end as usize]>([0; 305]); // grid-column-end
    std::mem::transmute::<[u8; 306], [u8; nsCSSPropertyID::eCSSProperty_grid_column_start as usize]>([0; 306]); // grid-column-start
    std::mem::transmute::<[u8; 307], [u8; nsCSSPropertyID::eCSSProperty_grid_row_end as usize]>([0; 307]); // grid-row-end
    std::mem::transmute::<[u8; 308], [u8; nsCSSPropertyID::eCSSProperty_grid_row_start as usize]>([0; 308]); // grid-row-start
    std::mem::transmute::<[u8; 309], [u8; nsCSSPropertyID::eCSSProperty_max_block_size as usize]>([0; 309]); // max-block-size
    std::mem::transmute::<[u8; 310], [u8; nsCSSPropertyID::eCSSProperty_max_height as usize]>([0; 310]); // max-height
    std::mem::transmute::<[u8; 311], [u8; nsCSSPropertyID::eCSSProperty_max_inline_size as usize]>([0; 311]); // max-inline-size
    std::mem::transmute::<[u8; 312], [u8; nsCSSPropertyID::eCSSProperty_max_width as usize]>([0; 312]); // max-width
    std::mem::transmute::<[u8; 313], [u8; nsCSSPropertyID::eCSSProperty_cx as usize]>([0; 313]); // cx
    std::mem::transmute::<[u8; 314], [u8; nsCSSPropertyID::eCSSProperty_cy as usize]>([0; 314]); // cy
    std::mem::transmute::<[u8; 315], [u8; nsCSSPropertyID::eCSSProperty_offset_distance as usize]>([0; 315]); // offset-distance
    std::mem::transmute::<[u8; 316], [u8; nsCSSPropertyID::eCSSProperty_x as usize]>([0; 316]); // x
    std::mem::transmute::<[u8; 317], [u8; nsCSSPropertyID::eCSSProperty_y as usize]>([0; 317]); // y
    std::mem::transmute::<[u8; 318], [u8; nsCSSPropertyID::eCSSProperty_border_bottom_left_radius as usize]>([0; 318]); // border-bottom-left-radius
    std::mem::transmute::<[u8; 319], [u8; nsCSSPropertyID::eCSSProperty_border_bottom_right_radius as usize]>([0; 319]); // border-bottom-right-radius
    std::mem::transmute::<[u8; 320], [u8; nsCSSPropertyID::eCSSProperty_border_end_end_radius as usize]>([0; 320]); // border-end-end-radius
    std::mem::transmute::<[u8; 321], [u8; nsCSSPropertyID::eCSSProperty_border_end_start_radius as usize]>([0; 321]); // border-end-start-radius
    std::mem::transmute::<[u8; 322], [u8; nsCSSPropertyID::eCSSProperty_border_start_end_radius as usize]>([0; 322]); // border-start-end-radius
    std::mem::transmute::<[u8; 323], [u8; nsCSSPropertyID::eCSSProperty_border_start_start_radius as usize]>([0; 323]); // border-start-start-radius
    std::mem::transmute::<[u8; 324], [u8; nsCSSPropertyID::eCSSProperty_border_top_left_radius as usize]>([0; 324]); // border-top-left-radius
    std::mem::transmute::<[u8; 325], [u8; nsCSSPropertyID::eCSSProperty_border_top_right_radius as usize]>([0; 325]); // border-top-right-radius
    std::mem::transmute::<[u8; 326], [u8; nsCSSPropertyID::eCSSProperty_block_size as usize]>([0; 326]); // block-size
    std::mem::transmute::<[u8; 327], [u8; nsCSSPropertyID::eCSSProperty_height as usize]>([0; 327]); // height
    std::mem::transmute::<[u8; 328], [u8; nsCSSPropertyID::eCSSProperty_inline_size as usize]>([0; 328]); // inline-size
    std::mem::transmute::<[u8; 329], [u8; nsCSSPropertyID::eCSSProperty_min_block_size as usize]>([0; 329]); // min-block-size
    std::mem::transmute::<[u8; 330], [u8; nsCSSPropertyID::eCSSProperty_min_height as usize]>([0; 330]); // min-height
    std::mem::transmute::<[u8; 331], [u8; nsCSSPropertyID::eCSSProperty_min_inline_size as usize]>([0; 331]); // min-inline-size
    std::mem::transmute::<[u8; 332], [u8; nsCSSPropertyID::eCSSProperty_min_width as usize]>([0; 332]); // min-width
    std::mem::transmute::<[u8; 333], [u8; nsCSSPropertyID::eCSSProperty_width as usize]>([0; 333]); // width
    std::mem::transmute::<[u8; 334], [u8; nsCSSPropertyID::eCSSProperty_border_block_end_width as usize]>([0; 334]); // border-block-end-width
    std::mem::transmute::<[u8; 335], [u8; nsCSSPropertyID::eCSSProperty_border_block_start_width as usize]>([0; 335]); // border-block-start-width
    std::mem::transmute::<[u8; 336], [u8; nsCSSPropertyID::eCSSProperty_border_bottom_width as usize]>([0; 336]); // border-bottom-width
    std::mem::transmute::<[u8; 337], [u8; nsCSSPropertyID::eCSSProperty_border_inline_end_width as usize]>([0; 337]); // border-inline-end-width
    std::mem::transmute::<[u8; 338], [u8; nsCSSPropertyID::eCSSProperty_border_inline_start_width as usize]>([0; 338]); // border-inline-start-width
    std::mem::transmute::<[u8; 339], [u8; nsCSSPropertyID::eCSSProperty_border_left_width as usize]>([0; 339]); // border-left-width
    std::mem::transmute::<[u8; 340], [u8; nsCSSPropertyID::eCSSProperty_border_right_width as usize]>([0; 340]); // border-right-width
    std::mem::transmute::<[u8; 341], [u8; nsCSSPropertyID::eCSSProperty_border_top_width as usize]>([0; 341]); // border-top-width
    std::mem::transmute::<[u8; 342], [u8; nsCSSPropertyID::eCSSProperty_column_rule_width as usize]>([0; 342]); // column-rule-width
    std::mem::transmute::<[u8; 343], [u8; nsCSSPropertyID::eCSSProperty_outline_width as usize]>([0; 343]); // outline-width
    std::mem::transmute::<[u8; 344], [u8; nsCSSPropertyID::eCSSProperty_padding_block_end as usize]>([0; 344]); // padding-block-end
    std::mem::transmute::<[u8; 345], [u8; nsCSSPropertyID::eCSSProperty_padding_block_start as usize]>([0; 345]); // padding-block-start
    std::mem::transmute::<[u8; 346], [u8; nsCSSPropertyID::eCSSProperty_padding_bottom as usize]>([0; 346]); // padding-bottom
    std::mem::transmute::<[u8; 347], [u8; nsCSSPropertyID::eCSSProperty_padding_inline_end as usize]>([0; 347]); // padding-inline-end
    std::mem::transmute::<[u8; 348], [u8; nsCSSPropertyID::eCSSProperty_padding_inline_start as usize]>([0; 348]); // padding-inline-start
    std::mem::transmute::<[u8; 349], [u8; nsCSSPropertyID::eCSSProperty_padding_left as usize]>([0; 349]); // padding-left
    std::mem::transmute::<[u8; 350], [u8; nsCSSPropertyID::eCSSProperty_padding_right as usize]>([0; 350]); // padding-right
    std::mem::transmute::<[u8; 351], [u8; nsCSSPropertyID::eCSSProperty_padding_top as usize]>([0; 351]); // padding-top
    std::mem::transmute::<[u8; 352], [u8; nsCSSPropertyID::eCSSProperty_r as usize]>([0; 352]); // r
    std::mem::transmute::<[u8; 353], [u8; nsCSSPropertyID::eCSSProperty_shape_margin as usize]>([0; 353]); // shape-margin
    std::mem::transmute::<[u8; 354], [u8; nsCSSPropertyID::eCSSProperty_rx as usize]>([0; 354]); // rx
    std::mem::transmute::<[u8; 355], [u8; nsCSSPropertyID::eCSSProperty_ry as usize]>([0; 355]); // ry
    std::mem::transmute::<[u8; 356], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_block_end as usize]>([0; 356]); // scroll-padding-block-end
    std::mem::transmute::<[u8; 357], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_block_start as usize]>([0; 357]); // scroll-padding-block-start
    std::mem::transmute::<[u8; 358], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_bottom as usize]>([0; 358]); // scroll-padding-bottom
    std::mem::transmute::<[u8; 359], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_inline_end as usize]>([0; 359]); // scroll-padding-inline-end
    std::mem::transmute::<[u8; 360], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_inline_start as usize]>([0; 360]); // scroll-padding-inline-start
    std::mem::transmute::<[u8; 361], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_left as usize]>([0; 361]); // scroll-padding-left
    std::mem::transmute::<[u8; 362], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_right as usize]>([0; 362]); // scroll-padding-right
    std::mem::transmute::<[u8; 363], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_top as usize]>([0; 363]); // scroll-padding-top
    std::mem::transmute::<[u8; 364], [u8; nsCSSPropertyID::eCSSProperty__moz_window_input_region_margin as usize]>([0; 364]); // -moz-window-input-region-margin
    std::mem::transmute::<[u8; 365], [u8; nsCSSPropertyID::eCSSProperty_outline_offset as usize]>([0; 365]); // outline-offset
    std::mem::transmute::<[u8; 366], [u8; nsCSSPropertyID::eCSSProperty_overflow_clip_margin as usize]>([0; 366]); // overflow-clip-margin
    std::mem::transmute::<[u8; 367], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_block_end as usize]>([0; 367]); // scroll-margin-block-end
    std::mem::transmute::<[u8; 368], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_block_start as usize]>([0; 368]); // scroll-margin-block-start
    std::mem::transmute::<[u8; 369], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_bottom as usize]>([0; 369]); // scroll-margin-bottom
    std::mem::transmute::<[u8; 370], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_inline_end as usize]>([0; 370]); // scroll-margin-inline-end
    std::mem::transmute::<[u8; 371], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_inline_start as usize]>([0; 371]); // scroll-margin-inline-start
    std::mem::transmute::<[u8; 372], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_left as usize]>([0; 372]); // scroll-margin-left
    std::mem::transmute::<[u8; 373], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_right as usize]>([0; 373]); // scroll-margin-right
    std::mem::transmute::<[u8; 374], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_top as usize]>([0; 374]); // scroll-margin-top
    std::mem::transmute::<[u8; 375], [u8; nsCSSPropertyID::eCSSProperty_bottom as usize]>([0; 375]); // bottom
    std::mem::transmute::<[u8; 376], [u8; nsCSSPropertyID::eCSSProperty_inset_block_end as usize]>([0; 376]); // inset-block-end
    std::mem::transmute::<[u8; 377], [u8; nsCSSPropertyID::eCSSProperty_inset_block_start as usize]>([0; 377]); // inset-block-start
    std::mem::transmute::<[u8; 378], [u8; nsCSSPropertyID::eCSSProperty_inset_inline_end as usize]>([0; 378]); // inset-inline-end
    std::mem::transmute::<[u8; 379], [u8; nsCSSPropertyID::eCSSProperty_inset_inline_start as usize]>([0; 379]); // inset-inline-start
    std::mem::transmute::<[u8; 380], [u8; nsCSSPropertyID::eCSSProperty_left as usize]>([0; 380]); // left
    std::mem::transmute::<[u8; 381], [u8; nsCSSPropertyID::eCSSProperty_margin_block_end as usize]>([0; 381]); // margin-block-end
    std::mem::transmute::<[u8; 382], [u8; nsCSSPropertyID::eCSSProperty_margin_block_start as usize]>([0; 382]); // margin-block-start
    std::mem::transmute::<[u8; 383], [u8; nsCSSPropertyID::eCSSProperty_margin_bottom as usize]>([0; 383]); // margin-bottom
    std::mem::transmute::<[u8; 384], [u8; nsCSSPropertyID::eCSSProperty_margin_inline_end as usize]>([0; 384]); // margin-inline-end
    std::mem::transmute::<[u8; 385], [u8; nsCSSPropertyID::eCSSProperty_margin_inline_start as usize]>([0; 385]); // margin-inline-start
    std::mem::transmute::<[u8; 386], [u8; nsCSSPropertyID::eCSSProperty_margin_left as usize]>([0; 386]); // margin-left
    std::mem::transmute::<[u8; 387], [u8; nsCSSPropertyID::eCSSProperty_margin_right as usize]>([0; 387]); // margin-right
    std::mem::transmute::<[u8; 388], [u8; nsCSSPropertyID::eCSSProperty_margin_top as usize]>([0; 388]); // margin-top
    std::mem::transmute::<[u8; 389], [u8; nsCSSPropertyID::eCSSProperty_right as usize]>([0; 389]); // right
    std::mem::transmute::<[u8; 390], [u8; nsCSSPropertyID::eCSSProperty_text_underline_offset as usize]>([0; 390]); // text-underline-offset
    std::mem::transmute::<[u8; 391], [u8; nsCSSPropertyID::eCSSProperty_top as usize]>([0; 391]); // top
    std::mem::transmute::<[u8; 392], [u8; nsCSSPropertyID::eCSSProperty_background_color as usize]>([0; 392]); // background-color
    std::mem::transmute::<[u8; 393], [u8; nsCSSPropertyID::eCSSProperty_border_block_end_color as usize]>([0; 393]); // border-block-end-color
    std::mem::transmute::<[u8; 394], [u8; nsCSSPropertyID::eCSSProperty_border_block_start_color as usize]>([0; 394]); // border-block-start-color
    std::mem::transmute::<[u8; 395], [u8; nsCSSPropertyID::eCSSProperty_border_bottom_color as usize]>([0; 395]); // border-bottom-color
    std::mem::transmute::<[u8; 396], [u8; nsCSSPropertyID::eCSSProperty_border_inline_end_color as usize]>([0; 396]); // border-inline-end-color
    std::mem::transmute::<[u8; 397], [u8; nsCSSPropertyID::eCSSProperty_border_inline_start_color as usize]>([0; 397]); // border-inline-start-color
    std::mem::transmute::<[u8; 398], [u8; nsCSSPropertyID::eCSSProperty_border_left_color as usize]>([0; 398]); // border-left-color
    std::mem::transmute::<[u8; 399], [u8; nsCSSPropertyID::eCSSProperty_border_right_color as usize]>([0; 399]); // border-right-color
    std::mem::transmute::<[u8; 400], [u8; nsCSSPropertyID::eCSSProperty_border_top_color as usize]>([0; 400]); // border-top-color
    std::mem::transmute::<[u8; 401], [u8; nsCSSPropertyID::eCSSProperty_column_rule_color as usize]>([0; 401]); // column-rule-color
    std::mem::transmute::<[u8; 402], [u8; nsCSSPropertyID::eCSSProperty_flood_color as usize]>([0; 402]); // flood-color
    std::mem::transmute::<[u8; 403], [u8; nsCSSPropertyID::eCSSProperty_lighting_color as usize]>([0; 403]); // lighting-color
    std::mem::transmute::<[u8; 404], [u8; nsCSSPropertyID::eCSSProperty_outline_color as usize]>([0; 404]); // outline-color
    std::mem::transmute::<[u8; 405], [u8; nsCSSPropertyID::eCSSProperty_stop_color as usize]>([0; 405]); // stop-color
    std::mem::transmute::<[u8; 406], [u8; nsCSSPropertyID::eCSSProperty_text_decoration_color as usize]>([0; 406]); // text-decoration-color
    std::mem::transmute::<[u8; 407], [u8; nsCSSPropertyID::eCSSProperty_text_emphasis_color as usize]>([0; 407]); // text-emphasis-color
    std::mem::transmute::<[u8; 408], [u8; nsCSSPropertyID::eCSSProperty__webkit_text_fill_color as usize]>([0; 408]); // -webkit-text-fill-color
    std::mem::transmute::<[u8; 409], [u8; nsCSSPropertyID::eCSSProperty__webkit_text_stroke_color as usize]>([0; 409]); // -webkit-text-stroke-color
    std::mem::transmute::<[u8; 410], [u8; nsCSSPropertyID::eCSSProperty_background as usize]>([0; 410]); // background
    std::mem::transmute::<[u8; 411], [u8; nsCSSPropertyID::eCSSProperty_background_position as usize]>([0; 411]); // background-position
    std::mem::transmute::<[u8; 412], [u8; nsCSSPropertyID::eCSSProperty_border_color as usize]>([0; 412]); // border-color
    std::mem::transmute::<[u8; 413], [u8; nsCSSPropertyID::eCSSProperty_border_style as usize]>([0; 413]); // border-style
    std::mem::transmute::<[u8; 414], [u8; nsCSSPropertyID::eCSSProperty_border_width as usize]>([0; 414]); // border-width
    std::mem::transmute::<[u8; 415], [u8; nsCSSPropertyID::eCSSProperty_border_top as usize]>([0; 415]); // border-top
    std::mem::transmute::<[u8; 416], [u8; nsCSSPropertyID::eCSSProperty_border_right as usize]>([0; 416]); // border-right
    std::mem::transmute::<[u8; 417], [u8; nsCSSPropertyID::eCSSProperty_border_bottom as usize]>([0; 417]); // border-bottom
    std::mem::transmute::<[u8; 418], [u8; nsCSSPropertyID::eCSSProperty_border_left as usize]>([0; 418]); // border-left
    std::mem::transmute::<[u8; 419], [u8; nsCSSPropertyID::eCSSProperty_border_block_start as usize]>([0; 419]); // border-block-start
    std::mem::transmute::<[u8; 420], [u8; nsCSSPropertyID::eCSSProperty_border_block_end as usize]>([0; 420]); // border-block-end
    std::mem::transmute::<[u8; 421], [u8; nsCSSPropertyID::eCSSProperty_border_inline_start as usize]>([0; 421]); // border-inline-start
    std::mem::transmute::<[u8; 422], [u8; nsCSSPropertyID::eCSSProperty_border_inline_end as usize]>([0; 422]); // border-inline-end
    std::mem::transmute::<[u8; 423], [u8; nsCSSPropertyID::eCSSProperty_border as usize]>([0; 423]); // border
    std::mem::transmute::<[u8; 424], [u8; nsCSSPropertyID::eCSSProperty_border_radius as usize]>([0; 424]); // border-radius
    std::mem::transmute::<[u8; 425], [u8; nsCSSPropertyID::eCSSProperty_border_image as usize]>([0; 425]); // border-image
    std::mem::transmute::<[u8; 426], [u8; nsCSSPropertyID::eCSSProperty_border_block_width as usize]>([0; 426]); // border-block-width
    std::mem::transmute::<[u8; 427], [u8; nsCSSPropertyID::eCSSProperty_border_block_style as usize]>([0; 427]); // border-block-style
    std::mem::transmute::<[u8; 428], [u8; nsCSSPropertyID::eCSSProperty_border_block_color as usize]>([0; 428]); // border-block-color
    std::mem::transmute::<[u8; 429], [u8; nsCSSPropertyID::eCSSProperty_border_inline_width as usize]>([0; 429]); // border-inline-width
    std::mem::transmute::<[u8; 430], [u8; nsCSSPropertyID::eCSSProperty_border_inline_style as usize]>([0; 430]); // border-inline-style
    std::mem::transmute::<[u8; 431], [u8; nsCSSPropertyID::eCSSProperty_border_inline_color as usize]>([0; 431]); // border-inline-color
    std::mem::transmute::<[u8; 432], [u8; nsCSSPropertyID::eCSSProperty_border_block as usize]>([0; 432]); // border-block
    std::mem::transmute::<[u8; 433], [u8; nsCSSPropertyID::eCSSProperty_border_inline as usize]>([0; 433]); // border-inline
    std::mem::transmute::<[u8; 434], [u8; nsCSSPropertyID::eCSSProperty_overflow as usize]>([0; 434]); // overflow
    std::mem::transmute::<[u8; 435], [u8; nsCSSPropertyID::eCSSProperty_overflow_clip_box as usize]>([0; 435]); // overflow-clip-box
    std::mem::transmute::<[u8; 436], [u8; nsCSSPropertyID::eCSSProperty_overscroll_behavior as usize]>([0; 436]); // overscroll-behavior
    std::mem::transmute::<[u8; 437], [u8; nsCSSPropertyID::eCSSProperty_container as usize]>([0; 437]); // container
    std::mem::transmute::<[u8; 438], [u8; nsCSSPropertyID::eCSSProperty_page_break_before as usize]>([0; 438]); // page-break-before
    std::mem::transmute::<[u8; 439], [u8; nsCSSPropertyID::eCSSProperty_page_break_after as usize]>([0; 439]); // page-break-after
    std::mem::transmute::<[u8; 440], [u8; nsCSSPropertyID::eCSSProperty_page_break_inside as usize]>([0; 440]); // page-break-inside
    std::mem::transmute::<[u8; 441], [u8; nsCSSPropertyID::eCSSProperty_offset as usize]>([0; 441]); // offset
    std::mem::transmute::<[u8; 442], [u8; nsCSSPropertyID::eCSSProperty_columns as usize]>([0; 442]); // columns
    std::mem::transmute::<[u8; 443], [u8; nsCSSPropertyID::eCSSProperty_column_rule as usize]>([0; 443]); // column-rule
    std::mem::transmute::<[u8; 444], [u8; nsCSSPropertyID::eCSSProperty_font as usize]>([0; 444]); // font
    std::mem::transmute::<[u8; 445], [u8; nsCSSPropertyID::eCSSProperty_font_variant as usize]>([0; 445]); // font-variant
    std::mem::transmute::<[u8; 446], [u8; nsCSSPropertyID::eCSSProperty_font_synthesis as usize]>([0; 446]); // font-synthesis
    std::mem::transmute::<[u8; 447], [u8; nsCSSPropertyID::eCSSProperty_marker as usize]>([0; 447]); // marker
    std::mem::transmute::<[u8; 448], [u8; nsCSSPropertyID::eCSSProperty_text_emphasis as usize]>([0; 448]); // text-emphasis
    std::mem::transmute::<[u8; 449], [u8; nsCSSPropertyID::eCSSProperty_text_wrap as usize]>([0; 449]); // text-wrap
    std::mem::transmute::<[u8; 450], [u8; nsCSSPropertyID::eCSSProperty_white_space as usize]>([0; 450]); // white-space
    std::mem::transmute::<[u8; 451], [u8; nsCSSPropertyID::eCSSProperty__webkit_text_stroke as usize]>([0; 451]); // -webkit-text-stroke
    std::mem::transmute::<[u8; 452], [u8; nsCSSPropertyID::eCSSProperty_list_style as usize]>([0; 452]); // list-style
    std::mem::transmute::<[u8; 453], [u8; nsCSSPropertyID::eCSSProperty_margin as usize]>([0; 453]); // margin
    std::mem::transmute::<[u8; 454], [u8; nsCSSPropertyID::eCSSProperty_margin_block as usize]>([0; 454]); // margin-block
    std::mem::transmute::<[u8; 455], [u8; nsCSSPropertyID::eCSSProperty_margin_inline as usize]>([0; 455]); // margin-inline
    std::mem::transmute::<[u8; 456], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin as usize]>([0; 456]); // scroll-margin
    std::mem::transmute::<[u8; 457], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_block as usize]>([0; 457]); // scroll-margin-block
    std::mem::transmute::<[u8; 458], [u8; nsCSSPropertyID::eCSSProperty_scroll_margin_inline as usize]>([0; 458]); // scroll-margin-inline
    std::mem::transmute::<[u8; 459], [u8; nsCSSPropertyID::eCSSProperty_outline as usize]>([0; 459]); // outline
    std::mem::transmute::<[u8; 460], [u8; nsCSSPropertyID::eCSSProperty_padding as usize]>([0; 460]); // padding
    std::mem::transmute::<[u8; 461], [u8; nsCSSPropertyID::eCSSProperty_padding_block as usize]>([0; 461]); // padding-block
    std::mem::transmute::<[u8; 462], [u8; nsCSSPropertyID::eCSSProperty_padding_inline as usize]>([0; 462]); // padding-inline
    std::mem::transmute::<[u8; 463], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding as usize]>([0; 463]); // scroll-padding
    std::mem::transmute::<[u8; 464], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_block as usize]>([0; 464]); // scroll-padding-block
    std::mem::transmute::<[u8; 465], [u8; nsCSSPropertyID::eCSSProperty_scroll_padding_inline as usize]>([0; 465]); // scroll-padding-inline
    std::mem::transmute::<[u8; 466], [u8; nsCSSPropertyID::eCSSProperty_flex_flow as usize]>([0; 466]); // flex-flow
    std::mem::transmute::<[u8; 467], [u8; nsCSSPropertyID::eCSSProperty_flex as usize]>([0; 467]); // flex
    std::mem::transmute::<[u8; 468], [u8; nsCSSPropertyID::eCSSProperty_gap as usize]>([0; 468]); // gap
    std::mem::transmute::<[u8; 469], [u8; nsCSSPropertyID::eCSSProperty_grid_row as usize]>([0; 469]); // grid-row
    std::mem::transmute::<[u8; 470], [u8; nsCSSPropertyID::eCSSProperty_grid_column as usize]>([0; 470]); // grid-column
    std::mem::transmute::<[u8; 471], [u8; nsCSSPropertyID::eCSSProperty_grid_area as usize]>([0; 471]); // grid-area
    std::mem::transmute::<[u8; 472], [u8; nsCSSPropertyID::eCSSProperty_grid_template as usize]>([0; 472]); // grid-template
    std::mem::transmute::<[u8; 473], [u8; nsCSSPropertyID::eCSSProperty_grid as usize]>([0; 473]); // grid
    std::mem::transmute::<[u8; 474], [u8; nsCSSPropertyID::eCSSProperty_place_content as usize]>([0; 474]); // place-content
    std::mem::transmute::<[u8; 475], [u8; nsCSSPropertyID::eCSSProperty_place_self as usize]>([0; 475]); // place-self
    std::mem::transmute::<[u8; 476], [u8; nsCSSPropertyID::eCSSProperty_place_items as usize]>([0; 476]); // place-items
    std::mem::transmute::<[u8; 477], [u8; nsCSSPropertyID::eCSSProperty_inset as usize]>([0; 477]); // inset
    std::mem::transmute::<[u8; 478], [u8; nsCSSPropertyID::eCSSProperty_inset_block as usize]>([0; 478]); // inset-block
    std::mem::transmute::<[u8; 479], [u8; nsCSSPropertyID::eCSSProperty_inset_inline as usize]>([0; 479]); // inset-inline
    std::mem::transmute::<[u8; 480], [u8; nsCSSPropertyID::eCSSProperty_contain_intrinsic_size as usize]>([0; 480]); // contain-intrinsic-size
    std::mem::transmute::<[u8; 481], [u8; nsCSSPropertyID::eCSSProperty_mask as usize]>([0; 481]); // mask
    std::mem::transmute::<[u8; 482], [u8; nsCSSPropertyID::eCSSProperty_mask_position as usize]>([0; 482]); // mask-position
    std::mem::transmute::<[u8; 483], [u8; nsCSSPropertyID::eCSSProperty_text_decoration as usize]>([0; 483]); // text-decoration
    std::mem::transmute::<[u8; 484], [u8; nsCSSPropertyID::eCSSProperty_transition as usize]>([0; 484]); // transition
    std::mem::transmute::<[u8; 485], [u8; nsCSSPropertyID::eCSSProperty_animation as usize]>([0; 485]); // animation
    std::mem::transmute::<[u8; 486], [u8; nsCSSPropertyID::eCSSProperty_scroll_timeline as usize]>([0; 486]); // scroll-timeline
    std::mem::transmute::<[u8; 487], [u8; nsCSSPropertyID::eCSSProperty_view_timeline as usize]>([0; 487]); // view-timeline
    std::mem::transmute::<[u8; 488], [u8; nsCSSPropertyID::eCSSProperty_all as usize]>([0; 488]); // all
    std::mem::transmute::<[u8; 489], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_background_clip as usize]>([0; 489]); // -webkit-background-clip
    std::mem::transmute::<[u8; 490], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_background_origin as usize]>([0; 490]); // -webkit-background-origin
    std::mem::transmute::<[u8; 491], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_background_size as usize]>([0; 491]); // -webkit-background-size
    std::mem::transmute::<[u8; 492], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_start_color as usize]>([0; 492]); // -moz-border-start-color
    std::mem::transmute::<[u8; 493], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_start_style as usize]>([0; 493]); // -moz-border-start-style
    std::mem::transmute::<[u8; 494], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_start_width as usize]>([0; 494]); // -moz-border-start-width
    std::mem::transmute::<[u8; 495], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_end_color as usize]>([0; 495]); // -moz-border-end-color
    std::mem::transmute::<[u8; 496], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_end_style as usize]>([0; 496]); // -moz-border-end-style
    std::mem::transmute::<[u8; 497], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_end_width as usize]>([0; 497]); // -moz-border-end-width
    std::mem::transmute::<[u8; 498], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_border_top_left_radius as usize]>([0; 498]); // -webkit-border-top-left-radius
    std::mem::transmute::<[u8; 499], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_border_top_right_radius as usize]>([0; 499]); // -webkit-border-top-right-radius
    std::mem::transmute::<[u8; 500], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_border_bottom_right_radius as usize]>([0; 500]); // -webkit-border-bottom-right-radius
    std::mem::transmute::<[u8; 501], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_border_bottom_left_radius as usize]>([0; 501]); // -webkit-border-bottom-left-radius
    std::mem::transmute::<[u8; 502], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transform as usize]>([0; 502]); // -moz-transform
    std::mem::transmute::<[u8; 503], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transform as usize]>([0; 503]); // -webkit-transform
    std::mem::transmute::<[u8; 504], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_perspective as usize]>([0; 504]); // -moz-perspective
    std::mem::transmute::<[u8; 505], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_perspective as usize]>([0; 505]); // -webkit-perspective
    std::mem::transmute::<[u8; 506], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_perspective_origin as usize]>([0; 506]); // -moz-perspective-origin
    std::mem::transmute::<[u8; 507], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_perspective_origin as usize]>([0; 507]); // -webkit-perspective-origin
    std::mem::transmute::<[u8; 508], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_backface_visibility as usize]>([0; 508]); // -moz-backface-visibility
    std::mem::transmute::<[u8; 509], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_backface_visibility as usize]>([0; 509]); // -webkit-backface-visibility
    std::mem::transmute::<[u8; 510], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transform_style as usize]>([0; 510]); // -moz-transform-style
    std::mem::transmute::<[u8; 511], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transform_style as usize]>([0; 511]); // -webkit-transform-style
    std::mem::transmute::<[u8; 512], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transform_origin as usize]>([0; 512]); // -moz-transform-origin
    std::mem::transmute::<[u8; 513], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transform_origin as usize]>([0; 513]); // -webkit-transform-origin
    std::mem::transmute::<[u8; 514], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_appearance as usize]>([0; 514]); // -moz-appearance
    std::mem::transmute::<[u8; 515], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_appearance as usize]>([0; 515]); // -webkit-appearance
    std::mem::transmute::<[u8; 516], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_shadow as usize]>([0; 516]); // -webkit-box-shadow
    std::mem::transmute::<[u8; 517], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_filter as usize]>([0; 517]); // -webkit-filter
    std::mem::transmute::<[u8; 518], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_font_feature_settings as usize]>([0; 518]); // -moz-font-feature-settings
    std::mem::transmute::<[u8; 519], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_font_language_override as usize]>([0; 519]); // -moz-font-language-override
    std::mem::transmute::<[u8; 520], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_font_smoothing as usize]>([0; 520]); // -webkit-font-smoothing
    std::mem::transmute::<[u8; 521], [u8; nsCSSPropertyID::eCSSPropertyAlias_color_adjust as usize]>([0; 521]); // color-adjust
    std::mem::transmute::<[u8; 522], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_hyphens as usize]>([0; 522]); // -moz-hyphens
    std::mem::transmute::<[u8; 523], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_text_size_adjust as usize]>([0; 523]); // -webkit-text-size-adjust
    std::mem::transmute::<[u8; 524], [u8; nsCSSPropertyID::eCSSPropertyAlias_word_wrap as usize]>([0; 524]); // word-wrap
    std::mem::transmute::<[u8; 525], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_tab_size as usize]>([0; 525]); // -moz-tab-size
    std::mem::transmute::<[u8; 526], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_margin_start as usize]>([0; 526]); // -moz-margin-start
    std::mem::transmute::<[u8; 527], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_margin_end as usize]>([0; 527]); // -moz-margin-end
    std::mem::transmute::<[u8; 528], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_padding_start as usize]>([0; 528]); // -moz-padding-start
    std::mem::transmute::<[u8; 529], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_padding_end as usize]>([0; 529]); // -moz-padding-end
    std::mem::transmute::<[u8; 530], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_flex_direction as usize]>([0; 530]); // -webkit-flex-direction
    std::mem::transmute::<[u8; 531], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_flex_wrap as usize]>([0; 531]); // -webkit-flex-wrap
    std::mem::transmute::<[u8; 532], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_justify_content as usize]>([0; 532]); // -webkit-justify-content
    std::mem::transmute::<[u8; 533], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_align_content as usize]>([0; 533]); // -webkit-align-content
    std::mem::transmute::<[u8; 534], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_align_items as usize]>([0; 534]); // -webkit-align-items
    std::mem::transmute::<[u8; 535], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_flex_grow as usize]>([0; 535]); // -webkit-flex-grow
    std::mem::transmute::<[u8; 536], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_flex_shrink as usize]>([0; 536]); // -webkit-flex-shrink
    std::mem::transmute::<[u8; 537], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_align_self as usize]>([0; 537]); // -webkit-align-self
    std::mem::transmute::<[u8; 538], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_order as usize]>([0; 538]); // -webkit-order
    std::mem::transmute::<[u8; 539], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_flex_basis as usize]>([0; 539]); // -webkit-flex-basis
    std::mem::transmute::<[u8; 540], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_box_sizing as usize]>([0; 540]); // -moz-box-sizing
    std::mem::transmute::<[u8; 541], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_sizing as usize]>([0; 541]); // -webkit-box-sizing
    std::mem::transmute::<[u8; 542], [u8; nsCSSPropertyID::eCSSPropertyAlias_grid_column_gap as usize]>([0; 542]); // grid-column-gap
    std::mem::transmute::<[u8; 543], [u8; nsCSSPropertyID::eCSSPropertyAlias_grid_row_gap as usize]>([0; 543]); // grid-row-gap
    std::mem::transmute::<[u8; 544], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_clip_path as usize]>([0; 544]); // -webkit-clip-path
    std::mem::transmute::<[u8; 545], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_repeat as usize]>([0; 545]); // -webkit-mask-repeat
    std::mem::transmute::<[u8; 546], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_position_x as usize]>([0; 546]); // -webkit-mask-position-x
    std::mem::transmute::<[u8; 547], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_position_y as usize]>([0; 547]); // -webkit-mask-position-y
    std::mem::transmute::<[u8; 548], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_clip as usize]>([0; 548]); // -webkit-mask-clip
    std::mem::transmute::<[u8; 549], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_origin as usize]>([0; 549]); // -webkit-mask-origin
    std::mem::transmute::<[u8; 550], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_size as usize]>([0; 550]); // -webkit-mask-size
    std::mem::transmute::<[u8; 551], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_composite as usize]>([0; 551]); // -webkit-mask-composite
    std::mem::transmute::<[u8; 552], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_image as usize]>([0; 552]); // -webkit-mask-image
    std::mem::transmute::<[u8; 553], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_user_select as usize]>([0; 553]); // -moz-user-select
    std::mem::transmute::<[u8; 554], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_user_select as usize]>([0; 554]); // -webkit-user-select
    std::mem::transmute::<[u8; 555], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transition_duration as usize]>([0; 555]); // -moz-transition-duration
    std::mem::transmute::<[u8; 556], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transition_duration as usize]>([0; 556]); // -webkit-transition-duration
    std::mem::transmute::<[u8; 557], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transition_timing_function as usize]>([0; 557]); // -moz-transition-timing-function
    std::mem::transmute::<[u8; 558], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transition_timing_function as usize]>([0; 558]); // -webkit-transition-timing-function
    std::mem::transmute::<[u8; 559], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transition_property as usize]>([0; 559]); // -moz-transition-property
    std::mem::transmute::<[u8; 560], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transition_property as usize]>([0; 560]); // -webkit-transition-property
    std::mem::transmute::<[u8; 561], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transition_delay as usize]>([0; 561]); // -moz-transition-delay
    std::mem::transmute::<[u8; 562], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transition_delay as usize]>([0; 562]); // -webkit-transition-delay
    std::mem::transmute::<[u8; 563], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_name as usize]>([0; 563]); // -moz-animation-name
    std::mem::transmute::<[u8; 564], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_name as usize]>([0; 564]); // -webkit-animation-name
    std::mem::transmute::<[u8; 565], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_duration as usize]>([0; 565]); // -moz-animation-duration
    std::mem::transmute::<[u8; 566], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_duration as usize]>([0; 566]); // -webkit-animation-duration
    std::mem::transmute::<[u8; 567], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_timing_function as usize]>([0; 567]); // -moz-animation-timing-function
    std::mem::transmute::<[u8; 568], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_timing_function as usize]>([0; 568]); // -webkit-animation-timing-function
    std::mem::transmute::<[u8; 569], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_iteration_count as usize]>([0; 569]); // -moz-animation-iteration-count
    std::mem::transmute::<[u8; 570], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_iteration_count as usize]>([0; 570]); // -webkit-animation-iteration-count
    std::mem::transmute::<[u8; 571], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_direction as usize]>([0; 571]); // -moz-animation-direction
    std::mem::transmute::<[u8; 572], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_direction as usize]>([0; 572]); // -webkit-animation-direction
    std::mem::transmute::<[u8; 573], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_play_state as usize]>([0; 573]); // -moz-animation-play-state
    std::mem::transmute::<[u8; 574], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_play_state as usize]>([0; 574]); // -webkit-animation-play-state
    std::mem::transmute::<[u8; 575], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_fill_mode as usize]>([0; 575]); // -moz-animation-fill-mode
    std::mem::transmute::<[u8; 576], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_fill_mode as usize]>([0; 576]); // -webkit-animation-fill-mode
    std::mem::transmute::<[u8; 577], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation_delay as usize]>([0; 577]); // -moz-animation-delay
    std::mem::transmute::<[u8; 578], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation_delay as usize]>([0; 578]); // -webkit-animation-delay
    std::mem::transmute::<[u8; 579], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_align as usize]>([0; 579]); // -webkit-box-align
    std::mem::transmute::<[u8; 580], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_direction as usize]>([0; 580]); // -webkit-box-direction
    std::mem::transmute::<[u8; 581], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_flex as usize]>([0; 581]); // -webkit-box-flex
    std::mem::transmute::<[u8; 582], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_orient as usize]>([0; 582]); // -webkit-box-orient
    std::mem::transmute::<[u8; 583], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_pack as usize]>([0; 583]); // -webkit-box-pack
    std::mem::transmute::<[u8; 584], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_box_ordinal_group as usize]>([0; 584]); // -webkit-box-ordinal-group
    std::mem::transmute::<[u8; 585], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_start as usize]>([0; 585]); // -moz-border-start
    std::mem::transmute::<[u8; 586], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_end as usize]>([0; 586]); // -moz-border-end
    std::mem::transmute::<[u8; 587], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_border_radius as usize]>([0; 587]); // -webkit-border-radius
    std::mem::transmute::<[u8; 588], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_border_image as usize]>([0; 588]); // -moz-border-image
    std::mem::transmute::<[u8; 589], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_border_image as usize]>([0; 589]); // -webkit-border-image
    std::mem::transmute::<[u8; 590], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_flex_flow as usize]>([0; 590]); // -webkit-flex-flow
    std::mem::transmute::<[u8; 591], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_flex as usize]>([0; 591]); // -webkit-flex
    std::mem::transmute::<[u8; 592], [u8; nsCSSPropertyID::eCSSPropertyAlias_grid_gap as usize]>([0; 592]); // grid-gap
    std::mem::transmute::<[u8; 593], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask as usize]>([0; 593]); // -webkit-mask
    std::mem::transmute::<[u8; 594], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_mask_position as usize]>([0; 594]); // -webkit-mask-position
    std::mem::transmute::<[u8; 595], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_transition as usize]>([0; 595]); // -moz-transition
    std::mem::transmute::<[u8; 596], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_transition as usize]>([0; 596]); // -webkit-transition
    std::mem::transmute::<[u8; 597], [u8; nsCSSPropertyID::eCSSPropertyAlias__moz_animation as usize]>([0; 597]); // -moz-animation
    std::mem::transmute::<[u8; 598], [u8; nsCSSPropertyID::eCSSPropertyAlias__webkit_animation as usize]>([0; 598]); // -webkit-animation
}

impl NonCustomPropertyId {
    /// Get the property name.
    #[inline]
    pub fn name(self) -> &'static str {
        static MAP: [&'static str; property_counts::NON_CUSTOM] = [
            "align-content",
            "align-items",
            "align-self",
            "aspect-ratio",
            "backface-visibility",
            "baseline-source",
            "border-collapse",
            "border-image-repeat",
            "box-decoration-break",
            "box-sizing",
            "break-inside",
            "caption-side",
            "clear",
            "color-interpolation",
            "color-interpolation-filters",
            "column-count",
            "column-fill",
            "column-span",
            "contain",
            "container-type",
            "content-visibility",
            "direction",
            "display",
            "dominant-baseline",
            "empty-cells",
            "flex-direction",
            "flex-wrap",
            "float",
            "font-kerning",
            "font-language-override",
            "font-optical-sizing",
            "font-size-adjust",
            "font-stretch",
            "font-style",
            "font-variant-caps",
            "font-variant-east-asian",
            "font-variant-emoji",
            "font-variant-ligatures",
            "font-variant-numeric",
            "font-variant-position",
            "font-weight",
            "forced-color-adjust",
            "grid-auto-flow",
            "hyphens",
            "image-orientation",
            "image-rendering",
            "ime-mode",
            "initial-letter",
            "inset-area",
            "isolation",
            "justify-content",
            "justify-items",
            "justify-self",
            "line-break",
            "list-style-position",
            "mask-type",
            "masonry-auto-flow",
            "math-depth",
            "math-style",
            "mix-blend-mode",
            "-moz-box-align",
            "-moz-box-collapse",
            "-moz-box-direction",
            "-moz-box-orient",
            "-moz-box-pack",
            "-moz-control-character-visibility",
            "-moz-float-edge",
            "-moz-inert",
            "-moz-math-variant",
            "-moz-min-font-size-ratio",
            "-moz-orient",
            "-moz-osx-font-smoothing",
            "-moz-text-size-adjust",
            "-moz-theme",
            "-moz-top-layer",
            "-moz-user-focus",
            "-moz-user-input",
            "-moz-user-modify",
            "-moz-window-dragging",
            "-moz-window-shadow",
            "object-fit",
            "offset-rotate",
            "outline-style",
            "overflow-anchor",
            "overflow-wrap",
            "page-orientation",
            "paint-order",
            "pointer-events",
            "position",
            "position-try-order",
            "position-visibility",
            "print-color-adjust",
            "resize",
            "ruby-align",
            "ruby-position",
            "scroll-behavior",
            "scroll-snap-align",
            "scroll-snap-stop",
            "scroll-snap-type",
            "scrollbar-gutter",
            "scrollbar-width",
            "shape-rendering",
            "stroke-linecap",
            "stroke-linejoin",
            "table-layout",
            "text-align",
            "text-align-last",
            "text-anchor",
            "text-combine-upright",
            "text-decoration-line",
            "text-decoration-skip-ink",
            "text-decoration-style",
            "text-emphasis-position",
            "text-justify",
            "text-orientation",
            "text-rendering",
            "text-transform",
            "text-underline-position",
            "text-wrap-mode",
            "text-wrap-style",
            "touch-action",
            "transform-box",
            "transform-style",
            "unicode-bidi",
            "user-select",
            "vector-effect",
            "visibility",
            "-webkit-line-clamp",
            "-webkit-text-security",
            "white-space-collapse",
            "word-break",
            "writing-mode",
            "-x-text-scale",
            "z-index",
            "zoom",
            "appearance",
            "-moz-default-appearance",
            "-moz-force-broken-image-icon",
            "-moz-subtree-hidden-only-visually",
            "break-after",
            "break-before",
            "clip-rule",
            "fill-rule",
            "overflow-clip-box-block",
            "overflow-clip-box-inline",
            "fill-opacity",
            "stroke-opacity",
            "-moz-box-ordinal-group",
            "order",
            "-x-span",
            "font-synthesis-position",
            "font-synthesis-small-caps",
            "font-synthesis-style",
            "font-synthesis-weight",
            "flex-grow",
            "flex-shrink",
            "-moz-box-flex",
            "stroke-miterlimit",
            "overflow-block",
            "overflow-inline",
            "overflow-x",
            "overflow-y",
            "overscroll-behavior-block",
            "overscroll-behavior-inline",
            "overscroll-behavior-x",
            "overscroll-behavior-y",
            "flood-opacity",
            "-moz-window-opacity",
            "opacity",
            "shape-image-threshold",
            "stop-opacity",
            "border-block-end-style",
            "border-block-start-style",
            "border-bottom-style",
            "border-inline-end-style",
            "border-inline-start-style",
            "border-left-style",
            "border-right-style",
            "border-top-style",
            "column-rule-style",
            "accent-color",
            "anchor-name",
            "anchor-scope",
            "animation-composition",
            "animation-delay",
            "animation-direction",
            "animation-duration",
            "animation-fill-mode",
            "animation-iteration-count",
            "animation-name",
            "animation-play-state",
            "animation-timeline",
            "animation-timing-function",
            "backdrop-filter",
            "background-attachment",
            "background-blend-mode",
            "background-clip",
            "background-image",
            "background-origin",
            "background-position-x",
            "background-position-y",
            "background-repeat",
            "background-size",
            "border-image-outset",
            "border-image-slice",
            "border-image-width",
            "border-spacing",
            "box-shadow",
            "caret-color",
            "clip",
            "clip-path",
            "color",
            "color-scheme",
            "column-width",
            "container-name",
            "content",
            "counter-increment",
            "counter-reset",
            "counter-set",
            "cursor",
            "d",
            "filter",
            "flex-basis",
            "font-family",
            "font-feature-settings",
            "font-palette",
            "font-size",
            "font-variant-alternates",
            "font-variation-settings",
            "grid-template-areas",
            "hyphenate-character",
            "letter-spacing",
            "line-height",
            "list-style-type",
            "mask-clip",
            "mask-composite",
            "mask-image",
            "mask-mode",
            "mask-origin",
            "mask-position-x",
            "mask-position-y",
            "mask-repeat",
            "mask-size",
            "-moz-context-properties",
            "offset-anchor",
            "offset-path",
            "offset-position",
            "page",
            "perspective",
            "position-anchor",
            "position-try-options",
            "quotes",
            "rotate",
            "scale",
            "scroll-timeline-axis",
            "scroll-timeline-name",
            "scrollbar-color",
            "shape-outside",
            "size",
            "stroke-dasharray",
            "stroke-dashoffset",
            "stroke-width",
            "tab-size",
            "text-decoration-thickness",
            "text-emphasis-style",
            "text-indent",
            "text-overflow",
            "text-shadow",
            "transition-behavior",
            "transition-delay",
            "transition-duration",
            "transition-property",
            "transition-timing-function",
            "translate",
            "vertical-align",
            "view-timeline-axis",
            "view-timeline-inset",
            "view-timeline-name",
            "-webkit-text-stroke-width",
            "will-change",
            "word-spacing",
            "-x-lang",
            "object-position",
            "perspective-origin",
            "fill",
            "stroke",
            "-moz-window-transform-origin",
            "transform-origin",
            "grid-template-columns",
            "grid-template-rows",
            "border-image-source",
            "list-style-image",
            "grid-auto-columns",
            "grid-auto-rows",
            "-moz-window-transform",
            "transform",
            "column-gap",
            "row-gap",
            "marker-end",
            "marker-mid",
            "marker-start",
            "contain-intrinsic-block-size",
            "contain-intrinsic-height",
            "contain-intrinsic-inline-size",
            "contain-intrinsic-width",
            "grid-column-end",
            "grid-column-start",
            "grid-row-end",
            "grid-row-start",
            "max-block-size",
            "max-height",
            "max-inline-size",
            "max-width",
            "cx",
            "cy",
            "offset-distance",
            "x",
            "y",
            "border-bottom-left-radius",
            "border-bottom-right-radius",
            "border-end-end-radius",
            "border-end-start-radius",
            "border-start-end-radius",
            "border-start-start-radius",
            "border-top-left-radius",
            "border-top-right-radius",
            "block-size",
            "height",
            "inline-size",
            "min-block-size",
            "min-height",
            "min-inline-size",
            "min-width",
            "width",
            "border-block-end-width",
            "border-block-start-width",
            "border-bottom-width",
            "border-inline-end-width",
            "border-inline-start-width",
            "border-left-width",
            "border-right-width",
            "border-top-width",
            "column-rule-width",
            "outline-width",
            "padding-block-end",
            "padding-block-start",
            "padding-bottom",
            "padding-inline-end",
            "padding-inline-start",
            "padding-left",
            "padding-right",
            "padding-top",
            "r",
            "shape-margin",
            "rx",
            "ry",
            "scroll-padding-block-end",
            "scroll-padding-block-start",
            "scroll-padding-bottom",
            "scroll-padding-inline-end",
            "scroll-padding-inline-start",
            "scroll-padding-left",
            "scroll-padding-right",
            "scroll-padding-top",
            "-moz-window-input-region-margin",
            "outline-offset",
            "overflow-clip-margin",
            "scroll-margin-block-end",
            "scroll-margin-block-start",
            "scroll-margin-bottom",
            "scroll-margin-inline-end",
            "scroll-margin-inline-start",
            "scroll-margin-left",
            "scroll-margin-right",
            "scroll-margin-top",
            "bottom",
            "inset-block-end",
            "inset-block-start",
            "inset-inline-end",
            "inset-inline-start",
            "left",
            "margin-block-end",
            "margin-block-start",
            "margin-bottom",
            "margin-inline-end",
            "margin-inline-start",
            "margin-left",
            "margin-right",
            "margin-top",
            "right",
            "text-underline-offset",
            "top",
            "background-color",
            "border-block-end-color",
            "border-block-start-color",
            "border-bottom-color",
            "border-inline-end-color",
            "border-inline-start-color",
            "border-left-color",
            "border-right-color",
            "border-top-color",
            "column-rule-color",
            "flood-color",
            "lighting-color",
            "outline-color",
            "stop-color",
            "text-decoration-color",
            "text-emphasis-color",
            "-webkit-text-fill-color",
            "-webkit-text-stroke-color",
            "background",
            "background-position",
            "border-color",
            "border-style",
            "border-width",
            "border-top",
            "border-right",
            "border-bottom",
            "border-left",
            "border-block-start",
            "border-block-end",
            "border-inline-start",
            "border-inline-end",
            "border",
            "border-radius",
            "border-image",
            "border-block-width",
            "border-block-style",
            "border-block-color",
            "border-inline-width",
            "border-inline-style",
            "border-inline-color",
            "border-block",
            "border-inline",
            "overflow",
            "overflow-clip-box",
            "overscroll-behavior",
            "container",
            "page-break-before",
            "page-break-after",
            "page-break-inside",
            "offset",
            "columns",
            "column-rule",
            "font",
            "font-variant",
            "font-synthesis",
            "marker",
            "text-emphasis",
            "text-wrap",
            "white-space",
            "-webkit-text-stroke",
            "list-style",
            "margin",
            "margin-block",
            "margin-inline",
            "scroll-margin",
            "scroll-margin-block",
            "scroll-margin-inline",
            "outline",
            "padding",
            "padding-block",
            "padding-inline",
            "scroll-padding",
            "scroll-padding-block",
            "scroll-padding-inline",
            "flex-flow",
            "flex",
            "gap",
            "grid-row",
            "grid-column",
            "grid-area",
            "grid-template",
            "grid",
            "place-content",
            "place-self",
            "place-items",
            "inset",
            "inset-block",
            "inset-inline",
            "contain-intrinsic-size",
            "mask",
            "mask-position",
            "text-decoration",
            "transition",
            "animation",
            "scroll-timeline",
            "view-timeline",
            "all",
            "-webkit-background-clip",
            "-webkit-background-origin",
            "-webkit-background-size",
            "-moz-border-start-color",
            "-moz-border-start-style",
            "-moz-border-start-width",
            "-moz-border-end-color",
            "-moz-border-end-style",
            "-moz-border-end-width",
            "-webkit-border-top-left-radius",
            "-webkit-border-top-right-radius",
            "-webkit-border-bottom-right-radius",
            "-webkit-border-bottom-left-radius",
            "-moz-transform",
            "-webkit-transform",
            "-moz-perspective",
            "-webkit-perspective",
            "-moz-perspective-origin",
            "-webkit-perspective-origin",
            "-moz-backface-visibility",
            "-webkit-backface-visibility",
            "-moz-transform-style",
            "-webkit-transform-style",
            "-moz-transform-origin",
            "-webkit-transform-origin",
            "-moz-appearance",
            "-webkit-appearance",
            "-webkit-box-shadow",
            "-webkit-filter",
            "-moz-font-feature-settings",
            "-moz-font-language-override",
            "-webkit-font-smoothing",
            "color-adjust",
            "-moz-hyphens",
            "-webkit-text-size-adjust",
            "word-wrap",
            "-moz-tab-size",
            "-moz-margin-start",
            "-moz-margin-end",
            "-moz-padding-start",
            "-moz-padding-end",
            "-webkit-flex-direction",
            "-webkit-flex-wrap",
            "-webkit-justify-content",
            "-webkit-align-content",
            "-webkit-align-items",
            "-webkit-flex-grow",
            "-webkit-flex-shrink",
            "-webkit-align-self",
            "-webkit-order",
            "-webkit-flex-basis",
            "-moz-box-sizing",
            "-webkit-box-sizing",
            "grid-column-gap",
            "grid-row-gap",
            "-webkit-clip-path",
            "-webkit-mask-repeat",
            "-webkit-mask-position-x",
            "-webkit-mask-position-y",
            "-webkit-mask-clip",
            "-webkit-mask-origin",
            "-webkit-mask-size",
            "-webkit-mask-composite",
            "-webkit-mask-image",
            "-moz-user-select",
            "-webkit-user-select",
            "-moz-transition-duration",
            "-webkit-transition-duration",
            "-moz-transition-timing-function",
            "-webkit-transition-timing-function",
            "-moz-transition-property",
            "-webkit-transition-property",
            "-moz-transition-delay",
            "-webkit-transition-delay",
            "-moz-animation-name",
            "-webkit-animation-name",
            "-moz-animation-duration",
            "-webkit-animation-duration",
            "-moz-animation-timing-function",
            "-webkit-animation-timing-function",
            "-moz-animation-iteration-count",
            "-webkit-animation-iteration-count",
            "-moz-animation-direction",
            "-webkit-animation-direction",
            "-moz-animation-play-state",
            "-webkit-animation-play-state",
            "-moz-animation-fill-mode",
            "-webkit-animation-fill-mode",
            "-moz-animation-delay",
            "-webkit-animation-delay",
            "-webkit-box-align",
            "-webkit-box-direction",
            "-webkit-box-flex",
            "-webkit-box-orient",
            "-webkit-box-pack",
            "-webkit-box-ordinal-group",
            "-moz-border-start",
            "-moz-border-end",
            "-webkit-border-radius",
            "-moz-border-image",
            "-webkit-border-image",
            "-webkit-flex-flow",
            "-webkit-flex",
            "grid-gap",
            "-webkit-mask",
            "-webkit-mask-position",
            "-moz-transition",
            "-webkit-transition",
            "-moz-animation",
            "-webkit-animation",
        ];
        MAP[self.0 as usize]
    }

    /// Returns whether this property is animatable.
    #[inline]
    pub fn is_animatable(self) -> bool {
        
static ANIMATABLE: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0xffd3ffff, 0xd9ffffff, 0xffdffbcd, 0xf7fbefff, 0xffdffee7, 0x7f27ff, 0xffbffffe, 0x3ff7ffff, 0xfd460ffb, 0xffffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0xffdfb7ff, 0xffffffff, 0xfffedf0f, 0xffffffff, 0x7ff, 0x7fff8]
};

        ANIMATABLE.contains(self)
    }

    /// Whether this property is enabled for all content right now.
    #[inline]
    pub(super) fn enabled_for_all_content(self) -> bool {
        
static EXPERIMENTAL: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x40100000, 0x1018210, 0x6280082, 0x800000, 0x18040, 0x80e0003c, 0x2, 0xc6080012, 0x381000, 0x1e000, 0x0, 0x0, 0x0, 0x180000, 0x0, 0x554000c1, 0x100001c1, 0xaaaaa800, 0x281002]
};


        
static ALWAYS_ENABLED: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0xbfefffff, 0xdefe7def, 0xf9d77145, 0xff7fffff, 0xffde7aaf, 0x7f1fff43, 0xfffffffd, 0x39f7ffed, 0xbdc7efff, 0xfffe1fbf, 0xffffffff, 0xffffefff, 0xffffffff, 0xffe7ffff, 0xffffffff, 0xaabfff3e, 0xeffffe3e, 0x555557ff, 0x57effd]
};


        let passes_pref_check = || {
                unsafe { structs::nsCSSProps_gPropertyEnabled[self.0 as usize] }
        };

        if ALWAYS_ENABLED.contains(self) {
            return true
        }

        if EXPERIMENTAL.contains(self) && passes_pref_check() {
            return true
        }

        false
    }

    /// Returns whether a given rule allows a given property.
    #[inline]
    pub fn allowed_in_rule(self, rule_types: CssRuleTypes) -> bool {
        debug_assert!(
            rule_types.contains(CssRuleType::Keyframe) ||
            rule_types.contains(CssRuleType::Page) ||
            rule_types.contains(CssRuleType::Style),
            "Declarations are only expected inside a keyframe, page, or style rule."
        );

        static MAP: [u32; property_counts::NON_CUSTOM] = [
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Page.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Page.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Page.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            CssRuleType::Keyframe.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
            CssRuleType::Style.bit() |
            0,
        ];
        MAP[self.0 as usize] & rule_types.bits() != 0
    }

    pub(super) fn allowed_in(self, context: &ParserContext) -> bool {
        if !self.allowed_in_rule(context.rule_types()) {
            return false;
        }

        self.allowed_in_ignoring_rule_type(context)
    }


    pub(super) fn allowed_in_ignoring_rule_type(self, context: &ParserContext) -> bool {
        // The semantics of these are kinda hard to reason about, what follows
        // is a description of the different combinations that can happen with
        // these three sets.
        //
        // Experimental properties are generally controlled by prefs, but an
        // experimental property explicitly enabled in certain context (UA or
        // chrome sheets) is always usable in the context regardless of the
        // pref value.
        //
        // Non-experimental properties are either normal properties which are
        // usable everywhere, or internal-only properties which are only usable
        // in certain context they are explicitly enabled in.
        if self.enabled_for_all_content() {
            return true;
        }

        
static ENABLED_IN_UA_SHEETS: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x20000000, 0x8e2a, 0x0, 0x18540, 0x80, 0x0, 0x80000, 0x40000000, 0x40, 0x0, 0x1000, 0x0, 0x80000, 0x0, 0x0, 0x0, 0x0, 0x0]
};

        
static ENABLED_IN_CHROME: NonCustomPropertyIdSet = NonCustomPropertyIdSet {
    
    storage: [0x0, 0x20000000, 0x8a02, 0x0, 0x540, 0x80, 0x0, 0x80000, 0x40000000, 0x40, 0x0, 0x1000, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0]
};


        if context.stylesheet_origin == Origin::UserAgent &&
            ENABLED_IN_UA_SHEETS.contains(self)
        {
            return true
        }

        if context.chrome_rules_enabled() && ENABLED_IN_CHROME.contains(self) {
            return true
        }

        false
    }

    /// The supported types of this property. The return value should be
    /// style_traits::CssType when it can become a bitflags type.
    pub(super) fn supported_types(&self) -> u8 {
        const SUPPORTED_TYPES: [u8; 489] = [
                <crate::values::specified::AlignContent as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::AlignItems as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::AlignSelf as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::AspectRatio as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::backface_visibility::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BaselineSource as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::border_collapse::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderImageRepeat as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::box_decoration_break::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::box_sizing::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BreakWithin as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::table::CaptionSide as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Clear as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::color_interpolation::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::color_interpolation_filters::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ColumnCount as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::column_fill::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::column_span::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Contain as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ContainerType as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ContentVisibility as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::direction::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Display as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::dominant_baseline::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::empty_cells::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::flex_direction::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::flex_wrap::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Float as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::font_kerning::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontLanguageOverride as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::font_optical_sizing::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontSizeAdjust as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontStretch as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::font_variant_caps::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontVariantEastAsian as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::font_variant_emoji::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontVariantLigatures as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontVariantNumeric as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::font_variant_position::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontWeight as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ForcedColorAdjust as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridAutoFlow as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::hyphens::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::image_orientation::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ImageRendering as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::ime_mode::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::InitialLetter as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::InsetArea as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::isolation::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::JustifyContent as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::JustifyItems as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::JustifySelf as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LineBreak as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::list_style_position::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_type::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::MasonryAutoFlow as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::MathDepth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::math_style::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mix_blend_mode::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_box_align::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_box_collapse::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_box_direction::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_box_orient::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_box_pack::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::text::MozControlCharacterVisibility as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_float_edge::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_inert::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_math_variant::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Percentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_orient::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_osx_font_smoothing::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_text_size_adjust::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ui::MozTheme as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_top_layer::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_user_focus::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_user_input::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_user_modify::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_window_dragging::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_moz_window_shadow::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::object_fit::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OffsetRotate as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OutlineStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverflowAnchor as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverflowWrap as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::PageOrientation as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::SVGPaintOrder as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::pointer_events::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::position::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::PositionTryOrder as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::PositionVisibility as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::PrintColorAdjust as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Resize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::ruby_align::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::RubyPosition as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::scroll_behavior::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ScrollSnapAlign as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ScrollSnapStop as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ScrollSnapType as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ScrollbarGutter as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::scrollbar_width::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::shape_rendering::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::stroke_linecap::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::stroke_linejoin::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::table_layout::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextAlign as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextAlignLast as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_anchor::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_combine_upright::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextDecorationLine as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextDecorationSkipInk as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_decoration_style::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextEmphasisPosition as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextJustify as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_orientation::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_rendering::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextTransform as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextUnderlinePosition as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_wrap_mode::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_wrap_style::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TouchAction as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TransformBox as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TransformStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::unicode_bidi::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::UserSelect as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::vector_effect::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::visibility::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LineClamp as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::_webkit_text_security::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::white_space_collapse::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::WordBreak as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::writing_mode::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::XTextScale as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ZIndex as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Zoom as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Appearance as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Appearance as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BoolInteger as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BoolInteger as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BreakBetween as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BreakBetween as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FillRule as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FillRule as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverflowClipBox as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverflowClipBox as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::SVGOpacity as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::SVGOpacity as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Integer as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Integer as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Integer as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ColorOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::AnchorName as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::AnchorScope as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_composition::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_delay::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_direction::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_duration::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_fill_mode::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_iteration_count::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_name::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_play_state::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_timeline::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::animation_timing_function::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::backdrop_filter::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_attachment::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_blend_mode::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_clip::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_image::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_origin::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_position_x::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_position_y::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_repeat::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::background_size::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::NonNegativeLengthOrNumberRect> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderImageSlice> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderImageWidth> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderSpacing> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::box_shadow::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::color::CaretColor as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::ClipRectOrAuto> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::basic_shape::ClipPath as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ColorPropertyValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ColorScheme as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::length::NonNegativeLengthOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ContainerName as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Content as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::CounterIncrement as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::CounterReset as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::CounterSet as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Cursor as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::DProperty as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::filter::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::FlexBasis> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontFamily as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontFeatureSettings as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontPalette as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontVariantAlternates as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::FontVariationSettings as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridTemplateAreas as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::HyphenateCharacter as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LetterSpacing as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LineHeight as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ListStyleType as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_clip::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_composite::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_image::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_mode::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_origin::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_position_x::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_position_y::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_repeat::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::mask_size::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::MozContextProperties as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::PositionOrAuto> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::OffsetPath as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::OffsetPosition> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::PageName as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Perspective as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::PositionAnchor as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::PositionTryOptions as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Quotes as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::Rotate> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::Scale> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::scroll_timeline_axis::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::scroll_timeline_name::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::ui::ScrollbarColor> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::basic_shape::ShapeOutside as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::PageSize> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::SVGStrokeDashArray as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::SVGLength as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::SVGWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthOrNumber as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextDecorationLength as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextEmphasisStyle as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::TextIndent as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::TextOverflow> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::text_shadow::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::transition_behavior::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::transition_delay::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::transition_duration::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::transition_property::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::transition_timing_function::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::Translate> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::VerticalAlign as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::view_timeline_axis::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::view_timeline_inset::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <longhands::view_timeline_name::SpecifiedValue as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LineWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::WillChange as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::WordSpacing as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::XLang as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::Position> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::Position> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::SVGPaint> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::SVGPaint> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::TransformOrigin> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::TransformOrigin> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridTemplateComponent as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridTemplateComponent as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Image as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Image as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ImplicitGridTracks as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ImplicitGridTracks as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Transform as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Transform as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::length::NonNegativeLengthPercentageOrNormal as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::length::NonNegativeLengthPercentageOrNormal as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::url::UrlOrNone as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::url::UrlOrNone as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::url::UrlOrNone as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Size as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Length as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <crate::values::specified::Color as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::background::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::background_position::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_color::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_style::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_width::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_top::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_right::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_bottom::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_left::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_block_start::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_block_end::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_inline_start::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_inline_end::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_radius::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_image::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_block_width::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_block_style::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_block_color::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_inline_width::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_inline_style::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_inline_color::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_block::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::border_inline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::overflow::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::overflow_clip_box::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::overscroll_behavior::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::container::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::page_break_before::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::page_break_after::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::page_break_inside::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::offset::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::columns::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::column_rule::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::font::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::font_variant::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::font_synthesis::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::marker::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::text_emphasis::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::text_wrap::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::white_space::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::_webkit_text_stroke::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::list_style::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::margin::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::margin_block::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::margin_inline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::scroll_margin::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::scroll_margin_block::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::scroll_margin_inline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::outline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::padding::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::padding_block::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::padding_inline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::scroll_padding::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::scroll_padding_block::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::scroll_padding_inline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::flex_flow::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::flex::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::gap::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::grid_row::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::grid_column::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::grid_area::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::grid_template::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::grid::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::place_content::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::place_self::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::place_items::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::inset::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::inset_block::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::inset_inline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::contain_intrinsic_size::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::mask::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::mask_position::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::text_decoration::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::transition::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::animation::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::scroll_timeline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                <shorthands::view_timeline::Longhands as SpecifiedValueInfo>::SUPPORTED_TYPES,
                0, // 'all' accepts no value other than CSS-wide keywords
        ];
        SUPPORTED_TYPES[self.0 as usize]
    }

    /// See PropertyId::collect_property_completion_keywords.
    pub(super) fn collect_property_completion_keywords(&self, f: KeywordsCollectFn) {
        fn do_nothing(_: KeywordsCollectFn) {}
        const COLLECT_FUNCTIONS: [fn(KeywordsCollectFn);
                                  489] = [
                <crate::values::specified::AlignContent as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::AlignItems as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::AlignSelf as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::AspectRatio as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::backface_visibility::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BaselineSource as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::border_collapse::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderImageRepeat as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::box_decoration_break::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::box_sizing::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BreakWithin as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::table::CaptionSide as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Clear as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::color_interpolation::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::color_interpolation_filters::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ColumnCount as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::column_fill::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::column_span::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Contain as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ContainerType as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ContentVisibility as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::direction::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Display as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::dominant_baseline::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::empty_cells::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::flex_direction::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::flex_wrap::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Float as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::font_kerning::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontLanguageOverride as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::font_optical_sizing::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontSizeAdjust as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontStretch as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::font_variant_caps::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontVariantEastAsian as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::font_variant_emoji::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontVariantLigatures as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontVariantNumeric as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::font_variant_position::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontWeight as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ForcedColorAdjust as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridAutoFlow as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::hyphens::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::image_orientation::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ImageRendering as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::ime_mode::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::InitialLetter as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::InsetArea as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::isolation::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::JustifyContent as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::JustifyItems as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::JustifySelf as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LineBreak as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::list_style_position::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_type::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::MasonryAutoFlow as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::MathDepth as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::math_style::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mix_blend_mode::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_box_align::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_box_collapse::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_box_direction::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_box_orient::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_box_pack::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::text::MozControlCharacterVisibility as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_float_edge::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_inert::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_math_variant::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Percentage as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_orient::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_osx_font_smoothing::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_text_size_adjust::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ui::MozTheme as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_top_layer::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_user_focus::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_user_input::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_user_modify::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_window_dragging::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_moz_window_shadow::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::object_fit::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OffsetRotate as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OutlineStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverflowAnchor as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverflowWrap as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::PageOrientation as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::SVGPaintOrder as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::pointer_events::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::position::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::PositionTryOrder as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::PositionVisibility as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::PrintColorAdjust as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Resize as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::ruby_align::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::RubyPosition as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::scroll_behavior::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ScrollSnapAlign as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ScrollSnapStop as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ScrollSnapType as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ScrollbarGutter as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::scrollbar_width::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::shape_rendering::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::stroke_linecap::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::stroke_linejoin::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::table_layout::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextAlign as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextAlignLast as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_anchor::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_combine_upright::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextDecorationLine as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextDecorationSkipInk as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_decoration_style::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextEmphasisPosition as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextJustify as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_orientation::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_rendering::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextTransform as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextUnderlinePosition as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_wrap_mode::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_wrap_style::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TouchAction as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TransformBox as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TransformStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::unicode_bidi::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::UserSelect as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::vector_effect::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::visibility::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LineClamp as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::_webkit_text_security::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::white_space_collapse::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::WordBreak as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::writing_mode::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::XTextScale as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ZIndex as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Zoom as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Appearance as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Appearance as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BoolInteger as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BoolInteger as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BreakBetween as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BreakBetween as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FillRule as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FillRule as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverflowClipBox as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverflowClipBox as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::SVGOpacity as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::SVGOpacity as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Integer as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Integer as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Integer as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontSynthesis as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeNumber as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Overflow as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OverscrollBehavior as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Opacity as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ColorOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::AnchorName as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::AnchorScope as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_composition::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_delay::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_direction::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_duration::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_fill_mode::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_iteration_count::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_name::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_play_state::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_timeline::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::animation_timing_function::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::backdrop_filter::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_attachment::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_blend_mode::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_clip::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_image::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_origin::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_position_x::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_position_y::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_repeat::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::background_size::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::NonNegativeLengthOrNumberRect> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderImageSlice> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderImageWidth> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderSpacing> as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::box_shadow::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::color::CaretColor as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::ClipRectOrAuto> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::basic_shape::ClipPath as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ColorPropertyValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ColorScheme as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::length::NonNegativeLengthOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ContainerName as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Content as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::CounterIncrement as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::CounterReset as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::CounterSet as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Cursor as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::DProperty as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::filter::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::FlexBasis> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontFamily as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontFeatureSettings as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontPalette as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontVariantAlternates as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::FontVariationSettings as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridTemplateAreas as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::HyphenateCharacter as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LetterSpacing as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LineHeight as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ListStyleType as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_clip::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_composite::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_image::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_mode::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_origin::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_position_x::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_position_y::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_repeat::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::mask_size::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::MozContextProperties as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::PositionOrAuto> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::OffsetPath as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::OffsetPosition> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::PageName as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Perspective as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::PositionAnchor as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::PositionTryOptions as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Quotes as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::Rotate> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::Scale> as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::scroll_timeline_axis::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::scroll_timeline_name::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::ui::ScrollbarColor> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::basic_shape::ShapeOutside as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::PageSize> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::SVGStrokeDashArray as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::SVGLength as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::SVGWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthOrNumber as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextDecorationLength as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextEmphasisStyle as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::TextIndent as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::TextOverflow> as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::text_shadow::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::transition_behavior::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::transition_delay::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::transition_duration::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::transition_property::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::transition_timing_function::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::Translate> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::VerticalAlign as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::view_timeline_axis::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::view_timeline_inset::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <longhands::view_timeline_name::SpecifiedValue as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LineWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::WillChange as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::WordSpacing as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::XLang as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::Position> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::Position> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::SVGPaint> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::SVGPaint> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::TransformOrigin> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::TransformOrigin> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridTemplateComponent as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridTemplateComponent as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Image as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Image as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ImplicitGridTracks as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ImplicitGridTracks as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Transform as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Transform as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::length::NonNegativeLengthPercentageOrNormal as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::length::NonNegativeLengthPercentageOrNormal as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::url::UrlOrNone as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::url::UrlOrNone as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::url::UrlOrNone as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::ContainIntrinsicSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::GridLine as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::MaxSize as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <Box<crate::values::specified::BorderCornerRadius> as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Size as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::BorderSideWidth as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentage as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::NonNegativeLengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Length as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::LengthPercentageOrAuto as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <crate::values::specified::Color as SpecifiedValueInfo>::collect_completion_keywords,
                <shorthands::background::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::background_position::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_color::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_style::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_width::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_top::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_right::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_bottom::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_left::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_block_start::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_block_end::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_inline_start::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_inline_end::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_radius::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_image::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_block_width::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_block_style::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_block_color::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_inline_width::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_inline_style::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_inline_color::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_block::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::border_inline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::overflow::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::overflow_clip_box::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::overscroll_behavior::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::container::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::page_break_before::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::page_break_after::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::page_break_inside::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::offset::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::columns::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::column_rule::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::font::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::font_variant::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::font_synthesis::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::marker::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::text_emphasis::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::text_wrap::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::white_space::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::_webkit_text_stroke::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::list_style::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::margin::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::margin_block::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::margin_inline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::scroll_margin::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::scroll_margin_block::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::scroll_margin_inline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::outline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::padding::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::padding_block::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::padding_inline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::scroll_padding::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::scroll_padding_block::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::scroll_padding_inline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::flex_flow::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::flex::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::gap::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::grid_row::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::grid_column::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::grid_area::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::grid_template::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::grid::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::place_content::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::place_self::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::place_items::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::inset::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::inset_block::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::inset_inline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::contain_intrinsic_size::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::mask::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::mask_position::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::text_decoration::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::transition::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::animation::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::scroll_timeline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                <shorthands::view_timeline::Longhands as SpecifiedValueInfo>::
                    collect_completion_keywords,
                do_nothing, // 'all' accepts no value other than CSS-wide keywords
        ];
        COLLECT_FUNCTIONS[self.0 as usize](f);
    }
}







/// A group for properties which may override each other via logical resolution.
#[derive(Clone, Copy, Debug, Eq, Hash, PartialEq)]
#[repr(u8)]
pub enum LogicalGroupId {
    /// overflow
    Overflow = 0,
    /// overscroll-behavior
    OverscrollBehavior = 1,
    /// border-style
    BorderStyle = 2,
    /// contain-intrinsic-size
    ContainIntrinsicSize = 3,
    /// max-size
    MaxSize = 4,
    /// border-radius
    BorderRadius = 5,
    /// size
    Size = 6,
    /// min-size
    MinSize = 7,
    /// border-width
    BorderWidth = 8,
    /// padding
    Padding = 9,
    /// scroll-padding
    ScrollPadding = 10,
    /// scroll-margin
    ScrollMargin = 11,
    /// inset
    Inset = 12,
    /// margin
    Margin = 13,
    /// border-color
    BorderColor = 14,
}

impl LogicalGroupId {
    /// Return the list of physical mapped properties for a given logical group.
    fn physical_properties(self) -> &'static [LonghandId] {
        static PROPS: [[LonghandId; 4]; 15] = [
        [
            
            LonghandId::OverflowY,
            LonghandId::OverflowX,
            LonghandId::OverflowY,
            LonghandId::OverflowY,
        ],
        [
            
            LonghandId::OverscrollBehaviorY,
            LonghandId::OverscrollBehaviorX,
            LonghandId::OverscrollBehaviorY,
            LonghandId::OverscrollBehaviorY,
        ],
        [
            
            LonghandId::BorderTopStyle,
            LonghandId::BorderRightStyle,
            LonghandId::BorderBottomStyle,
            LonghandId::BorderLeftStyle,
        ],
        [
            
            LonghandId::ContainIntrinsicHeight,
            LonghandId::ContainIntrinsicWidth,
            LonghandId::ContainIntrinsicHeight,
            LonghandId::ContainIntrinsicHeight,
        ],
        [
            
            LonghandId::MaxHeight,
            LonghandId::MaxWidth,
            LonghandId::MaxHeight,
            LonghandId::MaxHeight,
        ],
        [
            
            LonghandId::BorderTopLeftRadius,
            LonghandId::BorderTopRightRadius,
            LonghandId::BorderBottomRightRadius,
            LonghandId::BorderBottomLeftRadius,
        ],
        [
            
            LonghandId::Height,
            LonghandId::Width,
            LonghandId::Height,
            LonghandId::Height,
        ],
        [
            
            LonghandId::MinHeight,
            LonghandId::MinWidth,
            LonghandId::MinHeight,
            LonghandId::MinHeight,
        ],
        [
            
            LonghandId::BorderTopWidth,
            LonghandId::BorderRightWidth,
            LonghandId::BorderBottomWidth,
            LonghandId::BorderLeftWidth,
        ],
        [
            
            LonghandId::PaddingTop,
            LonghandId::PaddingRight,
            LonghandId::PaddingBottom,
            LonghandId::PaddingLeft,
        ],
        [
            
            LonghandId::ScrollPaddingTop,
            LonghandId::ScrollPaddingRight,
            LonghandId::ScrollPaddingBottom,
            LonghandId::ScrollPaddingLeft,
        ],
        [
            
            LonghandId::ScrollMarginTop,
            LonghandId::ScrollMarginRight,
            LonghandId::ScrollMarginBottom,
            LonghandId::ScrollMarginLeft,
        ],
        [
            
            LonghandId::Top,
            LonghandId::Right,
            LonghandId::Bottom,
            LonghandId::Left,
        ],
        [
            
            LonghandId::MarginTop,
            LonghandId::MarginRight,
            LonghandId::MarginBottom,
            LonghandId::MarginLeft,
        ],
        [
            
            LonghandId::BorderTopColor,
            LonghandId::BorderRightColor,
            LonghandId::BorderBottomColor,
            LonghandId::BorderLeftColor,
        ],
        ];
        &PROPS[self as usize]
    }
}

/// A set of logical groups.
#[derive(Clone, Copy, Debug, Default, MallocSizeOf, PartialEq)]
pub struct LogicalGroupSet {
    storage: [u32; (15 - 1 + 32) / 32]
}

impl LogicalGroupSet {
    /// Creates an empty `NonCustomPropertyIdSet`.
    pub fn new() -> Self {
        Self {
            storage: Default::default(),
        }
    }

    /// Return whether the given group is in the set
    #[inline]
    pub fn contains(&self, g: LogicalGroupId) -> bool {
        let bit = g as usize;
        (self.storage[bit / 32] & (1 << (bit % 32))) != 0
    }

    /// Insert a group the set.
    #[inline]
    pub fn insert(&mut self, g: LogicalGroupId) {
        let bit = g as usize;
        self.storage[bit / 32] |= 1 << (bit % 32);
    }
}


#[repr(u8)]
#[derive(Copy, Clone, Debug)]
pub(crate) enum PrioritaryPropertyId {
    Direction,
    FontSizeAdjust,
    FontStretch,
    FontStyle,
    FontWeight,
    ForcedColorAdjust,
    MathDepth,
    MozMinFontSizeRatio,
    TextOrientation,
    WritingMode,
    XTextScale,
    Zoom,
    ColorScheme,
    FontFamily,
    FontSize,
    LineHeight,
    XLang,
}

impl PrioritaryPropertyId {
    #[inline]
    pub fn to_longhand(self) -> LonghandId {
        static PRIORITARY_TO_LONGHAND: [LonghandId; property_counts::PRIORITARY] = [
            LonghandId::Direction,
            LonghandId::FontSizeAdjust,
            LonghandId::FontStretch,
            LonghandId::FontStyle,
            LonghandId::FontWeight,
            LonghandId::ForcedColorAdjust,
            LonghandId::MathDepth,
            LonghandId::MozMinFontSizeRatio,
            LonghandId::TextOrientation,
            LonghandId::WritingMode,
            LonghandId::XTextScale,
            LonghandId::Zoom,
            LonghandId::ColorScheme,
            LonghandId::FontFamily,
            LonghandId::FontSize,
            LonghandId::LineHeight,
            LonghandId::XLang,
        ];
        PRIORITARY_TO_LONGHAND[self as usize]
    }
    #[inline]
    pub fn from_longhand(l: LonghandId) -> Option<Self> {
        static LONGHAND_TO_PRIORITARY: [Option<PrioritaryPropertyId>; 410] = [
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::Direction),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::FontSizeAdjust),
            Some(PrioritaryPropertyId::FontStretch),
            Some(PrioritaryPropertyId::FontStyle),
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::FontWeight),
            Some(PrioritaryPropertyId::ForcedColorAdjust),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::MathDepth),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::MozMinFontSizeRatio),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::TextOrientation),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::WritingMode),
            Some(PrioritaryPropertyId::XTextScale),
            None,
            Some(PrioritaryPropertyId::Zoom),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::ColorScheme),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::FontFamily),
            None,
            None,
            Some(PrioritaryPropertyId::FontSize),
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::LineHeight),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(PrioritaryPropertyId::XLang),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
        ];
        LONGHAND_TO_PRIORITARY[l as usize]
    }
}

impl LonghandIdSet {
    /// The set of non-inherited longhands.
    #[inline]
    pub(super) fn reset() -> &'static Self {
        
static RESET: LonghandIdSet = LonghandIdSet {
    
    storage: [0xe5f97bf, 0xd99fc400, 0x972fc445, 0xbf00a11f, 0xdc399fe0, 0xffefffff, 0x77e6bfff, 0xf7f7fc20, 0xccbff486, 0xffffe3f7, 0xffffffff, 0xffffffff, 0x7fffbf]
};

        &RESET
    }

    #[inline]
    pub(super) fn discrete_animatable() -> &'static Self {
        
static DISCRETE_ANIMATABLE: LonghandIdSet = LonghandIdSet {
    
    storage: [0x7fc37ff7, 0xd9fffefc, 0xffddfbcd, 0x37fbefff, 0xc3c9fe87, 0x6f203f, 0x8f90027c, 0xe827e6b, 0x400500, 0x1e1c3c, 0x0, 0x0, 0x0]
};

        &DISCRETE_ANIMATABLE
    }

    #[inline]
    pub(super) fn logical() -> &'static Self {
        
static LOGICAL: LonghandIdSet = LonghandIdSet {
    
    storage: [0x0, 0x0, 0x0, 0x0, 0xc0000000, 0xd80c, 0x0, 0x0, 0x0, 0xa0a000, 0x1b06cb4f, 0x6f0d81b0, 0x3603]
};

        &LOGICAL
    }

    /// Returns the set of longhands that are ignored when document colors are
    /// disabled.
    #[inline]
    pub(super) fn ignored_when_colors_disabled() -> &'static Self {
        
static IGNORED_WHEN_COLORS_DISABLED: LonghandIdSet = LonghandIdSet {
    
    storage: [0x0, 0x0, 0x0, 0x0, 0x0, 0x100000, 0x198020, 0x0, 0x801, 0x4, 0x0, 0x0, 0x3d3ff00]
};

        &IGNORED_WHEN_COLORS_DISABLED
    }

    /// Only a few properties are allowed to depend on the visited state of
    /// links. When cascading visited styles, we can save time by only
    /// processing these properties.
    pub(super) fn visited_dependent() -> &'static Self {
        
static VISITED_DEPENDENT: LonghandIdSet = LonghandIdSet {
    
    storage: [0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x90000, 0x0, 0x30000000, 0x0, 0x0, 0x0, 0x3d3ff00]
};

        debug_assert!(Self::late_group().contains_all(&VISITED_DEPENDENT));
        &VISITED_DEPENDENT
    }

    #[inline]
    pub(super) fn prioritary_properties() -> &'static Self {
        
static PRIORITARY_PROPERTIES: LonghandIdSet = LonghandIdSet {
    
    storage: [0x80200000, 0x2000303, 0x20, 0x40000, 0x58, 0x0, 0x80100000, 0x104, 0x2000000, 0x0, 0x0, 0x0, 0x0]
};

        &PRIORITARY_PROPERTIES
    }

    #[inline]
    pub(super) fn late_group_only_inherited() -> &'static Self {
        
static LATE_GROUP_ONLY_INHERITED: LonghandIdSet = LonghandIdSet {
    
    storage: [0x71806840, 0x246038fc, 0x68d03b9a, 0x40fb5ee0, 0x23c66007, 0x100000, 0x8094000, 0x80802db, 0x31400b79, 0x1c08, 0x0, 0x0, 0x3800040]
};

        &LATE_GROUP_ONLY_INHERITED
    }

    #[inline]
    pub(super) fn late_group() -> &'static Self {
        
static LATE_GROUP: LonghandIdSet = LonghandIdSet {
    
    storage: [0x7fdfffff, 0xfdfffcfc, 0xffffffdf, 0xfffbffff, 0xffffffa7, 0xffffffff, 0x7fefffff, 0xfffffefb, 0xfdffffff, 0xffffffff, 0xffffffff, 0xffffffff, 0x3ffffff]
};

        &LATE_GROUP
    }

    /// Returns the set of properties that are declared as having no effect on
    /// Gecko <scrollbar> elements or their descendant scrollbar parts.
    #[cfg(debug_assertions)]
    #[cfg(feature = "gecko")]
    #[inline]
    pub fn has_no_effect_on_gecko_scrollbars() -> &'static Self {
        // data.py asserts that has_no_effect_on_gecko_scrollbars is True or
        // False for properties that are inherited and Gecko pref controlled,
        // and is None for all other properties.
        
static HAS_NO_EFFECT_ON_SCROLLBARS: LonghandIdSet = LonghandIdSet {
    
    storage: [0x40000000, 0x210, 0x92, 0x800000, 0x10, 0x0, 0x0, 0x80012, 0x2000000, 0x0, 0x0, 0x0, 0x0]
};

        &HAS_NO_EFFECT_ON_SCROLLBARS
    }

    /// Returns the set of border properties for the purpose of disabling native
    /// appearance.
    #[inline]
    pub fn border_background_properties() -> &'static Self {
        
static BORDER_BACKGROUND_PROPERTIES: LonghandIdSet = LonghandIdSet {
    
    storage: [0x0, 0x0, 0x0, 0x0, 0x0, 0x7f800, 0x20, 0x0, 0x0, 0xc0000000, 0x3fc03f, 0x0, 0x1ff00]
};

        &BORDER_BACKGROUND_PROPERTIES
    }
}

/// An identifier for a given longhand property.
#[derive(Clone, Copy, Eq, Hash, MallocSizeOf, PartialEq, ToComputedValue, ToResolvedValue, ToShmem)]
#[repr(u16)]
pub enum LonghandId {
        /// align-content
        AlignContent = 0,
        /// align-items
        AlignItems = 1,
        /// align-self
        AlignSelf = 2,
        /// aspect-ratio
        AspectRatio = 3,
        /// backface-visibility
        BackfaceVisibility = 4,
        /// baseline-source
        BaselineSource = 5,
        /// border-collapse
        BorderCollapse = 6,
        /// border-image-repeat
        BorderImageRepeat = 7,
        /// box-decoration-break
        BoxDecorationBreak = 8,
        /// box-sizing
        BoxSizing = 9,
        /// break-inside
        BreakInside = 10,
        /// caption-side
        CaptionSide = 11,
        /// clear
        Clear = 12,
        /// color-interpolation
        ColorInterpolation = 13,
        /// color-interpolation-filters
        ColorInterpolationFilters = 14,
        /// column-count
        ColumnCount = 15,
        /// column-fill
        ColumnFill = 16,
        /// column-span
        ColumnSpan = 17,
        /// contain
        Contain = 18,
        /// container-type
        ContainerType = 19,
        /// content-visibility
        ContentVisibility = 20,
        /// direction
        Direction = 21,
        /// display
        Display = 22,
        /// dominant-baseline
        DominantBaseline = 23,
        /// empty-cells
        EmptyCells = 24,
        /// flex-direction
        FlexDirection = 25,
        /// flex-wrap
        FlexWrap = 26,
        /// float
        Float = 27,
        /// font-kerning
        FontKerning = 28,
        /// font-language-override
        FontLanguageOverride = 29,
        /// font-optical-sizing
        FontOpticalSizing = 30,
        /// font-size-adjust
        FontSizeAdjust = 31,
        /// font-stretch
        FontStretch = 32,
        /// font-style
        FontStyle = 33,
        /// font-variant-caps
        FontVariantCaps = 34,
        /// font-variant-east-asian
        FontVariantEastAsian = 35,
        /// font-variant-emoji
        FontVariantEmoji = 36,
        /// font-variant-ligatures
        FontVariantLigatures = 37,
        /// font-variant-numeric
        FontVariantNumeric = 38,
        /// font-variant-position
        FontVariantPosition = 39,
        /// font-weight
        FontWeight = 40,
        /// forced-color-adjust
        ForcedColorAdjust = 41,
        /// grid-auto-flow
        GridAutoFlow = 42,
        /// hyphens
        Hyphens = 43,
        /// image-orientation
        ImageOrientation = 44,
        /// image-rendering
        ImageRendering = 45,
        /// ime-mode
        ImeMode = 46,
        /// initial-letter
        InitialLetter = 47,
        /// inset-area
        InsetArea = 48,
        /// isolation
        Isolation = 49,
        /// justify-content
        JustifyContent = 50,
        /// justify-items
        JustifyItems = 51,
        /// justify-self
        JustifySelf = 52,
        /// line-break
        LineBreak = 53,
        /// list-style-position
        ListStylePosition = 54,
        /// mask-type
        MaskType = 55,
        /// masonry-auto-flow
        MasonryAutoFlow = 56,
        /// math-depth
        MathDepth = 57,
        /// math-style
        MathStyle = 58,
        /// mix-blend-mode
        MixBlendMode = 59,
        /// -moz-box-align
        MozBoxAlign = 60,
        /// -moz-box-collapse
        MozBoxCollapse = 61,
        /// -moz-box-direction
        MozBoxDirection = 62,
        /// -moz-box-orient
        MozBoxOrient = 63,
        /// -moz-box-pack
        MozBoxPack = 64,
        /// -moz-control-character-visibility
        MozControlCharacterVisibility = 65,
        /// -moz-float-edge
        MozFloatEdge = 66,
        /// -moz-inert
        MozInert = 67,
        /// -moz-math-variant
        MozMathVariant = 68,
        /// -moz-min-font-size-ratio
        MozMinFontSizeRatio = 69,
        /// -moz-orient
        MozOrient = 70,
        /// -moz-osx-font-smoothing
        MozOsxFontSmoothing = 71,
        /// -moz-text-size-adjust
        MozTextSizeAdjust = 72,
        /// -moz-theme
        MozTheme = 73,
        /// -moz-top-layer
        MozTopLayer = 74,
        /// -moz-user-focus
        MozUserFocus = 75,
        /// -moz-user-input
        MozUserInput = 76,
        /// -moz-user-modify
        MozUserModify = 77,
        /// -moz-window-dragging
        MozWindowDragging = 78,
        /// -moz-window-shadow
        MozWindowShadow = 79,
        /// object-fit
        ObjectFit = 80,
        /// offset-rotate
        OffsetRotate = 81,
        /// outline-style
        OutlineStyle = 82,
        /// overflow-anchor
        OverflowAnchor = 83,
        /// overflow-wrap
        OverflowWrap = 84,
        /// page-orientation
        PageOrientation = 85,
        /// paint-order
        PaintOrder = 86,
        /// pointer-events
        PointerEvents = 87,
        /// position
        Position = 88,
        /// position-try-order
        PositionTryOrder = 89,
        /// position-visibility
        PositionVisibility = 90,
        /// print-color-adjust
        PrintColorAdjust = 91,
        /// resize
        Resize = 92,
        /// ruby-align
        RubyAlign = 93,
        /// ruby-position
        RubyPosition = 94,
        /// scroll-behavior
        ScrollBehavior = 95,
        /// scroll-snap-align
        ScrollSnapAlign = 96,
        /// scroll-snap-stop
        ScrollSnapStop = 97,
        /// scroll-snap-type
        ScrollSnapType = 98,
        /// scrollbar-gutter
        ScrollbarGutter = 99,
        /// scrollbar-width
        ScrollbarWidth = 100,
        /// shape-rendering
        ShapeRendering = 101,
        /// stroke-linecap
        StrokeLinecap = 102,
        /// stroke-linejoin
        StrokeLinejoin = 103,
        /// table-layout
        TableLayout = 104,
        /// text-align
        TextAlign = 105,
        /// text-align-last
        TextAlignLast = 106,
        /// text-anchor
        TextAnchor = 107,
        /// text-combine-upright
        TextCombineUpright = 108,
        /// text-decoration-line
        TextDecorationLine = 109,
        /// text-decoration-skip-ink
        TextDecorationSkipInk = 110,
        /// text-decoration-style
        TextDecorationStyle = 111,
        /// text-emphasis-position
        TextEmphasisPosition = 112,
        /// text-justify
        TextJustify = 113,
        /// text-orientation
        TextOrientation = 114,
        /// text-rendering
        TextRendering = 115,
        /// text-transform
        TextTransform = 116,
        /// text-underline-position
        TextUnderlinePosition = 117,
        /// text-wrap-mode
        TextWrapMode = 118,
        /// text-wrap-style
        TextWrapStyle = 119,
        /// touch-action
        TouchAction = 120,
        /// transform-box
        TransformBox = 121,
        /// transform-style
        TransformStyle = 122,
        /// unicode-bidi
        UnicodeBidi = 123,
        /// user-select
        UserSelect = 124,
        /// vector-effect
        VectorEffect = 125,
        /// visibility
        Visibility = 126,
        /// -webkit-line-clamp
        WebkitLineClamp = 127,
        /// -webkit-text-security
        WebkitTextSecurity = 128,
        /// white-space-collapse
        WhiteSpaceCollapse = 129,
        /// word-break
        WordBreak = 130,
        /// writing-mode
        WritingMode = 131,
        /// -x-text-scale
        XTextScale = 132,
        /// z-index
        ZIndex = 133,
        /// zoom
        Zoom = 134,
        /// appearance
        Appearance = 135,
        /// -moz-default-appearance
        MozDefaultAppearance = 136,
        /// -moz-force-broken-image-icon
        MozForceBrokenImageIcon = 137,
        /// -moz-subtree-hidden-only-visually
        MozSubtreeHiddenOnlyVisually = 138,
        /// break-after
        BreakAfter = 139,
        /// break-before
        BreakBefore = 140,
        /// clip-rule
        ClipRule = 141,
        /// fill-rule
        FillRule = 142,
        /// overflow-clip-box-block
        OverflowClipBoxBlock = 143,
        /// overflow-clip-box-inline
        OverflowClipBoxInline = 144,
        /// fill-opacity
        FillOpacity = 145,
        /// stroke-opacity
        StrokeOpacity = 146,
        /// -moz-box-ordinal-group
        MozBoxOrdinalGroup = 147,
        /// order
        Order = 148,
        /// -x-span
        XSpan = 149,
        /// font-synthesis-position
        FontSynthesisPosition = 150,
        /// font-synthesis-small-caps
        FontSynthesisSmallCaps = 151,
        /// font-synthesis-style
        FontSynthesisStyle = 152,
        /// font-synthesis-weight
        FontSynthesisWeight = 153,
        /// flex-grow
        FlexGrow = 154,
        /// flex-shrink
        FlexShrink = 155,
        /// -moz-box-flex
        MozBoxFlex = 156,
        /// stroke-miterlimit
        StrokeMiterlimit = 157,
        /// overflow-block
        OverflowBlock = 158,
        /// overflow-inline
        OverflowInline = 159,
        /// overflow-x
        OverflowX = 160,
        /// overflow-y
        OverflowY = 161,
        /// overscroll-behavior-block
        OverscrollBehaviorBlock = 162,
        /// overscroll-behavior-inline
        OverscrollBehaviorInline = 163,
        /// overscroll-behavior-x
        OverscrollBehaviorX = 164,
        /// overscroll-behavior-y
        OverscrollBehaviorY = 165,
        /// flood-opacity
        FloodOpacity = 166,
        /// -moz-window-opacity
        MozWindowOpacity = 167,
        /// opacity
        Opacity = 168,
        /// shape-image-threshold
        ShapeImageThreshold = 169,
        /// stop-opacity
        StopOpacity = 170,
        /// border-block-end-style
        BorderBlockEndStyle = 171,
        /// border-block-start-style
        BorderBlockStartStyle = 172,
        /// border-bottom-style
        BorderBottomStyle = 173,
        /// border-inline-end-style
        BorderInlineEndStyle = 174,
        /// border-inline-start-style
        BorderInlineStartStyle = 175,
        /// border-left-style
        BorderLeftStyle = 176,
        /// border-right-style
        BorderRightStyle = 177,
        /// border-top-style
        BorderTopStyle = 178,
        /// column-rule-style
        ColumnRuleStyle = 179,
        /// accent-color
        AccentColor = 180,
        /// anchor-name
        AnchorName = 181,
        /// anchor-scope
        AnchorScope = 182,
        /// animation-composition
        AnimationComposition = 183,
        /// animation-delay
        AnimationDelay = 184,
        /// animation-direction
        AnimationDirection = 185,
        /// animation-duration
        AnimationDuration = 186,
        /// animation-fill-mode
        AnimationFillMode = 187,
        /// animation-iteration-count
        AnimationIterationCount = 188,
        /// animation-name
        AnimationName = 189,
        /// animation-play-state
        AnimationPlayState = 190,
        /// animation-timeline
        AnimationTimeline = 191,
        /// animation-timing-function
        AnimationTimingFunction = 192,
        /// backdrop-filter
        BackdropFilter = 193,
        /// background-attachment
        BackgroundAttachment = 194,
        /// background-blend-mode
        BackgroundBlendMode = 195,
        /// background-clip
        BackgroundClip = 196,
        /// background-image
        BackgroundImage = 197,
        /// background-origin
        BackgroundOrigin = 198,
        /// background-position-x
        BackgroundPositionX = 199,
        /// background-position-y
        BackgroundPositionY = 200,
        /// background-repeat
        BackgroundRepeat = 201,
        /// background-size
        BackgroundSize = 202,
        /// border-image-outset
        BorderImageOutset = 203,
        /// border-image-slice
        BorderImageSlice = 204,
        /// border-image-width
        BorderImageWidth = 205,
        /// border-spacing
        BorderSpacing = 206,
        /// box-shadow
        BoxShadow = 207,
        /// caret-color
        CaretColor = 208,
        /// clip
        Clip = 209,
        /// clip-path
        ClipPath = 210,
        /// color
        Color = 211,
        /// color-scheme
        ColorScheme = 212,
        /// column-width
        ColumnWidth = 213,
        /// container-name
        ContainerName = 214,
        /// content
        Content = 215,
        /// counter-increment
        CounterIncrement = 216,
        /// counter-reset
        CounterReset = 217,
        /// counter-set
        CounterSet = 218,
        /// cursor
        Cursor = 219,
        /// d
        D = 220,
        /// filter
        Filter = 221,
        /// flex-basis
        FlexBasis = 222,
        /// font-family
        FontFamily = 223,
        /// font-feature-settings
        FontFeatureSettings = 224,
        /// font-palette
        FontPalette = 225,
        /// font-size
        FontSize = 226,
        /// font-variant-alternates
        FontVariantAlternates = 227,
        /// font-variation-settings
        FontVariationSettings = 228,
        /// grid-template-areas
        GridTemplateAreas = 229,
        /// hyphenate-character
        HyphenateCharacter = 230,
        /// letter-spacing
        LetterSpacing = 231,
        /// line-height
        LineHeight = 232,
        /// list-style-type
        ListStyleType = 233,
        /// mask-clip
        MaskClip = 234,
        /// mask-composite
        MaskComposite = 235,
        /// mask-image
        MaskImage = 236,
        /// mask-mode
        MaskMode = 237,
        /// mask-origin
        MaskOrigin = 238,
        /// mask-position-x
        MaskPositionX = 239,
        /// mask-position-y
        MaskPositionY = 240,
        /// mask-repeat
        MaskRepeat = 241,
        /// mask-size
        MaskSize = 242,
        /// -moz-context-properties
        MozContextProperties = 243,
        /// offset-anchor
        OffsetAnchor = 244,
        /// offset-path
        OffsetPath = 245,
        /// offset-position
        OffsetPosition = 246,
        /// page
        Page = 247,
        /// perspective
        Perspective = 248,
        /// position-anchor
        PositionAnchor = 249,
        /// position-try-options
        PositionTryOptions = 250,
        /// quotes
        Quotes = 251,
        /// rotate
        Rotate = 252,
        /// scale
        Scale = 253,
        /// scroll-timeline-axis
        ScrollTimelineAxis = 254,
        /// scroll-timeline-name
        ScrollTimelineName = 255,
        /// scrollbar-color
        ScrollbarColor = 256,
        /// shape-outside
        ShapeOutside = 257,
        /// size
        Size = 258,
        /// stroke-dasharray
        StrokeDasharray = 259,
        /// stroke-dashoffset
        StrokeDashoffset = 260,
        /// stroke-width
        StrokeWidth = 261,
        /// tab-size
        TabSize = 262,
        /// text-decoration-thickness
        TextDecorationThickness = 263,
        /// text-emphasis-style
        TextEmphasisStyle = 264,
        /// text-indent
        TextIndent = 265,
        /// text-overflow
        TextOverflow = 266,
        /// text-shadow
        TextShadow = 267,
        /// transition-behavior
        TransitionBehavior = 268,
        /// transition-delay
        TransitionDelay = 269,
        /// transition-duration
        TransitionDuration = 270,
        /// transition-property
        TransitionProperty = 271,
        /// transition-timing-function
        TransitionTimingFunction = 272,
        /// translate
        Translate = 273,
        /// vertical-align
        VerticalAlign = 274,
        /// view-timeline-axis
        ViewTimelineAxis = 275,
        /// view-timeline-inset
        ViewTimelineInset = 276,
        /// view-timeline-name
        ViewTimelineName = 277,
        /// -webkit-text-stroke-width
        WebkitTextStrokeWidth = 278,
        /// will-change
        WillChange = 279,
        /// word-spacing
        WordSpacing = 280,
        /// -x-lang
        XLang = 281,
        /// object-position
        ObjectPosition = 282,
        /// perspective-origin
        PerspectiveOrigin = 283,
        /// fill
        Fill = 284,
        /// stroke
        Stroke = 285,
        /// -moz-window-transform-origin
        MozWindowTransformOrigin = 286,
        /// transform-origin
        TransformOrigin = 287,
        /// grid-template-columns
        GridTemplateColumns = 288,
        /// grid-template-rows
        GridTemplateRows = 289,
        /// border-image-source
        BorderImageSource = 290,
        /// list-style-image
        ListStyleImage = 291,
        /// grid-auto-columns
        GridAutoColumns = 292,
        /// grid-auto-rows
        GridAutoRows = 293,
        /// -moz-window-transform
        MozWindowTransform = 294,
        /// transform
        Transform = 295,
        /// column-gap
        ColumnGap = 296,
        /// row-gap
        RowGap = 297,
        /// marker-end
        MarkerEnd = 298,
        /// marker-mid
        MarkerMid = 299,
        /// marker-start
        MarkerStart = 300,
        /// contain-intrinsic-block-size
        ContainIntrinsicBlockSize = 301,
        /// contain-intrinsic-height
        ContainIntrinsicHeight = 302,
        /// contain-intrinsic-inline-size
        ContainIntrinsicInlineSize = 303,
        /// contain-intrinsic-width
        ContainIntrinsicWidth = 304,
        /// grid-column-end
        GridColumnEnd = 305,
        /// grid-column-start
        GridColumnStart = 306,
        /// grid-row-end
        GridRowEnd = 307,
        /// grid-row-start
        GridRowStart = 308,
        /// max-block-size
        MaxBlockSize = 309,
        /// max-height
        MaxHeight = 310,
        /// max-inline-size
        MaxInlineSize = 311,
        /// max-width
        MaxWidth = 312,
        /// cx
        Cx = 313,
        /// cy
        Cy = 314,
        /// offset-distance
        OffsetDistance = 315,
        /// x
        X = 316,
        /// y
        Y = 317,
        /// border-bottom-left-radius
        BorderBottomLeftRadius = 318,
        /// border-bottom-right-radius
        BorderBottomRightRadius = 319,
        /// border-end-end-radius
        BorderEndEndRadius = 320,
        /// border-end-start-radius
        BorderEndStartRadius = 321,
        /// border-start-end-radius
        BorderStartEndRadius = 322,
        /// border-start-start-radius
        BorderStartStartRadius = 323,
        /// border-top-left-radius
        BorderTopLeftRadius = 324,
        /// border-top-right-radius
        BorderTopRightRadius = 325,
        /// block-size
        BlockSize = 326,
        /// height
        Height = 327,
        /// inline-size
        InlineSize = 328,
        /// min-block-size
        MinBlockSize = 329,
        /// min-height
        MinHeight = 330,
        /// min-inline-size
        MinInlineSize = 331,
        /// min-width
        MinWidth = 332,
        /// width
        Width = 333,
        /// border-block-end-width
        BorderBlockEndWidth = 334,
        /// border-block-start-width
        BorderBlockStartWidth = 335,
        /// border-bottom-width
        BorderBottomWidth = 336,
        /// border-inline-end-width
        BorderInlineEndWidth = 337,
        /// border-inline-start-width
        BorderInlineStartWidth = 338,
        /// border-left-width
        BorderLeftWidth = 339,
        /// border-right-width
        BorderRightWidth = 340,
        /// border-top-width
        BorderTopWidth = 341,
        /// column-rule-width
        ColumnRuleWidth = 342,
        /// outline-width
        OutlineWidth = 343,
        /// padding-block-end
        PaddingBlockEnd = 344,
        /// padding-block-start
        PaddingBlockStart = 345,
        /// padding-bottom
        PaddingBottom = 346,
        /// padding-inline-end
        PaddingInlineEnd = 347,
        /// padding-inline-start
        PaddingInlineStart = 348,
        /// padding-left
        PaddingLeft = 349,
        /// padding-right
        PaddingRight = 350,
        /// padding-top
        PaddingTop = 351,
        /// r
        R = 352,
        /// shape-margin
        ShapeMargin = 353,
        /// rx
        Rx = 354,
        /// ry
        Ry = 355,
        /// scroll-padding-block-end
        ScrollPaddingBlockEnd = 356,
        /// scroll-padding-block-start
        ScrollPaddingBlockStart = 357,
        /// scroll-padding-bottom
        ScrollPaddingBottom = 358,
        /// scroll-padding-inline-end
        ScrollPaddingInlineEnd = 359,
        /// scroll-padding-inline-start
        ScrollPaddingInlineStart = 360,
        /// scroll-padding-left
        ScrollPaddingLeft = 361,
        /// scroll-padding-right
        ScrollPaddingRight = 362,
        /// scroll-padding-top
        ScrollPaddingTop = 363,
        /// -moz-window-input-region-margin
        MozWindowInputRegionMargin = 364,
        /// outline-offset
        OutlineOffset = 365,
        /// overflow-clip-margin
        OverflowClipMargin = 366,
        /// scroll-margin-block-end
        ScrollMarginBlockEnd = 367,
        /// scroll-margin-block-start
        ScrollMarginBlockStart = 368,
        /// scroll-margin-bottom
        ScrollMarginBottom = 369,
        /// scroll-margin-inline-end
        ScrollMarginInlineEnd = 370,
        /// scroll-margin-inline-start
        ScrollMarginInlineStart = 371,
        /// scroll-margin-left
        ScrollMarginLeft = 372,
        /// scroll-margin-right
        ScrollMarginRight = 373,
        /// scroll-margin-top
        ScrollMarginTop = 374,
        /// bottom
        Bottom = 375,
        /// inset-block-end
        InsetBlockEnd = 376,
        /// inset-block-start
        InsetBlockStart = 377,
        /// inset-inline-end
        InsetInlineEnd = 378,
        /// inset-inline-start
        InsetInlineStart = 379,
        /// left
        Left = 380,
        /// margin-block-end
        MarginBlockEnd = 381,
        /// margin-block-start
        MarginBlockStart = 382,
        /// margin-bottom
        MarginBottom = 383,
        /// margin-inline-end
        MarginInlineEnd = 384,
        /// margin-inline-start
        MarginInlineStart = 385,
        /// margin-left
        MarginLeft = 386,
        /// margin-right
        MarginRight = 387,
        /// margin-top
        MarginTop = 388,
        /// right
        Right = 389,
        /// text-underline-offset
        TextUnderlineOffset = 390,
        /// top
        Top = 391,
        /// background-color
        BackgroundColor = 392,
        /// border-block-end-color
        BorderBlockEndColor = 393,
        /// border-block-start-color
        BorderBlockStartColor = 394,
        /// border-bottom-color
        BorderBottomColor = 395,
        /// border-inline-end-color
        BorderInlineEndColor = 396,
        /// border-inline-start-color
        BorderInlineStartColor = 397,
        /// border-left-color
        BorderLeftColor = 398,
        /// border-right-color
        BorderRightColor = 399,
        /// border-top-color
        BorderTopColor = 400,
        /// column-rule-color
        ColumnRuleColor = 401,
        /// flood-color
        FloodColor = 402,
        /// lighting-color
        LightingColor = 403,
        /// outline-color
        OutlineColor = 404,
        /// stop-color
        StopColor = 405,
        /// text-decoration-color
        TextDecorationColor = 406,
        /// text-emphasis-color
        TextEmphasisColor = 407,
        /// -webkit-text-fill-color
        WebkitTextFillColor = 408,
        /// -webkit-text-stroke-color
        WebkitTextStrokeColor = 409,
}

enum LogicalMappingKind {
    Side(LogicalSide),
    Corner(LogicalCorner),
    Axis(LogicalAxis),
}

struct LogicalMappingData {
    group: LogicalGroupId,
    kind: LogicalMappingKind,
}

impl LogicalMappingData {
    fn to_physical(&self, wm: WritingMode) -> LonghandId {
        let index = match self.kind {
            LogicalMappingKind::Side(s) => s.to_physical(wm) as usize,
            LogicalMappingKind::Corner(c) => c.to_physical(wm) as usize,
            LogicalMappingKind::Axis(a) => a.to_physical(wm) as usize,
        };
        self.group.physical_properties()[index]
    }
}

impl LonghandId {
    /// Returns an iterator over all the shorthands that include this longhand.
    pub fn shorthands(self) -> NonCustomPropertyIterator<ShorthandId> {
        // first generate longhand to shorthands lookup map
        //
        // NOTE(emilio): This currently doesn't exclude the "all" shorthand. It
        // could potentially do so, which would speed up serialization
        // algorithms and what not, I guess.
        

        // based on lookup results for each longhand, create result arrays
        static MAP: [&'static [ShorthandId]; property_counts::LONGHANDS] = [
            &[
                    ShorthandId::All,
                    ShorthandId::PlaceContent,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PlaceItems,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PlaceSelf,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PageBreakInside,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Columns,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Container,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::FlexFlow,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::FlexFlow,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PlaceContent,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PlaceItems,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PlaceSelf,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Offset,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextWrap,
                    ShorthandId::WhiteSpace,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextWrap,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::WhiteSpace,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PageBreakAfter,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PageBreakBefore,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::OverflowClipBox,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::OverflowClipBox,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::FontSynthesis,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::FontSynthesis,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::FontSynthesis,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::FontSynthesis,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Overflow,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Overflow,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::OverscrollBehavior,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::OverscrollBehavior,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderBlock,
                    ShorthandId::BorderBlockEnd,
                    ShorthandId::BorderBlockStyle,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderBlock,
                    ShorthandId::BorderBlockStart,
                    ShorthandId::BorderBlockStyle,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderBottom,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderInline,
                    ShorthandId::BorderInlineEnd,
                    ShorthandId::BorderInlineStyle,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderInline,
                    ShorthandId::BorderInlineStart,
                    ShorthandId::BorderInlineStyle,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderLeft,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderRight,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderStyle,
                    ShorthandId::BorderTop,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Animation,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
                    ShorthandId::BackgroundPosition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
                    ShorthandId::BackgroundPosition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Columns,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Container,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Flex,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
                    ShorthandId::FontVariant,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Font,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
                    ShorthandId::MaskPosition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
                    ShorthandId::MaskPosition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Mask,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Offset,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Offset,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Offset,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollTimeline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollTimeline,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextEmphasis,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Transition,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ViewTimeline,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ViewTimeline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::WebkitTextStroke,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Grid,
                    ShorthandId::GridTemplate,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderImage,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ListStyle,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Grid,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Gap,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Gap,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Marker,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ContainIntrinsicSize,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ContainIntrinsicSize,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridColumn,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridColumn,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridRow,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::GridArea,
                    ShorthandId::GridRow,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Offset,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderRadius,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderBlock,
                    ShorthandId::BorderBlockEnd,
                    ShorthandId::BorderBlockWidth,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderBlock,
                    ShorthandId::BorderBlockStart,
                    ShorthandId::BorderBlockWidth,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderBottom,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderInline,
                    ShorthandId::BorderInlineEnd,
                    ShorthandId::BorderInlineWidth,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderInline,
                    ShorthandId::BorderInlineStart,
                    ShorthandId::BorderInlineWidth,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderLeft,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderRight,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderWidth,
                    ShorthandId::BorderTop,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PaddingBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PaddingBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PaddingInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::PaddingInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Padding,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPaddingBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPaddingBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPadding,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPaddingInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPaddingInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPadding,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPadding,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollPadding,
            ],
            &[
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMarginBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMarginBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMargin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMarginInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMarginInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMargin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMargin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ScrollMargin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Inset,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::InsetBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::InsetBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::InsetInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::InsetInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Inset,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::MarginBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::MarginBlock,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::MarginInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::MarginInline,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Margin,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Inset,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Inset,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Background,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderBlock,
                    ShorthandId::BorderBlockEnd,
                    ShorthandId::BorderBlockColor,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderBlock,
                    ShorthandId::BorderBlockStart,
                    ShorthandId::BorderBlockColor,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderBottom,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderInline,
                    ShorthandId::BorderInlineEnd,
                    ShorthandId::BorderInlineColor,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::BorderInline,
                    ShorthandId::BorderInlineStart,
                    ShorthandId::BorderInlineColor,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderLeft,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderRight,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Border,
                    ShorthandId::BorderColor,
                    ShorthandId::BorderTop,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::ColumnRule,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::Outline,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextDecoration,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::TextEmphasis,
            ],
            &[
                    ShorthandId::All,
            ],
            &[
                    ShorthandId::All,
                    ShorthandId::WebkitTextStroke,
            ],
        ];

        NonCustomPropertyIterator {
            filter: NonCustomPropertyId::from(self).enabled_for_all_content(),
            iter: MAP[self as usize].iter(),
        }
    }

    pub(super) fn parse_value<'i, 't>(
        self,
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<PropertyDeclaration, ParseError<'i>> {
        type ParsePropertyFn = for<'i, 't> fn(
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<PropertyDeclaration, ParseError<'i>>;
        static PARSE_PROPERTY: [ParsePropertyFn; 410] = [
            longhands::align_content::parse_declared,
            longhands::align_items::parse_declared,
            longhands::align_self::parse_declared,
            longhands::aspect_ratio::parse_declared,
            longhands::backface_visibility::parse_declared,
            longhands::baseline_source::parse_declared,
            longhands::border_collapse::parse_declared,
            longhands::border_image_repeat::parse_declared,
            longhands::box_decoration_break::parse_declared,
            longhands::box_sizing::parse_declared,
            longhands::break_inside::parse_declared,
            longhands::caption_side::parse_declared,
            longhands::clear::parse_declared,
            longhands::color_interpolation::parse_declared,
            longhands::color_interpolation_filters::parse_declared,
            longhands::column_count::parse_declared,
            longhands::column_fill::parse_declared,
            longhands::column_span::parse_declared,
            longhands::contain::parse_declared,
            longhands::container_type::parse_declared,
            longhands::content_visibility::parse_declared,
            longhands::direction::parse_declared,
            longhands::display::parse_declared,
            longhands::dominant_baseline::parse_declared,
            longhands::empty_cells::parse_declared,
            longhands::flex_direction::parse_declared,
            longhands::flex_wrap::parse_declared,
            longhands::float::parse_declared,
            longhands::font_kerning::parse_declared,
            longhands::font_language_override::parse_declared,
            longhands::font_optical_sizing::parse_declared,
            longhands::font_size_adjust::parse_declared,
            longhands::font_stretch::parse_declared,
            longhands::font_style::parse_declared,
            longhands::font_variant_caps::parse_declared,
            longhands::font_variant_east_asian::parse_declared,
            longhands::font_variant_emoji::parse_declared,
            longhands::font_variant_ligatures::parse_declared,
            longhands::font_variant_numeric::parse_declared,
            longhands::font_variant_position::parse_declared,
            longhands::font_weight::parse_declared,
            longhands::forced_color_adjust::parse_declared,
            longhands::grid_auto_flow::parse_declared,
            longhands::hyphens::parse_declared,
            longhands::image_orientation::parse_declared,
            longhands::image_rendering::parse_declared,
            longhands::ime_mode::parse_declared,
            longhands::initial_letter::parse_declared,
            longhands::inset_area::parse_declared,
            longhands::isolation::parse_declared,
            longhands::justify_content::parse_declared,
            longhands::justify_items::parse_declared,
            longhands::justify_self::parse_declared,
            longhands::line_break::parse_declared,
            longhands::list_style_position::parse_declared,
            longhands::mask_type::parse_declared,
            longhands::masonry_auto_flow::parse_declared,
            longhands::math_depth::parse_declared,
            longhands::math_style::parse_declared,
            longhands::mix_blend_mode::parse_declared,
            longhands::_moz_box_align::parse_declared,
            longhands::_moz_box_collapse::parse_declared,
            longhands::_moz_box_direction::parse_declared,
            longhands::_moz_box_orient::parse_declared,
            longhands::_moz_box_pack::parse_declared,
            longhands::_moz_control_character_visibility::parse_declared,
            longhands::_moz_float_edge::parse_declared,
            longhands::_moz_inert::parse_declared,
            longhands::_moz_math_variant::parse_declared,
            longhands::_moz_min_font_size_ratio::parse_declared,
            longhands::_moz_orient::parse_declared,
            longhands::_moz_osx_font_smoothing::parse_declared,
            longhands::_moz_text_size_adjust::parse_declared,
            longhands::_moz_theme::parse_declared,
            longhands::_moz_top_layer::parse_declared,
            longhands::_moz_user_focus::parse_declared,
            longhands::_moz_user_input::parse_declared,
            longhands::_moz_user_modify::parse_declared,
            longhands::_moz_window_dragging::parse_declared,
            longhands::_moz_window_shadow::parse_declared,
            longhands::object_fit::parse_declared,
            longhands::offset_rotate::parse_declared,
            longhands::outline_style::parse_declared,
            longhands::overflow_anchor::parse_declared,
            longhands::overflow_wrap::parse_declared,
            longhands::page_orientation::parse_declared,
            longhands::paint_order::parse_declared,
            longhands::pointer_events::parse_declared,
            longhands::position::parse_declared,
            longhands::position_try_order::parse_declared,
            longhands::position_visibility::parse_declared,
            longhands::print_color_adjust::parse_declared,
            longhands::resize::parse_declared,
            longhands::ruby_align::parse_declared,
            longhands::ruby_position::parse_declared,
            longhands::scroll_behavior::parse_declared,
            longhands::scroll_snap_align::parse_declared,
            longhands::scroll_snap_stop::parse_declared,
            longhands::scroll_snap_type::parse_declared,
            longhands::scrollbar_gutter::parse_declared,
            longhands::scrollbar_width::parse_declared,
            longhands::shape_rendering::parse_declared,
            longhands::stroke_linecap::parse_declared,
            longhands::stroke_linejoin::parse_declared,
            longhands::table_layout::parse_declared,
            longhands::text_align::parse_declared,
            longhands::text_align_last::parse_declared,
            longhands::text_anchor::parse_declared,
            longhands::text_combine_upright::parse_declared,
            longhands::text_decoration_line::parse_declared,
            longhands::text_decoration_skip_ink::parse_declared,
            longhands::text_decoration_style::parse_declared,
            longhands::text_emphasis_position::parse_declared,
            longhands::text_justify::parse_declared,
            longhands::text_orientation::parse_declared,
            longhands::text_rendering::parse_declared,
            longhands::text_transform::parse_declared,
            longhands::text_underline_position::parse_declared,
            longhands::text_wrap_mode::parse_declared,
            longhands::text_wrap_style::parse_declared,
            longhands::touch_action::parse_declared,
            longhands::transform_box::parse_declared,
            longhands::transform_style::parse_declared,
            longhands::unicode_bidi::parse_declared,
            longhands::user_select::parse_declared,
            longhands::vector_effect::parse_declared,
            longhands::visibility::parse_declared,
            longhands::_webkit_line_clamp::parse_declared,
            longhands::_webkit_text_security::parse_declared,
            longhands::white_space_collapse::parse_declared,
            longhands::word_break::parse_declared,
            longhands::writing_mode::parse_declared,
            longhands::_x_text_scale::parse_declared,
            longhands::z_index::parse_declared,
            longhands::zoom::parse_declared,
            longhands::appearance::parse_declared,
            longhands::_moz_default_appearance::parse_declared,
            longhands::_moz_force_broken_image_icon::parse_declared,
            longhands::_moz_subtree_hidden_only_visually::parse_declared,
            longhands::break_after::parse_declared,
            longhands::break_before::parse_declared,
            longhands::clip_rule::parse_declared,
            longhands::fill_rule::parse_declared,
            longhands::overflow_clip_box_block::parse_declared,
            longhands::overflow_clip_box_inline::parse_declared,
            longhands::fill_opacity::parse_declared,
            longhands::stroke_opacity::parse_declared,
            longhands::_moz_box_ordinal_group::parse_declared,
            longhands::order::parse_declared,
            longhands::_x_span::parse_declared,
            longhands::font_synthesis_position::parse_declared,
            longhands::font_synthesis_small_caps::parse_declared,
            longhands::font_synthesis_style::parse_declared,
            longhands::font_synthesis_weight::parse_declared,
            longhands::flex_grow::parse_declared,
            longhands::flex_shrink::parse_declared,
            longhands::_moz_box_flex::parse_declared,
            longhands::stroke_miterlimit::parse_declared,
            longhands::overflow_block::parse_declared,
            longhands::overflow_inline::parse_declared,
            longhands::overflow_x::parse_declared,
            longhands::overflow_y::parse_declared,
            longhands::overscroll_behavior_block::parse_declared,
            longhands::overscroll_behavior_inline::parse_declared,
            longhands::overscroll_behavior_x::parse_declared,
            longhands::overscroll_behavior_y::parse_declared,
            longhands::flood_opacity::parse_declared,
            longhands::_moz_window_opacity::parse_declared,
            longhands::opacity::parse_declared,
            longhands::shape_image_threshold::parse_declared,
            longhands::stop_opacity::parse_declared,
            longhands::border_block_end_style::parse_declared,
            longhands::border_block_start_style::parse_declared,
            longhands::border_bottom_style::parse_declared,
            longhands::border_inline_end_style::parse_declared,
            longhands::border_inline_start_style::parse_declared,
            longhands::border_left_style::parse_declared,
            longhands::border_right_style::parse_declared,
            longhands::border_top_style::parse_declared,
            longhands::column_rule_style::parse_declared,
            longhands::accent_color::parse_declared,
            longhands::anchor_name::parse_declared,
            longhands::anchor_scope::parse_declared,
            longhands::animation_composition::parse_declared,
            longhands::animation_delay::parse_declared,
            longhands::animation_direction::parse_declared,
            longhands::animation_duration::parse_declared,
            longhands::animation_fill_mode::parse_declared,
            longhands::animation_iteration_count::parse_declared,
            longhands::animation_name::parse_declared,
            longhands::animation_play_state::parse_declared,
            longhands::animation_timeline::parse_declared,
            longhands::animation_timing_function::parse_declared,
            longhands::backdrop_filter::parse_declared,
            longhands::background_attachment::parse_declared,
            longhands::background_blend_mode::parse_declared,
            longhands::background_clip::parse_declared,
            longhands::background_image::parse_declared,
            longhands::background_origin::parse_declared,
            longhands::background_position_x::parse_declared,
            longhands::background_position_y::parse_declared,
            longhands::background_repeat::parse_declared,
            longhands::background_size::parse_declared,
            longhands::border_image_outset::parse_declared,
            longhands::border_image_slice::parse_declared,
            longhands::border_image_width::parse_declared,
            longhands::border_spacing::parse_declared,
            longhands::box_shadow::parse_declared,
            longhands::caret_color::parse_declared,
            longhands::clip::parse_declared,
            longhands::clip_path::parse_declared,
            longhands::color::parse_declared,
            longhands::color_scheme::parse_declared,
            longhands::column_width::parse_declared,
            longhands::container_name::parse_declared,
            longhands::content::parse_declared,
            longhands::counter_increment::parse_declared,
            longhands::counter_reset::parse_declared,
            longhands::counter_set::parse_declared,
            longhands::cursor::parse_declared,
            longhands::d::parse_declared,
            longhands::filter::parse_declared,
            longhands::flex_basis::parse_declared,
            longhands::font_family::parse_declared,
            longhands::font_feature_settings::parse_declared,
            longhands::font_palette::parse_declared,
            longhands::font_size::parse_declared,
            longhands::font_variant_alternates::parse_declared,
            longhands::font_variation_settings::parse_declared,
            longhands::grid_template_areas::parse_declared,
            longhands::hyphenate_character::parse_declared,
            longhands::letter_spacing::parse_declared,
            longhands::line_height::parse_declared,
            longhands::list_style_type::parse_declared,
            longhands::mask_clip::parse_declared,
            longhands::mask_composite::parse_declared,
            longhands::mask_image::parse_declared,
            longhands::mask_mode::parse_declared,
            longhands::mask_origin::parse_declared,
            longhands::mask_position_x::parse_declared,
            longhands::mask_position_y::parse_declared,
            longhands::mask_repeat::parse_declared,
            longhands::mask_size::parse_declared,
            longhands::_moz_context_properties::parse_declared,
            longhands::offset_anchor::parse_declared,
            longhands::offset_path::parse_declared,
            longhands::offset_position::parse_declared,
            longhands::page::parse_declared,
            longhands::perspective::parse_declared,
            longhands::position_anchor::parse_declared,
            longhands::position_try_options::parse_declared,
            longhands::quotes::parse_declared,
            longhands::rotate::parse_declared,
            longhands::scale::parse_declared,
            longhands::scroll_timeline_axis::parse_declared,
            longhands::scroll_timeline_name::parse_declared,
            longhands::scrollbar_color::parse_declared,
            longhands::shape_outside::parse_declared,
            longhands::size::parse_declared,
            longhands::stroke_dasharray::parse_declared,
            longhands::stroke_dashoffset::parse_declared,
            longhands::stroke_width::parse_declared,
            longhands::tab_size::parse_declared,
            longhands::text_decoration_thickness::parse_declared,
            longhands::text_emphasis_style::parse_declared,
            longhands::text_indent::parse_declared,
            longhands::text_overflow::parse_declared,
            longhands::text_shadow::parse_declared,
            longhands::transition_behavior::parse_declared,
            longhands::transition_delay::parse_declared,
            longhands::transition_duration::parse_declared,
            longhands::transition_property::parse_declared,
            longhands::transition_timing_function::parse_declared,
            longhands::translate::parse_declared,
            longhands::vertical_align::parse_declared,
            longhands::view_timeline_axis::parse_declared,
            longhands::view_timeline_inset::parse_declared,
            longhands::view_timeline_name::parse_declared,
            longhands::_webkit_text_stroke_width::parse_declared,
            longhands::will_change::parse_declared,
            longhands::word_spacing::parse_declared,
            longhands::_x_lang::parse_declared,
            longhands::object_position::parse_declared,
            longhands::perspective_origin::parse_declared,
            longhands::fill::parse_declared,
            longhands::stroke::parse_declared,
            longhands::_moz_window_transform_origin::parse_declared,
            longhands::transform_origin::parse_declared,
            longhands::grid_template_columns::parse_declared,
            longhands::grid_template_rows::parse_declared,
            longhands::border_image_source::parse_declared,
            longhands::list_style_image::parse_declared,
            longhands::grid_auto_columns::parse_declared,
            longhands::grid_auto_rows::parse_declared,
            longhands::_moz_window_transform::parse_declared,
            longhands::transform::parse_declared,
            longhands::column_gap::parse_declared,
            longhands::row_gap::parse_declared,
            longhands::marker_end::parse_declared,
            longhands::marker_mid::parse_declared,
            longhands::marker_start::parse_declared,
            longhands::contain_intrinsic_block_size::parse_declared,
            longhands::contain_intrinsic_height::parse_declared,
            longhands::contain_intrinsic_inline_size::parse_declared,
            longhands::contain_intrinsic_width::parse_declared,
            longhands::grid_column_end::parse_declared,
            longhands::grid_column_start::parse_declared,
            longhands::grid_row_end::parse_declared,
            longhands::grid_row_start::parse_declared,
            longhands::max_block_size::parse_declared,
            longhands::max_height::parse_declared,
            longhands::max_inline_size::parse_declared,
            longhands::max_width::parse_declared,
            longhands::cx::parse_declared,
            longhands::cy::parse_declared,
            longhands::offset_distance::parse_declared,
            longhands::x::parse_declared,
            longhands::y::parse_declared,
            longhands::border_bottom_left_radius::parse_declared,
            longhands::border_bottom_right_radius::parse_declared,
            longhands::border_end_end_radius::parse_declared,
            longhands::border_end_start_radius::parse_declared,
            longhands::border_start_end_radius::parse_declared,
            longhands::border_start_start_radius::parse_declared,
            longhands::border_top_left_radius::parse_declared,
            longhands::border_top_right_radius::parse_declared,
            longhands::block_size::parse_declared,
            longhands::height::parse_declared,
            longhands::inline_size::parse_declared,
            longhands::min_block_size::parse_declared,
            longhands::min_height::parse_declared,
            longhands::min_inline_size::parse_declared,
            longhands::min_width::parse_declared,
            longhands::width::parse_declared,
            longhands::border_block_end_width::parse_declared,
            longhands::border_block_start_width::parse_declared,
            longhands::border_bottom_width::parse_declared,
            longhands::border_inline_end_width::parse_declared,
            longhands::border_inline_start_width::parse_declared,
            longhands::border_left_width::parse_declared,
            longhands::border_right_width::parse_declared,
            longhands::border_top_width::parse_declared,
            longhands::column_rule_width::parse_declared,
            longhands::outline_width::parse_declared,
            longhands::padding_block_end::parse_declared,
            longhands::padding_block_start::parse_declared,
            longhands::padding_bottom::parse_declared,
            longhands::padding_inline_end::parse_declared,
            longhands::padding_inline_start::parse_declared,
            longhands::padding_left::parse_declared,
            longhands::padding_right::parse_declared,
            longhands::padding_top::parse_declared,
            longhands::r::parse_declared,
            longhands::shape_margin::parse_declared,
            longhands::rx::parse_declared,
            longhands::ry::parse_declared,
            longhands::scroll_padding_block_end::parse_declared,
            longhands::scroll_padding_block_start::parse_declared,
            longhands::scroll_padding_bottom::parse_declared,
            longhands::scroll_padding_inline_end::parse_declared,
            longhands::scroll_padding_inline_start::parse_declared,
            longhands::scroll_padding_left::parse_declared,
            longhands::scroll_padding_right::parse_declared,
            longhands::scroll_padding_top::parse_declared,
            longhands::_moz_window_input_region_margin::parse_declared,
            longhands::outline_offset::parse_declared,
            longhands::overflow_clip_margin::parse_declared,
            longhands::scroll_margin_block_end::parse_declared,
            longhands::scroll_margin_block_start::parse_declared,
            longhands::scroll_margin_bottom::parse_declared,
            longhands::scroll_margin_inline_end::parse_declared,
            longhands::scroll_margin_inline_start::parse_declared,
            longhands::scroll_margin_left::parse_declared,
            longhands::scroll_margin_right::parse_declared,
            longhands::scroll_margin_top::parse_declared,
            longhands::bottom::parse_declared,
            longhands::inset_block_end::parse_declared,
            longhands::inset_block_start::parse_declared,
            longhands::inset_inline_end::parse_declared,
            longhands::inset_inline_start::parse_declared,
            longhands::left::parse_declared,
            longhands::margin_block_end::parse_declared,
            longhands::margin_block_start::parse_declared,
            longhands::margin_bottom::parse_declared,
            longhands::margin_inline_end::parse_declared,
            longhands::margin_inline_start::parse_declared,
            longhands::margin_left::parse_declared,
            longhands::margin_right::parse_declared,
            longhands::margin_top::parse_declared,
            longhands::right::parse_declared,
            longhands::text_underline_offset::parse_declared,
            longhands::top::parse_declared,
            longhands::background_color::parse_declared,
            longhands::border_block_end_color::parse_declared,
            longhands::border_block_start_color::parse_declared,
            longhands::border_bottom_color::parse_declared,
            longhands::border_inline_end_color::parse_declared,
            longhands::border_inline_start_color::parse_declared,
            longhands::border_left_color::parse_declared,
            longhands::border_right_color::parse_declared,
            longhands::border_top_color::parse_declared,
            longhands::column_rule_color::parse_declared,
            longhands::flood_color::parse_declared,
            longhands::lighting_color::parse_declared,
            longhands::outline_color::parse_declared,
            longhands::stop_color::parse_declared,
            longhands::text_decoration_color::parse_declared,
            longhands::text_emphasis_color::parse_declared,
            longhands::_webkit_text_fill_color::parse_declared,
            longhands::_webkit_text_stroke_color::parse_declared,
        ];
        (PARSE_PROPERTY[self as usize])(context, input)
    }

    /// Return the relevant data to map a particular logical property into physical.
    fn logical_mapping_data(self) -> Option<&'static LogicalMappingData> {
        const LOGICAL_MAPPING_DATA: [Option<LogicalMappingData>; 410] = [
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Overflow,
                kind: LogicalMappingKind::Axis(LogicalAxis::Block)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Overflow,
                kind: LogicalMappingKind::Axis(LogicalAxis::Inline)
            }),
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::OverscrollBehavior,
                kind: LogicalMappingKind::Axis(LogicalAxis::Block)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::OverscrollBehavior,
                kind: LogicalMappingKind::Axis(LogicalAxis::Inline)
            }),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderStyle,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderStyle,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderStyle,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderStyle,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::ContainIntrinsicSize,
                kind: LogicalMappingKind::Axis(LogicalAxis::Block)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::ContainIntrinsicSize,
                kind: LogicalMappingKind::Axis(LogicalAxis::Inline)
            }),
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::MaxSize,
                kind: LogicalMappingKind::Axis(LogicalAxis::Block)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::MaxSize,
                kind: LogicalMappingKind::Axis(LogicalAxis::Inline)
            }),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderRadius,
                kind: LogicalMappingKind::Corner(LogicalCorner::EndEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderRadius,
                kind: LogicalMappingKind::Corner(LogicalCorner::EndStart)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderRadius,
                kind: LogicalMappingKind::Corner(LogicalCorner::StartEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderRadius,
                kind: LogicalMappingKind::Corner(LogicalCorner::StartStart)
            }),
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Size,
                kind: LogicalMappingKind::Axis(LogicalAxis::Block)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Size,
                kind: LogicalMappingKind::Axis(LogicalAxis::Inline)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::MinSize,
                kind: LogicalMappingKind::Axis(LogicalAxis::Block)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::MinSize,
                kind: LogicalMappingKind::Axis(LogicalAxis::Inline)
            }),
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderWidth,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderWidth,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderWidth,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderWidth,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Padding,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Padding,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Padding,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Padding,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollPadding,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollPadding,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollPadding,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollPadding,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollMargin,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollMargin,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollMargin,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::ScrollMargin,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Inset,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Inset,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Inset,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Inset,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Margin,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Margin,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::Margin,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::Margin,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderColor,
                kind: LogicalMappingKind::Side(LogicalSide::BlockEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderColor,
                kind: LogicalMappingKind::Side(LogicalSide::BlockStart)
            }),
            None,
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderColor,
                kind: LogicalMappingKind::Side(LogicalSide::InlineEnd)
            }),
            Some(LogicalMappingData {
                group: LogicalGroupId::BorderColor,
                kind: LogicalMappingKind::Side(LogicalSide::InlineStart)
            }),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
        ];
        LOGICAL_MAPPING_DATA[self as usize].as_ref()
    }

    /// If this is a logical property, return the corresponding physical one in the given
    /// writing mode. Otherwise, return unchanged.
    #[inline]
    pub fn to_physical(self, wm: WritingMode) -> Self {
        let Some(data) = self.logical_mapping_data() else { return self };
        data.to_physical(wm)
    }

    /// Return the logical group of this longhand property.
    pub fn logical_group(self) -> Option<LogicalGroupId> {
        const LOGICAL_GROUP_IDS: [Option<LogicalGroupId>; 410] = [
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalGroupId::Overflow),
            Some(LogicalGroupId::Overflow),
            Some(LogicalGroupId::Overflow),
            Some(LogicalGroupId::Overflow),
            Some(LogicalGroupId::OverscrollBehavior),
            Some(LogicalGroupId::OverscrollBehavior),
            Some(LogicalGroupId::OverscrollBehavior),
            Some(LogicalGroupId::OverscrollBehavior),
            None,
            None,
            None,
            None,
            None,
            Some(LogicalGroupId::BorderStyle),
            Some(LogicalGroupId::BorderStyle),
            Some(LogicalGroupId::BorderStyle),
            Some(LogicalGroupId::BorderStyle),
            Some(LogicalGroupId::BorderStyle),
            Some(LogicalGroupId::BorderStyle),
            Some(LogicalGroupId::BorderStyle),
            Some(LogicalGroupId::BorderStyle),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            Some(LogicalGroupId::ContainIntrinsicSize),
            Some(LogicalGroupId::ContainIntrinsicSize),
            Some(LogicalGroupId::ContainIntrinsicSize),
            Some(LogicalGroupId::ContainIntrinsicSize),
            None,
            None,
            None,
            None,
            Some(LogicalGroupId::MaxSize),
            Some(LogicalGroupId::MaxSize),
            Some(LogicalGroupId::MaxSize),
            Some(LogicalGroupId::MaxSize),
            None,
            None,
            None,
            None,
            None,
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::BorderRadius),
            Some(LogicalGroupId::Size),
            Some(LogicalGroupId::Size),
            Some(LogicalGroupId::Size),
            Some(LogicalGroupId::MinSize),
            Some(LogicalGroupId::MinSize),
            Some(LogicalGroupId::MinSize),
            Some(LogicalGroupId::MinSize),
            Some(LogicalGroupId::Size),
            Some(LogicalGroupId::BorderWidth),
            Some(LogicalGroupId::BorderWidth),
            Some(LogicalGroupId::BorderWidth),
            Some(LogicalGroupId::BorderWidth),
            Some(LogicalGroupId::BorderWidth),
            Some(LogicalGroupId::BorderWidth),
            Some(LogicalGroupId::BorderWidth),
            Some(LogicalGroupId::BorderWidth),
            None,
            None,
            Some(LogicalGroupId::Padding),
            Some(LogicalGroupId::Padding),
            Some(LogicalGroupId::Padding),
            Some(LogicalGroupId::Padding),
            Some(LogicalGroupId::Padding),
            Some(LogicalGroupId::Padding),
            Some(LogicalGroupId::Padding),
            Some(LogicalGroupId::Padding),
            None,
            None,
            None,
            None,
            Some(LogicalGroupId::ScrollPadding),
            Some(LogicalGroupId::ScrollPadding),
            Some(LogicalGroupId::ScrollPadding),
            Some(LogicalGroupId::ScrollPadding),
            Some(LogicalGroupId::ScrollPadding),
            Some(LogicalGroupId::ScrollPadding),
            Some(LogicalGroupId::ScrollPadding),
            Some(LogicalGroupId::ScrollPadding),
            None,
            None,
            None,
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::ScrollMargin),
            Some(LogicalGroupId::Inset),
            Some(LogicalGroupId::Inset),
            Some(LogicalGroupId::Inset),
            Some(LogicalGroupId::Inset),
            Some(LogicalGroupId::Inset),
            Some(LogicalGroupId::Inset),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Margin),
            Some(LogicalGroupId::Inset),
            None,
            Some(LogicalGroupId::Inset),
            None,
            Some(LogicalGroupId::BorderColor),
            Some(LogicalGroupId::BorderColor),
            Some(LogicalGroupId::BorderColor),
            Some(LogicalGroupId::BorderColor),
            Some(LogicalGroupId::BorderColor),
            Some(LogicalGroupId::BorderColor),
            Some(LogicalGroupId::BorderColor),
            Some(LogicalGroupId::BorderColor),
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
            None,
        ];
        LOGICAL_GROUP_IDS[self as usize]
    }

    /// Returns PropertyFlags for given longhand property.
    #[inline(always)]
    pub fn flags(self) -> PropertyFlags {
        // TODO(emilio): This can be simplified further as Rust gains more
        // constant expression support.
        const FLAGS: [u16; 410] = [
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                0,
                0,
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                0,
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                0,
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::APPLIES_TO_MARKER.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                0,
                0,
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::AFFECTS_OVERFLOW.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_LAYOUT.bits() |
                0,
                    PropertyFlags::CAN_ANIMATE_ON_COMPOSITOR.bits() |
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                    PropertyFlags::APPLIES_TO_CUE.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
                    PropertyFlags::AFFECTS_PAINT.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LINE.bits() |
                    PropertyFlags::APPLIES_TO_FIRST_LETTER.bits() |
                    PropertyFlags::APPLIES_TO_PLACEHOLDER.bits() |
                0,
        ];
        PropertyFlags::from_bits_retain(FLAGS[self as usize])
    }
}

/// An identifier for a given shorthand property.
#[derive(Clone, Copy, Debug, Eq, Hash, MallocSizeOf, PartialEq, ToComputedValue, ToResolvedValue, ToShmem)]
#[repr(u16)]
pub enum ShorthandId {
        /// background
        Background = 0,
        /// background-position
        BackgroundPosition = 1,
        /// border-color
        BorderColor = 2,
        /// border-style
        BorderStyle = 3,
        /// border-width
        BorderWidth = 4,
        /// border-top
        BorderTop = 5,
        /// border-right
        BorderRight = 6,
        /// border-bottom
        BorderBottom = 7,
        /// border-left
        BorderLeft = 8,
        /// border-block-start
        BorderBlockStart = 9,
        /// border-block-end
        BorderBlockEnd = 10,
        /// border-inline-start
        BorderInlineStart = 11,
        /// border-inline-end
        BorderInlineEnd = 12,
        /// border
        Border = 13,
        /// border-radius
        BorderRadius = 14,
        /// border-image
        BorderImage = 15,
        /// border-block-width
        BorderBlockWidth = 16,
        /// border-block-style
        BorderBlockStyle = 17,
        /// border-block-color
        BorderBlockColor = 18,
        /// border-inline-width
        BorderInlineWidth = 19,
        /// border-inline-style
        BorderInlineStyle = 20,
        /// border-inline-color
        BorderInlineColor = 21,
        /// border-block
        BorderBlock = 22,
        /// border-inline
        BorderInline = 23,
        /// overflow
        Overflow = 24,
        /// overflow-clip-box
        OverflowClipBox = 25,
        /// overscroll-behavior
        OverscrollBehavior = 26,
        /// container
        Container = 27,
        /// page-break-before
        PageBreakBefore = 28,
        /// page-break-after
        PageBreakAfter = 29,
        /// page-break-inside
        PageBreakInside = 30,
        /// offset
        Offset = 31,
        /// columns
        Columns = 32,
        /// column-rule
        ColumnRule = 33,
        /// font
        Font = 34,
        /// font-variant
        FontVariant = 35,
        /// font-synthesis
        FontSynthesis = 36,
        /// marker
        Marker = 37,
        /// text-emphasis
        TextEmphasis = 38,
        /// text-wrap
        TextWrap = 39,
        /// white-space
        WhiteSpace = 40,
        /// -webkit-text-stroke
        WebkitTextStroke = 41,
        /// list-style
        ListStyle = 42,
        /// margin
        Margin = 43,
        /// margin-block
        MarginBlock = 44,
        /// margin-inline
        MarginInline = 45,
        /// scroll-margin
        ScrollMargin = 46,
        /// scroll-margin-block
        ScrollMarginBlock = 47,
        /// scroll-margin-inline
        ScrollMarginInline = 48,
        /// outline
        Outline = 49,
        /// padding
        Padding = 50,
        /// padding-block
        PaddingBlock = 51,
        /// padding-inline
        PaddingInline = 52,
        /// scroll-padding
        ScrollPadding = 53,
        /// scroll-padding-block
        ScrollPaddingBlock = 54,
        /// scroll-padding-inline
        ScrollPaddingInline = 55,
        /// flex-flow
        FlexFlow = 56,
        /// flex
        Flex = 57,
        /// gap
        Gap = 58,
        /// grid-row
        GridRow = 59,
        /// grid-column
        GridColumn = 60,
        /// grid-area
        GridArea = 61,
        /// grid-template
        GridTemplate = 62,
        /// grid
        Grid = 63,
        /// place-content
        PlaceContent = 64,
        /// place-self
        PlaceSelf = 65,
        /// place-items
        PlaceItems = 66,
        /// inset
        Inset = 67,
        /// inset-block
        InsetBlock = 68,
        /// inset-inline
        InsetInline = 69,
        /// contain-intrinsic-size
        ContainIntrinsicSize = 70,
        /// mask
        Mask = 71,
        /// mask-position
        MaskPosition = 72,
        /// text-decoration
        TextDecoration = 73,
        /// transition
        Transition = 74,
        /// animation
        Animation = 75,
        /// scroll-timeline
        ScrollTimeline = 76,
        /// view-timeline
        ViewTimeline = 77,
        /// all
        All = 78,
}

impl ShorthandId {
    /// Get the longhand ids that form this shorthand.
    pub fn longhands(self) -> NonCustomPropertyIterator<LonghandId> {
        static MAP: [&'static [LonghandId]; property_counts::SHORTHANDS] = [
            &[
                    LonghandId::BackgroundColor,
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
                    LonghandId::BackgroundRepeat,
                    LonghandId::BackgroundAttachment,
                    LonghandId::BackgroundImage,
                    LonghandId::BackgroundSize,
                    LonghandId::BackgroundOrigin,
                    LonghandId::BackgroundClip,
            ],
            &[
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
            ],
            &[
                    LonghandId::BorderTopColor,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderLeftColor,
            ],
            &[
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderLeftStyle,
            ],
            &[
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderLeftWidth,
            ],
            &[
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopColor,
            ],
            &[
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightColor,
            ],
            &[
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomColor,
            ],
            &[
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftColor,
            ],
            &[
                    LonghandId::BorderBlockStartWidth,
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockStartColor,
            ],
            &[
                    LonghandId::BorderBlockEndWidth,
                    LonghandId::BorderBlockEndStyle,
                    LonghandId::BorderBlockEndColor,
            ],
            &[
                    LonghandId::BorderInlineStartWidth,
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineStartColor,
            ],
            &[
                    LonghandId::BorderInlineEndWidth,
                    LonghandId::BorderInlineEndStyle,
                    LonghandId::BorderInlineEndColor,
            ],
            &[
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopColor,
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageSlice,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageWidth,
            ],
            &[
                    LonghandId::BorderTopLeftRadius,
                    LonghandId::BorderTopRightRadius,
                    LonghandId::BorderBottomRightRadius,
                    LonghandId::BorderBottomLeftRadius,
            ],
            &[
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageSlice,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageWidth,
            ],
            &[
                    LonghandId::BorderBlockStartWidth,
                    LonghandId::BorderBlockEndWidth,
            ],
            &[
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockEndStyle,
            ],
            &[
                    LonghandId::BorderBlockStartColor,
                    LonghandId::BorderBlockEndColor,
            ],
            &[
                    LonghandId::BorderInlineStartWidth,
                    LonghandId::BorderInlineEndWidth,
            ],
            &[
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineEndStyle,
            ],
            &[
                    LonghandId::BorderInlineStartColor,
                    LonghandId::BorderInlineEndColor,
            ],
            &[
                    LonghandId::BorderBlockStartWidth,
                    LonghandId::BorderBlockEndWidth,
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockEndStyle,
                    LonghandId::BorderBlockStartColor,
                    LonghandId::BorderBlockEndColor,
            ],
            &[
                    LonghandId::BorderInlineStartWidth,
                    LonghandId::BorderInlineEndWidth,
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineEndStyle,
                    LonghandId::BorderInlineStartColor,
                    LonghandId::BorderInlineEndColor,
            ],
            &[
                    LonghandId::OverflowX,
                    LonghandId::OverflowY,
            ],
            &[
                    LonghandId::OverflowClipBoxBlock,
                    LonghandId::OverflowClipBoxInline,
            ],
            &[
                    LonghandId::OverscrollBehaviorX,
                    LonghandId::OverscrollBehaviorY,
            ],
            &[
                    LonghandId::ContainerName,
                    LonghandId::ContainerType,
            ],
            &[
                    LonghandId::BreakBefore,
            ],
            &[
                    LonghandId::BreakAfter,
            ],
            &[
                    LonghandId::BreakInside,
            ],
            &[
                    LonghandId::OffsetPath,
                    LonghandId::OffsetDistance,
                    LonghandId::OffsetRotate,
                    LonghandId::OffsetAnchor,
                    LonghandId::OffsetPosition,
            ],
            &[
                    LonghandId::ColumnWidth,
                    LonghandId::ColumnCount,
            ],
            &[
                    LonghandId::ColumnRuleWidth,
                    LonghandId::ColumnRuleStyle,
                    LonghandId::ColumnRuleColor,
            ],
            &[
                    LonghandId::FontStyle,
                    LonghandId::FontVariantCaps,
                    LonghandId::FontWeight,
                    LonghandId::FontStretch,
                    LonghandId::FontSize,
                    LonghandId::LineHeight,
                    LonghandId::FontFamily,
                    LonghandId::FontSizeAdjust,
                    LonghandId::FontKerning,
                    LonghandId::FontOpticalSizing,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantEmoji,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
                    LonghandId::FontLanguageOverride,
                    LonghandId::FontFeatureSettings,
                    LonghandId::FontVariationSettings,
            ],
            &[
                    LonghandId::FontVariantCaps,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantEmoji,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
            ],
            &[
                    LonghandId::FontSynthesisWeight,
                    LonghandId::FontSynthesisStyle,
                    LonghandId::FontSynthesisSmallCaps,
                    LonghandId::FontSynthesisPosition,
            ],
            &[
                    LonghandId::MarkerStart,
                    LonghandId::MarkerEnd,
                    LonghandId::MarkerMid,
            ],
            &[
                    LonghandId::TextEmphasisStyle,
                    LonghandId::TextEmphasisColor,
            ],
            &[
                    LonghandId::TextWrapMode,
                    LonghandId::TextWrapStyle,
            ],
            &[
                    LonghandId::TextWrapMode,
                    LonghandId::WhiteSpaceCollapse,
            ],
            &[
                    LonghandId::WebkitTextStrokeWidth,
                    LonghandId::WebkitTextStrokeColor,
            ],
            &[
                    LonghandId::ListStylePosition,
                    LonghandId::ListStyleImage,
                    LonghandId::ListStyleType,
            ],
            &[
                    LonghandId::MarginTop,
                    LonghandId::MarginRight,
                    LonghandId::MarginBottom,
                    LonghandId::MarginLeft,
            ],
            &[
                    LonghandId::MarginBlockStart,
                    LonghandId::MarginBlockEnd,
            ],
            &[
                    LonghandId::MarginInlineStart,
                    LonghandId::MarginInlineEnd,
            ],
            &[
                    LonghandId::ScrollMarginTop,
                    LonghandId::ScrollMarginRight,
                    LonghandId::ScrollMarginBottom,
                    LonghandId::ScrollMarginLeft,
            ],
            &[
                    LonghandId::ScrollMarginBlockStart,
                    LonghandId::ScrollMarginBlockEnd,
            ],
            &[
                    LonghandId::ScrollMarginInlineStart,
                    LonghandId::ScrollMarginInlineEnd,
            ],
            &[
                    LonghandId::OutlineColor,
                    LonghandId::OutlineStyle,
                    LonghandId::OutlineWidth,
            ],
            &[
                    LonghandId::PaddingTop,
                    LonghandId::PaddingRight,
                    LonghandId::PaddingBottom,
                    LonghandId::PaddingLeft,
            ],
            &[
                    LonghandId::PaddingBlockStart,
                    LonghandId::PaddingBlockEnd,
            ],
            &[
                    LonghandId::PaddingInlineStart,
                    LonghandId::PaddingInlineEnd,
            ],
            &[
                    LonghandId::ScrollPaddingTop,
                    LonghandId::ScrollPaddingRight,
                    LonghandId::ScrollPaddingBottom,
                    LonghandId::ScrollPaddingLeft,
            ],
            &[
                    LonghandId::ScrollPaddingBlockStart,
                    LonghandId::ScrollPaddingBlockEnd,
            ],
            &[
                    LonghandId::ScrollPaddingInlineStart,
                    LonghandId::ScrollPaddingInlineEnd,
            ],
            &[
                    LonghandId::FlexDirection,
                    LonghandId::FlexWrap,
            ],
            &[
                    LonghandId::FlexGrow,
                    LonghandId::FlexShrink,
                    LonghandId::FlexBasis,
            ],
            &[
                    LonghandId::RowGap,
                    LonghandId::ColumnGap,
            ],
            &[
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
            ],
            &[
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
            ],
            &[
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
            ],
            &[
                    LonghandId::GridTemplateRows,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridTemplateAreas,
            ],
            &[
                    LonghandId::GridTemplateRows,
                    LonghandId::GridTemplateColumns,
                    LonghandId::GridTemplateAreas,
                    LonghandId::GridAutoRows,
                    LonghandId::GridAutoColumns,
                    LonghandId::GridAutoFlow,
            ],
            &[
                    LonghandId::AlignContent,
                    LonghandId::JustifyContent,
            ],
            &[
                    LonghandId::AlignSelf,
                    LonghandId::JustifySelf,
            ],
            &[
                    LonghandId::AlignItems,
                    LonghandId::JustifyItems,
            ],
            &[
                    LonghandId::Top,
                    LonghandId::Right,
                    LonghandId::Bottom,
                    LonghandId::Left,
            ],
            &[
                    LonghandId::InsetBlockStart,
                    LonghandId::InsetBlockEnd,
            ],
            &[
                    LonghandId::InsetInlineStart,
                    LonghandId::InsetInlineEnd,
            ],
            &[
                    LonghandId::ContainIntrinsicWidth,
                    LonghandId::ContainIntrinsicHeight,
            ],
            &[
                    LonghandId::MaskMode,
                    LonghandId::MaskRepeat,
                    LonghandId::MaskClip,
                    LonghandId::MaskOrigin,
                    LonghandId::MaskComposite,
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
                    LonghandId::MaskSize,
                    LonghandId::MaskImage,
            ],
            &[
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
            ],
            &[
                    LonghandId::TextDecorationLine,
                    LonghandId::TextDecorationStyle,
                    LonghandId::TextDecorationColor,
                    LonghandId::TextDecorationThickness,
            ],
            &[
                    LonghandId::TransitionProperty,
                    LonghandId::TransitionDuration,
                    LonghandId::TransitionTimingFunction,
                    LonghandId::TransitionDelay,
                    LonghandId::TransitionBehavior,
            ],
            &[
                    LonghandId::AnimationName,
                    LonghandId::AnimationDuration,
                    LonghandId::AnimationTimingFunction,
                    LonghandId::AnimationDelay,
                    LonghandId::AnimationIterationCount,
                    LonghandId::AnimationDirection,
                    LonghandId::AnimationFillMode,
                    LonghandId::AnimationPlayState,
                    LonghandId::AnimationTimeline,
            ],
            &[
                    LonghandId::ScrollTimelineName,
                    LonghandId::ScrollTimelineAxis,
            ],
            &[
                    LonghandId::ViewTimelineName,
                    LonghandId::ViewTimelineAxis,
            ],
            &[
                    LonghandId::BorderBlockStartColor,
                    LonghandId::BorderBlockStartStyle,
                    LonghandId::BorderBlockStartWidth,
                    LonghandId::BorderBlockEndColor,
                    LonghandId::BorderBlockEndStyle,
                    LonghandId::BorderBlockEndWidth,
                    LonghandId::BorderInlineStartColor,
                    LonghandId::BorderInlineStartStyle,
                    LonghandId::BorderInlineStartWidth,
                    LonghandId::BorderInlineEndColor,
                    LonghandId::BorderInlineEndStyle,
                    LonghandId::BorderInlineEndWidth,
                    LonghandId::BorderStartStartRadius,
                    LonghandId::BorderStartEndRadius,
                    LonghandId::BorderEndStartRadius,
                    LonghandId::BorderEndEndRadius,
                    LonghandId::OverflowBlock,
                    LonghandId::OverflowInline,
                    LonghandId::OverscrollBehaviorBlock,
                    LonghandId::OverscrollBehaviorInline,
                    LonghandId::MarginBlockStart,
                    LonghandId::MarginBlockEnd,
                    LonghandId::MarginInlineStart,
                    LonghandId::MarginInlineEnd,
                    LonghandId::ScrollMarginBlockStart,
                    LonghandId::ScrollMarginBlockEnd,
                    LonghandId::ScrollMarginInlineStart,
                    LonghandId::ScrollMarginInlineEnd,
                    LonghandId::PaddingBlockStart,
                    LonghandId::PaddingBlockEnd,
                    LonghandId::PaddingInlineStart,
                    LonghandId::PaddingInlineEnd,
                    LonghandId::ScrollPaddingBlockStart,
                    LonghandId::ScrollPaddingBlockEnd,
                    LonghandId::ScrollPaddingInlineStart,
                    LonghandId::ScrollPaddingInlineEnd,
                    LonghandId::InsetBlockStart,
                    LonghandId::InsetBlockEnd,
                    LonghandId::InsetInlineStart,
                    LonghandId::InsetInlineEnd,
                    LonghandId::BlockSize,
                    LonghandId::MinBlockSize,
                    LonghandId::MaxBlockSize,
                    LonghandId::InlineSize,
                    LonghandId::MinInlineSize,
                    LonghandId::MaxInlineSize,
                    LonghandId::ContainIntrinsicBlockSize,
                    LonghandId::ContainIntrinsicInlineSize,
                    LonghandId::BackgroundColor,
                    LonghandId::BackgroundImage,
                    LonghandId::BackgroundPositionX,
                    LonghandId::BackgroundPositionY,
                    LonghandId::BackgroundRepeat,
                    LonghandId::BackgroundAttachment,
                    LonghandId::BackgroundClip,
                    LonghandId::BackgroundOrigin,
                    LonghandId::BackgroundSize,
                    LonghandId::BackgroundBlendMode,
                    LonghandId::BorderTopColor,
                    LonghandId::BorderTopStyle,
                    LonghandId::BorderTopWidth,
                    LonghandId::BorderRightColor,
                    LonghandId::BorderRightStyle,
                    LonghandId::BorderRightWidth,
                    LonghandId::BorderBottomColor,
                    LonghandId::BorderBottomStyle,
                    LonghandId::BorderBottomWidth,
                    LonghandId::BorderLeftColor,
                    LonghandId::BorderLeftStyle,
                    LonghandId::BorderLeftWidth,
                    LonghandId::BorderTopLeftRadius,
                    LonghandId::BorderTopRightRadius,
                    LonghandId::BorderBottomRightRadius,
                    LonghandId::BorderBottomLeftRadius,
                    LonghandId::BoxDecorationBreak,
                    LonghandId::MozFloatEdge,
                    LonghandId::BorderImageSource,
                    LonghandId::BorderImageOutset,
                    LonghandId::BorderImageRepeat,
                    LonghandId::BorderImageWidth,
                    LonghandId::BorderImageSlice,
                    LonghandId::Display,
                    LonghandId::Position,
                    LonghandId::AnchorName,
                    LonghandId::AnchorScope,
                    LonghandId::Float,
                    LonghandId::Clear,
                    LonghandId::VerticalAlign,
                    LonghandId::BaselineSource,
                    LonghandId::OverflowClipBoxInline,
                    LonghandId::OverflowClipBoxBlock,
                    LonghandId::OverflowY,
                    LonghandId::OverflowX,
                    LonghandId::OverflowAnchor,
                    LonghandId::Transform,
                    LonghandId::Rotate,
                    LonghandId::Scale,
                    LonghandId::Translate,
                    LonghandId::OffsetPath,
                    LonghandId::OffsetDistance,
                    LonghandId::OffsetRotate,
                    LonghandId::OffsetAnchor,
                    LonghandId::OffsetPosition,
                    LonghandId::ScrollBehavior,
                    LonghandId::ScrollSnapAlign,
                    LonghandId::ScrollSnapType,
                    LonghandId::ScrollSnapStop,
                    LonghandId::OverscrollBehaviorY,
                    LonghandId::OverscrollBehaviorX,
                    LonghandId::Isolation,
                    LonghandId::BreakAfter,
                    LonghandId::BreakBefore,
                    LonghandId::BreakInside,
                    LonghandId::Resize,
                    LonghandId::Perspective,
                    LonghandId::PerspectiveOrigin,
                    LonghandId::BackfaceVisibility,
                    LonghandId::TransformBox,
                    LonghandId::TransformStyle,
                    LonghandId::TransformOrigin,
                    LonghandId::Contain,
                    LonghandId::ContentVisibility,
                    LonghandId::ContainerType,
                    LonghandId::ContainerName,
                    LonghandId::Appearance,
                    LonghandId::MozOrient,
                    LonghandId::WillChange,
                    LonghandId::ShapeImageThreshold,
                    LonghandId::ShapeMargin,
                    LonghandId::ShapeOutside,
                    LonghandId::TouchAction,
                    LonghandId::WebkitLineClamp,
                    LonghandId::ScrollbarGutter,
                    LonghandId::Zoom,
                    LonghandId::ColumnWidth,
                    LonghandId::ColumnCount,
                    LonghandId::ColumnFill,
                    LonghandId::ColumnRuleWidth,
                    LonghandId::ColumnRuleColor,
                    LonghandId::ColumnSpan,
                    LonghandId::ColumnRuleStyle,
                    LonghandId::Content,
                    LonghandId::CounterIncrement,
                    LonghandId::CounterReset,
                    LonghandId::CounterSet,
                    LonghandId::Opacity,
                    LonghandId::BoxShadow,
                    LonghandId::Clip,
                    LonghandId::Filter,
                    LonghandId::BackdropFilter,
                    LonghandId::MixBlendMode,
                    LonghandId::FontFamily,
                    LonghandId::FontStyle,
                    LonghandId::FontVariantCaps,
                    LonghandId::FontWeight,
                    LonghandId::FontSize,
                    LonghandId::FontSizeAdjust,
                    LonghandId::FontSynthesisWeight,
                    LonghandId::FontSynthesisStyle,
                    LonghandId::FontSynthesisSmallCaps,
                    LonghandId::FontSynthesisPosition,
                    LonghandId::FontStretch,
                    LonghandId::FontKerning,
                    LonghandId::FontVariantAlternates,
                    LonghandId::FontVariantEastAsian,
                    LonghandId::FontVariantEmoji,
                    LonghandId::FontVariantLigatures,
                    LonghandId::FontVariantNumeric,
                    LonghandId::FontVariantPosition,
                    LonghandId::FontFeatureSettings,
                    LonghandId::FontVariationSettings,
                    LonghandId::FontLanguageOverride,
                    LonghandId::FontOpticalSizing,
                    LonghandId::FontPalette,
                    LonghandId::MathDepth,
                    LonghandId::MathStyle,
                    LonghandId::LineHeight,
                    LonghandId::MozOsxFontSmoothing,
                    LonghandId::Visibility,
                    LonghandId::WritingMode,
                    LonghandId::TextOrientation,
                    LonghandId::PrintColorAdjust,
                    LonghandId::ImageRendering,
                    LonghandId::ImageOrientation,
                    LonghandId::DominantBaseline,
                    LonghandId::TextAnchor,
                    LonghandId::ColorInterpolation,
                    LonghandId::ColorInterpolationFilters,
                    LonghandId::Fill,
                    LonghandId::FillOpacity,
                    LonghandId::FillRule,
                    LonghandId::ShapeRendering,
                    LonghandId::Stroke,
                    LonghandId::StrokeWidth,
                    LonghandId::StrokeLinecap,
                    LonghandId::StrokeLinejoin,
                    LonghandId::StrokeMiterlimit,
                    LonghandId::StrokeOpacity,
                    LonghandId::StrokeDasharray,
                    LonghandId::StrokeDashoffset,
                    LonghandId::ClipRule,
                    LonghandId::MarkerStart,
                    LonghandId::MarkerMid,
                    LonghandId::MarkerEnd,
                    LonghandId::PaintOrder,
                    LonghandId::MozContextProperties,
                    LonghandId::BorderCollapse,
                    LonghandId::EmptyCells,
                    LonghandId::CaptionSide,
                    LonghandId::BorderSpacing,
                    LonghandId::Color,
                    LonghandId::TextTransform,
                    LonghandId::Hyphens,
                    LonghandId::MozTextSizeAdjust,
                    LonghandId::TextIndent,
                    LonghandId::OverflowWrap,
                    LonghandId::WordBreak,
                    LonghandId::TextJustify,
                    LonghandId::TextAlignLast,
                    LonghandId::TextAlign,
                    LonghandId::LetterSpacing,
                    LonghandId::WordSpacing,
                    LonghandId::WhiteSpaceCollapse,
                    LonghandId::TextShadow,
                    LonghandId::TextEmphasisStyle,
                    LonghandId::TextEmphasisPosition,
                    LonghandId::TextEmphasisColor,
                    LonghandId::TabSize,
                    LonghandId::LineBreak,
                    LonghandId::WebkitTextFillColor,
                    LonghandId::WebkitTextStrokeColor,
                    LonghandId::WebkitTextStrokeWidth,
                    LonghandId::RubyAlign,
                    LonghandId::RubyPosition,
                    LonghandId::TextCombineUpright,
                    LonghandId::TextRendering,
                    LonghandId::MozControlCharacterVisibility,
                    LonghandId::TextUnderlineOffset,
                    LonghandId::TextUnderlinePosition,
                    LonghandId::TextDecorationSkipInk,
                    LonghandId::HyphenateCharacter,
                    LonghandId::ForcedColorAdjust,
                    LonghandId::WebkitTextSecurity,
                    LonghandId::TextWrapMode,
                    LonghandId::TextWrapStyle,
                    LonghandId::Cursor,
                    LonghandId::PointerEvents,
                    LonghandId::MozUserInput,
                    LonghandId::MozUserModify,
                    LonghandId::CaretColor,
                    LonghandId::AccentColor,
                    LonghandId::ColorScheme,
                    LonghandId::ScrollbarColor,
                    LonghandId::ListStylePosition,
                    LonghandId::ListStyleType,
                    LonghandId::ListStyleImage,
                    LonghandId::Quotes,
                    LonghandId::MarginTop,
                    LonghandId::MarginRight,
                    LonghandId::MarginBottom,
                    LonghandId::MarginLeft,
                    LonghandId::OverflowClipMargin,
                    LonghandId::ScrollMarginTop,
                    LonghandId::ScrollMarginRight,
                    LonghandId::ScrollMarginBottom,
                    LonghandId::ScrollMarginLeft,
                    LonghandId::OutlineColor,
                    LonghandId::OutlineStyle,
                    LonghandId::OutlineWidth,
                    LonghandId::OutlineOffset,
                    LonghandId::PaddingTop,
                    LonghandId::PaddingRight,
                    LonghandId::PaddingBottom,
                    LonghandId::PaddingLeft,
                    LonghandId::ScrollPaddingTop,
                    LonghandId::ScrollPaddingRight,
                    LonghandId::ScrollPaddingBottom,
                    LonghandId::ScrollPaddingLeft,
                    LonghandId::Page,
                    LonghandId::Top,
                    LonghandId::Right,
                    LonghandId::Bottom,
                    LonghandId::Left,
                    LonghandId::ZIndex,
                    LonghandId::FlexDirection,
                    LonghandId::FlexWrap,
                    LonghandId::JustifyContent,
                    LonghandId::AlignContent,
                    LonghandId::AlignItems,
                    LonghandId::JustifyItems,
                    LonghandId::FlexGrow,
                    LonghandId::FlexShrink,
                    LonghandId::AlignSelf,
                    LonghandId::JustifySelf,
                    LonghandId::Order,
                    LonghandId::FlexBasis,
                    LonghandId::Height,
                    LonghandId::MinHeight,
                    LonghandId::MaxHeight,
                    LonghandId::Width,
                    LonghandId::MinWidth,
                    LonghandId::MaxWidth,
                    LonghandId::PositionAnchor,
                    LonghandId::PositionVisibility,
                    LonghandId::InsetArea,
                    LonghandId::PositionTryOptions,
                    LonghandId::PositionTryOrder,
                    LonghandId::BoxSizing,
                    LonghandId::ObjectFit,
                    LonghandId::ObjectPosition,
                    LonghandId::GridRowStart,
                    LonghandId::GridRowEnd,
                    LonghandId::GridAutoRows,
                    LonghandId::GridTemplateRows,
                    LonghandId::GridColumnStart,
                    LonghandId::GridColumnEnd,
                    LonghandId::GridAutoColumns,
                    LonghandId::GridTemplateColumns,
                    LonghandId::MasonryAutoFlow,
                    LonghandId::GridAutoFlow,
                    LonghandId::GridTemplateAreas,
                    LonghandId::ColumnGap,
                    LonghandId::RowGap,
                    LonghandId::AspectRatio,
                    LonghandId::ContainIntrinsicHeight,
                    LonghandId::ContainIntrinsicWidth,
                    LonghandId::VectorEffect,
                    LonghandId::StopColor,
                    LonghandId::StopOpacity,
                    LonghandId::FloodColor,
                    LonghandId::FloodOpacity,
                    LonghandId::LightingColor,
                    LonghandId::MaskType,
                    LonghandId::ClipPath,
                    LonghandId::MaskMode,
                    LonghandId::MaskRepeat,
                    LonghandId::MaskPositionX,
                    LonghandId::MaskPositionY,
                    LonghandId::MaskClip,
                    LonghandId::MaskOrigin,
                    LonghandId::MaskSize,
                    LonghandId::MaskComposite,
                    LonghandId::MaskImage,
                    LonghandId::X,
                    LonghandId::Y,
                    LonghandId::Cx,
                    LonghandId::Cy,
                    LonghandId::Rx,
                    LonghandId::Ry,
                    LonghandId::R,
                    LonghandId::D,
                    LonghandId::TableLayout,
                    LonghandId::TextOverflow,
                    LonghandId::TextDecorationLine,
                    LonghandId::TextDecorationStyle,
                    LonghandId::TextDecorationColor,
                    LonghandId::InitialLetter,
                    LonghandId::TextDecorationThickness,
                    LonghandId::ImeMode,
                    LonghandId::ScrollbarWidth,
                    LonghandId::UserSelect,
                    LonghandId::MozWindowDragging,
                    LonghandId::MozForceBrokenImageIcon,
                    LonghandId::TransitionDuration,
                    LonghandId::TransitionTimingFunction,
                    LonghandId::TransitionProperty,
                    LonghandId::TransitionDelay,
                    LonghandId::TransitionBehavior,
                    LonghandId::AnimationName,
                    LonghandId::AnimationDuration,
                    LonghandId::AnimationTimingFunction,
                    LonghandId::AnimationIterationCount,
                    LonghandId::AnimationDirection,
                    LonghandId::AnimationPlayState,
                    LonghandId::AnimationFillMode,
                    LonghandId::AnimationComposition,
                    LonghandId::AnimationDelay,
                    LonghandId::AnimationTimeline,
                    LonghandId::ScrollTimelineName,
                    LonghandId::ScrollTimelineAxis,
                    LonghandId::ViewTimelineName,
                    LonghandId::ViewTimelineAxis,
                    LonghandId::ViewTimelineInset,
                    LonghandId::MozBoxAlign,
                    LonghandId::MozBoxDirection,
                    LonghandId::MozBoxFlex,
                    LonghandId::MozBoxOrient,
                    LonghandId::MozBoxPack,
                    LonghandId::MozBoxOrdinalGroup,
            ],
        ];
        NonCustomPropertyIterator {
            filter: NonCustomPropertyId::from(self).enabled_for_all_content(),
            iter: MAP[self as usize].iter(),
        }
    }

    /// Try to serialize the given declarations as this shorthand.
    ///
    /// Returns an error if writing to the stream fails, or if the declarations
    /// do not map to a shorthand.
    pub fn longhands_to_css(
        self,
        declarations: &[&PropertyDeclaration],
        dest: &mut CssStringWriter,
    ) -> fmt::Result {
        type LonghandsToCssFn = for<'a, 'b> fn(&'a [&'b PropertyDeclaration], &mut CssStringWriter) -> fmt::Result;
        fn all_to_css(_: &[&PropertyDeclaration], _: &mut CssStringWriter) -> fmt::Result {
            // No need to try to serialize the declarations as the 'all'
            // shorthand, since it only accepts CSS-wide keywords (and variable
            // references), which will be handled in
            // get_shorthand_appendable_value.
            Ok(())
        }

        static LONGHANDS_TO_CSS: [LonghandsToCssFn; 79] = [
                shorthands::background::to_css,
                shorthands::background_position::to_css,
                shorthands::border_color::to_css,
                shorthands::border_style::to_css,
                shorthands::border_width::to_css,
                shorthands::border_top::to_css,
                shorthands::border_right::to_css,
                shorthands::border_bottom::to_css,
                shorthands::border_left::to_css,
                shorthands::border_block_start::to_css,
                shorthands::border_block_end::to_css,
                shorthands::border_inline_start::to_css,
                shorthands::border_inline_end::to_css,
                shorthands::border::to_css,
                shorthands::border_radius::to_css,
                shorthands::border_image::to_css,
                shorthands::border_block_width::to_css,
                shorthands::border_block_style::to_css,
                shorthands::border_block_color::to_css,
                shorthands::border_inline_width::to_css,
                shorthands::border_inline_style::to_css,
                shorthands::border_inline_color::to_css,
                shorthands::border_block::to_css,
                shorthands::border_inline::to_css,
                shorthands::overflow::to_css,
                shorthands::overflow_clip_box::to_css,
                shorthands::overscroll_behavior::to_css,
                shorthands::container::to_css,
                shorthands::page_break_before::to_css,
                shorthands::page_break_after::to_css,
                shorthands::page_break_inside::to_css,
                shorthands::offset::to_css,
                shorthands::columns::to_css,
                shorthands::column_rule::to_css,
                shorthands::font::to_css,
                shorthands::font_variant::to_css,
                shorthands::font_synthesis::to_css,
                shorthands::marker::to_css,
                shorthands::text_emphasis::to_css,
                shorthands::text_wrap::to_css,
                shorthands::white_space::to_css,
                shorthands::_webkit_text_stroke::to_css,
                shorthands::list_style::to_css,
                shorthands::margin::to_css,
                shorthands::margin_block::to_css,
                shorthands::margin_inline::to_css,
                shorthands::scroll_margin::to_css,
                shorthands::scroll_margin_block::to_css,
                shorthands::scroll_margin_inline::to_css,
                shorthands::outline::to_css,
                shorthands::padding::to_css,
                shorthands::padding_block::to_css,
                shorthands::padding_inline::to_css,
                shorthands::scroll_padding::to_css,
                shorthands::scroll_padding_block::to_css,
                shorthands::scroll_padding_inline::to_css,
                shorthands::flex_flow::to_css,
                shorthands::flex::to_css,
                shorthands::gap::to_css,
                shorthands::grid_row::to_css,
                shorthands::grid_column::to_css,
                shorthands::grid_area::to_css,
                shorthands::grid_template::to_css,
                shorthands::grid::to_css,
                shorthands::place_content::to_css,
                shorthands::place_self::to_css,
                shorthands::place_items::to_css,
                shorthands::inset::to_css,
                shorthands::inset_block::to_css,
                shorthands::inset_inline::to_css,
                shorthands::contain_intrinsic_size::to_css,
                shorthands::mask::to_css,
                shorthands::mask_position::to_css,
                shorthands::text_decoration::to_css,
                shorthands::transition::to_css,
                shorthands::animation::to_css,
                shorthands::scroll_timeline::to_css,
                shorthands::view_timeline::to_css,
                all_to_css,
        ];

        LONGHANDS_TO_CSS[self as usize](declarations, dest)
    }

    /// Returns PropertyFlags for the given shorthand property.
    #[inline]
    pub fn flags(self) -> PropertyFlags {
        const FLAGS: [u16; 79] = [
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                    PropertyFlags::IS_LEGACY_SHORTHAND.bits() |
                0,
                    PropertyFlags::IS_LEGACY_SHORTHAND.bits() |
                0,
                    PropertyFlags::IS_LEGACY_SHORTHAND.bits() |
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
                0,
        ];
        PropertyFlags::from_bits_retain(FLAGS[self as usize])
    }

    /// Returns the order in which this property appears relative to other
    /// shorthands in idl-name-sorting order.
    #[inline]
    pub fn idl_name_sort_order(self) -> u32 {
        
        static IDL_NAME_SORT_ORDER: [u32; 79] = [
            3,
            4,
            13,
            24,
            26,
            25,
            23,
            12,
            21,
            9,
            8,
            18,
            17,
            5,
            22,
            14,
            11,
            10,
            7,
            20,
            19,
            16,
            6,
            15,
            54,
            55,
            56,
            30,
            61,
            60,
            62,
            52,
            28,
            27,
            33,
            35,
            34,
            49,
            74,
            75,
            78,
            0,
            45,
            46,
            47,
            48,
            66,
            67,
            68,
            53,
            57,
            58,
            59,
            69,
            70,
            71,
            32,
            31,
            36,
            40,
            39,
            38,
            41,
            37,
            63,
            65,
            64,
            42,
            43,
            44,
            29,
            50,
            51,
            73,
            76,
            2,
            72,
            77,
            1,
        ];
        IDL_NAME_SORT_ORDER[self as usize]
    }

    pub(super) fn parse_into<'i, 't>(
        self,
        declarations: &mut SourcePropertyDeclaration,
        context: &ParserContext,
        input: &mut Parser<'i, 't>,
    ) -> Result<(), ParseError<'i>> {
        type ParseIntoFn = for<'i, 't> fn(
            declarations: &mut SourcePropertyDeclaration,
            context: &ParserContext,
            input: &mut Parser<'i, 't>,
        ) -> Result<(), ParseError<'i>>;

        fn parse_all<'i, 't>(
            _: &mut SourcePropertyDeclaration,
            _: &ParserContext,
            input: &mut Parser<'i, 't>
        ) -> Result<(), ParseError<'i>> {
            // 'all' accepts no value other than CSS-wide keywords
            Err(input.new_custom_error(StyleParseErrorKind::UnspecifiedError))
        }

        static PARSE_INTO: [ParseIntoFn; 79] = [
            shorthands::background::parse_into,
            shorthands::background_position::parse_into,
            shorthands::border_color::parse_into,
            shorthands::border_style::parse_into,
            shorthands::border_width::parse_into,
            shorthands::border_top::parse_into,
            shorthands::border_right::parse_into,
            shorthands::border_bottom::parse_into,
            shorthands::border_left::parse_into,
            shorthands::border_block_start::parse_into,
            shorthands::border_block_end::parse_into,
            shorthands::border_inline_start::parse_into,
            shorthands::border_inline_end::parse_into,
            shorthands::border::parse_into,
            shorthands::border_radius::parse_into,
            shorthands::border_image::parse_into,
            shorthands::border_block_width::parse_into,
            shorthands::border_block_style::parse_into,
            shorthands::border_block_color::parse_into,
            shorthands::border_inline_width::parse_into,
            shorthands::border_inline_style::parse_into,
            shorthands::border_inline_color::parse_into,
            shorthands::border_block::parse_into,
            shorthands::border_inline::parse_into,
            shorthands::overflow::parse_into,
            shorthands::overflow_clip_box::parse_into,
            shorthands::overscroll_behavior::parse_into,
            shorthands::container::parse_into,
            shorthands::page_break_before::parse_into,
            shorthands::page_break_after::parse_into,
            shorthands::page_break_inside::parse_into,
            shorthands::offset::parse_into,
            shorthands::columns::parse_into,
            shorthands::column_rule::parse_into,
            shorthands::font::parse_into,
            shorthands::font_variant::parse_into,
            shorthands::font_synthesis::parse_into,
            shorthands::marker::parse_into,
            shorthands::text_emphasis::parse_into,
            shorthands::text_wrap::parse_into,
            shorthands::white_space::parse_into,
            shorthands::_webkit_text_stroke::parse_into,
            shorthands::list_style::parse_into,
            shorthands::margin::parse_into,
            shorthands::margin_block::parse_into,
            shorthands::margin_inline::parse_into,
            shorthands::scroll_margin::parse_into,
            shorthands::scroll_margin_block::parse_into,
            shorthands::scroll_margin_inline::parse_into,
            shorthands::outline::parse_into,
            shorthands::padding::parse_into,
            shorthands::padding_block::parse_into,
            shorthands::padding_inline::parse_into,
            shorthands::scroll_padding::parse_into,
            shorthands::scroll_padding_block::parse_into,
            shorthands::scroll_padding_inline::parse_into,
            shorthands::flex_flow::parse_into,
            shorthands::flex::parse_into,
            shorthands::gap::parse_into,
            shorthands::grid_row::parse_into,
            shorthands::grid_column::parse_into,
            shorthands::grid_area::parse_into,
            shorthands::grid_template::parse_into,
            shorthands::grid::parse_into,
            shorthands::place_content::parse_into,
            shorthands::place_self::parse_into,
            shorthands::place_items::parse_into,
            shorthands::inset::parse_into,
            shorthands::inset_block::parse_into,
            shorthands::inset_inline::parse_into,
            shorthands::contain_intrinsic_size::parse_into,
            shorthands::mask::parse_into,
            shorthands::mask_position::parse_into,
            shorthands::text_decoration::parse_into,
            shorthands::transition::parse_into,
            shorthands::animation::parse_into,
            shorthands::scroll_timeline::parse_into,
            shorthands::view_timeline::parse_into,
            parse_all,
        ];

        (PARSE_INTO[self as usize])(declarations, context, input)
    }
}

/// The counted unknown property list which is used for css use counters.
///
/// FIXME: This should be just #[repr(u8)], but can't be because of ABI issues,
/// see https://bugs.llvm.org/show_bug.cgi?id=44228.
#[derive(Clone, Copy, Debug, Eq, FromPrimitive, Hash, PartialEq)]
#[repr(u32)]
pub enum CountedUnknownProperty {
    /// -webkit-tap-highlight-color
    WebkitTapHighlightColor,
    /// speak
    Speak,
    /// text-size-adjust
    TextSizeAdjust,
    /// -webkit-font-feature-settings
    WebkitFontFeatureSettings,
    /// -webkit-user-drag
    WebkitUserDrag,
    /// orphans
    Orphans,
    /// widows
    Widows,
    /// -webkit-user-modify
    WebkitUserModify,
    /// -webkit-margin-before
    WebkitMarginBefore,
    /// -webkit-margin-after
    WebkitMarginAfter,
    /// -webkit-margin-start
    WebkitMarginStart,
    /// -webkit-column-break-inside
    WebkitColumnBreakInside,
    /// -webkit-padding-start
    WebkitPaddingStart,
    /// -webkit-margin-end
    WebkitMarginEnd,
    /// -webkit-box-reflect
    WebkitBoxReflect,
    /// -webkit-print-color-adjust
    WebkitPrintColorAdjust,
    /// -webkit-mask-box-image
    WebkitMaskBoxImage,
    /// -webkit-line-break
    WebkitLineBreak,
    /// alignment-baseline
    AlignmentBaseline,
    /// -webkit-writing-mode
    WebkitWritingMode,
    /// baseline-shift
    BaselineShift,
    /// -webkit-hyphenate-character
    WebkitHyphenateCharacter,
    /// -webkit-highlight
    WebkitHighlight,
    /// background-repeat-x
    BackgroundRepeatX,
    /// -webkit-padding-end
    WebkitPaddingEnd,
    /// background-repeat-y
    BackgroundRepeatY,
    /// -webkit-text-emphasis-color
    WebkitTextEmphasisColor,
    /// -webkit-margin-top-collapse
    WebkitMarginTopCollapse,
    /// -webkit-rtl-ordering
    WebkitRtlOrdering,
    /// -webkit-padding-before
    WebkitPaddingBefore,
    /// -webkit-text-decorations-in-effect
    WebkitTextDecorationsInEffect,
    /// -webkit-border-vertical-spacing
    WebkitBorderVerticalSpacing,
    /// -webkit-locale
    WebkitLocale,
    /// -webkit-padding-after
    WebkitPaddingAfter,
    /// -webkit-border-horizontal-spacing
    WebkitBorderHorizontalSpacing,
    /// color-rendering
    ColorRendering,
    /// -webkit-column-break-before
    WebkitColumnBreakBefore,
    /// -webkit-transform-origin-x
    WebkitTransformOriginX,
    /// -webkit-transform-origin-y
    WebkitTransformOriginY,
    /// -webkit-text-emphasis-position
    WebkitTextEmphasisPosition,
    /// buffered-rendering
    BufferedRendering,
    /// -webkit-text-orientation
    WebkitTextOrientation,
    /// -webkit-text-combine
    WebkitTextCombine,
    /// -webkit-text-emphasis-style
    WebkitTextEmphasisStyle,
    /// -webkit-text-emphasis
    WebkitTextEmphasis,
    /// -webkit-mask-box-image-width
    WebkitMaskBoxImageWidth,
    /// -webkit-mask-box-image-source
    WebkitMaskBoxImageSource,
    /// -webkit-mask-box-image-outset
    WebkitMaskBoxImageOutset,
    /// -webkit-mask-box-image-slice
    WebkitMaskBoxImageSlice,
    /// -webkit-mask-box-image-repeat
    WebkitMaskBoxImageRepeat,
    /// -webkit-margin-after-collapse
    WebkitMarginAfterCollapse,
    /// -webkit-border-before-color
    WebkitBorderBeforeColor,
    /// -webkit-border-before-width
    WebkitBorderBeforeWidth,
    /// -webkit-perspective-origin-x
    WebkitPerspectiveOriginX,
    /// -webkit-perspective-origin-y
    WebkitPerspectiveOriginY,
    /// -webkit-margin-before-collapse
    WebkitMarginBeforeCollapse,
    /// -webkit-border-before-style
    WebkitBorderBeforeStyle,
    /// -webkit-margin-bottom-collapse
    WebkitMarginBottomCollapse,
    /// -webkit-ruby-position
    WebkitRubyPosition,
    /// -webkit-column-break-after
    WebkitColumnBreakAfter,
    /// -webkit-margin-collapse
    WebkitMarginCollapse,
    /// -webkit-border-before
    WebkitBorderBefore,
    /// -webkit-border-end
    WebkitBorderEnd,
    /// -webkit-border-after
    WebkitBorderAfter,
    /// -webkit-border-start
    WebkitBorderStart,
    /// -webkit-min-logical-width
    WebkitMinLogicalWidth,
    /// -webkit-logical-height
    WebkitLogicalHeight,
    /// -webkit-transform-origin-z
    WebkitTransformOriginZ,
    /// -webkit-font-size-delta
    WebkitFontSizeDelta,
    /// -webkit-logical-width
    WebkitLogicalWidth,
    /// -webkit-max-logical-width
    WebkitMaxLogicalWidth,
    /// -webkit-min-logical-height
    WebkitMinLogicalHeight,
    /// -webkit-max-logical-height
    WebkitMaxLogicalHeight,
    /// -webkit-border-end-color
    WebkitBorderEndColor,
    /// -webkit-border-end-width
    WebkitBorderEndWidth,
    /// -webkit-border-start-color
    WebkitBorderStartColor,
    /// -webkit-border-start-width
    WebkitBorderStartWidth,
    /// -webkit-border-after-color
    WebkitBorderAfterColor,
    /// -webkit-border-after-width
    WebkitBorderAfterWidth,
    /// -webkit-border-end-style
    WebkitBorderEndStyle,
    /// -webkit-border-after-style
    WebkitBorderAfterStyle,
    /// -webkit-border-start-style
    WebkitBorderStartStyle,
    /// -webkit-mask-repeat-x
    WebkitMaskRepeatX,
    /// -webkit-mask-repeat-y
    WebkitMaskRepeatY,
    /// user-zoom
    UserZoom,
    /// min-zoom
    MinZoom,
    /// -webkit-box-decoration-break
    WebkitBoxDecorationBreak,
    /// orientation
    Orientation,
    /// max-zoom
    MaxZoom,
    /// -webkit-app-region
    WebkitAppRegion,
    /// -webkit-column-rule
    WebkitColumnRule,
    /// -webkit-column-span
    WebkitColumnSpan,
    /// -webkit-column-gap
    WebkitColumnGap,
    /// -webkit-shape-outside
    WebkitShapeOutside,
    /// -webkit-column-rule-width
    WebkitColumnRuleWidth,
    /// -webkit-column-count
    WebkitColumnCount,
    /// -webkit-opacity
    WebkitOpacity,
    /// -webkit-column-width
    WebkitColumnWidth,
    /// -webkit-shape-image-threshold
    WebkitShapeImageThreshold,
    /// -webkit-column-rule-style
    WebkitColumnRuleStyle,
    /// -webkit-columns
    WebkitColumns,
    /// -webkit-column-rule-color
    WebkitColumnRuleColor,
    /// -webkit-shape-margin
    WebkitShapeMargin,
}

impl CountedUnknownProperty {
    /// Parse the counted unknown property, for testing purposes only.
    pub fn parse_for_testing(property_name: &str) -> Option<Self> {
        ascii_case_insensitive_phf_map! {
            unknown_ids -> CountedUnknownProperty = {
                "-webkit-tap-highlight-color" => CountedUnknownProperty::WebkitTapHighlightColor,
                "speak" => CountedUnknownProperty::Speak,
                "text-size-adjust" => CountedUnknownProperty::TextSizeAdjust,
                "-webkit-font-feature-settings" => CountedUnknownProperty::WebkitFontFeatureSettings,
                "-webkit-user-drag" => CountedUnknownProperty::WebkitUserDrag,
                "orphans" => CountedUnknownProperty::Orphans,
                "widows" => CountedUnknownProperty::Widows,
                "-webkit-user-modify" => CountedUnknownProperty::WebkitUserModify,
                "-webkit-margin-before" => CountedUnknownProperty::WebkitMarginBefore,
                "-webkit-margin-after" => CountedUnknownProperty::WebkitMarginAfter,
                "-webkit-margin-start" => CountedUnknownProperty::WebkitMarginStart,
                "-webkit-column-break-inside" => CountedUnknownProperty::WebkitColumnBreakInside,
                "-webkit-padding-start" => CountedUnknownProperty::WebkitPaddingStart,
                "-webkit-margin-end" => CountedUnknownProperty::WebkitMarginEnd,
                "-webkit-box-reflect" => CountedUnknownProperty::WebkitBoxReflect,
                "-webkit-print-color-adjust" => CountedUnknownProperty::WebkitPrintColorAdjust,
                "-webkit-mask-box-image" => CountedUnknownProperty::WebkitMaskBoxImage,
                "-webkit-line-break" => CountedUnknownProperty::WebkitLineBreak,
                "alignment-baseline" => CountedUnknownProperty::AlignmentBaseline,
                "-webkit-writing-mode" => CountedUnknownProperty::WebkitWritingMode,
                "baseline-shift" => CountedUnknownProperty::BaselineShift,
                "-webkit-hyphenate-character" => CountedUnknownProperty::WebkitHyphenateCharacter,
                "-webkit-highlight" => CountedUnknownProperty::WebkitHighlight,
                "background-repeat-x" => CountedUnknownProperty::BackgroundRepeatX,
                "-webkit-padding-end" => CountedUnknownProperty::WebkitPaddingEnd,
                "background-repeat-y" => CountedUnknownProperty::BackgroundRepeatY,
                "-webkit-text-emphasis-color" => CountedUnknownProperty::WebkitTextEmphasisColor,
                "-webkit-margin-top-collapse" => CountedUnknownProperty::WebkitMarginTopCollapse,
                "-webkit-rtl-ordering" => CountedUnknownProperty::WebkitRtlOrdering,
                "-webkit-padding-before" => CountedUnknownProperty::WebkitPaddingBefore,
                "-webkit-text-decorations-in-effect" => CountedUnknownProperty::WebkitTextDecorationsInEffect,
                "-webkit-border-vertical-spacing" => CountedUnknownProperty::WebkitBorderVerticalSpacing,
                "-webkit-locale" => CountedUnknownProperty::WebkitLocale,
                "-webkit-padding-after" => CountedUnknownProperty::WebkitPaddingAfter,
                "-webkit-border-horizontal-spacing" => CountedUnknownProperty::WebkitBorderHorizontalSpacing,
                "color-rendering" => CountedUnknownProperty::ColorRendering,
                "-webkit-column-break-before" => CountedUnknownProperty::WebkitColumnBreakBefore,
                "-webkit-transform-origin-x" => CountedUnknownProperty::WebkitTransformOriginX,
                "-webkit-transform-origin-y" => CountedUnknownProperty::WebkitTransformOriginY,
                "-webkit-text-emphasis-position" => CountedUnknownProperty::WebkitTextEmphasisPosition,
                "buffered-rendering" => CountedUnknownProperty::BufferedRendering,
                "-webkit-text-orientation" => CountedUnknownProperty::WebkitTextOrientation,
                "-webkit-text-combine" => CountedUnknownProperty::WebkitTextCombine,
                "-webkit-text-emphasis-style" => CountedUnknownProperty::WebkitTextEmphasisStyle,
                "-webkit-text-emphasis" => CountedUnknownProperty::WebkitTextEmphasis,
                "-webkit-mask-box-image-width" => CountedUnknownProperty::WebkitMaskBoxImageWidth,
                "-webkit-mask-box-image-source" => CountedUnknownProperty::WebkitMaskBoxImageSource,
                "-webkit-mask-box-image-outset" => CountedUnknownProperty::WebkitMaskBoxImageOutset,
                "-webkit-mask-box-image-slice" => CountedUnknownProperty::WebkitMaskBoxImageSlice,
                "-webkit-mask-box-image-repeat" => CountedUnknownProperty::WebkitMaskBoxImageRepeat,
                "-webkit-margin-after-collapse" => CountedUnknownProperty::WebkitMarginAfterCollapse,
                "-webkit-border-before-color" => CountedUnknownProperty::WebkitBorderBeforeColor,
                "-webkit-border-before-width" => CountedUnknownProperty::WebkitBorderBeforeWidth,
                "-webkit-perspective-origin-x" => CountedUnknownProperty::WebkitPerspectiveOriginX,
                "-webkit-perspective-origin-y" => CountedUnknownProperty::WebkitPerspectiveOriginY,
                "-webkit-margin-before-collapse" => CountedUnknownProperty::WebkitMarginBeforeCollapse,
                "-webkit-border-before-style" => CountedUnknownProperty::WebkitBorderBeforeStyle,
                "-webkit-margin-bottom-collapse" => CountedUnknownProperty::WebkitMarginBottomCollapse,
                "-webkit-ruby-position" => CountedUnknownProperty::WebkitRubyPosition,
                "-webkit-column-break-after" => CountedUnknownProperty::WebkitColumnBreakAfter,
                "-webkit-margin-collapse" => CountedUnknownProperty::WebkitMarginCollapse,
                "-webkit-border-before" => CountedUnknownProperty::WebkitBorderBefore,
                "-webkit-border-end" => CountedUnknownProperty::WebkitBorderEnd,
                "-webkit-border-after" => CountedUnknownProperty::WebkitBorderAfter,
                "-webkit-border-start" => CountedUnknownProperty::WebkitBorderStart,
                "-webkit-min-logical-width" => CountedUnknownProperty::WebkitMinLogicalWidth,
                "-webkit-logical-height" => CountedUnknownProperty::WebkitLogicalHeight,
                "-webkit-transform-origin-z" => CountedUnknownProperty::WebkitTransformOriginZ,
                "-webkit-font-size-delta" => CountedUnknownProperty::WebkitFontSizeDelta,
                "-webkit-logical-width" => CountedUnknownProperty::WebkitLogicalWidth,
                "-webkit-max-logical-width" => CountedUnknownProperty::WebkitMaxLogicalWidth,
                "-webkit-min-logical-height" => CountedUnknownProperty::WebkitMinLogicalHeight,
                "-webkit-max-logical-height" => CountedUnknownProperty::WebkitMaxLogicalHeight,
                "-webkit-border-end-color" => CountedUnknownProperty::WebkitBorderEndColor,
                "-webkit-border-end-width" => CountedUnknownProperty::WebkitBorderEndWidth,
                "-webkit-border-start-color" => CountedUnknownProperty::WebkitBorderStartColor,
                "-webkit-border-start-width" => CountedUnknownProperty::WebkitBorderStartWidth,
                "-webkit-border-after-color" => CountedUnknownProperty::WebkitBorderAfterColor,
                "-webkit-border-after-width" => CountedUnknownProperty::WebkitBorderAfterWidth,
                "-webkit-border-end-style" => CountedUnknownProperty::WebkitBorderEndStyle,
                "-webkit-border-after-style" => CountedUnknownProperty::WebkitBorderAfterStyle,
                "-webkit-border-start-style" => CountedUnknownProperty::WebkitBorderStartStyle,
                "-webkit-mask-repeat-x" => CountedUnknownProperty::WebkitMaskRepeatX,
                "-webkit-mask-repeat-y" => CountedUnknownProperty::WebkitMaskRepeatY,
                "user-zoom" => CountedUnknownProperty::UserZoom,
                "min-zoom" => CountedUnknownProperty::MinZoom,
                "-webkit-box-decoration-break" => CountedUnknownProperty::WebkitBoxDecorationBreak,
                "orientation" => CountedUnknownProperty::Orientation,
                "max-zoom" => CountedUnknownProperty::MaxZoom,
                "-webkit-app-region" => CountedUnknownProperty::WebkitAppRegion,
                "-webkit-column-rule" => CountedUnknownProperty::WebkitColumnRule,
                "-webkit-column-span" => CountedUnknownProperty::WebkitColumnSpan,
                "-webkit-column-gap" => CountedUnknownProperty::WebkitColumnGap,
                "-webkit-shape-outside" => CountedUnknownProperty::WebkitShapeOutside,
                "-webkit-column-rule-width" => CountedUnknownProperty::WebkitColumnRuleWidth,
                "-webkit-column-count" => CountedUnknownProperty::WebkitColumnCount,
                "-webkit-opacity" => CountedUnknownProperty::WebkitOpacity,
                "-webkit-column-width" => CountedUnknownProperty::WebkitColumnWidth,
                "-webkit-shape-image-threshold" => CountedUnknownProperty::WebkitShapeImageThreshold,
                "-webkit-column-rule-style" => CountedUnknownProperty::WebkitColumnRuleStyle,
                "-webkit-columns" => CountedUnknownProperty::WebkitColumns,
                "-webkit-column-rule-color" => CountedUnknownProperty::WebkitColumnRuleColor,
                "-webkit-shape-margin" => CountedUnknownProperty::WebkitShapeMargin,
            }
        }
        unknown_ids::get(property_name).cloned()
    }

    /// Returns the underlying index, used for use counter.
    #[inline]
    pub fn bit(self) -> usize {
        self as usize
    }
}

impl PropertyId {
    /// Returns a given property from the given name, _regardless of whether it
    /// is enabled or not_, or Err(()) for unknown properties.
    pub(super) fn parse_unchecked(
        property_name: &str,
        use_counters: Option< &UseCounters>,
    ) -> Result<Self, ()> {
        // A special id for css use counters. ShorthandAlias is not used in the Servo build.
        // That's why we need to allow dead_code.
        pub enum StaticId {
            NonCustom(NonCustomPropertyId),
            CountedUnknown(CountedUnknownProperty),
        }
        ascii_case_insensitive_phf_map! {
            static_ids -> StaticId = {
                "align-content" => StaticId::NonCustom(NonCustomPropertyId(0)),
                "align-items" => StaticId::NonCustom(NonCustomPropertyId(1)),
                "align-self" => StaticId::NonCustom(NonCustomPropertyId(2)),
                "aspect-ratio" => StaticId::NonCustom(NonCustomPropertyId(3)),
                "backface-visibility" => StaticId::NonCustom(NonCustomPropertyId(4)),
                "baseline-source" => StaticId::NonCustom(NonCustomPropertyId(5)),
                "border-collapse" => StaticId::NonCustom(NonCustomPropertyId(6)),
                "border-image-repeat" => StaticId::NonCustom(NonCustomPropertyId(7)),
                "box-decoration-break" => StaticId::NonCustom(NonCustomPropertyId(8)),
                "box-sizing" => StaticId::NonCustom(NonCustomPropertyId(9)),
                "break-inside" => StaticId::NonCustom(NonCustomPropertyId(10)),
                "caption-side" => StaticId::NonCustom(NonCustomPropertyId(11)),
                "clear" => StaticId::NonCustom(NonCustomPropertyId(12)),
                "color-interpolation" => StaticId::NonCustom(NonCustomPropertyId(13)),
                "color-interpolation-filters" => StaticId::NonCustom(NonCustomPropertyId(14)),
                "column-count" => StaticId::NonCustom(NonCustomPropertyId(15)),
                "column-fill" => StaticId::NonCustom(NonCustomPropertyId(16)),
                "column-span" => StaticId::NonCustom(NonCustomPropertyId(17)),
                "contain" => StaticId::NonCustom(NonCustomPropertyId(18)),
                "container-type" => StaticId::NonCustom(NonCustomPropertyId(19)),
                "content-visibility" => StaticId::NonCustom(NonCustomPropertyId(20)),
                "direction" => StaticId::NonCustom(NonCustomPropertyId(21)),
                "display" => StaticId::NonCustom(NonCustomPropertyId(22)),
                "dominant-baseline" => StaticId::NonCustom(NonCustomPropertyId(23)),
                "empty-cells" => StaticId::NonCustom(NonCustomPropertyId(24)),
                "flex-direction" => StaticId::NonCustom(NonCustomPropertyId(25)),
                "flex-wrap" => StaticId::NonCustom(NonCustomPropertyId(26)),
                "float" => StaticId::NonCustom(NonCustomPropertyId(27)),
                "font-kerning" => StaticId::NonCustom(NonCustomPropertyId(28)),
                "font-language-override" => StaticId::NonCustom(NonCustomPropertyId(29)),
                "font-optical-sizing" => StaticId::NonCustom(NonCustomPropertyId(30)),
                "font-size-adjust" => StaticId::NonCustom(NonCustomPropertyId(31)),
                "font-stretch" => StaticId::NonCustom(NonCustomPropertyId(32)),
                "font-style" => StaticId::NonCustom(NonCustomPropertyId(33)),
                "font-variant-caps" => StaticId::NonCustom(NonCustomPropertyId(34)),
                "font-variant-east-asian" => StaticId::NonCustom(NonCustomPropertyId(35)),
                "font-variant-emoji" => StaticId::NonCustom(NonCustomPropertyId(36)),
                "font-variant-ligatures" => StaticId::NonCustom(NonCustomPropertyId(37)),
                "font-variant-numeric" => StaticId::NonCustom(NonCustomPropertyId(38)),
                "font-variant-position" => StaticId::NonCustom(NonCustomPropertyId(39)),
                "font-weight" => StaticId::NonCustom(NonCustomPropertyId(40)),
                "forced-color-adjust" => StaticId::NonCustom(NonCustomPropertyId(41)),
                "grid-auto-flow" => StaticId::NonCustom(NonCustomPropertyId(42)),
                "hyphens" => StaticId::NonCustom(NonCustomPropertyId(43)),
                "image-orientation" => StaticId::NonCustom(NonCustomPropertyId(44)),
                "image-rendering" => StaticId::NonCustom(NonCustomPropertyId(45)),
                "ime-mode" => StaticId::NonCustom(NonCustomPropertyId(46)),
                "initial-letter" => StaticId::NonCustom(NonCustomPropertyId(47)),
                "inset-area" => StaticId::NonCustom(NonCustomPropertyId(48)),
                "isolation" => StaticId::NonCustom(NonCustomPropertyId(49)),
                "justify-content" => StaticId::NonCustom(NonCustomPropertyId(50)),
                "justify-items" => StaticId::NonCustom(NonCustomPropertyId(51)),
                "justify-self" => StaticId::NonCustom(NonCustomPropertyId(52)),
                "line-break" => StaticId::NonCustom(NonCustomPropertyId(53)),
                "list-style-position" => StaticId::NonCustom(NonCustomPropertyId(54)),
                "mask-type" => StaticId::NonCustom(NonCustomPropertyId(55)),
                "masonry-auto-flow" => StaticId::NonCustom(NonCustomPropertyId(56)),
                "math-depth" => StaticId::NonCustom(NonCustomPropertyId(57)),
                "math-style" => StaticId::NonCustom(NonCustomPropertyId(58)),
                "mix-blend-mode" => StaticId::NonCustom(NonCustomPropertyId(59)),
                "-moz-box-align" => StaticId::NonCustom(NonCustomPropertyId(60)),
                "-moz-box-collapse" => StaticId::NonCustom(NonCustomPropertyId(61)),
                "-moz-box-direction" => StaticId::NonCustom(NonCustomPropertyId(62)),
                "-moz-box-orient" => StaticId::NonCustom(NonCustomPropertyId(63)),
                "-moz-box-pack" => StaticId::NonCustom(NonCustomPropertyId(64)),
                "-moz-control-character-visibility" => StaticId::NonCustom(NonCustomPropertyId(65)),
                "-moz-float-edge" => StaticId::NonCustom(NonCustomPropertyId(66)),
                "-moz-inert" => StaticId::NonCustom(NonCustomPropertyId(67)),
                "-moz-math-variant" => StaticId::NonCustom(NonCustomPropertyId(68)),
                "-moz-min-font-size-ratio" => StaticId::NonCustom(NonCustomPropertyId(69)),
                "-moz-orient" => StaticId::NonCustom(NonCustomPropertyId(70)),
                "-moz-osx-font-smoothing" => StaticId::NonCustom(NonCustomPropertyId(71)),
                "-moz-text-size-adjust" => StaticId::NonCustom(NonCustomPropertyId(72)),
                "-moz-theme" => StaticId::NonCustom(NonCustomPropertyId(73)),
                "-moz-top-layer" => StaticId::NonCustom(NonCustomPropertyId(74)),
                "-moz-user-focus" => StaticId::NonCustom(NonCustomPropertyId(75)),
                "-moz-user-input" => StaticId::NonCustom(NonCustomPropertyId(76)),
                "-moz-user-modify" => StaticId::NonCustom(NonCustomPropertyId(77)),
                "-moz-window-dragging" => StaticId::NonCustom(NonCustomPropertyId(78)),
                "-moz-window-shadow" => StaticId::NonCustom(NonCustomPropertyId(79)),
                "object-fit" => StaticId::NonCustom(NonCustomPropertyId(80)),
                "offset-rotate" => StaticId::NonCustom(NonCustomPropertyId(81)),
                "outline-style" => StaticId::NonCustom(NonCustomPropertyId(82)),
                "overflow-anchor" => StaticId::NonCustom(NonCustomPropertyId(83)),
                "overflow-wrap" => StaticId::NonCustom(NonCustomPropertyId(84)),
                "page-orientation" => StaticId::NonCustom(NonCustomPropertyId(85)),
                "paint-order" => StaticId::NonCustom(NonCustomPropertyId(86)),
                "pointer-events" => StaticId::NonCustom(NonCustomPropertyId(87)),
                "position" => StaticId::NonCustom(NonCustomPropertyId(88)),
                "position-try-order" => StaticId::NonCustom(NonCustomPropertyId(89)),
                "position-visibility" => StaticId::NonCustom(NonCustomPropertyId(90)),
                "print-color-adjust" => StaticId::NonCustom(NonCustomPropertyId(91)),
                "resize" => StaticId::NonCustom(NonCustomPropertyId(92)),
                "ruby-align" => StaticId::NonCustom(NonCustomPropertyId(93)),
                "ruby-position" => StaticId::NonCustom(NonCustomPropertyId(94)),
                "scroll-behavior" => StaticId::NonCustom(NonCustomPropertyId(95)),
                "scroll-snap-align" => StaticId::NonCustom(NonCustomPropertyId(96)),
                "scroll-snap-stop" => StaticId::NonCustom(NonCustomPropertyId(97)),
                "scroll-snap-type" => StaticId::NonCustom(NonCustomPropertyId(98)),
                "scrollbar-gutter" => StaticId::NonCustom(NonCustomPropertyId(99)),
                "scrollbar-width" => StaticId::NonCustom(NonCustomPropertyId(100)),
                "shape-rendering" => StaticId::NonCustom(NonCustomPropertyId(101)),
                "stroke-linecap" => StaticId::NonCustom(NonCustomPropertyId(102)),
                "stroke-linejoin" => StaticId::NonCustom(NonCustomPropertyId(103)),
                "table-layout" => StaticId::NonCustom(NonCustomPropertyId(104)),
                "text-align" => StaticId::NonCustom(NonCustomPropertyId(105)),
                "text-align-last" => StaticId::NonCustom(NonCustomPropertyId(106)),
                "text-anchor" => StaticId::NonCustom(NonCustomPropertyId(107)),
                "text-combine-upright" => StaticId::NonCustom(NonCustomPropertyId(108)),
                "text-decoration-line" => StaticId::NonCustom(NonCustomPropertyId(109)),
                "text-decoration-skip-ink" => StaticId::NonCustom(NonCustomPropertyId(110)),
                "text-decoration-style" => StaticId::NonCustom(NonCustomPropertyId(111)),
                "text-emphasis-position" => StaticId::NonCustom(NonCustomPropertyId(112)),
                "text-justify" => StaticId::NonCustom(NonCustomPropertyId(113)),
                "text-orientation" => StaticId::NonCustom(NonCustomPropertyId(114)),
                "text-rendering" => StaticId::NonCustom(NonCustomPropertyId(115)),
                "text-transform" => StaticId::NonCustom(NonCustomPropertyId(116)),
                "text-underline-position" => StaticId::NonCustom(NonCustomPropertyId(117)),
                "text-wrap-mode" => StaticId::NonCustom(NonCustomPropertyId(118)),
                "text-wrap-style" => StaticId::NonCustom(NonCustomPropertyId(119)),
                "touch-action" => StaticId::NonCustom(NonCustomPropertyId(120)),
                "transform-box" => StaticId::NonCustom(NonCustomPropertyId(121)),
                "transform-style" => StaticId::NonCustom(NonCustomPropertyId(122)),
                "unicode-bidi" => StaticId::NonCustom(NonCustomPropertyId(123)),
                "user-select" => StaticId::NonCustom(NonCustomPropertyId(124)),
                "vector-effect" => StaticId::NonCustom(NonCustomPropertyId(125)),
                "visibility" => StaticId::NonCustom(NonCustomPropertyId(126)),
                "-webkit-line-clamp" => StaticId::NonCustom(NonCustomPropertyId(127)),
                "-webkit-text-security" => StaticId::NonCustom(NonCustomPropertyId(128)),
                "white-space-collapse" => StaticId::NonCustom(NonCustomPropertyId(129)),
                "word-break" => StaticId::NonCustom(NonCustomPropertyId(130)),
                "writing-mode" => StaticId::NonCustom(NonCustomPropertyId(131)),
                "-x-text-scale" => StaticId::NonCustom(NonCustomPropertyId(132)),
                "z-index" => StaticId::NonCustom(NonCustomPropertyId(133)),
                "zoom" => StaticId::NonCustom(NonCustomPropertyId(134)),
                "appearance" => StaticId::NonCustom(NonCustomPropertyId(135)),
                "-moz-default-appearance" => StaticId::NonCustom(NonCustomPropertyId(136)),
                "-moz-force-broken-image-icon" => StaticId::NonCustom(NonCustomPropertyId(137)),
                "-moz-subtree-hidden-only-visually" => StaticId::NonCustom(NonCustomPropertyId(138)),
                "break-after" => StaticId::NonCustom(NonCustomPropertyId(139)),
                "break-before" => StaticId::NonCustom(NonCustomPropertyId(140)),
                "clip-rule" => StaticId::NonCustom(NonCustomPropertyId(141)),
                "fill-rule" => StaticId::NonCustom(NonCustomPropertyId(142)),
                "overflow-clip-box-block" => StaticId::NonCustom(NonCustomPropertyId(143)),
                "overflow-clip-box-inline" => StaticId::NonCustom(NonCustomPropertyId(144)),
                "fill-opacity" => StaticId::NonCustom(NonCustomPropertyId(145)),
                "stroke-opacity" => StaticId::NonCustom(NonCustomPropertyId(146)),
                "-moz-box-ordinal-group" => StaticId::NonCustom(NonCustomPropertyId(147)),
                "order" => StaticId::NonCustom(NonCustomPropertyId(148)),
                "-x-span" => StaticId::NonCustom(NonCustomPropertyId(149)),
                "font-synthesis-position" => StaticId::NonCustom(NonCustomPropertyId(150)),
                "font-synthesis-small-caps" => StaticId::NonCustom(NonCustomPropertyId(151)),
                "font-synthesis-style" => StaticId::NonCustom(NonCustomPropertyId(152)),
                "font-synthesis-weight" => StaticId::NonCustom(NonCustomPropertyId(153)),
                "flex-grow" => StaticId::NonCustom(NonCustomPropertyId(154)),
                "flex-shrink" => StaticId::NonCustom(NonCustomPropertyId(155)),
                "-moz-box-flex" => StaticId::NonCustom(NonCustomPropertyId(156)),
                "stroke-miterlimit" => StaticId::NonCustom(NonCustomPropertyId(157)),
                "overflow-block" => StaticId::NonCustom(NonCustomPropertyId(158)),
                "overflow-inline" => StaticId::NonCustom(NonCustomPropertyId(159)),
                "overflow-x" => StaticId::NonCustom(NonCustomPropertyId(160)),
                "overflow-y" => StaticId::NonCustom(NonCustomPropertyId(161)),
                "overscroll-behavior-block" => StaticId::NonCustom(NonCustomPropertyId(162)),
                "overscroll-behavior-inline" => StaticId::NonCustom(NonCustomPropertyId(163)),
                "overscroll-behavior-x" => StaticId::NonCustom(NonCustomPropertyId(164)),
                "overscroll-behavior-y" => StaticId::NonCustom(NonCustomPropertyId(165)),
                "flood-opacity" => StaticId::NonCustom(NonCustomPropertyId(166)),
                "-moz-window-opacity" => StaticId::NonCustom(NonCustomPropertyId(167)),
                "opacity" => StaticId::NonCustom(NonCustomPropertyId(168)),
                "shape-image-threshold" => StaticId::NonCustom(NonCustomPropertyId(169)),
                "stop-opacity" => StaticId::NonCustom(NonCustomPropertyId(170)),
                "border-block-end-style" => StaticId::NonCustom(NonCustomPropertyId(171)),
                "border-block-start-style" => StaticId::NonCustom(NonCustomPropertyId(172)),
                "border-bottom-style" => StaticId::NonCustom(NonCustomPropertyId(173)),
                "border-inline-end-style" => StaticId::NonCustom(NonCustomPropertyId(174)),
                "border-inline-start-style" => StaticId::NonCustom(NonCustomPropertyId(175)),
                "border-left-style" => StaticId::NonCustom(NonCustomPropertyId(176)),
                "border-right-style" => StaticId::NonCustom(NonCustomPropertyId(177)),
                "border-top-style" => StaticId::NonCustom(NonCustomPropertyId(178)),
                "column-rule-style" => StaticId::NonCustom(NonCustomPropertyId(179)),
                "accent-color" => StaticId::NonCustom(NonCustomPropertyId(180)),
                "anchor-name" => StaticId::NonCustom(NonCustomPropertyId(181)),
                "anchor-scope" => StaticId::NonCustom(NonCustomPropertyId(182)),
                "animation-composition" => StaticId::NonCustom(NonCustomPropertyId(183)),
                "animation-delay" => StaticId::NonCustom(NonCustomPropertyId(184)),
                "animation-direction" => StaticId::NonCustom(NonCustomPropertyId(185)),
                "animation-duration" => StaticId::NonCustom(NonCustomPropertyId(186)),
                "animation-fill-mode" => StaticId::NonCustom(NonCustomPropertyId(187)),
                "animation-iteration-count" => StaticId::NonCustom(NonCustomPropertyId(188)),
                "animation-name" => StaticId::NonCustom(NonCustomPropertyId(189)),
                "animation-play-state" => StaticId::NonCustom(NonCustomPropertyId(190)),
                "animation-timeline" => StaticId::NonCustom(NonCustomPropertyId(191)),
                "animation-timing-function" => StaticId::NonCustom(NonCustomPropertyId(192)),
                "backdrop-filter" => StaticId::NonCustom(NonCustomPropertyId(193)),
                "background-attachment" => StaticId::NonCustom(NonCustomPropertyId(194)),
                "background-blend-mode" => StaticId::NonCustom(NonCustomPropertyId(195)),
                "background-clip" => StaticId::NonCustom(NonCustomPropertyId(196)),
                "background-image" => StaticId::NonCustom(NonCustomPropertyId(197)),
                "background-origin" => StaticId::NonCustom(NonCustomPropertyId(198)),
                "background-position-x" => StaticId::NonCustom(NonCustomPropertyId(199)),
                "background-position-y" => StaticId::NonCustom(NonCustomPropertyId(200)),
                "background-repeat" => StaticId::NonCustom(NonCustomPropertyId(201)),
                "background-size" => StaticId::NonCustom(NonCustomPropertyId(202)),
                "border-image-outset" => StaticId::NonCustom(NonCustomPropertyId(203)),
                "border-image-slice" => StaticId::NonCustom(NonCustomPropertyId(204)),
                "border-image-width" => StaticId::NonCustom(NonCustomPropertyId(205)),
                "border-spacing" => StaticId::NonCustom(NonCustomPropertyId(206)),
                "box-shadow" => StaticId::NonCustom(NonCustomPropertyId(207)),
                "caret-color" => StaticId::NonCustom(NonCustomPropertyId(208)),
                "clip" => StaticId::NonCustom(NonCustomPropertyId(209)),
                "clip-path" => StaticId::NonCustom(NonCustomPropertyId(210)),
                "color" => StaticId::NonCustom(NonCustomPropertyId(211)),
                "color-scheme" => StaticId::NonCustom(NonCustomPropertyId(212)),
                "column-width" => StaticId::NonCustom(NonCustomPropertyId(213)),
                "container-name" => StaticId::NonCustom(NonCustomPropertyId(214)),
                "content" => StaticId::NonCustom(NonCustomPropertyId(215)),
                "counter-increment" => StaticId::NonCustom(NonCustomPropertyId(216)),
                "counter-reset" => StaticId::NonCustom(NonCustomPropertyId(217)),
                "counter-set" => StaticId::NonCustom(NonCustomPropertyId(218)),
                "cursor" => StaticId::NonCustom(NonCustomPropertyId(219)),
                "d" => StaticId::NonCustom(NonCustomPropertyId(220)),
                "filter" => StaticId::NonCustom(NonCustomPropertyId(221)),
                "flex-basis" => StaticId::NonCustom(NonCustomPropertyId(222)),
                "font-family" => StaticId::NonCustom(NonCustomPropertyId(223)),
                "font-feature-settings" => StaticId::NonCustom(NonCustomPropertyId(224)),
                "font-palette" => StaticId::NonCustom(NonCustomPropertyId(225)),
                "font-size" => StaticId::NonCustom(NonCustomPropertyId(226)),
                "font-variant-alternates" => StaticId::NonCustom(NonCustomPropertyId(227)),
                "font-variation-settings" => StaticId::NonCustom(NonCustomPropertyId(228)),
                "grid-template-areas" => StaticId::NonCustom(NonCustomPropertyId(229)),
                "hyphenate-character" => StaticId::NonCustom(NonCustomPropertyId(230)),
                "letter-spacing" => StaticId::NonCustom(NonCustomPropertyId(231)),
                "line-height" => StaticId::NonCustom(NonCustomPropertyId(232)),
                "list-style-type" => StaticId::NonCustom(NonCustomPropertyId(233)),
                "mask-clip" => StaticId::NonCustom(NonCustomPropertyId(234)),
                "mask-composite" => StaticId::NonCustom(NonCustomPropertyId(235)),
                "mask-image" => StaticId::NonCustom(NonCustomPropertyId(236)),
                "mask-mode" => StaticId::NonCustom(NonCustomPropertyId(237)),
                "mask-origin" => StaticId::NonCustom(NonCustomPropertyId(238)),
                "mask-position-x" => StaticId::NonCustom(NonCustomPropertyId(239)),
                "mask-position-y" => StaticId::NonCustom(NonCustomPropertyId(240)),
                "mask-repeat" => StaticId::NonCustom(NonCustomPropertyId(241)),
                "mask-size" => StaticId::NonCustom(NonCustomPropertyId(242)),
                "-moz-context-properties" => StaticId::NonCustom(NonCustomPropertyId(243)),
                "offset-anchor" => StaticId::NonCustom(NonCustomPropertyId(244)),
                "offset-path" => StaticId::NonCustom(NonCustomPropertyId(245)),
                "offset-position" => StaticId::NonCustom(NonCustomPropertyId(246)),
                "page" => StaticId::NonCustom(NonCustomPropertyId(247)),
                "perspective" => StaticId::NonCustom(NonCustomPropertyId(248)),
                "position-anchor" => StaticId::NonCustom(NonCustomPropertyId(249)),
                "position-try-options" => StaticId::NonCustom(NonCustomPropertyId(250)),
                "quotes" => StaticId::NonCustom(NonCustomPropertyId(251)),
                "rotate" => StaticId::NonCustom(NonCustomPropertyId(252)),
                "scale" => StaticId::NonCustom(NonCustomPropertyId(253)),
                "scroll-timeline-axis" => StaticId::NonCustom(NonCustomPropertyId(254)),
                "scroll-timeline-name" => StaticId::NonCustom(NonCustomPropertyId(255)),
                "scrollbar-color" => StaticId::NonCustom(NonCustomPropertyId(256)),
                "shape-outside" => StaticId::NonCustom(NonCustomPropertyId(257)),
                "size" => StaticId::NonCustom(NonCustomPropertyId(258)),
                "stroke-dasharray" => StaticId::NonCustom(NonCustomPropertyId(259)),
                "stroke-dashoffset" => StaticId::NonCustom(NonCustomPropertyId(260)),
                "stroke-width" => StaticId::NonCustom(NonCustomPropertyId(261)),
                "tab-size" => StaticId::NonCustom(NonCustomPropertyId(262)),
                "text-decoration-thickness" => StaticId::NonCustom(NonCustomPropertyId(263)),
                "text-emphasis-style" => StaticId::NonCustom(NonCustomPropertyId(264)),
                "text-indent" => StaticId::NonCustom(NonCustomPropertyId(265)),
                "text-overflow" => StaticId::NonCustom(NonCustomPropertyId(266)),
                "text-shadow" => StaticId::NonCustom(NonCustomPropertyId(267)),
                "transition-behavior" => StaticId::NonCustom(NonCustomPropertyId(268)),
                "transition-delay" => StaticId::NonCustom(NonCustomPropertyId(269)),
                "transition-duration" => StaticId::NonCustom(NonCustomPropertyId(270)),
                "transition-property" => StaticId::NonCustom(NonCustomPropertyId(271)),
                "transition-timing-function" => StaticId::NonCustom(NonCustomPropertyId(272)),
                "translate" => StaticId::NonCustom(NonCustomPropertyId(273)),
                "vertical-align" => StaticId::NonCustom(NonCustomPropertyId(274)),
                "view-timeline-axis" => StaticId::NonCustom(NonCustomPropertyId(275)),
                "view-timeline-inset" => StaticId::NonCustom(NonCustomPropertyId(276)),
                "view-timeline-name" => StaticId::NonCustom(NonCustomPropertyId(277)),
                "-webkit-text-stroke-width" => StaticId::NonCustom(NonCustomPropertyId(278)),
                "will-change" => StaticId::NonCustom(NonCustomPropertyId(279)),
                "word-spacing" => StaticId::NonCustom(NonCustomPropertyId(280)),
                "-x-lang" => StaticId::NonCustom(NonCustomPropertyId(281)),
                "object-position" => StaticId::NonCustom(NonCustomPropertyId(282)),
                "perspective-origin" => StaticId::NonCustom(NonCustomPropertyId(283)),
                "fill" => StaticId::NonCustom(NonCustomPropertyId(284)),
                "stroke" => StaticId::NonCustom(NonCustomPropertyId(285)),
                "-moz-window-transform-origin" => StaticId::NonCustom(NonCustomPropertyId(286)),
                "transform-origin" => StaticId::NonCustom(NonCustomPropertyId(287)),
                "grid-template-columns" => StaticId::NonCustom(NonCustomPropertyId(288)),
                "grid-template-rows" => StaticId::NonCustom(NonCustomPropertyId(289)),
                "border-image-source" => StaticId::NonCustom(NonCustomPropertyId(290)),
                "list-style-image" => StaticId::NonCustom(NonCustomPropertyId(291)),
                "grid-auto-columns" => StaticId::NonCustom(NonCustomPropertyId(292)),
                "grid-auto-rows" => StaticId::NonCustom(NonCustomPropertyId(293)),
                "-moz-window-transform" => StaticId::NonCustom(NonCustomPropertyId(294)),
                "transform" => StaticId::NonCustom(NonCustomPropertyId(295)),
                "column-gap" => StaticId::NonCustom(NonCustomPropertyId(296)),
                "row-gap" => StaticId::NonCustom(NonCustomPropertyId(297)),
                "marker-end" => StaticId::NonCustom(NonCustomPropertyId(298)),
                "marker-mid" => StaticId::NonCustom(NonCustomPropertyId(299)),
                "marker-start" => StaticId::NonCustom(NonCustomPropertyId(300)),
                "contain-intrinsic-block-size" => StaticId::NonCustom(NonCustomPropertyId(301)),
                "contain-intrinsic-height" => StaticId::NonCustom(NonCustomPropertyId(302)),
                "contain-intrinsic-inline-size" => StaticId::NonCustom(NonCustomPropertyId(303)),
                "contain-intrinsic-width" => StaticId::NonCustom(NonCustomPropertyId(304)),
                "grid-column-end" => StaticId::NonCustom(NonCustomPropertyId(305)),
                "grid-column-start" => StaticId::NonCustom(NonCustomPropertyId(306)),
                "grid-row-end" => StaticId::NonCustom(NonCustomPropertyId(307)),
                "grid-row-start" => StaticId::NonCustom(NonCustomPropertyId(308)),
                "max-block-size" => StaticId::NonCustom(NonCustomPropertyId(309)),
                "max-height" => StaticId::NonCustom(NonCustomPropertyId(310)),
                "max-inline-size" => StaticId::NonCustom(NonCustomPropertyId(311)),
                "max-width" => StaticId::NonCustom(NonCustomPropertyId(312)),
                "cx" => StaticId::NonCustom(NonCustomPropertyId(313)),
                "cy" => StaticId::NonCustom(NonCustomPropertyId(314)),
                "offset-distance" => StaticId::NonCustom(NonCustomPropertyId(315)),
                "x" => StaticId::NonCustom(NonCustomPropertyId(316)),
                "y" => StaticId::NonCustom(NonCustomPropertyId(317)),
                "border-bottom-left-radius" => StaticId::NonCustom(NonCustomPropertyId(318)),
                "border-bottom-right-radius" => StaticId::NonCustom(NonCustomPropertyId(319)),
                "border-end-end-radius" => StaticId::NonCustom(NonCustomPropertyId(320)),
                "border-end-start-radius" => StaticId::NonCustom(NonCustomPropertyId(321)),
                "border-start-end-radius" => StaticId::NonCustom(NonCustomPropertyId(322)),
                "border-start-start-radius" => StaticId::NonCustom(NonCustomPropertyId(323)),
                "border-top-left-radius" => StaticId::NonCustom(NonCustomPropertyId(324)),
                "border-top-right-radius" => StaticId::NonCustom(NonCustomPropertyId(325)),
                "block-size" => StaticId::NonCustom(NonCustomPropertyId(326)),
                "height" => StaticId::NonCustom(NonCustomPropertyId(327)),
                "inline-size" => StaticId::NonCustom(NonCustomPropertyId(328)),
                "min-block-size" => StaticId::NonCustom(NonCustomPropertyId(329)),
                "min-height" => StaticId::NonCustom(NonCustomPropertyId(330)),
                "min-inline-size" => StaticId::NonCustom(NonCustomPropertyId(331)),
                "min-width" => StaticId::NonCustom(NonCustomPropertyId(332)),
                "width" => StaticId::NonCustom(NonCustomPropertyId(333)),
                "border-block-end-width" => StaticId::NonCustom(NonCustomPropertyId(334)),
                "border-block-start-width" => StaticId::NonCustom(NonCustomPropertyId(335)),
                "border-bottom-width" => StaticId::NonCustom(NonCustomPropertyId(336)),
                "border-inline-end-width" => StaticId::NonCustom(NonCustomPropertyId(337)),
                "border-inline-start-width" => StaticId::NonCustom(NonCustomPropertyId(338)),
                "border-left-width" => StaticId::NonCustom(NonCustomPropertyId(339)),
                "border-right-width" => StaticId::NonCustom(NonCustomPropertyId(340)),
                "border-top-width" => StaticId::NonCustom(NonCustomPropertyId(341)),
                "column-rule-width" => StaticId::NonCustom(NonCustomPropertyId(342)),
                "outline-width" => StaticId::NonCustom(NonCustomPropertyId(343)),
                "padding-block-end" => StaticId::NonCustom(NonCustomPropertyId(344)),
                "padding-block-start" => StaticId::NonCustom(NonCustomPropertyId(345)),
                "padding-bottom" => StaticId::NonCustom(NonCustomPropertyId(346)),
                "padding-inline-end" => StaticId::NonCustom(NonCustomPropertyId(347)),
                "padding-inline-start" => StaticId::NonCustom(NonCustomPropertyId(348)),
                "padding-left" => StaticId::NonCustom(NonCustomPropertyId(349)),
                "padding-right" => StaticId::NonCustom(NonCustomPropertyId(350)),
                "padding-top" => StaticId::NonCustom(NonCustomPropertyId(351)),
                "r" => StaticId::NonCustom(NonCustomPropertyId(352)),
                "shape-margin" => StaticId::NonCustom(NonCustomPropertyId(353)),
                "rx" => StaticId::NonCustom(NonCustomPropertyId(354)),
                "ry" => StaticId::NonCustom(NonCustomPropertyId(355)),
                "scroll-padding-block-end" => StaticId::NonCustom(NonCustomPropertyId(356)),
                "scroll-padding-block-start" => StaticId::NonCustom(NonCustomPropertyId(357)),
                "scroll-padding-bottom" => StaticId::NonCustom(NonCustomPropertyId(358)),
                "scroll-padding-inline-end" => StaticId::NonCustom(NonCustomPropertyId(359)),
                "scroll-padding-inline-start" => StaticId::NonCustom(NonCustomPropertyId(360)),
                "scroll-padding-left" => StaticId::NonCustom(NonCustomPropertyId(361)),
                "scroll-padding-right" => StaticId::NonCustom(NonCustomPropertyId(362)),
                "scroll-padding-top" => StaticId::NonCustom(NonCustomPropertyId(363)),
                "-moz-window-input-region-margin" => StaticId::NonCustom(NonCustomPropertyId(364)),
                "outline-offset" => StaticId::NonCustom(NonCustomPropertyId(365)),
                "overflow-clip-margin" => StaticId::NonCustom(NonCustomPropertyId(366)),
                "scroll-margin-block-end" => StaticId::NonCustom(NonCustomPropertyId(367)),
                "scroll-margin-block-start" => StaticId::NonCustom(NonCustomPropertyId(368)),
                "scroll-margin-bottom" => StaticId::NonCustom(NonCustomPropertyId(369)),
                "scroll-margin-inline-end" => StaticId::NonCustom(NonCustomPropertyId(370)),
                "scroll-margin-inline-start" => StaticId::NonCustom(NonCustomPropertyId(371)),
                "scroll-margin-left" => StaticId::NonCustom(NonCustomPropertyId(372)),
                "scroll-margin-right" => StaticId::NonCustom(NonCustomPropertyId(373)),
                "scroll-margin-top" => StaticId::NonCustom(NonCustomPropertyId(374)),
                "bottom" => StaticId::NonCustom(NonCustomPropertyId(375)),
                "inset-block-end" => StaticId::NonCustom(NonCustomPropertyId(376)),
                "inset-block-start" => StaticId::NonCustom(NonCustomPropertyId(377)),
                "inset-inline-end" => StaticId::NonCustom(NonCustomPropertyId(378)),
                "inset-inline-start" => StaticId::NonCustom(NonCustomPropertyId(379)),
                "left" => StaticId::NonCustom(NonCustomPropertyId(380)),
                "margin-block-end" => StaticId::NonCustom(NonCustomPropertyId(381)),
                "margin-block-start" => StaticId::NonCustom(NonCustomPropertyId(382)),
                "margin-bottom" => StaticId::NonCustom(NonCustomPropertyId(383)),
                "margin-inline-end" => StaticId::NonCustom(NonCustomPropertyId(384)),
                "margin-inline-start" => StaticId::NonCustom(NonCustomPropertyId(385)),
                "margin-left" => StaticId::NonCustom(NonCustomPropertyId(386)),
                "margin-right" => StaticId::NonCustom(NonCustomPropertyId(387)),
                "margin-top" => StaticId::NonCustom(NonCustomPropertyId(388)),
                "right" => StaticId::NonCustom(NonCustomPropertyId(389)),
                "text-underline-offset" => StaticId::NonCustom(NonCustomPropertyId(390)),
                "top" => StaticId::NonCustom(NonCustomPropertyId(391)),
                "background-color" => StaticId::NonCustom(NonCustomPropertyId(392)),
                "border-block-end-color" => StaticId::NonCustom(NonCustomPropertyId(393)),
                "border-block-start-color" => StaticId::NonCustom(NonCustomPropertyId(394)),
                "border-bottom-color" => StaticId::NonCustom(NonCustomPropertyId(395)),
                "border-inline-end-color" => StaticId::NonCustom(NonCustomPropertyId(396)),
                "border-inline-start-color" => StaticId::NonCustom(NonCustomPropertyId(397)),
                "border-left-color" => StaticId::NonCustom(NonCustomPropertyId(398)),
                "border-right-color" => StaticId::NonCustom(NonCustomPropertyId(399)),
                "border-top-color" => StaticId::NonCustom(NonCustomPropertyId(400)),
                "column-rule-color" => StaticId::NonCustom(NonCustomPropertyId(401)),
                "flood-color" => StaticId::NonCustom(NonCustomPropertyId(402)),
                "lighting-color" => StaticId::NonCustom(NonCustomPropertyId(403)),
                "outline-color" => StaticId::NonCustom(NonCustomPropertyId(404)),
                "stop-color" => StaticId::NonCustom(NonCustomPropertyId(405)),
                "text-decoration-color" => StaticId::NonCustom(NonCustomPropertyId(406)),
                "text-emphasis-color" => StaticId::NonCustom(NonCustomPropertyId(407)),
                "-webkit-text-fill-color" => StaticId::NonCustom(NonCustomPropertyId(408)),
                "-webkit-text-stroke-color" => StaticId::NonCustom(NonCustomPropertyId(409)),
                "background" => StaticId::NonCustom(NonCustomPropertyId(410)),
                "background-position" => StaticId::NonCustom(NonCustomPropertyId(411)),
                "border-color" => StaticId::NonCustom(NonCustomPropertyId(412)),
                "border-style" => StaticId::NonCustom(NonCustomPropertyId(413)),
                "border-width" => StaticId::NonCustom(NonCustomPropertyId(414)),
                "border-top" => StaticId::NonCustom(NonCustomPropertyId(415)),
                "border-right" => StaticId::NonCustom(NonCustomPropertyId(416)),
                "border-bottom" => StaticId::NonCustom(NonCustomPropertyId(417)),
                "border-left" => StaticId::NonCustom(NonCustomPropertyId(418)),
                "border-block-start" => StaticId::NonCustom(NonCustomPropertyId(419)),
                "border-block-end" => StaticId::NonCustom(NonCustomPropertyId(420)),
                "border-inline-start" => StaticId::NonCustom(NonCustomPropertyId(421)),
                "border-inline-end" => StaticId::NonCustom(NonCustomPropertyId(422)),
                "border" => StaticId::NonCustom(NonCustomPropertyId(423)),
                "border-radius" => StaticId::NonCustom(NonCustomPropertyId(424)),
                "border-image" => StaticId::NonCustom(NonCustomPropertyId(425)),
                "border-block-width" => StaticId::NonCustom(NonCustomPropertyId(426)),
                "border-block-style" => StaticId::NonCustom(NonCustomPropertyId(427)),
                "border-block-color" => StaticId::NonCustom(NonCustomPropertyId(428)),
                "border-inline-width" => StaticId::NonCustom(NonCustomPropertyId(429)),
                "border-inline-style" => StaticId::NonCustom(NonCustomPropertyId(430)),
                "border-inline-color" => StaticId::NonCustom(NonCustomPropertyId(431)),
                "border-block" => StaticId::NonCustom(NonCustomPropertyId(432)),
                "border-inline" => StaticId::NonCustom(NonCustomPropertyId(433)),
                "overflow" => StaticId::NonCustom(NonCustomPropertyId(434)),
                "overflow-clip-box" => StaticId::NonCustom(NonCustomPropertyId(435)),
                "overscroll-behavior" => StaticId::NonCustom(NonCustomPropertyId(436)),
                "container" => StaticId::NonCustom(NonCustomPropertyId(437)),
                "page-break-before" => StaticId::NonCustom(NonCustomPropertyId(438)),
                "page-break-after" => StaticId::NonCustom(NonCustomPropertyId(439)),
                "page-break-inside" => StaticId::NonCustom(NonCustomPropertyId(440)),
                "offset" => StaticId::NonCustom(NonCustomPropertyId(441)),
                "columns" => StaticId::NonCustom(NonCustomPropertyId(442)),
                "column-rule" => StaticId::NonCustom(NonCustomPropertyId(443)),
                "font" => StaticId::NonCustom(NonCustomPropertyId(444)),
                "font-variant" => StaticId::NonCustom(NonCustomPropertyId(445)),
                "font-synthesis" => StaticId::NonCustom(NonCustomPropertyId(446)),
                "marker" => StaticId::NonCustom(NonCustomPropertyId(447)),
                "text-emphasis" => StaticId::NonCustom(NonCustomPropertyId(448)),
                "text-wrap" => StaticId::NonCustom(NonCustomPropertyId(449)),
                "white-space" => StaticId::NonCustom(NonCustomPropertyId(450)),
                "-webkit-text-stroke" => StaticId::NonCustom(NonCustomPropertyId(451)),
                "list-style" => StaticId::NonCustom(NonCustomPropertyId(452)),
                "margin" => StaticId::NonCustom(NonCustomPropertyId(453)),
                "margin-block" => StaticId::NonCustom(NonCustomPropertyId(454)),
                "margin-inline" => StaticId::NonCustom(NonCustomPropertyId(455)),
                "scroll-margin" => StaticId::NonCustom(NonCustomPropertyId(456)),
                "scroll-margin-block" => StaticId::NonCustom(NonCustomPropertyId(457)),
                "scroll-margin-inline" => StaticId::NonCustom(NonCustomPropertyId(458)),
                "outline" => StaticId::NonCustom(NonCustomPropertyId(459)),
                "padding" => StaticId::NonCustom(NonCustomPropertyId(460)),
                "padding-block" => StaticId::NonCustom(NonCustomPropertyId(461)),
                "padding-inline" => StaticId::NonCustom(NonCustomPropertyId(462)),
                "scroll-padding" => StaticId::NonCustom(NonCustomPropertyId(463)),
                "scroll-padding-block" => StaticId::NonCustom(NonCustomPropertyId(464)),
                "scroll-padding-inline" => StaticId::NonCustom(NonCustomPropertyId(465)),
                "flex-flow" => StaticId::NonCustom(NonCustomPropertyId(466)),
                "flex" => StaticId::NonCustom(NonCustomPropertyId(467)),
                "gap" => StaticId::NonCustom(NonCustomPropertyId(468)),
                "grid-row" => StaticId::NonCustom(NonCustomPropertyId(469)),
                "grid-column" => StaticId::NonCustom(NonCustomPropertyId(470)),
                "grid-area" => StaticId::NonCustom(NonCustomPropertyId(471)),
                "grid-template" => StaticId::NonCustom(NonCustomPropertyId(472)),
                "grid" => StaticId::NonCustom(NonCustomPropertyId(473)),
                "place-content" => StaticId::NonCustom(NonCustomPropertyId(474)),
                "place-self" => StaticId::NonCustom(NonCustomPropertyId(475)),
                "place-items" => StaticId::NonCustom(NonCustomPropertyId(476)),
                "inset" => StaticId::NonCustom(NonCustomPropertyId(477)),
                "inset-block" => StaticId::NonCustom(NonCustomPropertyId(478)),
                "inset-inline" => StaticId::NonCustom(NonCustomPropertyId(479)),
                "contain-intrinsic-size" => StaticId::NonCustom(NonCustomPropertyId(480)),
                "mask" => StaticId::NonCustom(NonCustomPropertyId(481)),
                "mask-position" => StaticId::NonCustom(NonCustomPropertyId(482)),
                "text-decoration" => StaticId::NonCustom(NonCustomPropertyId(483)),
                "transition" => StaticId::NonCustom(NonCustomPropertyId(484)),
                "animation" => StaticId::NonCustom(NonCustomPropertyId(485)),
                "scroll-timeline" => StaticId::NonCustom(NonCustomPropertyId(486)),
                "view-timeline" => StaticId::NonCustom(NonCustomPropertyId(487)),
                "all" => StaticId::NonCustom(NonCustomPropertyId(488)),
                "-webkit-background-clip" => StaticId::NonCustom(NonCustomPropertyId(489)),
                "-webkit-background-origin" => StaticId::NonCustom(NonCustomPropertyId(490)),
                "-webkit-background-size" => StaticId::NonCustom(NonCustomPropertyId(491)),
                "-moz-border-start-color" => StaticId::NonCustom(NonCustomPropertyId(492)),
                "-moz-border-start-style" => StaticId::NonCustom(NonCustomPropertyId(493)),
                "-moz-border-start-width" => StaticId::NonCustom(NonCustomPropertyId(494)),
                "-moz-border-end-color" => StaticId::NonCustom(NonCustomPropertyId(495)),
                "-moz-border-end-style" => StaticId::NonCustom(NonCustomPropertyId(496)),
                "-moz-border-end-width" => StaticId::NonCustom(NonCustomPropertyId(497)),
                "-webkit-border-top-left-radius" => StaticId::NonCustom(NonCustomPropertyId(498)),
                "-webkit-border-top-right-radius" => StaticId::NonCustom(NonCustomPropertyId(499)),
                "-webkit-border-bottom-right-radius" => StaticId::NonCustom(NonCustomPropertyId(500)),
                "-webkit-border-bottom-left-radius" => StaticId::NonCustom(NonCustomPropertyId(501)),
                "-moz-transform" => StaticId::NonCustom(NonCustomPropertyId(502)),
                "-webkit-transform" => StaticId::NonCustom(NonCustomPropertyId(503)),
                "-moz-perspective" => StaticId::NonCustom(NonCustomPropertyId(504)),
                "-webkit-perspective" => StaticId::NonCustom(NonCustomPropertyId(505)),
                "-moz-perspective-origin" => StaticId::NonCustom(NonCustomPropertyId(506)),
                "-webkit-perspective-origin" => StaticId::NonCustom(NonCustomPropertyId(507)),
                "-moz-backface-visibility" => StaticId::NonCustom(NonCustomPropertyId(508)),
                "-webkit-backface-visibility" => StaticId::NonCustom(NonCustomPropertyId(509)),
                "-moz-transform-style" => StaticId::NonCustom(NonCustomPropertyId(510)),
                "-webkit-transform-style" => StaticId::NonCustom(NonCustomPropertyId(511)),
                "-moz-transform-origin" => StaticId::NonCustom(NonCustomPropertyId(512)),
                "-webkit-transform-origin" => StaticId::NonCustom(NonCustomPropertyId(513)),
                "-moz-appearance" => StaticId::NonCustom(NonCustomPropertyId(514)),
                "-webkit-appearance" => StaticId::NonCustom(NonCustomPropertyId(515)),
                "-webkit-box-shadow" => StaticId::NonCustom(NonCustomPropertyId(516)),
                "-webkit-filter" => StaticId::NonCustom(NonCustomPropertyId(517)),
                "-moz-font-feature-settings" => StaticId::NonCustom(NonCustomPropertyId(518)),
                "-moz-font-language-override" => StaticId::NonCustom(NonCustomPropertyId(519)),
                "-webkit-font-smoothing" => StaticId::NonCustom(NonCustomPropertyId(520)),
                "color-adjust" => StaticId::NonCustom(NonCustomPropertyId(521)),
                "-moz-hyphens" => StaticId::NonCustom(NonCustomPropertyId(522)),
                "-webkit-text-size-adjust" => StaticId::NonCustom(NonCustomPropertyId(523)),
                "word-wrap" => StaticId::NonCustom(NonCustomPropertyId(524)),
                "-moz-tab-size" => StaticId::NonCustom(NonCustomPropertyId(525)),
                "-moz-margin-start" => StaticId::NonCustom(NonCustomPropertyId(526)),
                "-moz-margin-end" => StaticId::NonCustom(NonCustomPropertyId(527)),
                "-moz-padding-start" => StaticId::NonCustom(NonCustomPropertyId(528)),
                "-moz-padding-end" => StaticId::NonCustom(NonCustomPropertyId(529)),
                "-webkit-flex-direction" => StaticId::NonCustom(NonCustomPropertyId(530)),
                "-webkit-flex-wrap" => StaticId::NonCustom(NonCustomPropertyId(531)),
                "-webkit-justify-content" => StaticId::NonCustom(NonCustomPropertyId(532)),
                "-webkit-align-content" => StaticId::NonCustom(NonCustomPropertyId(533)),
                "-webkit-align-items" => StaticId::NonCustom(NonCustomPropertyId(534)),
                "-webkit-flex-grow" => StaticId::NonCustom(NonCustomPropertyId(535)),
                "-webkit-flex-shrink" => StaticId::NonCustom(NonCustomPropertyId(536)),
                "-webkit-align-self" => StaticId::NonCustom(NonCustomPropertyId(537)),
                "-webkit-order" => StaticId::NonCustom(NonCustomPropertyId(538)),
                "-webkit-flex-basis" => StaticId::NonCustom(NonCustomPropertyId(539)),
                "-moz-box-sizing" => StaticId::NonCustom(NonCustomPropertyId(540)),
                "-webkit-box-sizing" => StaticId::NonCustom(NonCustomPropertyId(541)),
                "grid-column-gap" => StaticId::NonCustom(NonCustomPropertyId(542)),
                "grid-row-gap" => StaticId::NonCustom(NonCustomPropertyId(543)),
                "-webkit-clip-path" => StaticId::NonCustom(NonCustomPropertyId(544)),
                "-webkit-mask-repeat" => StaticId::NonCustom(NonCustomPropertyId(545)),
                "-webkit-mask-position-x" => StaticId::NonCustom(NonCustomPropertyId(546)),
                "-webkit-mask-position-y" => StaticId::NonCustom(NonCustomPropertyId(547)),
                "-webkit-mask-clip" => StaticId::NonCustom(NonCustomPropertyId(548)),
                "-webkit-mask-origin" => StaticId::NonCustom(NonCustomPropertyId(549)),
                "-webkit-mask-size" => StaticId::NonCustom(NonCustomPropertyId(550)),
                "-webkit-mask-composite" => StaticId::NonCustom(NonCustomPropertyId(551)),
                "-webkit-mask-image" => StaticId::NonCustom(NonCustomPropertyId(552)),
                "-moz-user-select" => StaticId::NonCustom(NonCustomPropertyId(553)),
                "-webkit-user-select" => StaticId::NonCustom(NonCustomPropertyId(554)),
                "-moz-transition-duration" => StaticId::NonCustom(NonCustomPropertyId(555)),
                "-webkit-transition-duration" => StaticId::NonCustom(NonCustomPropertyId(556)),
                "-moz-transition-timing-function" => StaticId::NonCustom(NonCustomPropertyId(557)),
                "-webkit-transition-timing-function" => StaticId::NonCustom(NonCustomPropertyId(558)),
                "-moz-transition-property" => StaticId::NonCustom(NonCustomPropertyId(559)),
                "-webkit-transition-property" => StaticId::NonCustom(NonCustomPropertyId(560)),
                "-moz-transition-delay" => StaticId::NonCustom(NonCustomPropertyId(561)),
                "-webkit-transition-delay" => StaticId::NonCustom(NonCustomPropertyId(562)),
                "-moz-animation-name" => StaticId::NonCustom(NonCustomPropertyId(563)),
                "-webkit-animation-name" => StaticId::NonCustom(NonCustomPropertyId(564)),
                "-moz-animation-duration" => StaticId::NonCustom(NonCustomPropertyId(565)),
                "-webkit-animation-duration" => StaticId::NonCustom(NonCustomPropertyId(566)),
                "-moz-animation-timing-function" => StaticId::NonCustom(NonCustomPropertyId(567)),
                "-webkit-animation-timing-function" => StaticId::NonCustom(NonCustomPropertyId(568)),
                "-moz-animation-iteration-count" => StaticId::NonCustom(NonCustomPropertyId(569)),
                "-webkit-animation-iteration-count" => StaticId::NonCustom(NonCustomPropertyId(570)),
                "-moz-animation-direction" => StaticId::NonCustom(NonCustomPropertyId(571)),
                "-webkit-animation-direction" => StaticId::NonCustom(NonCustomPropertyId(572)),
                "-moz-animation-play-state" => StaticId::NonCustom(NonCustomPropertyId(573)),
                "-webkit-animation-play-state" => StaticId::NonCustom(NonCustomPropertyId(574)),
                "-moz-animation-fill-mode" => StaticId::NonCustom(NonCustomPropertyId(575)),
                "-webkit-animation-fill-mode" => StaticId::NonCustom(NonCustomPropertyId(576)),
                "-moz-animation-delay" => StaticId::NonCustom(NonCustomPropertyId(577)),
                "-webkit-animation-delay" => StaticId::NonCustom(NonCustomPropertyId(578)),
                "-webkit-box-align" => StaticId::NonCustom(NonCustomPropertyId(579)),
                "-webkit-box-direction" => StaticId::NonCustom(NonCustomPropertyId(580)),
                "-webkit-box-flex" => StaticId::NonCustom(NonCustomPropertyId(581)),
                "-webkit-box-orient" => StaticId::NonCustom(NonCustomPropertyId(582)),
                "-webkit-box-pack" => StaticId::NonCustom(NonCustomPropertyId(583)),
                "-webkit-box-ordinal-group" => StaticId::NonCustom(NonCustomPropertyId(584)),
                "-moz-border-start" => StaticId::NonCustom(NonCustomPropertyId(585)),
                "-moz-border-end" => StaticId::NonCustom(NonCustomPropertyId(586)),
                "-webkit-border-radius" => StaticId::NonCustom(NonCustomPropertyId(587)),
                "-moz-border-image" => StaticId::NonCustom(NonCustomPropertyId(588)),
                "-webkit-border-image" => StaticId::NonCustom(NonCustomPropertyId(589)),
                "-webkit-flex-flow" => StaticId::NonCustom(NonCustomPropertyId(590)),
                "-webkit-flex" => StaticId::NonCustom(NonCustomPropertyId(591)),
                "grid-gap" => StaticId::NonCustom(NonCustomPropertyId(592)),
                "-webkit-mask" => StaticId::NonCustom(NonCustomPropertyId(593)),
                "-webkit-mask-position" => StaticId::NonCustom(NonCustomPropertyId(594)),
                "-moz-transition" => StaticId::NonCustom(NonCustomPropertyId(595)),
                "-webkit-transition" => StaticId::NonCustom(NonCustomPropertyId(596)),
                "-moz-animation" => StaticId::NonCustom(NonCustomPropertyId(597)),
                "-webkit-animation" => StaticId::NonCustom(NonCustomPropertyId(598)),
                "-webkit-tap-highlight-color" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTapHighlightColor)
                },
                "speak" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::Speak)
                },
                "text-size-adjust" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::TextSizeAdjust)
                },
                "-webkit-font-feature-settings" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitFontFeatureSettings)
                },
                "-webkit-user-drag" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitUserDrag)
                },
                "orphans" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::Orphans)
                },
                "widows" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::Widows)
                },
                "-webkit-user-modify" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitUserModify)
                },
                "-webkit-margin-before" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginBefore)
                },
                "-webkit-margin-after" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginAfter)
                },
                "-webkit-margin-start" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginStart)
                },
                "-webkit-column-break-inside" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnBreakInside)
                },
                "-webkit-padding-start" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitPaddingStart)
                },
                "-webkit-margin-end" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginEnd)
                },
                "-webkit-box-reflect" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBoxReflect)
                },
                "-webkit-print-color-adjust" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitPrintColorAdjust)
                },
                "-webkit-mask-box-image" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskBoxImage)
                },
                "-webkit-line-break" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitLineBreak)
                },
                "alignment-baseline" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::AlignmentBaseline)
                },
                "-webkit-writing-mode" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitWritingMode)
                },
                "baseline-shift" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::BaselineShift)
                },
                "-webkit-hyphenate-character" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitHyphenateCharacter)
                },
                "-webkit-highlight" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitHighlight)
                },
                "background-repeat-x" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::BackgroundRepeatX)
                },
                "-webkit-padding-end" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitPaddingEnd)
                },
                "background-repeat-y" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::BackgroundRepeatY)
                },
                "-webkit-text-emphasis-color" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTextEmphasisColor)
                },
                "-webkit-margin-top-collapse" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginTopCollapse)
                },
                "-webkit-rtl-ordering" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitRtlOrdering)
                },
                "-webkit-padding-before" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitPaddingBefore)
                },
                "-webkit-text-decorations-in-effect" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTextDecorationsInEffect)
                },
                "-webkit-border-vertical-spacing" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderVerticalSpacing)
                },
                "-webkit-locale" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitLocale)
                },
                "-webkit-padding-after" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitPaddingAfter)
                },
                "-webkit-border-horizontal-spacing" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderHorizontalSpacing)
                },
                "color-rendering" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::ColorRendering)
                },
                "-webkit-column-break-before" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnBreakBefore)
                },
                "-webkit-transform-origin-x" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTransformOriginX)
                },
                "-webkit-transform-origin-y" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTransformOriginY)
                },
                "-webkit-text-emphasis-position" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTextEmphasisPosition)
                },
                "buffered-rendering" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::BufferedRendering)
                },
                "-webkit-text-orientation" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTextOrientation)
                },
                "-webkit-text-combine" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTextCombine)
                },
                "-webkit-text-emphasis-style" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTextEmphasisStyle)
                },
                "-webkit-text-emphasis" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTextEmphasis)
                },
                "-webkit-mask-box-image-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskBoxImageWidth)
                },
                "-webkit-mask-box-image-source" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskBoxImageSource)
                },
                "-webkit-mask-box-image-outset" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskBoxImageOutset)
                },
                "-webkit-mask-box-image-slice" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskBoxImageSlice)
                },
                "-webkit-mask-box-image-repeat" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskBoxImageRepeat)
                },
                "-webkit-margin-after-collapse" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginAfterCollapse)
                },
                "-webkit-border-before-color" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderBeforeColor)
                },
                "-webkit-border-before-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderBeforeWidth)
                },
                "-webkit-perspective-origin-x" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitPerspectiveOriginX)
                },
                "-webkit-perspective-origin-y" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitPerspectiveOriginY)
                },
                "-webkit-margin-before-collapse" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginBeforeCollapse)
                },
                "-webkit-border-before-style" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderBeforeStyle)
                },
                "-webkit-margin-bottom-collapse" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginBottomCollapse)
                },
                "-webkit-ruby-position" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitRubyPosition)
                },
                "-webkit-column-break-after" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnBreakAfter)
                },
                "-webkit-margin-collapse" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMarginCollapse)
                },
                "-webkit-border-before" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderBefore)
                },
                "-webkit-border-end" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderEnd)
                },
                "-webkit-border-after" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderAfter)
                },
                "-webkit-border-start" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderStart)
                },
                "-webkit-min-logical-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMinLogicalWidth)
                },
                "-webkit-logical-height" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitLogicalHeight)
                },
                "-webkit-transform-origin-z" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitTransformOriginZ)
                },
                "-webkit-font-size-delta" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitFontSizeDelta)
                },
                "-webkit-logical-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitLogicalWidth)
                },
                "-webkit-max-logical-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaxLogicalWidth)
                },
                "-webkit-min-logical-height" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMinLogicalHeight)
                },
                "-webkit-max-logical-height" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaxLogicalHeight)
                },
                "-webkit-border-end-color" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderEndColor)
                },
                "-webkit-border-end-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderEndWidth)
                },
                "-webkit-border-start-color" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderStartColor)
                },
                "-webkit-border-start-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderStartWidth)
                },
                "-webkit-border-after-color" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderAfterColor)
                },
                "-webkit-border-after-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderAfterWidth)
                },
                "-webkit-border-end-style" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderEndStyle)
                },
                "-webkit-border-after-style" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderAfterStyle)
                },
                "-webkit-border-start-style" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBorderStartStyle)
                },
                "-webkit-mask-repeat-x" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskRepeatX)
                },
                "-webkit-mask-repeat-y" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitMaskRepeatY)
                },
                "user-zoom" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::UserZoom)
                },
                "min-zoom" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::MinZoom)
                },
                "-webkit-box-decoration-break" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitBoxDecorationBreak)
                },
                "orientation" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::Orientation)
                },
                "max-zoom" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::MaxZoom)
                },
                "-webkit-app-region" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitAppRegion)
                },
                "-webkit-column-rule" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnRule)
                },
                "-webkit-column-span" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnSpan)
                },
                "-webkit-column-gap" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnGap)
                },
                "-webkit-shape-outside" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitShapeOutside)
                },
                "-webkit-column-rule-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnRuleWidth)
                },
                "-webkit-column-count" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnCount)
                },
                "-webkit-opacity" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitOpacity)
                },
                "-webkit-column-width" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnWidth)
                },
                "-webkit-shape-image-threshold" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitShapeImageThreshold)
                },
                "-webkit-column-rule-style" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnRuleStyle)
                },
                "-webkit-columns" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumns)
                },
                "-webkit-column-rule-color" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitColumnRuleColor)
                },
                "-webkit-shape-margin" => {
                    StaticId::CountedUnknown(CountedUnknownProperty::WebkitShapeMargin)
                },
            }
        }

        if let Some(id) = static_ids::get(property_name) {
            return Ok(match *id {
                StaticId::NonCustom(id) => PropertyId::NonCustom(id),
                StaticId::CountedUnknown(unknown_prop) => {
                    if let Some(counters) = use_counters {
                        counters.counted_unknown_properties.record(unknown_prop);
                    }
                    // Always return Err(()) because these aren't valid custom property names.
                    return Err(());
                }
            });
        }

        let name = crate::custom_properties::parse_name(property_name)?;
        Ok(PropertyId::Custom(crate::custom_properties::Name::from(name)))
    }
}

impl PropertyDeclaration {
    /// Given a property declaration, return the property declaration id.
    #[inline]
    pub fn id(&self) -> PropertyDeclarationId {
        match *self {
            PropertyDeclaration::Custom(ref declaration) => {
                return PropertyDeclarationId::Custom(&declaration.name)
            }
            PropertyDeclaration::CSSWideKeyword(ref declaration) => {
                return PropertyDeclarationId::Longhand(declaration.id);
            }
            PropertyDeclaration::WithVariables(ref declaration) => {
                return PropertyDeclarationId::Longhand(declaration.id);
            }
            _ => {}
        }
        // This is just fine because PropertyDeclaration and LonghandId
        // have corresponding discriminants.
        let id = unsafe { *(self as *const _ as *const LonghandId) };
        debug_assert_eq!(id, match *self {
            PropertyDeclaration::AlignContent(..) => LonghandId::AlignContent,
            PropertyDeclaration::AlignItems(..) => LonghandId::AlignItems,
            PropertyDeclaration::AlignSelf(..) => LonghandId::AlignSelf,
            PropertyDeclaration::AspectRatio(..) => LonghandId::AspectRatio,
            PropertyDeclaration::BackfaceVisibility(..) => LonghandId::BackfaceVisibility,
            PropertyDeclaration::BaselineSource(..) => LonghandId::BaselineSource,
            PropertyDeclaration::BorderCollapse(..) => LonghandId::BorderCollapse,
            PropertyDeclaration::BorderImageRepeat(..) => LonghandId::BorderImageRepeat,
            PropertyDeclaration::BoxDecorationBreak(..) => LonghandId::BoxDecorationBreak,
            PropertyDeclaration::BoxSizing(..) => LonghandId::BoxSizing,
            PropertyDeclaration::BreakInside(..) => LonghandId::BreakInside,
            PropertyDeclaration::CaptionSide(..) => LonghandId::CaptionSide,
            PropertyDeclaration::Clear(..) => LonghandId::Clear,
            PropertyDeclaration::ColorInterpolation(..) => LonghandId::ColorInterpolation,
            PropertyDeclaration::ColorInterpolationFilters(..) => LonghandId::ColorInterpolationFilters,
            PropertyDeclaration::ColumnCount(..) => LonghandId::ColumnCount,
            PropertyDeclaration::ColumnFill(..) => LonghandId::ColumnFill,
            PropertyDeclaration::ColumnSpan(..) => LonghandId::ColumnSpan,
            PropertyDeclaration::Contain(..) => LonghandId::Contain,
            PropertyDeclaration::ContainerType(..) => LonghandId::ContainerType,
            PropertyDeclaration::ContentVisibility(..) => LonghandId::ContentVisibility,
            PropertyDeclaration::Direction(..) => LonghandId::Direction,
            PropertyDeclaration::Display(..) => LonghandId::Display,
            PropertyDeclaration::DominantBaseline(..) => LonghandId::DominantBaseline,
            PropertyDeclaration::EmptyCells(..) => LonghandId::EmptyCells,
            PropertyDeclaration::FlexDirection(..) => LonghandId::FlexDirection,
            PropertyDeclaration::FlexWrap(..) => LonghandId::FlexWrap,
            PropertyDeclaration::Float(..) => LonghandId::Float,
            PropertyDeclaration::FontKerning(..) => LonghandId::FontKerning,
            PropertyDeclaration::FontLanguageOverride(..) => LonghandId::FontLanguageOverride,
            PropertyDeclaration::FontOpticalSizing(..) => LonghandId::FontOpticalSizing,
            PropertyDeclaration::FontSizeAdjust(..) => LonghandId::FontSizeAdjust,
            PropertyDeclaration::FontStretch(..) => LonghandId::FontStretch,
            PropertyDeclaration::FontStyle(..) => LonghandId::FontStyle,
            PropertyDeclaration::FontVariantCaps(..) => LonghandId::FontVariantCaps,
            PropertyDeclaration::FontVariantEastAsian(..) => LonghandId::FontVariantEastAsian,
            PropertyDeclaration::FontVariantEmoji(..) => LonghandId::FontVariantEmoji,
            PropertyDeclaration::FontVariantLigatures(..) => LonghandId::FontVariantLigatures,
            PropertyDeclaration::FontVariantNumeric(..) => LonghandId::FontVariantNumeric,
            PropertyDeclaration::FontVariantPosition(..) => LonghandId::FontVariantPosition,
            PropertyDeclaration::FontWeight(..) => LonghandId::FontWeight,
            PropertyDeclaration::ForcedColorAdjust(..) => LonghandId::ForcedColorAdjust,
            PropertyDeclaration::GridAutoFlow(..) => LonghandId::GridAutoFlow,
            PropertyDeclaration::Hyphens(..) => LonghandId::Hyphens,
            PropertyDeclaration::ImageOrientation(..) => LonghandId::ImageOrientation,
            PropertyDeclaration::ImageRendering(..) => LonghandId::ImageRendering,
            PropertyDeclaration::ImeMode(..) => LonghandId::ImeMode,
            PropertyDeclaration::InitialLetter(..) => LonghandId::InitialLetter,
            PropertyDeclaration::InsetArea(..) => LonghandId::InsetArea,
            PropertyDeclaration::Isolation(..) => LonghandId::Isolation,
            PropertyDeclaration::JustifyContent(..) => LonghandId::JustifyContent,
            PropertyDeclaration::JustifyItems(..) => LonghandId::JustifyItems,
            PropertyDeclaration::JustifySelf(..) => LonghandId::JustifySelf,
            PropertyDeclaration::LineBreak(..) => LonghandId::LineBreak,
            PropertyDeclaration::ListStylePosition(..) => LonghandId::ListStylePosition,
            PropertyDeclaration::MaskType(..) => LonghandId::MaskType,
            PropertyDeclaration::MasonryAutoFlow(..) => LonghandId::MasonryAutoFlow,
            PropertyDeclaration::MathDepth(..) => LonghandId::MathDepth,
            PropertyDeclaration::MathStyle(..) => LonghandId::MathStyle,
            PropertyDeclaration::MixBlendMode(..) => LonghandId::MixBlendMode,
            PropertyDeclaration::MozBoxAlign(..) => LonghandId::MozBoxAlign,
            PropertyDeclaration::MozBoxCollapse(..) => LonghandId::MozBoxCollapse,
            PropertyDeclaration::MozBoxDirection(..) => LonghandId::MozBoxDirection,
            PropertyDeclaration::MozBoxOrient(..) => LonghandId::MozBoxOrient,
            PropertyDeclaration::MozBoxPack(..) => LonghandId::MozBoxPack,
            PropertyDeclaration::MozControlCharacterVisibility(..) => LonghandId::MozControlCharacterVisibility,
            PropertyDeclaration::MozFloatEdge(..) => LonghandId::MozFloatEdge,
            PropertyDeclaration::MozInert(..) => LonghandId::MozInert,
            PropertyDeclaration::MozMathVariant(..) => LonghandId::MozMathVariant,
            PropertyDeclaration::MozMinFontSizeRatio(..) => LonghandId::MozMinFontSizeRatio,
            PropertyDeclaration::MozOrient(..) => LonghandId::MozOrient,
            PropertyDeclaration::MozOsxFontSmoothing(..) => LonghandId::MozOsxFontSmoothing,
            PropertyDeclaration::MozTextSizeAdjust(..) => LonghandId::MozTextSizeAdjust,
            PropertyDeclaration::MozTheme(..) => LonghandId::MozTheme,
            PropertyDeclaration::MozTopLayer(..) => LonghandId::MozTopLayer,
            PropertyDeclaration::MozUserFocus(..) => LonghandId::MozUserFocus,
            PropertyDeclaration::MozUserInput(..) => LonghandId::MozUserInput,
            PropertyDeclaration::MozUserModify(..) => LonghandId::MozUserModify,
            PropertyDeclaration::MozWindowDragging(..) => LonghandId::MozWindowDragging,
            PropertyDeclaration::MozWindowShadow(..) => LonghandId::MozWindowShadow,
            PropertyDeclaration::ObjectFit(..) => LonghandId::ObjectFit,
            PropertyDeclaration::OffsetRotate(..) => LonghandId::OffsetRotate,
            PropertyDeclaration::OutlineStyle(..) => LonghandId::OutlineStyle,
            PropertyDeclaration::OverflowAnchor(..) => LonghandId::OverflowAnchor,
            PropertyDeclaration::OverflowWrap(..) => LonghandId::OverflowWrap,
            PropertyDeclaration::PageOrientation(..) => LonghandId::PageOrientation,
            PropertyDeclaration::PaintOrder(..) => LonghandId::PaintOrder,
            PropertyDeclaration::PointerEvents(..) => LonghandId::PointerEvents,
            PropertyDeclaration::Position(..) => LonghandId::Position,
            PropertyDeclaration::PositionTryOrder(..) => LonghandId::PositionTryOrder,
            PropertyDeclaration::PositionVisibility(..) => LonghandId::PositionVisibility,
            PropertyDeclaration::PrintColorAdjust(..) => LonghandId::PrintColorAdjust,
            PropertyDeclaration::Resize(..) => LonghandId::Resize,
            PropertyDeclaration::RubyAlign(..) => LonghandId::RubyAlign,
            PropertyDeclaration::RubyPosition(..) => LonghandId::RubyPosition,
            PropertyDeclaration::ScrollBehavior(..) => LonghandId::ScrollBehavior,
            PropertyDeclaration::ScrollSnapAlign(..) => LonghandId::ScrollSnapAlign,
            PropertyDeclaration::ScrollSnapStop(..) => LonghandId::ScrollSnapStop,
            PropertyDeclaration::ScrollSnapType(..) => LonghandId::ScrollSnapType,
            PropertyDeclaration::ScrollbarGutter(..) => LonghandId::ScrollbarGutter,
            PropertyDeclaration::ScrollbarWidth(..) => LonghandId::ScrollbarWidth,
            PropertyDeclaration::ShapeRendering(..) => LonghandId::ShapeRendering,
            PropertyDeclaration::StrokeLinecap(..) => LonghandId::StrokeLinecap,
            PropertyDeclaration::StrokeLinejoin(..) => LonghandId::StrokeLinejoin,
            PropertyDeclaration::TableLayout(..) => LonghandId::TableLayout,
            PropertyDeclaration::TextAlign(..) => LonghandId::TextAlign,
            PropertyDeclaration::TextAlignLast(..) => LonghandId::TextAlignLast,
            PropertyDeclaration::TextAnchor(..) => LonghandId::TextAnchor,
            PropertyDeclaration::TextCombineUpright(..) => LonghandId::TextCombineUpright,
            PropertyDeclaration::TextDecorationLine(..) => LonghandId::TextDecorationLine,
            PropertyDeclaration::TextDecorationSkipInk(..) => LonghandId::TextDecorationSkipInk,
            PropertyDeclaration::TextDecorationStyle(..) => LonghandId::TextDecorationStyle,
            PropertyDeclaration::TextEmphasisPosition(..) => LonghandId::TextEmphasisPosition,
            PropertyDeclaration::TextJustify(..) => LonghandId::TextJustify,
            PropertyDeclaration::TextOrientation(..) => LonghandId::TextOrientation,
            PropertyDeclaration::TextRendering(..) => LonghandId::TextRendering,
            PropertyDeclaration::TextTransform(..) => LonghandId::TextTransform,
            PropertyDeclaration::TextUnderlinePosition(..) => LonghandId::TextUnderlinePosition,
            PropertyDeclaration::TextWrapMode(..) => LonghandId::TextWrapMode,
            PropertyDeclaration::TextWrapStyle(..) => LonghandId::TextWrapStyle,
            PropertyDeclaration::TouchAction(..) => LonghandId::TouchAction,
            PropertyDeclaration::TransformBox(..) => LonghandId::TransformBox,
            PropertyDeclaration::TransformStyle(..) => LonghandId::TransformStyle,
            PropertyDeclaration::UnicodeBidi(..) => LonghandId::UnicodeBidi,
            PropertyDeclaration::UserSelect(..) => LonghandId::UserSelect,
            PropertyDeclaration::VectorEffect(..) => LonghandId::VectorEffect,
            PropertyDeclaration::Visibility(..) => LonghandId::Visibility,
            PropertyDeclaration::WebkitLineClamp(..) => LonghandId::WebkitLineClamp,
            PropertyDeclaration::WebkitTextSecurity(..) => LonghandId::WebkitTextSecurity,
            PropertyDeclaration::WhiteSpaceCollapse(..) => LonghandId::WhiteSpaceCollapse,
            PropertyDeclaration::WordBreak(..) => LonghandId::WordBreak,
            PropertyDeclaration::WritingMode(..) => LonghandId::WritingMode,
            PropertyDeclaration::XTextScale(..) => LonghandId::XTextScale,
            PropertyDeclaration::ZIndex(..) => LonghandId::ZIndex,
            PropertyDeclaration::Zoom(..) => LonghandId::Zoom,
            PropertyDeclaration::Appearance(..) => LonghandId::Appearance,
            PropertyDeclaration::MozDefaultAppearance(..) => LonghandId::MozDefaultAppearance,
            PropertyDeclaration::MozForceBrokenImageIcon(..) => LonghandId::MozForceBrokenImageIcon,
            PropertyDeclaration::MozSubtreeHiddenOnlyVisually(..) => LonghandId::MozSubtreeHiddenOnlyVisually,
            PropertyDeclaration::BreakAfter(..) => LonghandId::BreakAfter,
            PropertyDeclaration::BreakBefore(..) => LonghandId::BreakBefore,
            PropertyDeclaration::ClipRule(..) => LonghandId::ClipRule,
            PropertyDeclaration::FillRule(..) => LonghandId::FillRule,
            PropertyDeclaration::OverflowClipBoxBlock(..) => LonghandId::OverflowClipBoxBlock,
            PropertyDeclaration::OverflowClipBoxInline(..) => LonghandId::OverflowClipBoxInline,
            PropertyDeclaration::FillOpacity(..) => LonghandId::FillOpacity,
            PropertyDeclaration::StrokeOpacity(..) => LonghandId::StrokeOpacity,
            PropertyDeclaration::MozBoxOrdinalGroup(..) => LonghandId::MozBoxOrdinalGroup,
            PropertyDeclaration::Order(..) => LonghandId::Order,
            PropertyDeclaration::XSpan(..) => LonghandId::XSpan,
            PropertyDeclaration::FontSynthesisPosition(..) => LonghandId::FontSynthesisPosition,
            PropertyDeclaration::FontSynthesisSmallCaps(..) => LonghandId::FontSynthesisSmallCaps,
            PropertyDeclaration::FontSynthesisStyle(..) => LonghandId::FontSynthesisStyle,
            PropertyDeclaration::FontSynthesisWeight(..) => LonghandId::FontSynthesisWeight,
            PropertyDeclaration::FlexGrow(..) => LonghandId::FlexGrow,
            PropertyDeclaration::FlexShrink(..) => LonghandId::FlexShrink,
            PropertyDeclaration::MozBoxFlex(..) => LonghandId::MozBoxFlex,
            PropertyDeclaration::StrokeMiterlimit(..) => LonghandId::StrokeMiterlimit,
            PropertyDeclaration::OverflowBlock(..) => LonghandId::OverflowBlock,
            PropertyDeclaration::OverflowInline(..) => LonghandId::OverflowInline,
            PropertyDeclaration::OverflowX(..) => LonghandId::OverflowX,
            PropertyDeclaration::OverflowY(..) => LonghandId::OverflowY,
            PropertyDeclaration::OverscrollBehaviorBlock(..) => LonghandId::OverscrollBehaviorBlock,
            PropertyDeclaration::OverscrollBehaviorInline(..) => LonghandId::OverscrollBehaviorInline,
            PropertyDeclaration::OverscrollBehaviorX(..) => LonghandId::OverscrollBehaviorX,
            PropertyDeclaration::OverscrollBehaviorY(..) => LonghandId::OverscrollBehaviorY,
            PropertyDeclaration::FloodOpacity(..) => LonghandId::FloodOpacity,
            PropertyDeclaration::MozWindowOpacity(..) => LonghandId::MozWindowOpacity,
            PropertyDeclaration::Opacity(..) => LonghandId::Opacity,
            PropertyDeclaration::ShapeImageThreshold(..) => LonghandId::ShapeImageThreshold,
            PropertyDeclaration::StopOpacity(..) => LonghandId::StopOpacity,
            PropertyDeclaration::BorderBlockEndStyle(..) => LonghandId::BorderBlockEndStyle,
            PropertyDeclaration::BorderBlockStartStyle(..) => LonghandId::BorderBlockStartStyle,
            PropertyDeclaration::BorderBottomStyle(..) => LonghandId::BorderBottomStyle,
            PropertyDeclaration::BorderInlineEndStyle(..) => LonghandId::BorderInlineEndStyle,
            PropertyDeclaration::BorderInlineStartStyle(..) => LonghandId::BorderInlineStartStyle,
            PropertyDeclaration::BorderLeftStyle(..) => LonghandId::BorderLeftStyle,
            PropertyDeclaration::BorderRightStyle(..) => LonghandId::BorderRightStyle,
            PropertyDeclaration::BorderTopStyle(..) => LonghandId::BorderTopStyle,
            PropertyDeclaration::ColumnRuleStyle(..) => LonghandId::ColumnRuleStyle,
            PropertyDeclaration::AccentColor(..) => LonghandId::AccentColor,
            PropertyDeclaration::AnchorName(..) => LonghandId::AnchorName,
            PropertyDeclaration::AnchorScope(..) => LonghandId::AnchorScope,
            PropertyDeclaration::AnimationComposition(..) => LonghandId::AnimationComposition,
            PropertyDeclaration::AnimationDelay(..) => LonghandId::AnimationDelay,
            PropertyDeclaration::AnimationDirection(..) => LonghandId::AnimationDirection,
            PropertyDeclaration::AnimationDuration(..) => LonghandId::AnimationDuration,
            PropertyDeclaration::AnimationFillMode(..) => LonghandId::AnimationFillMode,
            PropertyDeclaration::AnimationIterationCount(..) => LonghandId::AnimationIterationCount,
            PropertyDeclaration::AnimationName(..) => LonghandId::AnimationName,
            PropertyDeclaration::AnimationPlayState(..) => LonghandId::AnimationPlayState,
            PropertyDeclaration::AnimationTimeline(..) => LonghandId::AnimationTimeline,
            PropertyDeclaration::AnimationTimingFunction(..) => LonghandId::AnimationTimingFunction,
            PropertyDeclaration::BackdropFilter(..) => LonghandId::BackdropFilter,
            PropertyDeclaration::BackgroundAttachment(..) => LonghandId::BackgroundAttachment,
            PropertyDeclaration::BackgroundBlendMode(..) => LonghandId::BackgroundBlendMode,
            PropertyDeclaration::BackgroundClip(..) => LonghandId::BackgroundClip,
            PropertyDeclaration::BackgroundImage(..) => LonghandId::BackgroundImage,
            PropertyDeclaration::BackgroundOrigin(..) => LonghandId::BackgroundOrigin,
            PropertyDeclaration::BackgroundPositionX(..) => LonghandId::BackgroundPositionX,
            PropertyDeclaration::BackgroundPositionY(..) => LonghandId::BackgroundPositionY,
            PropertyDeclaration::BackgroundRepeat(..) => LonghandId::BackgroundRepeat,
            PropertyDeclaration::BackgroundSize(..) => LonghandId::BackgroundSize,
            PropertyDeclaration::BorderImageOutset(..) => LonghandId::BorderImageOutset,
            PropertyDeclaration::BorderImageSlice(..) => LonghandId::BorderImageSlice,
            PropertyDeclaration::BorderImageWidth(..) => LonghandId::BorderImageWidth,
            PropertyDeclaration::BorderSpacing(..) => LonghandId::BorderSpacing,
            PropertyDeclaration::BoxShadow(..) => LonghandId::BoxShadow,
            PropertyDeclaration::CaretColor(..) => LonghandId::CaretColor,
            PropertyDeclaration::Clip(..) => LonghandId::Clip,
            PropertyDeclaration::ClipPath(..) => LonghandId::ClipPath,
            PropertyDeclaration::Color(..) => LonghandId::Color,
            PropertyDeclaration::ColorScheme(..) => LonghandId::ColorScheme,
            PropertyDeclaration::ColumnWidth(..) => LonghandId::ColumnWidth,
            PropertyDeclaration::ContainerName(..) => LonghandId::ContainerName,
            PropertyDeclaration::Content(..) => LonghandId::Content,
            PropertyDeclaration::CounterIncrement(..) => LonghandId::CounterIncrement,
            PropertyDeclaration::CounterReset(..) => LonghandId::CounterReset,
            PropertyDeclaration::CounterSet(..) => LonghandId::CounterSet,
            PropertyDeclaration::Cursor(..) => LonghandId::Cursor,
            PropertyDeclaration::D(..) => LonghandId::D,
            PropertyDeclaration::Filter(..) => LonghandId::Filter,
            PropertyDeclaration::FlexBasis(..) => LonghandId::FlexBasis,
            PropertyDeclaration::FontFamily(..) => LonghandId::FontFamily,
            PropertyDeclaration::FontFeatureSettings(..) => LonghandId::FontFeatureSettings,
            PropertyDeclaration::FontPalette(..) => LonghandId::FontPalette,
            PropertyDeclaration::FontSize(..) => LonghandId::FontSize,
            PropertyDeclaration::FontVariantAlternates(..) => LonghandId::FontVariantAlternates,
            PropertyDeclaration::FontVariationSettings(..) => LonghandId::FontVariationSettings,
            PropertyDeclaration::GridTemplateAreas(..) => LonghandId::GridTemplateAreas,
            PropertyDeclaration::HyphenateCharacter(..) => LonghandId::HyphenateCharacter,
            PropertyDeclaration::LetterSpacing(..) => LonghandId::LetterSpacing,
            PropertyDeclaration::LineHeight(..) => LonghandId::LineHeight,
            PropertyDeclaration::ListStyleType(..) => LonghandId::ListStyleType,
            PropertyDeclaration::MaskClip(..) => LonghandId::MaskClip,
            PropertyDeclaration::MaskComposite(..) => LonghandId::MaskComposite,
            PropertyDeclaration::MaskImage(..) => LonghandId::MaskImage,
            PropertyDeclaration::MaskMode(..) => LonghandId::MaskMode,
            PropertyDeclaration::MaskOrigin(..) => LonghandId::MaskOrigin,
            PropertyDeclaration::MaskPositionX(..) => LonghandId::MaskPositionX,
            PropertyDeclaration::MaskPositionY(..) => LonghandId::MaskPositionY,
            PropertyDeclaration::MaskRepeat(..) => LonghandId::MaskRepeat,
            PropertyDeclaration::MaskSize(..) => LonghandId::MaskSize,
            PropertyDeclaration::MozContextProperties(..) => LonghandId::MozContextProperties,
            PropertyDeclaration::OffsetAnchor(..) => LonghandId::OffsetAnchor,
            PropertyDeclaration::OffsetPath(..) => LonghandId::OffsetPath,
            PropertyDeclaration::OffsetPosition(..) => LonghandId::OffsetPosition,
            PropertyDeclaration::Page(..) => LonghandId::Page,
            PropertyDeclaration::Perspective(..) => LonghandId::Perspective,
            PropertyDeclaration::PositionAnchor(..) => LonghandId::PositionAnchor,
            PropertyDeclaration::PositionTryOptions(..) => LonghandId::PositionTryOptions,
            PropertyDeclaration::Quotes(..) => LonghandId::Quotes,
            PropertyDeclaration::Rotate(..) => LonghandId::Rotate,
            PropertyDeclaration::Scale(..) => LonghandId::Scale,
            PropertyDeclaration::ScrollTimelineAxis(..) => LonghandId::ScrollTimelineAxis,
            PropertyDeclaration::ScrollTimelineName(..) => LonghandId::ScrollTimelineName,
            PropertyDeclaration::ScrollbarColor(..) => LonghandId::ScrollbarColor,
            PropertyDeclaration::ShapeOutside(..) => LonghandId::ShapeOutside,
            PropertyDeclaration::Size(..) => LonghandId::Size,
            PropertyDeclaration::StrokeDasharray(..) => LonghandId::StrokeDasharray,
            PropertyDeclaration::StrokeDashoffset(..) => LonghandId::StrokeDashoffset,
            PropertyDeclaration::StrokeWidth(..) => LonghandId::StrokeWidth,
            PropertyDeclaration::TabSize(..) => LonghandId::TabSize,
            PropertyDeclaration::TextDecorationThickness(..) => LonghandId::TextDecorationThickness,
            PropertyDeclaration::TextEmphasisStyle(..) => LonghandId::TextEmphasisStyle,
            PropertyDeclaration::TextIndent(..) => LonghandId::TextIndent,
            PropertyDeclaration::TextOverflow(..) => LonghandId::TextOverflow,
            PropertyDeclaration::TextShadow(..) => LonghandId::TextShadow,
            PropertyDeclaration::TransitionBehavior(..) => LonghandId::TransitionBehavior,
            PropertyDeclaration::TransitionDelay(..) => LonghandId::TransitionDelay,
            PropertyDeclaration::TransitionDuration(..) => LonghandId::TransitionDuration,
            PropertyDeclaration::TransitionProperty(..) => LonghandId::TransitionProperty,
            PropertyDeclaration::TransitionTimingFunction(..) => LonghandId::TransitionTimingFunction,
            PropertyDeclaration::Translate(..) => LonghandId::Translate,
            PropertyDeclaration::VerticalAlign(..) => LonghandId::VerticalAlign,
            PropertyDeclaration::ViewTimelineAxis(..) => LonghandId::ViewTimelineAxis,
            PropertyDeclaration::ViewTimelineInset(..) => LonghandId::ViewTimelineInset,
            PropertyDeclaration::ViewTimelineName(..) => LonghandId::ViewTimelineName,
            PropertyDeclaration::WebkitTextStrokeWidth(..) => LonghandId::WebkitTextStrokeWidth,
            PropertyDeclaration::WillChange(..) => LonghandId::WillChange,
            PropertyDeclaration::WordSpacing(..) => LonghandId::WordSpacing,
            PropertyDeclaration::XLang(..) => LonghandId::XLang,
            PropertyDeclaration::ObjectPosition(..) => LonghandId::ObjectPosition,
            PropertyDeclaration::PerspectiveOrigin(..) => LonghandId::PerspectiveOrigin,
            PropertyDeclaration::Fill(..) => LonghandId::Fill,
            PropertyDeclaration::Stroke(..) => LonghandId::Stroke,
            PropertyDeclaration::MozWindowTransformOrigin(..) => LonghandId::MozWindowTransformOrigin,
            PropertyDeclaration::TransformOrigin(..) => LonghandId::TransformOrigin,
            PropertyDeclaration::GridTemplateColumns(..) => LonghandId::GridTemplateColumns,
            PropertyDeclaration::GridTemplateRows(..) => LonghandId::GridTemplateRows,
            PropertyDeclaration::BorderImageSource(..) => LonghandId::BorderImageSource,
            PropertyDeclaration::ListStyleImage(..) => LonghandId::ListStyleImage,
            PropertyDeclaration::GridAutoColumns(..) => LonghandId::GridAutoColumns,
            PropertyDeclaration::GridAutoRows(..) => LonghandId::GridAutoRows,
            PropertyDeclaration::MozWindowTransform(..) => LonghandId::MozWindowTransform,
            PropertyDeclaration::Transform(..) => LonghandId::Transform,
            PropertyDeclaration::ColumnGap(..) => LonghandId::ColumnGap,
            PropertyDeclaration::RowGap(..) => LonghandId::RowGap,
            PropertyDeclaration::MarkerEnd(..) => LonghandId::MarkerEnd,
            PropertyDeclaration::MarkerMid(..) => LonghandId::MarkerMid,
            PropertyDeclaration::MarkerStart(..) => LonghandId::MarkerStart,
            PropertyDeclaration::ContainIntrinsicBlockSize(..) => LonghandId::ContainIntrinsicBlockSize,
            PropertyDeclaration::ContainIntrinsicHeight(..) => LonghandId::ContainIntrinsicHeight,
            PropertyDeclaration::ContainIntrinsicInlineSize(..) => LonghandId::ContainIntrinsicInlineSize,
            PropertyDeclaration::ContainIntrinsicWidth(..) => LonghandId::ContainIntrinsicWidth,
            PropertyDeclaration::GridColumnEnd(..) => LonghandId::GridColumnEnd,
            PropertyDeclaration::GridColumnStart(..) => LonghandId::GridColumnStart,
            PropertyDeclaration::GridRowEnd(..) => LonghandId::GridRowEnd,
            PropertyDeclaration::GridRowStart(..) => LonghandId::GridRowStart,
            PropertyDeclaration::MaxBlockSize(..) => LonghandId::MaxBlockSize,
            PropertyDeclaration::MaxHeight(..) => LonghandId::MaxHeight,
            PropertyDeclaration::MaxInlineSize(..) => LonghandId::MaxInlineSize,
            PropertyDeclaration::MaxWidth(..) => LonghandId::MaxWidth,
            PropertyDeclaration::Cx(..) => LonghandId::Cx,
            PropertyDeclaration::Cy(..) => LonghandId::Cy,
            PropertyDeclaration::OffsetDistance(..) => LonghandId::OffsetDistance,
            PropertyDeclaration::X(..) => LonghandId::X,
            PropertyDeclaration::Y(..) => LonghandId::Y,
            PropertyDeclaration::BorderBottomLeftRadius(..) => LonghandId::BorderBottomLeftRadius,
            PropertyDeclaration::BorderBottomRightRadius(..) => LonghandId::BorderBottomRightRadius,
            PropertyDeclaration::BorderEndEndRadius(..) => LonghandId::BorderEndEndRadius,
            PropertyDeclaration::BorderEndStartRadius(..) => LonghandId::BorderEndStartRadius,
            PropertyDeclaration::BorderStartEndRadius(..) => LonghandId::BorderStartEndRadius,
            PropertyDeclaration::BorderStartStartRadius(..) => LonghandId::BorderStartStartRadius,
            PropertyDeclaration::BorderTopLeftRadius(..) => LonghandId::BorderTopLeftRadius,
            PropertyDeclaration::BorderTopRightRadius(..) => LonghandId::BorderTopRightRadius,
            PropertyDeclaration::BlockSize(..) => LonghandId::BlockSize,
            PropertyDeclaration::Height(..) => LonghandId::Height,
            PropertyDeclaration::InlineSize(..) => LonghandId::InlineSize,
            PropertyDeclaration::MinBlockSize(..) => LonghandId::MinBlockSize,
            PropertyDeclaration::MinHeight(..) => LonghandId::MinHeight,
            PropertyDeclaration::MinInlineSize(..) => LonghandId::MinInlineSize,
            PropertyDeclaration::MinWidth(..) => LonghandId::MinWidth,
            PropertyDeclaration::Width(..) => LonghandId::Width,
            PropertyDeclaration::BorderBlockEndWidth(..) => LonghandId::BorderBlockEndWidth,
            PropertyDeclaration::BorderBlockStartWidth(..) => LonghandId::BorderBlockStartWidth,
            PropertyDeclaration::BorderBottomWidth(..) => LonghandId::BorderBottomWidth,
            PropertyDeclaration::BorderInlineEndWidth(..) => LonghandId::BorderInlineEndWidth,
            PropertyDeclaration::BorderInlineStartWidth(..) => LonghandId::BorderInlineStartWidth,
            PropertyDeclaration::BorderLeftWidth(..) => LonghandId::BorderLeftWidth,
            PropertyDeclaration::BorderRightWidth(..) => LonghandId::BorderRightWidth,
            PropertyDeclaration::BorderTopWidth(..) => LonghandId::BorderTopWidth,
            PropertyDeclaration::ColumnRuleWidth(..) => LonghandId::ColumnRuleWidth,
            PropertyDeclaration::OutlineWidth(..) => LonghandId::OutlineWidth,
            PropertyDeclaration::PaddingBlockEnd(..) => LonghandId::PaddingBlockEnd,
            PropertyDeclaration::PaddingBlockStart(..) => LonghandId::PaddingBlockStart,
            PropertyDeclaration::PaddingBottom(..) => LonghandId::PaddingBottom,
            PropertyDeclaration::PaddingInlineEnd(..) => LonghandId::PaddingInlineEnd,
            PropertyDeclaration::PaddingInlineStart(..) => LonghandId::PaddingInlineStart,
            PropertyDeclaration::PaddingLeft(..) => LonghandId::PaddingLeft,
            PropertyDeclaration::PaddingRight(..) => LonghandId::PaddingRight,
            PropertyDeclaration::PaddingTop(..) => LonghandId::PaddingTop,
            PropertyDeclaration::R(..) => LonghandId::R,
            PropertyDeclaration::ShapeMargin(..) => LonghandId::ShapeMargin,
            PropertyDeclaration::Rx(..) => LonghandId::Rx,
            PropertyDeclaration::Ry(..) => LonghandId::Ry,
            PropertyDeclaration::ScrollPaddingBlockEnd(..) => LonghandId::ScrollPaddingBlockEnd,
            PropertyDeclaration::ScrollPaddingBlockStart(..) => LonghandId::ScrollPaddingBlockStart,
            PropertyDeclaration::ScrollPaddingBottom(..) => LonghandId::ScrollPaddingBottom,
            PropertyDeclaration::ScrollPaddingInlineEnd(..) => LonghandId::ScrollPaddingInlineEnd,
            PropertyDeclaration::ScrollPaddingInlineStart(..) => LonghandId::ScrollPaddingInlineStart,
            PropertyDeclaration::ScrollPaddingLeft(..) => LonghandId::ScrollPaddingLeft,
            PropertyDeclaration::ScrollPaddingRight(..) => LonghandId::ScrollPaddingRight,
            PropertyDeclaration::ScrollPaddingTop(..) => LonghandId::ScrollPaddingTop,
            PropertyDeclaration::MozWindowInputRegionMargin(..) => LonghandId::MozWindowInputRegionMargin,
            PropertyDeclaration::OutlineOffset(..) => LonghandId::OutlineOffset,
            PropertyDeclaration::OverflowClipMargin(..) => LonghandId::OverflowClipMargin,
            PropertyDeclaration::ScrollMarginBlockEnd(..) => LonghandId::ScrollMarginBlockEnd,
            PropertyDeclaration::ScrollMarginBlockStart(..) => LonghandId::ScrollMarginBlockStart,
            PropertyDeclaration::ScrollMarginBottom(..) => LonghandId::ScrollMarginBottom,
            PropertyDeclaration::ScrollMarginInlineEnd(..) => LonghandId::ScrollMarginInlineEnd,
            PropertyDeclaration::ScrollMarginInlineStart(..) => LonghandId::ScrollMarginInlineStart,
            PropertyDeclaration::ScrollMarginLeft(..) => LonghandId::ScrollMarginLeft,
            PropertyDeclaration::ScrollMarginRight(..) => LonghandId::ScrollMarginRight,
            PropertyDeclaration::ScrollMarginTop(..) => LonghandId::ScrollMarginTop,
            PropertyDeclaration::Bottom(..) => LonghandId::Bottom,
            PropertyDeclaration::InsetBlockEnd(..) => LonghandId::InsetBlockEnd,
            PropertyDeclaration::InsetBlockStart(..) => LonghandId::InsetBlockStart,
            PropertyDeclaration::InsetInlineEnd(..) => LonghandId::InsetInlineEnd,
            PropertyDeclaration::InsetInlineStart(..) => LonghandId::InsetInlineStart,
            PropertyDeclaration::Left(..) => LonghandId::Left,
            PropertyDeclaration::MarginBlockEnd(..) => LonghandId::MarginBlockEnd,
            PropertyDeclaration::MarginBlockStart(..) => LonghandId::MarginBlockStart,
            PropertyDeclaration::MarginBottom(..) => LonghandId::MarginBottom,
            PropertyDeclaration::MarginInlineEnd(..) => LonghandId::MarginInlineEnd,
            PropertyDeclaration::MarginInlineStart(..) => LonghandId::MarginInlineStart,
            PropertyDeclaration::MarginLeft(..) => LonghandId::MarginLeft,
            PropertyDeclaration::MarginRight(..) => LonghandId::MarginRight,
            PropertyDeclaration::MarginTop(..) => LonghandId::MarginTop,
            PropertyDeclaration::Right(..) => LonghandId::Right,
            PropertyDeclaration::TextUnderlineOffset(..) => LonghandId::TextUnderlineOffset,
            PropertyDeclaration::Top(..) => LonghandId::Top,
            PropertyDeclaration::BackgroundColor(..) => LonghandId::BackgroundColor,
            PropertyDeclaration::BorderBlockEndColor(..) => LonghandId::BorderBlockEndColor,
            PropertyDeclaration::BorderBlockStartColor(..) => LonghandId::BorderBlockStartColor,
            PropertyDeclaration::BorderBottomColor(..) => LonghandId::BorderBottomColor,
            PropertyDeclaration::BorderInlineEndColor(..) => LonghandId::BorderInlineEndColor,
            PropertyDeclaration::BorderInlineStartColor(..) => LonghandId::BorderInlineStartColor,
            PropertyDeclaration::BorderLeftColor(..) => LonghandId::BorderLeftColor,
            PropertyDeclaration::BorderRightColor(..) => LonghandId::BorderRightColor,
            PropertyDeclaration::BorderTopColor(..) => LonghandId::BorderTopColor,
            PropertyDeclaration::ColumnRuleColor(..) => LonghandId::ColumnRuleColor,
            PropertyDeclaration::FloodColor(..) => LonghandId::FloodColor,
            PropertyDeclaration::LightingColor(..) => LonghandId::LightingColor,
            PropertyDeclaration::OutlineColor(..) => LonghandId::OutlineColor,
            PropertyDeclaration::StopColor(..) => LonghandId::StopColor,
            PropertyDeclaration::TextDecorationColor(..) => LonghandId::TextDecorationColor,
            PropertyDeclaration::TextEmphasisColor(..) => LonghandId::TextEmphasisColor,
            PropertyDeclaration::WebkitTextFillColor(..) => LonghandId::WebkitTextFillColor,
            PropertyDeclaration::WebkitTextStrokeColor(..) => LonghandId::WebkitTextStrokeColor,
            _ => id,
        });
        PropertyDeclarationId::Longhand(id)
    }

    /// Given a declaration, convert it into a declaration for a corresponding
    /// physical property.
    #[inline]
    pub fn to_physical(&self, wm: WritingMode) -> Self {
        match *self {
            PropertyDeclaration::WithVariables(VariableDeclaration {
                id,
                ref value,
            }) => {
                return PropertyDeclaration::WithVariables(VariableDeclaration {
                    id: id.to_physical(wm),
                    value: value.clone(),
                })
            }
            PropertyDeclaration::CSSWideKeyword(WideKeywordDeclaration {
                id,
                keyword,
            }) => {
                return PropertyDeclaration::CSSWideKeyword(WideKeywordDeclaration {
                    id: id.to_physical(wm),
                    keyword,
                })
            }
            PropertyDeclaration::Custom(..) => return self.clone(),
            PropertyDeclaration::AlignContent(..) => {},
            PropertyDeclaration::AlignItems(..) => {},
            PropertyDeclaration::AlignSelf(..) => {},
            PropertyDeclaration::AspectRatio(..) => {},
            PropertyDeclaration::BackfaceVisibility(..) => {},
            PropertyDeclaration::BaselineSource(..) => {},
            PropertyDeclaration::BorderCollapse(..) => {},
            PropertyDeclaration::BorderImageRepeat(..) => {},
            PropertyDeclaration::BoxDecorationBreak(..) => {},
            PropertyDeclaration::BoxSizing(..) => {},
            PropertyDeclaration::BreakInside(..) => {},
            PropertyDeclaration::CaptionSide(..) => {},
            PropertyDeclaration::Clear(..) => {},
            PropertyDeclaration::ColorInterpolation(..) => {},
            PropertyDeclaration::ColorInterpolationFilters(..) => {},
            PropertyDeclaration::ColumnCount(..) => {},
            PropertyDeclaration::ColumnFill(..) => {},
            PropertyDeclaration::ColumnSpan(..) => {},
            PropertyDeclaration::Contain(..) => {},
            PropertyDeclaration::ContainerType(..) => {},
            PropertyDeclaration::ContentVisibility(..) => {},
            PropertyDeclaration::Direction(..) => {},
            PropertyDeclaration::Display(..) => {},
            PropertyDeclaration::DominantBaseline(..) => {},
            PropertyDeclaration::EmptyCells(..) => {},
            PropertyDeclaration::FlexDirection(..) => {},
            PropertyDeclaration::FlexWrap(..) => {},
            PropertyDeclaration::Float(..) => {},
            PropertyDeclaration::FontKerning(..) => {},
            PropertyDeclaration::FontLanguageOverride(..) => {},
            PropertyDeclaration::FontOpticalSizing(..) => {},
            PropertyDeclaration::FontSizeAdjust(..) => {},
            PropertyDeclaration::FontStretch(..) => {},
            PropertyDeclaration::FontStyle(..) => {},
            PropertyDeclaration::FontVariantCaps(..) => {},
            PropertyDeclaration::FontVariantEastAsian(..) => {},
            PropertyDeclaration::FontVariantEmoji(..) => {},
            PropertyDeclaration::FontVariantLigatures(..) => {},
            PropertyDeclaration::FontVariantNumeric(..) => {},
            PropertyDeclaration::FontVariantPosition(..) => {},
            PropertyDeclaration::FontWeight(..) => {},
            PropertyDeclaration::ForcedColorAdjust(..) => {},
            PropertyDeclaration::GridAutoFlow(..) => {},
            PropertyDeclaration::Hyphens(..) => {},
            PropertyDeclaration::ImageOrientation(..) => {},
            PropertyDeclaration::ImageRendering(..) => {},
            PropertyDeclaration::ImeMode(..) => {},
            PropertyDeclaration::InitialLetter(..) => {},
            PropertyDeclaration::InsetArea(..) => {},
            PropertyDeclaration::Isolation(..) => {},
            PropertyDeclaration::JustifyContent(..) => {},
            PropertyDeclaration::JustifyItems(..) => {},
            PropertyDeclaration::JustifySelf(..) => {},
            PropertyDeclaration::LineBreak(..) => {},
            PropertyDeclaration::ListStylePosition(..) => {},
            PropertyDeclaration::MaskType(..) => {},
            PropertyDeclaration::MasonryAutoFlow(..) => {},
            PropertyDeclaration::MathDepth(..) => {},
            PropertyDeclaration::MathStyle(..) => {},
            PropertyDeclaration::MixBlendMode(..) => {},
            PropertyDeclaration::MozBoxAlign(..) => {},
            PropertyDeclaration::MozBoxCollapse(..) => {},
            PropertyDeclaration::MozBoxDirection(..) => {},
            PropertyDeclaration::MozBoxOrient(..) => {},
            PropertyDeclaration::MozBoxPack(..) => {},
            PropertyDeclaration::MozControlCharacterVisibility(..) => {},
            PropertyDeclaration::MozFloatEdge(..) => {},
            PropertyDeclaration::MozInert(..) => {},
            PropertyDeclaration::MozMathVariant(..) => {},
            PropertyDeclaration::MozMinFontSizeRatio(..) => {},
            PropertyDeclaration::MozOrient(..) => {},
            PropertyDeclaration::MozOsxFontSmoothing(..) => {},
            PropertyDeclaration::MozTextSizeAdjust(..) => {},
            PropertyDeclaration::MozTheme(..) => {},
            PropertyDeclaration::MozTopLayer(..) => {},
            PropertyDeclaration::MozUserFocus(..) => {},
            PropertyDeclaration::MozUserInput(..) => {},
            PropertyDeclaration::MozUserModify(..) => {},
            PropertyDeclaration::MozWindowDragging(..) => {},
            PropertyDeclaration::MozWindowShadow(..) => {},
            PropertyDeclaration::ObjectFit(..) => {},
            PropertyDeclaration::OffsetRotate(..) => {},
            PropertyDeclaration::OutlineStyle(..) => {},
            PropertyDeclaration::OverflowAnchor(..) => {},
            PropertyDeclaration::OverflowWrap(..) => {},
            PropertyDeclaration::PageOrientation(..) => {},
            PropertyDeclaration::PaintOrder(..) => {},
            PropertyDeclaration::PointerEvents(..) => {},
            PropertyDeclaration::Position(..) => {},
            PropertyDeclaration::PositionTryOrder(..) => {},
            PropertyDeclaration::PositionVisibility(..) => {},
            PropertyDeclaration::PrintColorAdjust(..) => {},
            PropertyDeclaration::Resize(..) => {},
            PropertyDeclaration::RubyAlign(..) => {},
            PropertyDeclaration::RubyPosition(..) => {},
            PropertyDeclaration::ScrollBehavior(..) => {},
            PropertyDeclaration::ScrollSnapAlign(..) => {},
            PropertyDeclaration::ScrollSnapStop(..) => {},
            PropertyDeclaration::ScrollSnapType(..) => {},
            PropertyDeclaration::ScrollbarGutter(..) => {},
            PropertyDeclaration::ScrollbarWidth(..) => {},
            PropertyDeclaration::ShapeRendering(..) => {},
            PropertyDeclaration::StrokeLinecap(..) => {},
            PropertyDeclaration::StrokeLinejoin(..) => {},
            PropertyDeclaration::TableLayout(..) => {},
            PropertyDeclaration::TextAlign(..) => {},
            PropertyDeclaration::TextAlignLast(..) => {},
            PropertyDeclaration::TextAnchor(..) => {},
            PropertyDeclaration::TextCombineUpright(..) => {},
            PropertyDeclaration::TextDecorationLine(..) => {},
            PropertyDeclaration::TextDecorationSkipInk(..) => {},
            PropertyDeclaration::TextDecorationStyle(..) => {},
            PropertyDeclaration::TextEmphasisPosition(..) => {},
            PropertyDeclaration::TextJustify(..) => {},
            PropertyDeclaration::TextOrientation(..) => {},
            PropertyDeclaration::TextRendering(..) => {},
            PropertyDeclaration::TextTransform(..) => {},
            PropertyDeclaration::TextUnderlinePosition(..) => {},
            PropertyDeclaration::TextWrapMode(..) => {},
            PropertyDeclaration::TextWrapStyle(..) => {},
            PropertyDeclaration::TouchAction(..) => {},
            PropertyDeclaration::TransformBox(..) => {},
            PropertyDeclaration::TransformStyle(..) => {},
            PropertyDeclaration::UnicodeBidi(..) => {},
            PropertyDeclaration::UserSelect(..) => {},
            PropertyDeclaration::VectorEffect(..) => {},
            PropertyDeclaration::Visibility(..) => {},
            PropertyDeclaration::WebkitLineClamp(..) => {},
            PropertyDeclaration::WebkitTextSecurity(..) => {},
            PropertyDeclaration::WhiteSpaceCollapse(..) => {},
            PropertyDeclaration::WordBreak(..) => {},
            PropertyDeclaration::WritingMode(..) => {},
            PropertyDeclaration::XTextScale(..) => {},
            PropertyDeclaration::ZIndex(..) => {},
            PropertyDeclaration::Zoom(..) => {},
            PropertyDeclaration::Appearance(..) => {},
            PropertyDeclaration::MozDefaultAppearance(..) => {},
            PropertyDeclaration::MozForceBrokenImageIcon(..) => {},
            PropertyDeclaration::MozSubtreeHiddenOnlyVisually(..) => {},
            PropertyDeclaration::BreakAfter(..) => {},
            PropertyDeclaration::BreakBefore(..) => {},
            PropertyDeclaration::ClipRule(..) => {},
            PropertyDeclaration::FillRule(..) => {},
            PropertyDeclaration::OverflowClipBoxBlock(..) => {},
            PropertyDeclaration::OverflowClipBoxInline(..) => {},
            PropertyDeclaration::FillOpacity(..) => {},
            PropertyDeclaration::StrokeOpacity(..) => {},
            PropertyDeclaration::MozBoxOrdinalGroup(..) => {},
            PropertyDeclaration::Order(..) => {},
            PropertyDeclaration::XSpan(..) => {},
            PropertyDeclaration::FontSynthesisPosition(..) => {},
            PropertyDeclaration::FontSynthesisSmallCaps(..) => {},
            PropertyDeclaration::FontSynthesisStyle(..) => {},
            PropertyDeclaration::FontSynthesisWeight(..) => {},
            PropertyDeclaration::FlexGrow(..) => {},
            PropertyDeclaration::FlexShrink(..) => {},
            PropertyDeclaration::MozBoxFlex(..) => {},
            PropertyDeclaration::StrokeMiterlimit(..) => {},
            PropertyDeclaration::OverflowBlock(..) => {},
            PropertyDeclaration::OverflowInline(..) => {},
            PropertyDeclaration::OverflowX(..) => {},
            PropertyDeclaration::OverflowY(..) => {},
            PropertyDeclaration::OverscrollBehaviorBlock(..) => {},
            PropertyDeclaration::OverscrollBehaviorInline(..) => {},
            PropertyDeclaration::OverscrollBehaviorX(..) => {},
            PropertyDeclaration::OverscrollBehaviorY(..) => {},
            PropertyDeclaration::FloodOpacity(..) => {},
            PropertyDeclaration::MozWindowOpacity(..) => {},
            PropertyDeclaration::Opacity(..) => {},
            PropertyDeclaration::ShapeImageThreshold(..) => {},
            PropertyDeclaration::StopOpacity(..) => {},
            PropertyDeclaration::BorderBlockEndStyle(..) => {},
            PropertyDeclaration::BorderBlockStartStyle(..) => {},
            PropertyDeclaration::BorderBottomStyle(..) => {},
            PropertyDeclaration::BorderInlineEndStyle(..) => {},
            PropertyDeclaration::BorderInlineStartStyle(..) => {},
            PropertyDeclaration::BorderLeftStyle(..) => {},
            PropertyDeclaration::BorderRightStyle(..) => {},
            PropertyDeclaration::BorderTopStyle(..) => {},
            PropertyDeclaration::ColumnRuleStyle(..) => {},
            PropertyDeclaration::AccentColor(..) => {},
            PropertyDeclaration::AnchorName(..) => {},
            PropertyDeclaration::AnchorScope(..) => {},
            PropertyDeclaration::AnimationComposition(..) => {},
            PropertyDeclaration::AnimationDelay(..) => {},
            PropertyDeclaration::AnimationDirection(..) => {},
            PropertyDeclaration::AnimationDuration(..) => {},
            PropertyDeclaration::AnimationFillMode(..) => {},
            PropertyDeclaration::AnimationIterationCount(..) => {},
            PropertyDeclaration::AnimationName(..) => {},
            PropertyDeclaration::AnimationPlayState(..) => {},
            PropertyDeclaration::AnimationTimeline(..) => {},
            PropertyDeclaration::AnimationTimingFunction(..) => {},
            PropertyDeclaration::BackdropFilter(..) => {},
            PropertyDeclaration::BackgroundAttachment(..) => {},
            PropertyDeclaration::BackgroundBlendMode(..) => {},
            PropertyDeclaration::BackgroundClip(..) => {},
            PropertyDeclaration::BackgroundImage(..) => {},
            PropertyDeclaration::BackgroundOrigin(..) => {},
            PropertyDeclaration::BackgroundPositionX(..) => {},
            PropertyDeclaration::BackgroundPositionY(..) => {},
            PropertyDeclaration::BackgroundRepeat(..) => {},
            PropertyDeclaration::BackgroundSize(..) => {},
            PropertyDeclaration::BorderImageOutset(..) => {},
            PropertyDeclaration::BorderImageSlice(..) => {},
            PropertyDeclaration::BorderImageWidth(..) => {},
            PropertyDeclaration::BorderSpacing(..) => {},
            PropertyDeclaration::BoxShadow(..) => {},
            PropertyDeclaration::CaretColor(..) => {},
            PropertyDeclaration::Clip(..) => {},
            PropertyDeclaration::ClipPath(..) => {},
            PropertyDeclaration::Color(..) => {},
            PropertyDeclaration::ColorScheme(..) => {},
            PropertyDeclaration::ColumnWidth(..) => {},
            PropertyDeclaration::ContainerName(..) => {},
            PropertyDeclaration::Content(..) => {},
            PropertyDeclaration::CounterIncrement(..) => {},
            PropertyDeclaration::CounterReset(..) => {},
            PropertyDeclaration::CounterSet(..) => {},
            PropertyDeclaration::Cursor(..) => {},
            PropertyDeclaration::D(..) => {},
            PropertyDeclaration::Filter(..) => {},
            PropertyDeclaration::FlexBasis(..) => {},
            PropertyDeclaration::FontFamily(..) => {},
            PropertyDeclaration::FontFeatureSettings(..) => {},
            PropertyDeclaration::FontPalette(..) => {},
            PropertyDeclaration::FontSize(..) => {},
            PropertyDeclaration::FontVariantAlternates(..) => {},
            PropertyDeclaration::FontVariationSettings(..) => {},
            PropertyDeclaration::GridTemplateAreas(..) => {},
            PropertyDeclaration::HyphenateCharacter(..) => {},
            PropertyDeclaration::LetterSpacing(..) => {},
            PropertyDeclaration::LineHeight(..) => {},
            PropertyDeclaration::ListStyleType(..) => {},
            PropertyDeclaration::MaskClip(..) => {},
            PropertyDeclaration::MaskComposite(..) => {},
            PropertyDeclaration::MaskImage(..) => {},
            PropertyDeclaration::MaskMode(..) => {},
            PropertyDeclaration::MaskOrigin(..) => {},
            PropertyDeclaration::MaskPositionX(..) => {},
            PropertyDeclaration::MaskPositionY(..) => {},
            PropertyDeclaration::MaskRepeat(..) => {},
            PropertyDeclaration::MaskSize(..) => {},
            PropertyDeclaration::MozContextProperties(..) => {},
            PropertyDeclaration::OffsetAnchor(..) => {},
            PropertyDeclaration::OffsetPath(..) => {},
            PropertyDeclaration::OffsetPosition(..) => {},
            PropertyDeclaration::Page(..) => {},
            PropertyDeclaration::Perspective(..) => {},
            PropertyDeclaration::PositionAnchor(..) => {},
            PropertyDeclaration::PositionTryOptions(..) => {},
            PropertyDeclaration::Quotes(..) => {},
            PropertyDeclaration::Rotate(..) => {},
            PropertyDeclaration::Scale(..) => {},
            PropertyDeclaration::ScrollTimelineAxis(..) => {},
            PropertyDeclaration::ScrollTimelineName(..) => {},
            PropertyDeclaration::ScrollbarColor(..) => {},
            PropertyDeclaration::ShapeOutside(..) => {},
            PropertyDeclaration::Size(..) => {},
            PropertyDeclaration::StrokeDasharray(..) => {},
            PropertyDeclaration::StrokeDashoffset(..) => {},
            PropertyDeclaration::StrokeWidth(..) => {},
            PropertyDeclaration::TabSize(..) => {},
            PropertyDeclaration::TextDecorationThickness(..) => {},
            PropertyDeclaration::TextEmphasisStyle(..) => {},
            PropertyDeclaration::TextIndent(..) => {},
            PropertyDeclaration::TextOverflow(..) => {},
            PropertyDeclaration::TextShadow(..) => {},
            PropertyDeclaration::TransitionBehavior(..) => {},
            PropertyDeclaration::TransitionDelay(..) => {},
            PropertyDeclaration::TransitionDuration(..) => {},
            PropertyDeclaration::TransitionProperty(..) => {},
            PropertyDeclaration::TransitionTimingFunction(..) => {},
            PropertyDeclaration::Translate(..) => {},
            PropertyDeclaration::VerticalAlign(..) => {},
            PropertyDeclaration::ViewTimelineAxis(..) => {},
            PropertyDeclaration::ViewTimelineInset(..) => {},
            PropertyDeclaration::ViewTimelineName(..) => {},
            PropertyDeclaration::WebkitTextStrokeWidth(..) => {},
            PropertyDeclaration::WillChange(..) => {},
            PropertyDeclaration::WordSpacing(..) => {},
            PropertyDeclaration::XLang(..) => {},
            PropertyDeclaration::ObjectPosition(..) => {},
            PropertyDeclaration::PerspectiveOrigin(..) => {},
            PropertyDeclaration::Fill(..) => {},
            PropertyDeclaration::Stroke(..) => {},
            PropertyDeclaration::MozWindowTransformOrigin(..) => {},
            PropertyDeclaration::TransformOrigin(..) => {},
            PropertyDeclaration::GridTemplateColumns(..) => {},
            PropertyDeclaration::GridTemplateRows(..) => {},
            PropertyDeclaration::BorderImageSource(..) => {},
            PropertyDeclaration::ListStyleImage(..) => {},
            PropertyDeclaration::GridAutoColumns(..) => {},
            PropertyDeclaration::GridAutoRows(..) => {},
            PropertyDeclaration::MozWindowTransform(..) => {},
            PropertyDeclaration::Transform(..) => {},
            PropertyDeclaration::ColumnGap(..) => {},
            PropertyDeclaration::RowGap(..) => {},
            PropertyDeclaration::MarkerEnd(..) => {},
            PropertyDeclaration::MarkerMid(..) => {},
            PropertyDeclaration::MarkerStart(..) => {},
            PropertyDeclaration::ContainIntrinsicBlockSize(..) => {},
            PropertyDeclaration::ContainIntrinsicHeight(..) => {},
            PropertyDeclaration::ContainIntrinsicInlineSize(..) => {},
            PropertyDeclaration::ContainIntrinsicWidth(..) => {},
            PropertyDeclaration::GridColumnEnd(..) => {},
            PropertyDeclaration::GridColumnStart(..) => {},
            PropertyDeclaration::GridRowEnd(..) => {},
            PropertyDeclaration::GridRowStart(..) => {},
            PropertyDeclaration::MaxBlockSize(..) => {},
            PropertyDeclaration::MaxHeight(..) => {},
            PropertyDeclaration::MaxInlineSize(..) => {},
            PropertyDeclaration::MaxWidth(..) => {},
            PropertyDeclaration::Cx(..) => {},
            PropertyDeclaration::Cy(..) => {},
            PropertyDeclaration::OffsetDistance(..) => {},
            PropertyDeclaration::X(..) => {},
            PropertyDeclaration::Y(..) => {},
            PropertyDeclaration::BorderBottomLeftRadius(..) => {},
            PropertyDeclaration::BorderBottomRightRadius(..) => {},
            PropertyDeclaration::BorderEndEndRadius(..) => {},
            PropertyDeclaration::BorderEndStartRadius(..) => {},
            PropertyDeclaration::BorderStartEndRadius(..) => {},
            PropertyDeclaration::BorderStartStartRadius(..) => {},
            PropertyDeclaration::BorderTopLeftRadius(..) => {},
            PropertyDeclaration::BorderTopRightRadius(..) => {},
            PropertyDeclaration::BlockSize(..) => {},
            PropertyDeclaration::Height(..) => {},
            PropertyDeclaration::InlineSize(..) => {},
            PropertyDeclaration::MinBlockSize(..) => {},
            PropertyDeclaration::MinHeight(..) => {},
            PropertyDeclaration::MinInlineSize(..) => {},
            PropertyDeclaration::MinWidth(..) => {},
            PropertyDeclaration::Width(..) => {},
            PropertyDeclaration::BorderBlockEndWidth(..) => {},
            PropertyDeclaration::BorderBlockStartWidth(..) => {},
            PropertyDeclaration::BorderBottomWidth(..) => {},
            PropertyDeclaration::BorderInlineEndWidth(..) => {},
            PropertyDeclaration::BorderInlineStartWidth(..) => {},
            PropertyDeclaration::BorderLeftWidth(..) => {},
            PropertyDeclaration::BorderRightWidth(..) => {},
            PropertyDeclaration::BorderTopWidth(..) => {},
            PropertyDeclaration::ColumnRuleWidth(..) => {},
            PropertyDeclaration::OutlineWidth(..) => {},
            PropertyDeclaration::PaddingBlockEnd(..) => {},
            PropertyDeclaration::PaddingBlockStart(..) => {},
            PropertyDeclaration::PaddingBottom(..) => {},
            PropertyDeclaration::PaddingInlineEnd(..) => {},
            PropertyDeclaration::PaddingInlineStart(..) => {},
            PropertyDeclaration::PaddingLeft(..) => {},
            PropertyDeclaration::PaddingRight(..) => {},
            PropertyDeclaration::PaddingTop(..) => {},
            PropertyDeclaration::R(..) => {},
            PropertyDeclaration::ShapeMargin(..) => {},
            PropertyDeclaration::Rx(..) => {},
            PropertyDeclaration::Ry(..) => {},
            PropertyDeclaration::ScrollPaddingBlockEnd(..) => {},
            PropertyDeclaration::ScrollPaddingBlockStart(..) => {},
            PropertyDeclaration::ScrollPaddingBottom(..) => {},
            PropertyDeclaration::ScrollPaddingInlineEnd(..) => {},
            PropertyDeclaration::ScrollPaddingInlineStart(..) => {},
            PropertyDeclaration::ScrollPaddingLeft(..) => {},
            PropertyDeclaration::ScrollPaddingRight(..) => {},
            PropertyDeclaration::ScrollPaddingTop(..) => {},
            PropertyDeclaration::MozWindowInputRegionMargin(..) => {},
            PropertyDeclaration::OutlineOffset(..) => {},
            PropertyDeclaration::OverflowClipMargin(..) => {},
            PropertyDeclaration::ScrollMarginBlockEnd(..) => {},
            PropertyDeclaration::ScrollMarginBlockStart(..) => {},
            PropertyDeclaration::ScrollMarginBottom(..) => {},
            PropertyDeclaration::ScrollMarginInlineEnd(..) => {},
            PropertyDeclaration::ScrollMarginInlineStart(..) => {},
            PropertyDeclaration::ScrollMarginLeft(..) => {},
            PropertyDeclaration::ScrollMarginRight(..) => {},
            PropertyDeclaration::ScrollMarginTop(..) => {},
            PropertyDeclaration::Bottom(..) => {},
            PropertyDeclaration::InsetBlockEnd(..) => {},
            PropertyDeclaration::InsetBlockStart(..) => {},
            PropertyDeclaration::InsetInlineEnd(..) => {},
            PropertyDeclaration::InsetInlineStart(..) => {},
            PropertyDeclaration::Left(..) => {},
            PropertyDeclaration::MarginBlockEnd(..) => {},
            PropertyDeclaration::MarginBlockStart(..) => {},
            PropertyDeclaration::MarginBottom(..) => {},
            PropertyDeclaration::MarginInlineEnd(..) => {},
            PropertyDeclaration::MarginInlineStart(..) => {},
            PropertyDeclaration::MarginLeft(..) => {},
            PropertyDeclaration::MarginRight(..) => {},
            PropertyDeclaration::MarginTop(..) => {},
            PropertyDeclaration::Right(..) => {},
            PropertyDeclaration::TextUnderlineOffset(..) => {},
            PropertyDeclaration::Top(..) => {},
            PropertyDeclaration::BackgroundColor(..) => {},
            PropertyDeclaration::BorderBlockEndColor(..) => {},
            PropertyDeclaration::BorderBlockStartColor(..) => {},
            PropertyDeclaration::BorderBottomColor(..) => {},
            PropertyDeclaration::BorderInlineEndColor(..) => {},
            PropertyDeclaration::BorderInlineStartColor(..) => {},
            PropertyDeclaration::BorderLeftColor(..) => {},
            PropertyDeclaration::BorderRightColor(..) => {},
            PropertyDeclaration::BorderTopColor(..) => {},
            PropertyDeclaration::ColumnRuleColor(..) => {},
            PropertyDeclaration::FloodColor(..) => {},
            PropertyDeclaration::LightingColor(..) => {},
            PropertyDeclaration::OutlineColor(..) => {},
            PropertyDeclaration::StopColor(..) => {},
            PropertyDeclaration::TextDecorationColor(..) => {},
            PropertyDeclaration::TextEmphasisColor(..) => {},
            PropertyDeclaration::WebkitTextFillColor(..) => {},
            PropertyDeclaration::WebkitTextStrokeColor(..) => {},
        }

        let mut ret = self.clone();


        unsafe {
            let longhand_id = *(&mut ret as *mut _ as *mut LonghandId);

            debug_assert_eq!(
                PropertyDeclarationId::Longhand(longhand_id),
                ret.id()
            );

            // This is just fine because PropertyDeclaration and LonghandId
            // have corresponding discriminants.
            *(&mut ret as *mut _ as *mut LonghandId) = longhand_id.to_physical(wm);

            debug_assert_eq!(
                PropertyDeclarationId::Longhand(longhand_id.to_physical(wm)),
                ret.id()
            );
        }

        ret
    }

    /// Returns whether or not the property is set by a system font
    pub fn get_system(&self) -> Option<SystemFont> {
        match *self {
                PropertyDeclaration::FontFamily(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontSize(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontStyle(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontStretch(ref prop) => {
                    prop.get_system()
                }
                PropertyDeclaration::FontWeight(ref prop) => {
                    prop.get_system()
                }
            _ => None,
        }
    }
}

#[cfg(feature = "gecko")]
pub use super::gecko::style_structs;

/// The module where all the style structs are defined.
#[cfg(feature = "servo")]
pub mod style_structs {
    use fxhash::FxHasher;
    use super::longhands;
    use std::hash::{Hash, Hasher};
    use crate::logical_geometry::WritingMode;
    use crate::media_queries::Device;
    use crate::values::computed::NonNegativeLength;

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Background style struct.
        pub struct Background {
                    /// The background-color computed value.
                    pub background_color: longhands::background_color::computed_value::T,
                    /// The background-image computed value.
                    pub background_image: longhands::background_image::computed_value::T,
                    /// The background-position-x computed value.
                    pub background_position_x: longhands::background_position_x::computed_value::T,
                    /// The background-position-y computed value.
                    pub background_position_y: longhands::background_position_y::computed_value::T,
                    /// The background-repeat computed value.
                    pub background_repeat: longhands::background_repeat::computed_value::T,
                    /// The background-attachment computed value.
                    pub background_attachment: longhands::background_attachment::computed_value::T,
                    /// The background-clip computed value.
                    pub background_clip: longhands::background_clip::computed_value::T,
                    /// The background-origin computed value.
                    pub background_origin: longhands::background_origin::computed_value::T,
                    /// The background-size computed value.
                    pub background_size: longhands::background_size::computed_value::T,
                    /// The background-blend-mode computed value.
                    pub background_blend_mode: longhands::background_blend_mode::computed_value::T,
        }

        impl Background {
                        /// Set background-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_color(&mut self, v: longhands::background_color::computed_value::T) {
                            self.background_color = v;
                        }
                        /// Set background-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_color_from(&mut self, other: &Self) {
                            self.background_color = other.background_color.clone();
                        }
                    /// Reset background-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_color(&mut self, other: &Self) {
                        self.copy_background_color_from(other)
                    }

                    /// Get the computed value for background-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_color(&self) -> longhands::background_color::computed_value::T {
                        self.background_color.clone()
                    }
                        /// Set background-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_image(&mut self, v: longhands::background_image::computed_value::T) {
                            self.background_image = v;
                        }
                        /// Set background-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_image_from(&mut self, other: &Self) {
                            self.background_image = other.background_image.clone();
                        }
                    /// Reset background-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_image(&mut self, other: &Self) {
                        self.copy_background_image_from(other)
                    }

                    /// Get the computed value for background-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_image(&self) -> longhands::background_image::computed_value::T {
                        self.background_image.clone()
                    }
                        /// Set background-position-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_position_x(&mut self, v: longhands::background_position_x::computed_value::T) {
                            self.background_position_x = v;
                        }
                        /// Set background-position-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_position_x_from(&mut self, other: &Self) {
                            self.background_position_x = other.background_position_x.clone();
                        }
                    /// Reset background-position-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_position_x(&mut self, other: &Self) {
                        self.copy_background_position_x_from(other)
                    }

                    /// Get the computed value for background-position-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_position_x(&self) -> longhands::background_position_x::computed_value::T {
                        self.background_position_x.clone()
                    }
                        /// Set background-position-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_position_y(&mut self, v: longhands::background_position_y::computed_value::T) {
                            self.background_position_y = v;
                        }
                        /// Set background-position-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_position_y_from(&mut self, other: &Self) {
                            self.background_position_y = other.background_position_y.clone();
                        }
                    /// Reset background-position-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_position_y(&mut self, other: &Self) {
                        self.copy_background_position_y_from(other)
                    }

                    /// Get the computed value for background-position-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_position_y(&self) -> longhands::background_position_y::computed_value::T {
                        self.background_position_y.clone()
                    }
                        /// Set background-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_repeat(&mut self, v: longhands::background_repeat::computed_value::T) {
                            self.background_repeat = v;
                        }
                        /// Set background-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_repeat_from(&mut self, other: &Self) {
                            self.background_repeat = other.background_repeat.clone();
                        }
                    /// Reset background-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_repeat(&mut self, other: &Self) {
                        self.copy_background_repeat_from(other)
                    }

                    /// Get the computed value for background-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_repeat(&self) -> longhands::background_repeat::computed_value::T {
                        self.background_repeat.clone()
                    }
                        /// Set background-attachment.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_attachment(&mut self, v: longhands::background_attachment::computed_value::T) {
                            self.background_attachment = v;
                        }
                        /// Set background-attachment from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_attachment_from(&mut self, other: &Self) {
                            self.background_attachment = other.background_attachment.clone();
                        }
                    /// Reset background-attachment from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_attachment(&mut self, other: &Self) {
                        self.copy_background_attachment_from(other)
                    }

                    /// Get the computed value for background-attachment.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_attachment(&self) -> longhands::background_attachment::computed_value::T {
                        self.background_attachment.clone()
                    }
                        /// Set background-clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_clip(&mut self, v: longhands::background_clip::computed_value::T) {
                            self.background_clip = v;
                        }
                        /// Set background-clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_clip_from(&mut self, other: &Self) {
                            self.background_clip = other.background_clip.clone();
                        }
                    /// Reset background-clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_clip(&mut self, other: &Self) {
                        self.copy_background_clip_from(other)
                    }

                    /// Get the computed value for background-clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_clip(&self) -> longhands::background_clip::computed_value::T {
                        self.background_clip.clone()
                    }
                        /// Set background-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_origin(&mut self, v: longhands::background_origin::computed_value::T) {
                            self.background_origin = v;
                        }
                        /// Set background-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_origin_from(&mut self, other: &Self) {
                            self.background_origin = other.background_origin.clone();
                        }
                    /// Reset background-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_origin(&mut self, other: &Self) {
                        self.copy_background_origin_from(other)
                    }

                    /// Get the computed value for background-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_origin(&self) -> longhands::background_origin::computed_value::T {
                        self.background_origin.clone()
                    }
                        /// Set background-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_size(&mut self, v: longhands::background_size::computed_value::T) {
                            self.background_size = v;
                        }
                        /// Set background-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_size_from(&mut self, other: &Self) {
                            self.background_size = other.background_size.clone();
                        }
                    /// Reset background-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_size(&mut self, other: &Self) {
                        self.copy_background_size_from(other)
                    }

                    /// Get the computed value for background-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_size(&self) -> longhands::background_size::computed_value::T {
                        self.background_size.clone()
                    }
                        /// Set background-blend-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_background_blend_mode(&mut self, v: longhands::background_blend_mode::computed_value::T) {
                            self.background_blend_mode = v;
                        }
                        /// Set background-blend-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_background_blend_mode_from(&mut self, other: &Self) {
                            self.background_blend_mode = other.background_blend_mode.clone();
                        }
                    /// Reset background-blend-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_background_blend_mode(&mut self, other: &Self) {
                        self.copy_background_blend_mode_from(other)
                    }

                    /// Get the computed value for background-blend-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_background_blend_mode(&self) -> longhands::background_blend_mode::computed_value::T {
                        self.background_blend_mode.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Border style struct.
        pub struct Border {
                    /// The border-top-color computed value.
                    pub border_top_color: longhands::border_top_color::computed_value::T,
                    /// The border-top-style computed value.
                    pub border_top_style: longhands::border_top_style::computed_value::T,
                    /// The border-top-width computed value.
                    pub border_top_width: longhands::border_top_width::computed_value::T,
                    /// The border-right-color computed value.
                    pub border_right_color: longhands::border_right_color::computed_value::T,
                    /// The border-right-style computed value.
                    pub border_right_style: longhands::border_right_style::computed_value::T,
                    /// The border-right-width computed value.
                    pub border_right_width: longhands::border_right_width::computed_value::T,
                    /// The border-bottom-color computed value.
                    pub border_bottom_color: longhands::border_bottom_color::computed_value::T,
                    /// The border-bottom-style computed value.
                    pub border_bottom_style: longhands::border_bottom_style::computed_value::T,
                    /// The border-bottom-width computed value.
                    pub border_bottom_width: longhands::border_bottom_width::computed_value::T,
                    /// The border-left-color computed value.
                    pub border_left_color: longhands::border_left_color::computed_value::T,
                    /// The border-left-style computed value.
                    pub border_left_style: longhands::border_left_style::computed_value::T,
                    /// The border-left-width computed value.
                    pub border_left_width: longhands::border_left_width::computed_value::T,
                    /// The border-top-left-radius computed value.
                    pub border_top_left_radius: longhands::border_top_left_radius::computed_value::T,
                    /// The border-top-right-radius computed value.
                    pub border_top_right_radius: longhands::border_top_right_radius::computed_value::T,
                    /// The border-bottom-right-radius computed value.
                    pub border_bottom_right_radius: longhands::border_bottom_right_radius::computed_value::T,
                    /// The border-bottom-left-radius computed value.
                    pub border_bottom_left_radius: longhands::border_bottom_left_radius::computed_value::T,
                    /// The box-decoration-break computed value.
                    pub box_decoration_break: longhands::box_decoration_break::computed_value::T,
                    /// The -moz-float-edge computed value.
                    pub _moz_float_edge: longhands::_moz_float_edge::computed_value::T,
                    /// The border-image-source computed value.
                    pub border_image_source: longhands::border_image_source::computed_value::T,
                    /// The border-image-outset computed value.
                    pub border_image_outset: longhands::border_image_outset::computed_value::T,
                    /// The border-image-repeat computed value.
                    pub border_image_repeat: longhands::border_image_repeat::computed_value::T,
                    /// The border-image-width computed value.
                    pub border_image_width: longhands::border_image_width::computed_value::T,
                    /// The border-image-slice computed value.
                    pub border_image_slice: longhands::border_image_slice::computed_value::T,
        }

        impl Border {
                        /// Set border-top-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_color(&mut self, v: longhands::border_top_color::computed_value::T) {
                            self.border_top_color = v;
                        }
                        /// Set border-top-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_color_from(&mut self, other: &Self) {
                            self.border_top_color = other.border_top_color.clone();
                        }
                    /// Reset border-top-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_color(&mut self, other: &Self) {
                        self.copy_border_top_color_from(other)
                    }

                    /// Get the computed value for border-top-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_color(&self) -> longhands::border_top_color::computed_value::T {
                        self.border_top_color.clone()
                    }
                        /// Set border-top-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_style(&mut self, v: longhands::border_top_style::computed_value::T) {
                            self.border_top_style = v;
                        }
                        /// Set border-top-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_style_from(&mut self, other: &Self) {
                            self.border_top_style = other.border_top_style.clone();
                        }
                    /// Reset border-top-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_style(&mut self, other: &Self) {
                        self.copy_border_top_style_from(other)
                    }

                    /// Get the computed value for border-top-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_style(&self) -> longhands::border_top_style::computed_value::T {
                        self.border_top_style.clone()
                    }
                        /// Set border-top-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_width(&mut self, v: longhands::border_top_width::computed_value::T) {
                            self.border_top_width = v;
                        }
                        /// Set border-top-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_width_from(&mut self, other: &Self) {
                            self.border_top_width = other.border_top_width.clone();
                        }
                    /// Reset border-top-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_width(&mut self, other: &Self) {
                        self.copy_border_top_width_from(other)
                    }

                    /// Get the computed value for border-top-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_width(&self) -> longhands::border_top_width::computed_value::T {
                        self.border_top_width.clone()
                    }
                        /// Set border-right-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_color(&mut self, v: longhands::border_right_color::computed_value::T) {
                            self.border_right_color = v;
                        }
                        /// Set border-right-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_color_from(&mut self, other: &Self) {
                            self.border_right_color = other.border_right_color.clone();
                        }
                    /// Reset border-right-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_color(&mut self, other: &Self) {
                        self.copy_border_right_color_from(other)
                    }

                    /// Get the computed value for border-right-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_color(&self) -> longhands::border_right_color::computed_value::T {
                        self.border_right_color.clone()
                    }
                        /// Set border-right-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_style(&mut self, v: longhands::border_right_style::computed_value::T) {
                            self.border_right_style = v;
                        }
                        /// Set border-right-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_style_from(&mut self, other: &Self) {
                            self.border_right_style = other.border_right_style.clone();
                        }
                    /// Reset border-right-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_style(&mut self, other: &Self) {
                        self.copy_border_right_style_from(other)
                    }

                    /// Get the computed value for border-right-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_style(&self) -> longhands::border_right_style::computed_value::T {
                        self.border_right_style.clone()
                    }
                        /// Set border-right-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_right_width(&mut self, v: longhands::border_right_width::computed_value::T) {
                            self.border_right_width = v;
                        }
                        /// Set border-right-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_right_width_from(&mut self, other: &Self) {
                            self.border_right_width = other.border_right_width.clone();
                        }
                    /// Reset border-right-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_right_width(&mut self, other: &Self) {
                        self.copy_border_right_width_from(other)
                    }

                    /// Get the computed value for border-right-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_right_width(&self) -> longhands::border_right_width::computed_value::T {
                        self.border_right_width.clone()
                    }
                        /// Set border-bottom-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_color(&mut self, v: longhands::border_bottom_color::computed_value::T) {
                            self.border_bottom_color = v;
                        }
                        /// Set border-bottom-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_color_from(&mut self, other: &Self) {
                            self.border_bottom_color = other.border_bottom_color.clone();
                        }
                    /// Reset border-bottom-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_color(&mut self, other: &Self) {
                        self.copy_border_bottom_color_from(other)
                    }

                    /// Get the computed value for border-bottom-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_color(&self) -> longhands::border_bottom_color::computed_value::T {
                        self.border_bottom_color.clone()
                    }
                        /// Set border-bottom-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_style(&mut self, v: longhands::border_bottom_style::computed_value::T) {
                            self.border_bottom_style = v;
                        }
                        /// Set border-bottom-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_style_from(&mut self, other: &Self) {
                            self.border_bottom_style = other.border_bottom_style.clone();
                        }
                    /// Reset border-bottom-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_style(&mut self, other: &Self) {
                        self.copy_border_bottom_style_from(other)
                    }

                    /// Get the computed value for border-bottom-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_style(&self) -> longhands::border_bottom_style::computed_value::T {
                        self.border_bottom_style.clone()
                    }
                        /// Set border-bottom-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_width(&mut self, v: longhands::border_bottom_width::computed_value::T) {
                            self.border_bottom_width = v;
                        }
                        /// Set border-bottom-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_width_from(&mut self, other: &Self) {
                            self.border_bottom_width = other.border_bottom_width.clone();
                        }
                    /// Reset border-bottom-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_width(&mut self, other: &Self) {
                        self.copy_border_bottom_width_from(other)
                    }

                    /// Get the computed value for border-bottom-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_width(&self) -> longhands::border_bottom_width::computed_value::T {
                        self.border_bottom_width.clone()
                    }
                        /// Set border-left-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_color(&mut self, v: longhands::border_left_color::computed_value::T) {
                            self.border_left_color = v;
                        }
                        /// Set border-left-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_color_from(&mut self, other: &Self) {
                            self.border_left_color = other.border_left_color.clone();
                        }
                    /// Reset border-left-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_color(&mut self, other: &Self) {
                        self.copy_border_left_color_from(other)
                    }

                    /// Get the computed value for border-left-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_color(&self) -> longhands::border_left_color::computed_value::T {
                        self.border_left_color.clone()
                    }
                        /// Set border-left-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_style(&mut self, v: longhands::border_left_style::computed_value::T) {
                            self.border_left_style = v;
                        }
                        /// Set border-left-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_style_from(&mut self, other: &Self) {
                            self.border_left_style = other.border_left_style.clone();
                        }
                    /// Reset border-left-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_style(&mut self, other: &Self) {
                        self.copy_border_left_style_from(other)
                    }

                    /// Get the computed value for border-left-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_style(&self) -> longhands::border_left_style::computed_value::T {
                        self.border_left_style.clone()
                    }
                        /// Set border-left-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_left_width(&mut self, v: longhands::border_left_width::computed_value::T) {
                            self.border_left_width = v;
                        }
                        /// Set border-left-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_left_width_from(&mut self, other: &Self) {
                            self.border_left_width = other.border_left_width.clone();
                        }
                    /// Reset border-left-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_left_width(&mut self, other: &Self) {
                        self.copy_border_left_width_from(other)
                    }

                    /// Get the computed value for border-left-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_left_width(&self) -> longhands::border_left_width::computed_value::T {
                        self.border_left_width.clone()
                    }
                        /// Set border-top-left-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_left_radius(&mut self, v: longhands::border_top_left_radius::computed_value::T) {
                            self.border_top_left_radius = v;
                        }
                        /// Set border-top-left-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_left_radius_from(&mut self, other: &Self) {
                            self.border_top_left_radius = other.border_top_left_radius.clone();
                        }
                    /// Reset border-top-left-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_left_radius(&mut self, other: &Self) {
                        self.copy_border_top_left_radius_from(other)
                    }

                    /// Get the computed value for border-top-left-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_left_radius(&self) -> longhands::border_top_left_radius::computed_value::T {
                        self.border_top_left_radius.clone()
                    }
                        /// Set border-top-right-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_top_right_radius(&mut self, v: longhands::border_top_right_radius::computed_value::T) {
                            self.border_top_right_radius = v;
                        }
                        /// Set border-top-right-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_top_right_radius_from(&mut self, other: &Self) {
                            self.border_top_right_radius = other.border_top_right_radius.clone();
                        }
                    /// Reset border-top-right-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_top_right_radius(&mut self, other: &Self) {
                        self.copy_border_top_right_radius_from(other)
                    }

                    /// Get the computed value for border-top-right-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_top_right_radius(&self) -> longhands::border_top_right_radius::computed_value::T {
                        self.border_top_right_radius.clone()
                    }
                        /// Set border-bottom-right-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_right_radius(&mut self, v: longhands::border_bottom_right_radius::computed_value::T) {
                            self.border_bottom_right_radius = v;
                        }
                        /// Set border-bottom-right-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_right_radius_from(&mut self, other: &Self) {
                            self.border_bottom_right_radius = other.border_bottom_right_radius.clone();
                        }
                    /// Reset border-bottom-right-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_right_radius(&mut self, other: &Self) {
                        self.copy_border_bottom_right_radius_from(other)
                    }

                    /// Get the computed value for border-bottom-right-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_right_radius(&self) -> longhands::border_bottom_right_radius::computed_value::T {
                        self.border_bottom_right_radius.clone()
                    }
                        /// Set border-bottom-left-radius.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_bottom_left_radius(&mut self, v: longhands::border_bottom_left_radius::computed_value::T) {
                            self.border_bottom_left_radius = v;
                        }
                        /// Set border-bottom-left-radius from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_bottom_left_radius_from(&mut self, other: &Self) {
                            self.border_bottom_left_radius = other.border_bottom_left_radius.clone();
                        }
                    /// Reset border-bottom-left-radius from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_bottom_left_radius(&mut self, other: &Self) {
                        self.copy_border_bottom_left_radius_from(other)
                    }

                    /// Get the computed value for border-bottom-left-radius.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_bottom_left_radius(&self) -> longhands::border_bottom_left_radius::computed_value::T {
                        self.border_bottom_left_radius.clone()
                    }
                        /// Set box-decoration-break.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_decoration_break(&mut self, v: longhands::box_decoration_break::computed_value::T) {
                            self.box_decoration_break = v;
                        }
                        /// Set box-decoration-break from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_decoration_break_from(&mut self, other: &Self) {
                            self.box_decoration_break = other.box_decoration_break.clone();
                        }
                    /// Reset box-decoration-break from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_decoration_break(&mut self, other: &Self) {
                        self.copy_box_decoration_break_from(other)
                    }

                    /// Get the computed value for box-decoration-break.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_decoration_break(&self) -> longhands::box_decoration_break::computed_value::T {
                        self.box_decoration_break.clone()
                    }
                        /// Set -moz-float-edge.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_float_edge(&mut self, v: longhands::_moz_float_edge::computed_value::T) {
                            self._moz_float_edge = v;
                        }
                        /// Set -moz-float-edge from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_float_edge_from(&mut self, other: &Self) {
                            self._moz_float_edge = other._moz_float_edge.clone();
                        }
                    /// Reset -moz-float-edge from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_float_edge(&mut self, other: &Self) {
                        self.copy__moz_float_edge_from(other)
                    }

                    /// Get the computed value for -moz-float-edge.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_float_edge(&self) -> longhands::_moz_float_edge::computed_value::T {
                        self._moz_float_edge.clone()
                    }
                        /// Set border-image-source.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_source(&mut self, v: longhands::border_image_source::computed_value::T) {
                            self.border_image_source = v;
                        }
                        /// Set border-image-source from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_source_from(&mut self, other: &Self) {
                            self.border_image_source = other.border_image_source.clone();
                        }
                    /// Reset border-image-source from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_source(&mut self, other: &Self) {
                        self.copy_border_image_source_from(other)
                    }

                    /// Get the computed value for border-image-source.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_source(&self) -> longhands::border_image_source::computed_value::T {
                        self.border_image_source.clone()
                    }
                        /// Set border-image-outset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_outset(&mut self, v: longhands::border_image_outset::computed_value::T) {
                            self.border_image_outset = v;
                        }
                        /// Set border-image-outset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_outset_from(&mut self, other: &Self) {
                            self.border_image_outset = other.border_image_outset.clone();
                        }
                    /// Reset border-image-outset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_outset(&mut self, other: &Self) {
                        self.copy_border_image_outset_from(other)
                    }

                    /// Get the computed value for border-image-outset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_outset(&self) -> longhands::border_image_outset::computed_value::T {
                        self.border_image_outset.clone()
                    }
                        /// Set border-image-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_repeat(&mut self, v: longhands::border_image_repeat::computed_value::T) {
                            self.border_image_repeat = v;
                        }
                        /// Set border-image-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_repeat_from(&mut self, other: &Self) {
                            self.border_image_repeat = other.border_image_repeat.clone();
                        }
                    /// Reset border-image-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_repeat(&mut self, other: &Self) {
                        self.copy_border_image_repeat_from(other)
                    }

                    /// Get the computed value for border-image-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_repeat(&self) -> longhands::border_image_repeat::computed_value::T {
                        self.border_image_repeat.clone()
                    }
                        /// Set border-image-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_width(&mut self, v: longhands::border_image_width::computed_value::T) {
                            self.border_image_width = v;
                        }
                        /// Set border-image-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_width_from(&mut self, other: &Self) {
                            self.border_image_width = other.border_image_width.clone();
                        }
                    /// Reset border-image-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_width(&mut self, other: &Self) {
                        self.copy_border_image_width_from(other)
                    }

                    /// Get the computed value for border-image-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_width(&self) -> longhands::border_image_width::computed_value::T {
                        self.border_image_width.clone()
                    }
                        /// Set border-image-slice.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_image_slice(&mut self, v: longhands::border_image_slice::computed_value::T) {
                            self.border_image_slice = v;
                        }
                        /// Set border-image-slice from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_image_slice_from(&mut self, other: &Self) {
                            self.border_image_slice = other.border_image_slice.clone();
                        }
                    /// Reset border-image-slice from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_image_slice(&mut self, other: &Self) {
                        self.copy_border_image_slice_from(other)
                    }

                    /// Get the computed value for border-image-slice.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_image_slice(&self) -> longhands::border_image_slice::computed_value::T {
                        self.border_image_slice.clone()
                    }
                    /// Whether the border-top property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_top_has_nonzero_width(&self) -> bool {
                        use crate::Zero;
                        !self.border_top_width.is_zero()
                    }
                    /// Whether the border-right property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_right_has_nonzero_width(&self) -> bool {
                        use crate::Zero;
                        !self.border_right_width.is_zero()
                    }
                    /// Whether the border-bottom property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_bottom_has_nonzero_width(&self) -> bool {
                        use crate::Zero;
                        !self.border_bottom_width.is_zero()
                    }
                    /// Whether the border-left property has nonzero width.
                    #[allow(non_snake_case)]
                    pub fn border_left_has_nonzero_width(&self) -> bool {
                        use crate::Zero;
                        !self.border_left_width.is_zero()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Box style struct.
        pub struct Box {
                    /// The display computed value.
                    pub display: longhands::display::computed_value::T,
                    /// The -moz-top-layer computed value.
                    pub _moz_top_layer: longhands::_moz_top_layer::computed_value::T,
                    /// The position computed value.
                    pub position: longhands::position::computed_value::T,
                    /// The anchor-name computed value.
                    pub anchor_name: longhands::anchor_name::computed_value::T,
                    /// The anchor-scope computed value.
                    pub anchor_scope: longhands::anchor_scope::computed_value::T,
                    /// The float computed value.
                    pub float: longhands::float::computed_value::T,
                    /// The clear computed value.
                    pub clear: longhands::clear::computed_value::T,
                    /// The vertical-align computed value.
                    pub vertical_align: longhands::vertical_align::computed_value::T,
                    /// The baseline-source computed value.
                    pub baseline_source: longhands::baseline_source::computed_value::T,
                    /// The overflow-clip-box-inline computed value.
                    pub overflow_clip_box_inline: longhands::overflow_clip_box_inline::computed_value::T,
                    /// The overflow-clip-box-block computed value.
                    pub overflow_clip_box_block: longhands::overflow_clip_box_block::computed_value::T,
                    /// The overflow-y computed value.
                    pub overflow_y: longhands::overflow_y::computed_value::T,
                    /// The overflow-x computed value.
                    pub overflow_x: longhands::overflow_x::computed_value::T,
                    /// The overflow-anchor computed value.
                    pub overflow_anchor: longhands::overflow_anchor::computed_value::T,
                    /// The transform computed value.
                    pub transform: longhands::transform::computed_value::T,
                    /// The rotate computed value.
                    pub rotate: longhands::rotate::computed_value::T,
                    /// The scale computed value.
                    pub scale: longhands::scale::computed_value::T,
                    /// The translate computed value.
                    pub translate: longhands::translate::computed_value::T,
                    /// The offset-path computed value.
                    pub offset_path: longhands::offset_path::computed_value::T,
                    /// The offset-distance computed value.
                    pub offset_distance: longhands::offset_distance::computed_value::T,
                    /// The offset-rotate computed value.
                    pub offset_rotate: longhands::offset_rotate::computed_value::T,
                    /// The offset-anchor computed value.
                    pub offset_anchor: longhands::offset_anchor::computed_value::T,
                    /// The offset-position computed value.
                    pub offset_position: longhands::offset_position::computed_value::T,
                    /// The scroll-behavior computed value.
                    pub scroll_behavior: longhands::scroll_behavior::computed_value::T,
                    /// The scroll-snap-align computed value.
                    pub scroll_snap_align: longhands::scroll_snap_align::computed_value::T,
                    /// The scroll-snap-type computed value.
                    pub scroll_snap_type: longhands::scroll_snap_type::computed_value::T,
                    /// The scroll-snap-stop computed value.
                    pub scroll_snap_stop: longhands::scroll_snap_stop::computed_value::T,
                    /// The overscroll-behavior-y computed value.
                    pub overscroll_behavior_y: longhands::overscroll_behavior_y::computed_value::T,
                    /// The overscroll-behavior-x computed value.
                    pub overscroll_behavior_x: longhands::overscroll_behavior_x::computed_value::T,
                    /// The isolation computed value.
                    pub isolation: longhands::isolation::computed_value::T,
                    /// The break-after computed value.
                    pub break_after: longhands::break_after::computed_value::T,
                    /// The break-before computed value.
                    pub break_before: longhands::break_before::computed_value::T,
                    /// The break-inside computed value.
                    pub break_inside: longhands::break_inside::computed_value::T,
                    /// The resize computed value.
                    pub resize: longhands::resize::computed_value::T,
                    /// The perspective computed value.
                    pub perspective: longhands::perspective::computed_value::T,
                    /// The perspective-origin computed value.
                    pub perspective_origin: longhands::perspective_origin::computed_value::T,
                    /// The backface-visibility computed value.
                    pub backface_visibility: longhands::backface_visibility::computed_value::T,
                    /// The transform-box computed value.
                    pub transform_box: longhands::transform_box::computed_value::T,
                    /// The transform-style computed value.
                    pub transform_style: longhands::transform_style::computed_value::T,
                    /// The transform-origin computed value.
                    pub transform_origin: longhands::transform_origin::computed_value::T,
                    /// The contain computed value.
                    pub contain: longhands::contain::computed_value::T,
                    /// The content-visibility computed value.
                    pub content_visibility: longhands::content_visibility::computed_value::T,
                    /// The container-type computed value.
                    pub container_type: longhands::container_type::computed_value::T,
                    /// The container-name computed value.
                    pub container_name: longhands::container_name::computed_value::T,
                    /// The appearance computed value.
                    pub appearance: longhands::appearance::computed_value::T,
                    /// The -moz-default-appearance computed value.
                    pub _moz_default_appearance: longhands::_moz_default_appearance::computed_value::T,
                    /// The -moz-orient computed value.
                    pub _moz_orient: longhands::_moz_orient::computed_value::T,
                    /// The will-change computed value.
                    pub will_change: longhands::will_change::computed_value::T,
                    /// The shape-image-threshold computed value.
                    pub shape_image_threshold: longhands::shape_image_threshold::computed_value::T,
                    /// The shape-margin computed value.
                    pub shape_margin: longhands::shape_margin::computed_value::T,
                    /// The shape-outside computed value.
                    pub shape_outside: longhands::shape_outside::computed_value::T,
                    /// The touch-action computed value.
                    pub touch_action: longhands::touch_action::computed_value::T,
                    /// The -webkit-line-clamp computed value.
                    pub _webkit_line_clamp: longhands::_webkit_line_clamp::computed_value::T,
                    /// The scrollbar-gutter computed value.
                    pub scrollbar_gutter: longhands::scrollbar_gutter::computed_value::T,
                    /// The zoom computed value.
                    pub zoom: longhands::zoom::computed_value::T,
                /// The display value specified by the CSS stylesheets (without any style adjustments),
                /// which is needed for hypothetical layout boxes.
                pub original_display: longhands::display::computed_value::T,
        }

        impl Box {
                        /// Set `display`.
                        ///
                        /// We need to keep track of the original display for hypothetical boxes,
                        /// so we need to special-case this.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_display(&mut self, v: longhands::display::computed_value::T) {
                            self.display = v;
                            self.original_display = v;
                        }
                        /// Set `display` from other struct.
                        ///
                        /// Same as `set_display` above.
                        /// Thus, we need to special-case this.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_display_from(&mut self, other: &Self) {
                            self.display = other.display.clone();
                            self.original_display = other.display.clone();
                        }
                    /// Reset display from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_display(&mut self, other: &Self) {
                        self.copy_display_from(other)
                    }

                    /// Get the computed value for display.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_display(&self) -> longhands::display::computed_value::T {
                        self.display.clone()
                    }
                        /// Set -moz-top-layer.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_top_layer(&mut self, v: longhands::_moz_top_layer::computed_value::T) {
                            self._moz_top_layer = v;
                        }
                        /// Set -moz-top-layer from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_top_layer_from(&mut self, other: &Self) {
                            self._moz_top_layer = other._moz_top_layer.clone();
                        }
                    /// Reset -moz-top-layer from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_top_layer(&mut self, other: &Self) {
                        self.copy__moz_top_layer_from(other)
                    }

                    /// Get the computed value for -moz-top-layer.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_top_layer(&self) -> longhands::_moz_top_layer::computed_value::T {
                        self._moz_top_layer.clone()
                    }
                        /// Set position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_position(&mut self, v: longhands::position::computed_value::T) {
                            self.position = v;
                        }
                        /// Set position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_position_from(&mut self, other: &Self) {
                            self.position = other.position.clone();
                        }
                    /// Reset position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_position(&mut self, other: &Self) {
                        self.copy_position_from(other)
                    }

                    /// Get the computed value for position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_position(&self) -> longhands::position::computed_value::T {
                        self.position.clone()
                    }
                        /// Set anchor-name.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_anchor_name(&mut self, v: longhands::anchor_name::computed_value::T) {
                            self.anchor_name = v;
                        }
                        /// Set anchor-name from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_anchor_name_from(&mut self, other: &Self) {
                            self.anchor_name = other.anchor_name.clone();
                        }
                    /// Reset anchor-name from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_anchor_name(&mut self, other: &Self) {
                        self.copy_anchor_name_from(other)
                    }

                    /// Get the computed value for anchor-name.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_anchor_name(&self) -> longhands::anchor_name::computed_value::T {
                        self.anchor_name.clone()
                    }
                        /// Set anchor-scope.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_anchor_scope(&mut self, v: longhands::anchor_scope::computed_value::T) {
                            self.anchor_scope = v;
                        }
                        /// Set anchor-scope from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_anchor_scope_from(&mut self, other: &Self) {
                            self.anchor_scope = other.anchor_scope.clone();
                        }
                    /// Reset anchor-scope from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_anchor_scope(&mut self, other: &Self) {
                        self.copy_anchor_scope_from(other)
                    }

                    /// Get the computed value for anchor-scope.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_anchor_scope(&self) -> longhands::anchor_scope::computed_value::T {
                        self.anchor_scope.clone()
                    }
                        /// Set float.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_float(&mut self, v: longhands::float::computed_value::T) {
                            self.float = v;
                        }
                        /// Set float from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_float_from(&mut self, other: &Self) {
                            self.float = other.float.clone();
                        }
                    /// Reset float from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_float(&mut self, other: &Self) {
                        self.copy_float_from(other)
                    }

                    /// Get the computed value for float.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_float(&self) -> longhands::float::computed_value::T {
                        self.float.clone()
                    }
                        /// Set clear.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clear(&mut self, v: longhands::clear::computed_value::T) {
                            self.clear = v;
                        }
                        /// Set clear from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clear_from(&mut self, other: &Self) {
                            self.clear = other.clear.clone();
                        }
                    /// Reset clear from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clear(&mut self, other: &Self) {
                        self.copy_clear_from(other)
                    }

                    /// Get the computed value for clear.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clear(&self) -> longhands::clear::computed_value::T {
                        self.clear.clone()
                    }
                        /// Set vertical-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_vertical_align(&mut self, v: longhands::vertical_align::computed_value::T) {
                            self.vertical_align = v;
                        }
                        /// Set vertical-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_vertical_align_from(&mut self, other: &Self) {
                            self.vertical_align = other.vertical_align.clone();
                        }
                    /// Reset vertical-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_vertical_align(&mut self, other: &Self) {
                        self.copy_vertical_align_from(other)
                    }

                    /// Get the computed value for vertical-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_vertical_align(&self) -> longhands::vertical_align::computed_value::T {
                        self.vertical_align.clone()
                    }
                        /// Set baseline-source.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_baseline_source(&mut self, v: longhands::baseline_source::computed_value::T) {
                            self.baseline_source = v;
                        }
                        /// Set baseline-source from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_baseline_source_from(&mut self, other: &Self) {
                            self.baseline_source = other.baseline_source.clone();
                        }
                    /// Reset baseline-source from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_baseline_source(&mut self, other: &Self) {
                        self.copy_baseline_source_from(other)
                    }

                    /// Get the computed value for baseline-source.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_baseline_source(&self) -> longhands::baseline_source::computed_value::T {
                        self.baseline_source.clone()
                    }
                        /// Set overflow-clip-box-inline.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_clip_box_inline(&mut self, v: longhands::overflow_clip_box_inline::computed_value::T) {
                            self.overflow_clip_box_inline = v;
                        }
                        /// Set overflow-clip-box-inline from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_clip_box_inline_from(&mut self, other: &Self) {
                            self.overflow_clip_box_inline = other.overflow_clip_box_inline.clone();
                        }
                    /// Reset overflow-clip-box-inline from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_clip_box_inline(&mut self, other: &Self) {
                        self.copy_overflow_clip_box_inline_from(other)
                    }

                    /// Get the computed value for overflow-clip-box-inline.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_clip_box_inline(&self) -> longhands::overflow_clip_box_inline::computed_value::T {
                        self.overflow_clip_box_inline.clone()
                    }
                        /// Set overflow-clip-box-block.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_clip_box_block(&mut self, v: longhands::overflow_clip_box_block::computed_value::T) {
                            self.overflow_clip_box_block = v;
                        }
                        /// Set overflow-clip-box-block from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_clip_box_block_from(&mut self, other: &Self) {
                            self.overflow_clip_box_block = other.overflow_clip_box_block.clone();
                        }
                    /// Reset overflow-clip-box-block from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_clip_box_block(&mut self, other: &Self) {
                        self.copy_overflow_clip_box_block_from(other)
                    }

                    /// Get the computed value for overflow-clip-box-block.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_clip_box_block(&self) -> longhands::overflow_clip_box_block::computed_value::T {
                        self.overflow_clip_box_block.clone()
                    }
                        /// Set overflow-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_y(&mut self, v: longhands::overflow_y::computed_value::T) {
                            self.overflow_y = v;
                        }
                        /// Set overflow-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_y_from(&mut self, other: &Self) {
                            self.overflow_y = other.overflow_y.clone();
                        }
                    /// Reset overflow-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_y(&mut self, other: &Self) {
                        self.copy_overflow_y_from(other)
                    }

                    /// Get the computed value for overflow-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_y(&self) -> longhands::overflow_y::computed_value::T {
                        self.overflow_y.clone()
                    }
                        /// Set overflow-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_x(&mut self, v: longhands::overflow_x::computed_value::T) {
                            self.overflow_x = v;
                        }
                        /// Set overflow-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_x_from(&mut self, other: &Self) {
                            self.overflow_x = other.overflow_x.clone();
                        }
                    /// Reset overflow-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_x(&mut self, other: &Self) {
                        self.copy_overflow_x_from(other)
                    }

                    /// Get the computed value for overflow-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_x(&self) -> longhands::overflow_x::computed_value::T {
                        self.overflow_x.clone()
                    }
                        /// Set overflow-anchor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_anchor(&mut self, v: longhands::overflow_anchor::computed_value::T) {
                            self.overflow_anchor = v;
                        }
                        /// Set overflow-anchor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_anchor_from(&mut self, other: &Self) {
                            self.overflow_anchor = other.overflow_anchor.clone();
                        }
                    /// Reset overflow-anchor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_anchor(&mut self, other: &Self) {
                        self.copy_overflow_anchor_from(other)
                    }

                    /// Get the computed value for overflow-anchor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_anchor(&self) -> longhands::overflow_anchor::computed_value::T {
                        self.overflow_anchor.clone()
                    }
                        /// Set transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform(&mut self, v: longhands::transform::computed_value::T) {
                            self.transform = v;
                        }
                        /// Set transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_from(&mut self, other: &Self) {
                            self.transform = other.transform.clone();
                        }
                    /// Reset transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform(&mut self, other: &Self) {
                        self.copy_transform_from(other)
                    }

                    /// Get the computed value for transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform(&self) -> longhands::transform::computed_value::T {
                        self.transform.clone()
                    }
                        /// Set rotate.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_rotate(&mut self, v: longhands::rotate::computed_value::T) {
                            self.rotate = v;
                        }
                        /// Set rotate from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_rotate_from(&mut self, other: &Self) {
                            self.rotate = other.rotate.clone();
                        }
                    /// Reset rotate from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_rotate(&mut self, other: &Self) {
                        self.copy_rotate_from(other)
                    }

                    /// Get the computed value for rotate.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_rotate(&self) -> longhands::rotate::computed_value::T {
                        self.rotate.clone()
                    }
                        /// Set scale.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scale(&mut self, v: longhands::scale::computed_value::T) {
                            self.scale = v;
                        }
                        /// Set scale from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scale_from(&mut self, other: &Self) {
                            self.scale = other.scale.clone();
                        }
                    /// Reset scale from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scale(&mut self, other: &Self) {
                        self.copy_scale_from(other)
                    }

                    /// Get the computed value for scale.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scale(&self) -> longhands::scale::computed_value::T {
                        self.scale.clone()
                    }
                        /// Set translate.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_translate(&mut self, v: longhands::translate::computed_value::T) {
                            self.translate = v;
                        }
                        /// Set translate from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_translate_from(&mut self, other: &Self) {
                            self.translate = other.translate.clone();
                        }
                    /// Reset translate from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_translate(&mut self, other: &Self) {
                        self.copy_translate_from(other)
                    }

                    /// Get the computed value for translate.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_translate(&self) -> longhands::translate::computed_value::T {
                        self.translate.clone()
                    }
                        /// Set offset-path.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_offset_path(&mut self, v: longhands::offset_path::computed_value::T) {
                            self.offset_path = v;
                        }
                        /// Set offset-path from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_offset_path_from(&mut self, other: &Self) {
                            self.offset_path = other.offset_path.clone();
                        }
                    /// Reset offset-path from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_offset_path(&mut self, other: &Self) {
                        self.copy_offset_path_from(other)
                    }

                    /// Get the computed value for offset-path.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_offset_path(&self) -> longhands::offset_path::computed_value::T {
                        self.offset_path.clone()
                    }
                        /// Set offset-distance.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_offset_distance(&mut self, v: longhands::offset_distance::computed_value::T) {
                            self.offset_distance = v;
                        }
                        /// Set offset-distance from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_offset_distance_from(&mut self, other: &Self) {
                            self.offset_distance = other.offset_distance.clone();
                        }
                    /// Reset offset-distance from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_offset_distance(&mut self, other: &Self) {
                        self.copy_offset_distance_from(other)
                    }

                    /// Get the computed value for offset-distance.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_offset_distance(&self) -> longhands::offset_distance::computed_value::T {
                        self.offset_distance.clone()
                    }
                        /// Set offset-rotate.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_offset_rotate(&mut self, v: longhands::offset_rotate::computed_value::T) {
                            self.offset_rotate = v;
                        }
                        /// Set offset-rotate from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_offset_rotate_from(&mut self, other: &Self) {
                            self.offset_rotate = other.offset_rotate.clone();
                        }
                    /// Reset offset-rotate from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_offset_rotate(&mut self, other: &Self) {
                        self.copy_offset_rotate_from(other)
                    }

                    /// Get the computed value for offset-rotate.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_offset_rotate(&self) -> longhands::offset_rotate::computed_value::T {
                        self.offset_rotate.clone()
                    }
                        /// Set offset-anchor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_offset_anchor(&mut self, v: longhands::offset_anchor::computed_value::T) {
                            self.offset_anchor = v;
                        }
                        /// Set offset-anchor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_offset_anchor_from(&mut self, other: &Self) {
                            self.offset_anchor = other.offset_anchor.clone();
                        }
                    /// Reset offset-anchor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_offset_anchor(&mut self, other: &Self) {
                        self.copy_offset_anchor_from(other)
                    }

                    /// Get the computed value for offset-anchor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_offset_anchor(&self) -> longhands::offset_anchor::computed_value::T {
                        self.offset_anchor.clone()
                    }
                        /// Set offset-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_offset_position(&mut self, v: longhands::offset_position::computed_value::T) {
                            self.offset_position = v;
                        }
                        /// Set offset-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_offset_position_from(&mut self, other: &Self) {
                            self.offset_position = other.offset_position.clone();
                        }
                    /// Reset offset-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_offset_position(&mut self, other: &Self) {
                        self.copy_offset_position_from(other)
                    }

                    /// Get the computed value for offset-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_offset_position(&self) -> longhands::offset_position::computed_value::T {
                        self.offset_position.clone()
                    }
                        /// Set scroll-behavior.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_behavior(&mut self, v: longhands::scroll_behavior::computed_value::T) {
                            self.scroll_behavior = v;
                        }
                        /// Set scroll-behavior from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_behavior_from(&mut self, other: &Self) {
                            self.scroll_behavior = other.scroll_behavior.clone();
                        }
                    /// Reset scroll-behavior from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_behavior(&mut self, other: &Self) {
                        self.copy_scroll_behavior_from(other)
                    }

                    /// Get the computed value for scroll-behavior.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_behavior(&self) -> longhands::scroll_behavior::computed_value::T {
                        self.scroll_behavior.clone()
                    }
                        /// Set scroll-snap-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_align(&mut self, v: longhands::scroll_snap_align::computed_value::T) {
                            self.scroll_snap_align = v;
                        }
                        /// Set scroll-snap-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_align_from(&mut self, other: &Self) {
                            self.scroll_snap_align = other.scroll_snap_align.clone();
                        }
                    /// Reset scroll-snap-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_align(&mut self, other: &Self) {
                        self.copy_scroll_snap_align_from(other)
                    }

                    /// Get the computed value for scroll-snap-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_align(&self) -> longhands::scroll_snap_align::computed_value::T {
                        self.scroll_snap_align.clone()
                    }
                        /// Set scroll-snap-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_type(&mut self, v: longhands::scroll_snap_type::computed_value::T) {
                            self.scroll_snap_type = v;
                        }
                        /// Set scroll-snap-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_type_from(&mut self, other: &Self) {
                            self.scroll_snap_type = other.scroll_snap_type.clone();
                        }
                    /// Reset scroll-snap-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_type(&mut self, other: &Self) {
                        self.copy_scroll_snap_type_from(other)
                    }

                    /// Get the computed value for scroll-snap-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_type(&self) -> longhands::scroll_snap_type::computed_value::T {
                        self.scroll_snap_type.clone()
                    }
                        /// Set scroll-snap-stop.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_snap_stop(&mut self, v: longhands::scroll_snap_stop::computed_value::T) {
                            self.scroll_snap_stop = v;
                        }
                        /// Set scroll-snap-stop from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_snap_stop_from(&mut self, other: &Self) {
                            self.scroll_snap_stop = other.scroll_snap_stop.clone();
                        }
                    /// Reset scroll-snap-stop from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_snap_stop(&mut self, other: &Self) {
                        self.copy_scroll_snap_stop_from(other)
                    }

                    /// Get the computed value for scroll-snap-stop.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_snap_stop(&self) -> longhands::scroll_snap_stop::computed_value::T {
                        self.scroll_snap_stop.clone()
                    }
                        /// Set overscroll-behavior-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overscroll_behavior_y(&mut self, v: longhands::overscroll_behavior_y::computed_value::T) {
                            self.overscroll_behavior_y = v;
                        }
                        /// Set overscroll-behavior-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overscroll_behavior_y_from(&mut self, other: &Self) {
                            self.overscroll_behavior_y = other.overscroll_behavior_y.clone();
                        }
                    /// Reset overscroll-behavior-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overscroll_behavior_y(&mut self, other: &Self) {
                        self.copy_overscroll_behavior_y_from(other)
                    }

                    /// Get the computed value for overscroll-behavior-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overscroll_behavior_y(&self) -> longhands::overscroll_behavior_y::computed_value::T {
                        self.overscroll_behavior_y.clone()
                    }
                        /// Set overscroll-behavior-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overscroll_behavior_x(&mut self, v: longhands::overscroll_behavior_x::computed_value::T) {
                            self.overscroll_behavior_x = v;
                        }
                        /// Set overscroll-behavior-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overscroll_behavior_x_from(&mut self, other: &Self) {
                            self.overscroll_behavior_x = other.overscroll_behavior_x.clone();
                        }
                    /// Reset overscroll-behavior-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overscroll_behavior_x(&mut self, other: &Self) {
                        self.copy_overscroll_behavior_x_from(other)
                    }

                    /// Get the computed value for overscroll-behavior-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overscroll_behavior_x(&self) -> longhands::overscroll_behavior_x::computed_value::T {
                        self.overscroll_behavior_x.clone()
                    }
                        /// Set isolation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_isolation(&mut self, v: longhands::isolation::computed_value::T) {
                            self.isolation = v;
                        }
                        /// Set isolation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_isolation_from(&mut self, other: &Self) {
                            self.isolation = other.isolation.clone();
                        }
                    /// Reset isolation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_isolation(&mut self, other: &Self) {
                        self.copy_isolation_from(other)
                    }

                    /// Get the computed value for isolation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_isolation(&self) -> longhands::isolation::computed_value::T {
                        self.isolation.clone()
                    }
                        /// Set break-after.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_break_after(&mut self, v: longhands::break_after::computed_value::T) {
                            self.break_after = v;
                        }
                        /// Set break-after from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_break_after_from(&mut self, other: &Self) {
                            self.break_after = other.break_after.clone();
                        }
                    /// Reset break-after from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_break_after(&mut self, other: &Self) {
                        self.copy_break_after_from(other)
                    }

                    /// Get the computed value for break-after.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_break_after(&self) -> longhands::break_after::computed_value::T {
                        self.break_after.clone()
                    }
                        /// Set break-before.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_break_before(&mut self, v: longhands::break_before::computed_value::T) {
                            self.break_before = v;
                        }
                        /// Set break-before from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_break_before_from(&mut self, other: &Self) {
                            self.break_before = other.break_before.clone();
                        }
                    /// Reset break-before from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_break_before(&mut self, other: &Self) {
                        self.copy_break_before_from(other)
                    }

                    /// Get the computed value for break-before.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_break_before(&self) -> longhands::break_before::computed_value::T {
                        self.break_before.clone()
                    }
                        /// Set break-inside.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_break_inside(&mut self, v: longhands::break_inside::computed_value::T) {
                            self.break_inside = v;
                        }
                        /// Set break-inside from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_break_inside_from(&mut self, other: &Self) {
                            self.break_inside = other.break_inside.clone();
                        }
                    /// Reset break-inside from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_break_inside(&mut self, other: &Self) {
                        self.copy_break_inside_from(other)
                    }

                    /// Get the computed value for break-inside.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_break_inside(&self) -> longhands::break_inside::computed_value::T {
                        self.break_inside.clone()
                    }
                        /// Set resize.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_resize(&mut self, v: longhands::resize::computed_value::T) {
                            self.resize = v;
                        }
                        /// Set resize from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_resize_from(&mut self, other: &Self) {
                            self.resize = other.resize.clone();
                        }
                    /// Reset resize from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_resize(&mut self, other: &Self) {
                        self.copy_resize_from(other)
                    }

                    /// Get the computed value for resize.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_resize(&self) -> longhands::resize::computed_value::T {
                        self.resize.clone()
                    }
                        /// Set perspective.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_perspective(&mut self, v: longhands::perspective::computed_value::T) {
                            self.perspective = v;
                        }
                        /// Set perspective from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_perspective_from(&mut self, other: &Self) {
                            self.perspective = other.perspective.clone();
                        }
                    /// Reset perspective from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_perspective(&mut self, other: &Self) {
                        self.copy_perspective_from(other)
                    }

                    /// Get the computed value for perspective.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_perspective(&self) -> longhands::perspective::computed_value::T {
                        self.perspective.clone()
                    }
                        /// Set perspective-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_perspective_origin(&mut self, v: longhands::perspective_origin::computed_value::T) {
                            self.perspective_origin = v;
                        }
                        /// Set perspective-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_perspective_origin_from(&mut self, other: &Self) {
                            self.perspective_origin = other.perspective_origin.clone();
                        }
                    /// Reset perspective-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_perspective_origin(&mut self, other: &Self) {
                        self.copy_perspective_origin_from(other)
                    }

                    /// Get the computed value for perspective-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_perspective_origin(&self) -> longhands::perspective_origin::computed_value::T {
                        self.perspective_origin.clone()
                    }
                        /// Set backface-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_backface_visibility(&mut self, v: longhands::backface_visibility::computed_value::T) {
                            self.backface_visibility = v;
                        }
                        /// Set backface-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_backface_visibility_from(&mut self, other: &Self) {
                            self.backface_visibility = other.backface_visibility.clone();
                        }
                    /// Reset backface-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_backface_visibility(&mut self, other: &Self) {
                        self.copy_backface_visibility_from(other)
                    }

                    /// Get the computed value for backface-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_backface_visibility(&self) -> longhands::backface_visibility::computed_value::T {
                        self.backface_visibility.clone()
                    }
                        /// Set transform-box.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_box(&mut self, v: longhands::transform_box::computed_value::T) {
                            self.transform_box = v;
                        }
                        /// Set transform-box from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_box_from(&mut self, other: &Self) {
                            self.transform_box = other.transform_box.clone();
                        }
                    /// Reset transform-box from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_box(&mut self, other: &Self) {
                        self.copy_transform_box_from(other)
                    }

                    /// Get the computed value for transform-box.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_box(&self) -> longhands::transform_box::computed_value::T {
                        self.transform_box.clone()
                    }
                        /// Set transform-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_style(&mut self, v: longhands::transform_style::computed_value::T) {
                            self.transform_style = v;
                        }
                        /// Set transform-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_style_from(&mut self, other: &Self) {
                            self.transform_style = other.transform_style.clone();
                        }
                    /// Reset transform-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_style(&mut self, other: &Self) {
                        self.copy_transform_style_from(other)
                    }

                    /// Get the computed value for transform-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_style(&self) -> longhands::transform_style::computed_value::T {
                        self.transform_style.clone()
                    }
                        /// Set transform-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transform_origin(&mut self, v: longhands::transform_origin::computed_value::T) {
                            self.transform_origin = v;
                        }
                        /// Set transform-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transform_origin_from(&mut self, other: &Self) {
                            self.transform_origin = other.transform_origin.clone();
                        }
                    /// Reset transform-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transform_origin(&mut self, other: &Self) {
                        self.copy_transform_origin_from(other)
                    }

                    /// Get the computed value for transform-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transform_origin(&self) -> longhands::transform_origin::computed_value::T {
                        self.transform_origin.clone()
                    }
                        /// Set contain.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_contain(&mut self, v: longhands::contain::computed_value::T) {
                            self.contain = v;
                        }
                        /// Set contain from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_contain_from(&mut self, other: &Self) {
                            self.contain = other.contain.clone();
                        }
                    /// Reset contain from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_contain(&mut self, other: &Self) {
                        self.copy_contain_from(other)
                    }

                    /// Get the computed value for contain.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_contain(&self) -> longhands::contain::computed_value::T {
                        self.contain.clone()
                    }
                        /// Set content-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_content_visibility(&mut self, v: longhands::content_visibility::computed_value::T) {
                            self.content_visibility = v;
                        }
                        /// Set content-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_content_visibility_from(&mut self, other: &Self) {
                            self.content_visibility = other.content_visibility.clone();
                        }
                    /// Reset content-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_content_visibility(&mut self, other: &Self) {
                        self.copy_content_visibility_from(other)
                    }

                    /// Get the computed value for content-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_content_visibility(&self) -> longhands::content_visibility::computed_value::T {
                        self.content_visibility.clone()
                    }
                        /// Set container-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_container_type(&mut self, v: longhands::container_type::computed_value::T) {
                            self.container_type = v;
                        }
                        /// Set container-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_container_type_from(&mut self, other: &Self) {
                            self.container_type = other.container_type.clone();
                        }
                    /// Reset container-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_container_type(&mut self, other: &Self) {
                        self.copy_container_type_from(other)
                    }

                    /// Get the computed value for container-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_container_type(&self) -> longhands::container_type::computed_value::T {
                        self.container_type.clone()
                    }
                        /// Set container-name.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_container_name(&mut self, v: longhands::container_name::computed_value::T) {
                            self.container_name = v;
                        }
                        /// Set container-name from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_container_name_from(&mut self, other: &Self) {
                            self.container_name = other.container_name.clone();
                        }
                    /// Reset container-name from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_container_name(&mut self, other: &Self) {
                        self.copy_container_name_from(other)
                    }

                    /// Get the computed value for container-name.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_container_name(&self) -> longhands::container_name::computed_value::T {
                        self.container_name.clone()
                    }
                        /// Set appearance.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_appearance(&mut self, v: longhands::appearance::computed_value::T) {
                            self.appearance = v;
                        }
                        /// Set appearance from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_appearance_from(&mut self, other: &Self) {
                            self.appearance = other.appearance.clone();
                        }
                    /// Reset appearance from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_appearance(&mut self, other: &Self) {
                        self.copy_appearance_from(other)
                    }

                    /// Get the computed value for appearance.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_appearance(&self) -> longhands::appearance::computed_value::T {
                        self.appearance.clone()
                    }
                        /// Set -moz-default-appearance.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_default_appearance(&mut self, v: longhands::_moz_default_appearance::computed_value::T) {
                            self._moz_default_appearance = v;
                        }
                        /// Set -moz-default-appearance from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_default_appearance_from(&mut self, other: &Self) {
                            self._moz_default_appearance = other._moz_default_appearance.clone();
                        }
                    /// Reset -moz-default-appearance from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_default_appearance(&mut self, other: &Self) {
                        self.copy__moz_default_appearance_from(other)
                    }

                    /// Get the computed value for -moz-default-appearance.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_default_appearance(&self) -> longhands::_moz_default_appearance::computed_value::T {
                        self._moz_default_appearance.clone()
                    }
                        /// Set -moz-orient.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_orient(&mut self, v: longhands::_moz_orient::computed_value::T) {
                            self._moz_orient = v;
                        }
                        /// Set -moz-orient from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_orient_from(&mut self, other: &Self) {
                            self._moz_orient = other._moz_orient.clone();
                        }
                    /// Reset -moz-orient from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_orient(&mut self, other: &Self) {
                        self.copy__moz_orient_from(other)
                    }

                    /// Get the computed value for -moz-orient.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_orient(&self) -> longhands::_moz_orient::computed_value::T {
                        self._moz_orient.clone()
                    }
                        /// Set will-change.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_will_change(&mut self, v: longhands::will_change::computed_value::T) {
                            self.will_change = v;
                        }
                        /// Set will-change from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_will_change_from(&mut self, other: &Self) {
                            self.will_change = other.will_change.clone();
                        }
                    /// Reset will-change from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_will_change(&mut self, other: &Self) {
                        self.copy_will_change_from(other)
                    }

                    /// Get the computed value for will-change.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_will_change(&self) -> longhands::will_change::computed_value::T {
                        self.will_change.clone()
                    }
                        /// Set shape-image-threshold.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_image_threshold(&mut self, v: longhands::shape_image_threshold::computed_value::T) {
                            self.shape_image_threshold = v;
                        }
                        /// Set shape-image-threshold from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_image_threshold_from(&mut self, other: &Self) {
                            self.shape_image_threshold = other.shape_image_threshold.clone();
                        }
                    /// Reset shape-image-threshold from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_image_threshold(&mut self, other: &Self) {
                        self.copy_shape_image_threshold_from(other)
                    }

                    /// Get the computed value for shape-image-threshold.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_image_threshold(&self) -> longhands::shape_image_threshold::computed_value::T {
                        self.shape_image_threshold.clone()
                    }
                        /// Set shape-margin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_margin(&mut self, v: longhands::shape_margin::computed_value::T) {
                            self.shape_margin = v;
                        }
                        /// Set shape-margin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_margin_from(&mut self, other: &Self) {
                            self.shape_margin = other.shape_margin.clone();
                        }
                    /// Reset shape-margin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_margin(&mut self, other: &Self) {
                        self.copy_shape_margin_from(other)
                    }

                    /// Get the computed value for shape-margin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_margin(&self) -> longhands::shape_margin::computed_value::T {
                        self.shape_margin.clone()
                    }
                        /// Set shape-outside.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_outside(&mut self, v: longhands::shape_outside::computed_value::T) {
                            self.shape_outside = v;
                        }
                        /// Set shape-outside from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_outside_from(&mut self, other: &Self) {
                            self.shape_outside = other.shape_outside.clone();
                        }
                    /// Reset shape-outside from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_outside(&mut self, other: &Self) {
                        self.copy_shape_outside_from(other)
                    }

                    /// Get the computed value for shape-outside.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_outside(&self) -> longhands::shape_outside::computed_value::T {
                        self.shape_outside.clone()
                    }
                        /// Set touch-action.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_touch_action(&mut self, v: longhands::touch_action::computed_value::T) {
                            self.touch_action = v;
                        }
                        /// Set touch-action from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_touch_action_from(&mut self, other: &Self) {
                            self.touch_action = other.touch_action.clone();
                        }
                    /// Reset touch-action from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_touch_action(&mut self, other: &Self) {
                        self.copy_touch_action_from(other)
                    }

                    /// Get the computed value for touch-action.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_touch_action(&self) -> longhands::touch_action::computed_value::T {
                        self.touch_action.clone()
                    }
                        /// Set -webkit-line-clamp.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_line_clamp(&mut self, v: longhands::_webkit_line_clamp::computed_value::T) {
                            self._webkit_line_clamp = v;
                        }
                        /// Set -webkit-line-clamp from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_line_clamp_from(&mut self, other: &Self) {
                            self._webkit_line_clamp = other._webkit_line_clamp.clone();
                        }
                    /// Reset -webkit-line-clamp from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_line_clamp(&mut self, other: &Self) {
                        self.copy__webkit_line_clamp_from(other)
                    }

                    /// Get the computed value for -webkit-line-clamp.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_line_clamp(&self) -> longhands::_webkit_line_clamp::computed_value::T {
                        self._webkit_line_clamp.clone()
                    }
                        /// Set scrollbar-gutter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scrollbar_gutter(&mut self, v: longhands::scrollbar_gutter::computed_value::T) {
                            self.scrollbar_gutter = v;
                        }
                        /// Set scrollbar-gutter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scrollbar_gutter_from(&mut self, other: &Self) {
                            self.scrollbar_gutter = other.scrollbar_gutter.clone();
                        }
                    /// Reset scrollbar-gutter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scrollbar_gutter(&mut self, other: &Self) {
                        self.copy_scrollbar_gutter_from(other)
                    }

                    /// Get the computed value for scrollbar-gutter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scrollbar_gutter(&self) -> longhands::scrollbar_gutter::computed_value::T {
                        self.scrollbar_gutter.clone()
                    }
                        /// Set zoom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_zoom(&mut self, v: longhands::zoom::computed_value::T) {
                            self.zoom = v;
                        }
                        /// Set zoom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_zoom_from(&mut self, other: &Self) {
                            self.zoom = other.zoom.clone();
                        }
                    /// Reset zoom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_zoom(&mut self, other: &Self) {
                        self.copy_zoom_from(other)
                    }

                    /// Get the computed value for zoom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_zoom(&self) -> longhands::zoom::computed_value::T {
                        self.zoom.clone()
                    }
                /// Sets the display property, but without touching original_display,
                /// except when the adjustment comes from root or item display fixups.
                pub fn set_adjusted_display(
                    &mut self,
                    dpy: longhands::display::computed_value::T,
                    is_item_or_root: bool
                ) {
                    self.display = dpy;
                    if is_item_or_root {
                        self.original_display = dpy;
                    }
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Column style struct.
        pub struct Column {
                    /// The column-width computed value.
                    pub column_width: longhands::column_width::computed_value::T,
                    /// The column-count computed value.
                    pub column_count: longhands::column_count::computed_value::T,
                    /// The column-fill computed value.
                    pub column_fill: longhands::column_fill::computed_value::T,
                    /// The column-rule-width computed value.
                    pub column_rule_width: longhands::column_rule_width::computed_value::T,
                    /// The column-rule-color computed value.
                    pub column_rule_color: longhands::column_rule_color::computed_value::T,
                    /// The column-span computed value.
                    pub column_span: longhands::column_span::computed_value::T,
                    /// The column-rule-style computed value.
                    pub column_rule_style: longhands::column_rule_style::computed_value::T,
        }

        impl Column {
                        /// Set column-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_width(&mut self, v: longhands::column_width::computed_value::T) {
                            self.column_width = v;
                        }
                        /// Set column-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_width_from(&mut self, other: &Self) {
                            self.column_width = other.column_width.clone();
                        }
                    /// Reset column-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_width(&mut self, other: &Self) {
                        self.copy_column_width_from(other)
                    }

                    /// Get the computed value for column-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_width(&self) -> longhands::column_width::computed_value::T {
                        self.column_width.clone()
                    }
                        /// Set column-count.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_count(&mut self, v: longhands::column_count::computed_value::T) {
                            self.column_count = v;
                        }
                        /// Set column-count from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_count_from(&mut self, other: &Self) {
                            self.column_count = other.column_count.clone();
                        }
                    /// Reset column-count from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_count(&mut self, other: &Self) {
                        self.copy_column_count_from(other)
                    }

                    /// Get the computed value for column-count.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_count(&self) -> longhands::column_count::computed_value::T {
                        self.column_count.clone()
                    }
                        /// Set column-fill.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_fill(&mut self, v: longhands::column_fill::computed_value::T) {
                            self.column_fill = v;
                        }
                        /// Set column-fill from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_fill_from(&mut self, other: &Self) {
                            self.column_fill = other.column_fill.clone();
                        }
                    /// Reset column-fill from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_fill(&mut self, other: &Self) {
                        self.copy_column_fill_from(other)
                    }

                    /// Get the computed value for column-fill.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_fill(&self) -> longhands::column_fill::computed_value::T {
                        self.column_fill.clone()
                    }
                        /// Set column-rule-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_width(&mut self, v: longhands::column_rule_width::computed_value::T) {
                            self.column_rule_width = v;
                        }
                        /// Set column-rule-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_width_from(&mut self, other: &Self) {
                            self.column_rule_width = other.column_rule_width.clone();
                        }
                    /// Reset column-rule-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_width(&mut self, other: &Self) {
                        self.copy_column_rule_width_from(other)
                    }

                    /// Get the computed value for column-rule-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_width(&self) -> longhands::column_rule_width::computed_value::T {
                        self.column_rule_width.clone()
                    }
                        /// Set column-rule-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_color(&mut self, v: longhands::column_rule_color::computed_value::T) {
                            self.column_rule_color = v;
                        }
                        /// Set column-rule-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_color_from(&mut self, other: &Self) {
                            self.column_rule_color = other.column_rule_color.clone();
                        }
                    /// Reset column-rule-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_color(&mut self, other: &Self) {
                        self.copy_column_rule_color_from(other)
                    }

                    /// Get the computed value for column-rule-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_color(&self) -> longhands::column_rule_color::computed_value::T {
                        self.column_rule_color.clone()
                    }
                        /// Set column-span.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_span(&mut self, v: longhands::column_span::computed_value::T) {
                            self.column_span = v;
                        }
                        /// Set column-span from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_span_from(&mut self, other: &Self) {
                            self.column_span = other.column_span.clone();
                        }
                    /// Reset column-span from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_span(&mut self, other: &Self) {
                        self.copy_column_span_from(other)
                    }

                    /// Get the computed value for column-span.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_span(&self) -> longhands::column_span::computed_value::T {
                        self.column_span.clone()
                    }
                        /// Set column-rule-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_rule_style(&mut self, v: longhands::column_rule_style::computed_value::T) {
                            self.column_rule_style = v;
                        }
                        /// Set column-rule-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_rule_style_from(&mut self, other: &Self) {
                            self.column_rule_style = other.column_rule_style.clone();
                        }
                    /// Reset column-rule-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_rule_style(&mut self, other: &Self) {
                        self.copy_column_rule_style_from(other)
                    }

                    /// Get the computed value for column-rule-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_rule_style(&self) -> longhands::column_rule_style::computed_value::T {
                        self.column_rule_style.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Counters style struct.
        pub struct Counters {
                    /// The content computed value.
                    pub content: longhands::content::computed_value::T,
                    /// The counter-increment computed value.
                    pub counter_increment: longhands::counter_increment::computed_value::T,
                    /// The counter-reset computed value.
                    pub counter_reset: longhands::counter_reset::computed_value::T,
                    /// The counter-set computed value.
                    pub counter_set: longhands::counter_set::computed_value::T,
        }

        impl Counters {
                        /// Set content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_content(&mut self, v: longhands::content::computed_value::T) {
                            self.content = v;
                        }
                        /// Set content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_content_from(&mut self, other: &Self) {
                            self.content = other.content.clone();
                        }
                    /// Reset content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_content(&mut self, other: &Self) {
                        self.copy_content_from(other)
                    }

                    /// Get the computed value for content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_content(&self) -> longhands::content::computed_value::T {
                        self.content.clone()
                    }
                        /// Set counter-increment.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_counter_increment(&mut self, v: longhands::counter_increment::computed_value::T) {
                            self.counter_increment = v;
                        }
                        /// Set counter-increment from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_counter_increment_from(&mut self, other: &Self) {
                            self.counter_increment = other.counter_increment.clone();
                        }
                    /// Reset counter-increment from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_counter_increment(&mut self, other: &Self) {
                        self.copy_counter_increment_from(other)
                    }

                    /// Get the computed value for counter-increment.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_counter_increment(&self) -> longhands::counter_increment::computed_value::T {
                        self.counter_increment.clone()
                    }
                        /// Set counter-reset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_counter_reset(&mut self, v: longhands::counter_reset::computed_value::T) {
                            self.counter_reset = v;
                        }
                        /// Set counter-reset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_counter_reset_from(&mut self, other: &Self) {
                            self.counter_reset = other.counter_reset.clone();
                        }
                    /// Reset counter-reset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_counter_reset(&mut self, other: &Self) {
                        self.copy_counter_reset_from(other)
                    }

                    /// Get the computed value for counter-reset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_counter_reset(&self) -> longhands::counter_reset::computed_value::T {
                        self.counter_reset.clone()
                    }
                        /// Set counter-set.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_counter_set(&mut self, v: longhands::counter_set::computed_value::T) {
                            self.counter_set = v;
                        }
                        /// Set counter-set from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_counter_set_from(&mut self, other: &Self) {
                            self.counter_set = other.counter_set.clone();
                        }
                    /// Reset counter-set from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_counter_set(&mut self, other: &Self) {
                        self.copy_counter_set_from(other)
                    }

                    /// Get the computed value for counter-set.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_counter_set(&self) -> longhands::counter_set::computed_value::T {
                        self.counter_set.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Effects style struct.
        pub struct Effects {
                    /// The opacity computed value.
                    pub opacity: longhands::opacity::computed_value::T,
                    /// The box-shadow computed value.
                    pub box_shadow: longhands::box_shadow::computed_value::T,
                    /// The clip computed value.
                    pub clip: longhands::clip::computed_value::T,
                    /// The filter computed value.
                    pub filter: longhands::filter::computed_value::T,
                    /// The backdrop-filter computed value.
                    pub backdrop_filter: longhands::backdrop_filter::computed_value::T,
                    /// The mix-blend-mode computed value.
                    pub mix_blend_mode: longhands::mix_blend_mode::computed_value::T,
        }

        impl Effects {
                        /// Set opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_opacity(&mut self, v: longhands::opacity::computed_value::T) {
                            self.opacity = v;
                        }
                        /// Set opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_opacity_from(&mut self, other: &Self) {
                            self.opacity = other.opacity.clone();
                        }
                    /// Reset opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_opacity(&mut self, other: &Self) {
                        self.copy_opacity_from(other)
                    }

                    /// Get the computed value for opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_opacity(&self) -> longhands::opacity::computed_value::T {
                        self.opacity.clone()
                    }
                        /// Set box-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_shadow(&mut self, v: longhands::box_shadow::computed_value::T) {
                            self.box_shadow = v;
                        }
                        /// Set box-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_shadow_from(&mut self, other: &Self) {
                            self.box_shadow = other.box_shadow.clone();
                        }
                    /// Reset box-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_shadow(&mut self, other: &Self) {
                        self.copy_box_shadow_from(other)
                    }

                    /// Get the computed value for box-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_shadow(&self) -> longhands::box_shadow::computed_value::T {
                        self.box_shadow.clone()
                    }
                        /// Set clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip(&mut self, v: longhands::clip::computed_value::T) {
                            self.clip = v;
                        }
                        /// Set clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_from(&mut self, other: &Self) {
                            self.clip = other.clip.clone();
                        }
                    /// Reset clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip(&mut self, other: &Self) {
                        self.copy_clip_from(other)
                    }

                    /// Get the computed value for clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip(&self) -> longhands::clip::computed_value::T {
                        self.clip.clone()
                    }
                        /// Set filter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_filter(&mut self, v: longhands::filter::computed_value::T) {
                            self.filter = v;
                        }
                        /// Set filter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_filter_from(&mut self, other: &Self) {
                            self.filter = other.filter.clone();
                        }
                    /// Reset filter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_filter(&mut self, other: &Self) {
                        self.copy_filter_from(other)
                    }

                    /// Get the computed value for filter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_filter(&self) -> longhands::filter::computed_value::T {
                        self.filter.clone()
                    }
                        /// Set backdrop-filter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_backdrop_filter(&mut self, v: longhands::backdrop_filter::computed_value::T) {
                            self.backdrop_filter = v;
                        }
                        /// Set backdrop-filter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_backdrop_filter_from(&mut self, other: &Self) {
                            self.backdrop_filter = other.backdrop_filter.clone();
                        }
                    /// Reset backdrop-filter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_backdrop_filter(&mut self, other: &Self) {
                        self.copy_backdrop_filter_from(other)
                    }

                    /// Get the computed value for backdrop-filter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_backdrop_filter(&self) -> longhands::backdrop_filter::computed_value::T {
                        self.backdrop_filter.clone()
                    }
                        /// Set mix-blend-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mix_blend_mode(&mut self, v: longhands::mix_blend_mode::computed_value::T) {
                            self.mix_blend_mode = v;
                        }
                        /// Set mix-blend-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mix_blend_mode_from(&mut self, other: &Self) {
                            self.mix_blend_mode = other.mix_blend_mode.clone();
                        }
                    /// Reset mix-blend-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mix_blend_mode(&mut self, other: &Self) {
                        self.copy_mix_blend_mode_from(other)
                    }

                    /// Get the computed value for mix-blend-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mix_blend_mode(&self) -> longhands::mix_blend_mode::computed_value::T {
                        self.mix_blend_mode.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf)]
        #[cfg_attr(feature = "servo", derive(Serialize, Deserialize))]
        /// The Font style struct.
        pub struct Font {
                    /// The font-family computed value.
                    pub font_family: longhands::font_family::computed_value::T,
                    /// The font-style computed value.
                    pub font_style: longhands::font_style::computed_value::T,
                    /// The font-variant-caps computed value.
                    pub font_variant_caps: longhands::font_variant_caps::computed_value::T,
                    /// The font-weight computed value.
                    pub font_weight: longhands::font_weight::computed_value::T,
                    /// The font-size computed value.
                    pub font_size: longhands::font_size::computed_value::T,
                    /// The font-size-adjust computed value.
                    pub font_size_adjust: longhands::font_size_adjust::computed_value::T,
                    /// The font-synthesis-weight computed value.
                    pub font_synthesis_weight: longhands::font_synthesis_weight::computed_value::T,
                    /// The font-synthesis-style computed value.
                    pub font_synthesis_style: longhands::font_synthesis_style::computed_value::T,
                    /// The font-synthesis-small-caps computed value.
                    pub font_synthesis_small_caps: longhands::font_synthesis_small_caps::computed_value::T,
                    /// The font-synthesis-position computed value.
                    pub font_synthesis_position: longhands::font_synthesis_position::computed_value::T,
                    /// The font-stretch computed value.
                    pub font_stretch: longhands::font_stretch::computed_value::T,
                    /// The font-kerning computed value.
                    pub font_kerning: longhands::font_kerning::computed_value::T,
                    /// The font-variant-alternates computed value.
                    pub font_variant_alternates: longhands::font_variant_alternates::computed_value::T,
                    /// The font-variant-east-asian computed value.
                    pub font_variant_east_asian: longhands::font_variant_east_asian::computed_value::T,
                    /// The font-variant-emoji computed value.
                    pub font_variant_emoji: longhands::font_variant_emoji::computed_value::T,
                    /// The font-variant-ligatures computed value.
                    pub font_variant_ligatures: longhands::font_variant_ligatures::computed_value::T,
                    /// The font-variant-numeric computed value.
                    pub font_variant_numeric: longhands::font_variant_numeric::computed_value::T,
                    /// The font-variant-position computed value.
                    pub font_variant_position: longhands::font_variant_position::computed_value::T,
                    /// The font-feature-settings computed value.
                    pub font_feature_settings: longhands::font_feature_settings::computed_value::T,
                    /// The font-variation-settings computed value.
                    pub font_variation_settings: longhands::font_variation_settings::computed_value::T,
                    /// The font-language-override computed value.
                    pub font_language_override: longhands::font_language_override::computed_value::T,
                    /// The font-optical-sizing computed value.
                    pub font_optical_sizing: longhands::font_optical_sizing::computed_value::T,
                    /// The font-palette computed value.
                    pub font_palette: longhands::font_palette::computed_value::T,
                    /// The -x-lang computed value.
                    pub _x_lang: longhands::_x_lang::computed_value::T,
                    /// The math-depth computed value.
                    pub math_depth: longhands::math_depth::computed_value::T,
                    /// The math-style computed value.
                    pub math_style: longhands::math_style::computed_value::T,
                    /// The -moz-math-variant computed value.
                    pub _moz_math_variant: longhands::_moz_math_variant::computed_value::T,
                    /// The -x-text-scale computed value.
                    pub _x_text_scale: longhands::_x_text_scale::computed_value::T,
                    /// The line-height computed value.
                    pub line_height: longhands::line_height::computed_value::T,
                    /// The -moz-osx-font-smoothing computed value.
                    pub _moz_osx_font_smoothing: longhands::_moz_osx_font_smoothing::computed_value::T,
                    /// The -moz-min-font-size-ratio computed value.
                    pub _moz_min_font_size_ratio: longhands::_moz_min_font_size_ratio::computed_value::T,
                /// The font hash, used for font caching.
                pub hash: u64,
        }
        impl PartialEq for Font {
            fn eq(&self, other: &Font) -> bool {
                self.hash == other.hash
                    && self.font_family == other.font_family
                    && self.font_style == other.font_style
                    && self.font_variant_caps == other.font_variant_caps
                    && self.font_weight == other.font_weight
                    && self.font_size == other.font_size
                    && self.font_size_adjust == other.font_size_adjust
                    && self.font_synthesis_weight == other.font_synthesis_weight
                    && self.font_synthesis_style == other.font_synthesis_style
                    && self.font_synthesis_small_caps == other.font_synthesis_small_caps
                    && self.font_synthesis_position == other.font_synthesis_position
                    && self.font_stretch == other.font_stretch
                    && self.font_kerning == other.font_kerning
                    && self.font_variant_alternates == other.font_variant_alternates
                    && self.font_variant_east_asian == other.font_variant_east_asian
                    && self.font_variant_emoji == other.font_variant_emoji
                    && self.font_variant_ligatures == other.font_variant_ligatures
                    && self.font_variant_numeric == other.font_variant_numeric
                    && self.font_variant_position == other.font_variant_position
                    && self.font_feature_settings == other.font_feature_settings
                    && self.font_variation_settings == other.font_variation_settings
                    && self.font_language_override == other.font_language_override
                    && self.font_optical_sizing == other.font_optical_sizing
                    && self.font_palette == other.font_palette
                    && self._x_lang == other._x_lang
                    && self.math_depth == other.math_depth
                    && self.math_style == other.math_style
                    && self._moz_math_variant == other._moz_math_variant
                    && self._x_text_scale == other._x_text_scale
                    && self.line_height == other.line_height
                    && self._moz_osx_font_smoothing == other._moz_osx_font_smoothing
                    && self._moz_min_font_size_ratio == other._moz_min_font_size_ratio
            }
        }

        impl Font {
                        /// Set font-family.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_family(&mut self, v: longhands::font_family::computed_value::T) {
                            self.font_family = v;
                        }
                        /// Set font-family from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_family_from(&mut self, other: &Self) {
                            self.font_family = other.font_family.clone();
                        }
                    /// Reset font-family from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_family(&mut self, other: &Self) {
                        self.copy_font_family_from(other)
                    }

                    /// Get the computed value for font-family.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_family(&self) -> longhands::font_family::computed_value::T {
                        self.font_family.clone()
                    }
                        /// Set font-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_style(&mut self, v: longhands::font_style::computed_value::T) {
                            self.font_style = v;
                        }
                        /// Set font-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_style_from(&mut self, other: &Self) {
                            self.font_style = other.font_style.clone();
                        }
                    /// Reset font-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_style(&mut self, other: &Self) {
                        self.copy_font_style_from(other)
                    }

                    /// Get the computed value for font-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_style(&self) -> longhands::font_style::computed_value::T {
                        self.font_style.clone()
                    }
                        /// Set font-variant-caps.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_caps(&mut self, v: longhands::font_variant_caps::computed_value::T) {
                            self.font_variant_caps = v;
                        }
                        /// Set font-variant-caps from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_caps_from(&mut self, other: &Self) {
                            self.font_variant_caps = other.font_variant_caps.clone();
                        }
                    /// Reset font-variant-caps from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_caps(&mut self, other: &Self) {
                        self.copy_font_variant_caps_from(other)
                    }

                    /// Get the computed value for font-variant-caps.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_caps(&self) -> longhands::font_variant_caps::computed_value::T {
                        self.font_variant_caps.clone()
                    }
                        /// Set font-weight.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_weight(&mut self, v: longhands::font_weight::computed_value::T) {
                            self.font_weight = v;
                        }
                        /// Set font-weight from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_weight_from(&mut self, other: &Self) {
                            self.font_weight = other.font_weight.clone();
                        }
                    /// Reset font-weight from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_weight(&mut self, other: &Self) {
                        self.copy_font_weight_from(other)
                    }

                    /// Get the computed value for font-weight.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_weight(&self) -> longhands::font_weight::computed_value::T {
                        self.font_weight.clone()
                    }
                        /// Set font-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_size(&mut self, v: longhands::font_size::computed_value::T) {
                            self.font_size = v;
                        }
                        /// Set font-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_size_from(&mut self, other: &Self) {
                            self.font_size = other.font_size.clone();
                        }
                    /// Reset font-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_size(&mut self, other: &Self) {
                        self.copy_font_size_from(other)
                    }

                    /// Get the computed value for font-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_size(&self) -> longhands::font_size::computed_value::T {
                        self.font_size.clone()
                    }
                        /// Set font-size-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_size_adjust(&mut self, v: longhands::font_size_adjust::computed_value::T) {
                            self.font_size_adjust = v;
                        }
                        /// Set font-size-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_size_adjust_from(&mut self, other: &Self) {
                            self.font_size_adjust = other.font_size_adjust.clone();
                        }
                    /// Reset font-size-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_size_adjust(&mut self, other: &Self) {
                        self.copy_font_size_adjust_from(other)
                    }

                    /// Get the computed value for font-size-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_size_adjust(&self) -> longhands::font_size_adjust::computed_value::T {
                        self.font_size_adjust.clone()
                    }
                        /// Set font-synthesis-weight.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_synthesis_weight(&mut self, v: longhands::font_synthesis_weight::computed_value::T) {
                            self.font_synthesis_weight = v;
                        }
                        /// Set font-synthesis-weight from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_synthesis_weight_from(&mut self, other: &Self) {
                            self.font_synthesis_weight = other.font_synthesis_weight.clone();
                        }
                    /// Reset font-synthesis-weight from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_synthesis_weight(&mut self, other: &Self) {
                        self.copy_font_synthesis_weight_from(other)
                    }

                    /// Get the computed value for font-synthesis-weight.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_synthesis_weight(&self) -> longhands::font_synthesis_weight::computed_value::T {
                        self.font_synthesis_weight.clone()
                    }
                        /// Set font-synthesis-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_synthesis_style(&mut self, v: longhands::font_synthesis_style::computed_value::T) {
                            self.font_synthesis_style = v;
                        }
                        /// Set font-synthesis-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_synthesis_style_from(&mut self, other: &Self) {
                            self.font_synthesis_style = other.font_synthesis_style.clone();
                        }
                    /// Reset font-synthesis-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_synthesis_style(&mut self, other: &Self) {
                        self.copy_font_synthesis_style_from(other)
                    }

                    /// Get the computed value for font-synthesis-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_synthesis_style(&self) -> longhands::font_synthesis_style::computed_value::T {
                        self.font_synthesis_style.clone()
                    }
                        /// Set font-synthesis-small-caps.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_synthesis_small_caps(&mut self, v: longhands::font_synthesis_small_caps::computed_value::T) {
                            self.font_synthesis_small_caps = v;
                        }
                        /// Set font-synthesis-small-caps from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_synthesis_small_caps_from(&mut self, other: &Self) {
                            self.font_synthesis_small_caps = other.font_synthesis_small_caps.clone();
                        }
                    /// Reset font-synthesis-small-caps from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_synthesis_small_caps(&mut self, other: &Self) {
                        self.copy_font_synthesis_small_caps_from(other)
                    }

                    /// Get the computed value for font-synthesis-small-caps.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_synthesis_small_caps(&self) -> longhands::font_synthesis_small_caps::computed_value::T {
                        self.font_synthesis_small_caps.clone()
                    }
                        /// Set font-synthesis-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_synthesis_position(&mut self, v: longhands::font_synthesis_position::computed_value::T) {
                            self.font_synthesis_position = v;
                        }
                        /// Set font-synthesis-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_synthesis_position_from(&mut self, other: &Self) {
                            self.font_synthesis_position = other.font_synthesis_position.clone();
                        }
                    /// Reset font-synthesis-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_synthesis_position(&mut self, other: &Self) {
                        self.copy_font_synthesis_position_from(other)
                    }

                    /// Get the computed value for font-synthesis-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_synthesis_position(&self) -> longhands::font_synthesis_position::computed_value::T {
                        self.font_synthesis_position.clone()
                    }
                        /// Set font-stretch.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_stretch(&mut self, v: longhands::font_stretch::computed_value::T) {
                            self.font_stretch = v;
                        }
                        /// Set font-stretch from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_stretch_from(&mut self, other: &Self) {
                            self.font_stretch = other.font_stretch.clone();
                        }
                    /// Reset font-stretch from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_stretch(&mut self, other: &Self) {
                        self.copy_font_stretch_from(other)
                    }

                    /// Get the computed value for font-stretch.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_stretch(&self) -> longhands::font_stretch::computed_value::T {
                        self.font_stretch.clone()
                    }
                        /// Set font-kerning.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_kerning(&mut self, v: longhands::font_kerning::computed_value::T) {
                            self.font_kerning = v;
                        }
                        /// Set font-kerning from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_kerning_from(&mut self, other: &Self) {
                            self.font_kerning = other.font_kerning.clone();
                        }
                    /// Reset font-kerning from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_kerning(&mut self, other: &Self) {
                        self.copy_font_kerning_from(other)
                    }

                    /// Get the computed value for font-kerning.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_kerning(&self) -> longhands::font_kerning::computed_value::T {
                        self.font_kerning.clone()
                    }
                        /// Set font-variant-alternates.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_alternates(&mut self, v: longhands::font_variant_alternates::computed_value::T) {
                            self.font_variant_alternates = v;
                        }
                        /// Set font-variant-alternates from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_alternates_from(&mut self, other: &Self) {
                            self.font_variant_alternates = other.font_variant_alternates.clone();
                        }
                    /// Reset font-variant-alternates from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_alternates(&mut self, other: &Self) {
                        self.copy_font_variant_alternates_from(other)
                    }

                    /// Get the computed value for font-variant-alternates.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_alternates(&self) -> longhands::font_variant_alternates::computed_value::T {
                        self.font_variant_alternates.clone()
                    }
                        /// Set font-variant-east-asian.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_east_asian(&mut self, v: longhands::font_variant_east_asian::computed_value::T) {
                            self.font_variant_east_asian = v;
                        }
                        /// Set font-variant-east-asian from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_east_asian_from(&mut self, other: &Self) {
                            self.font_variant_east_asian = other.font_variant_east_asian.clone();
                        }
                    /// Reset font-variant-east-asian from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_east_asian(&mut self, other: &Self) {
                        self.copy_font_variant_east_asian_from(other)
                    }

                    /// Get the computed value for font-variant-east-asian.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_east_asian(&self) -> longhands::font_variant_east_asian::computed_value::T {
                        self.font_variant_east_asian.clone()
                    }
                        /// Set font-variant-emoji.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_emoji(&mut self, v: longhands::font_variant_emoji::computed_value::T) {
                            self.font_variant_emoji = v;
                        }
                        /// Set font-variant-emoji from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_emoji_from(&mut self, other: &Self) {
                            self.font_variant_emoji = other.font_variant_emoji.clone();
                        }
                    /// Reset font-variant-emoji from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_emoji(&mut self, other: &Self) {
                        self.copy_font_variant_emoji_from(other)
                    }

                    /// Get the computed value for font-variant-emoji.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_emoji(&self) -> longhands::font_variant_emoji::computed_value::T {
                        self.font_variant_emoji.clone()
                    }
                        /// Set font-variant-ligatures.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_ligatures(&mut self, v: longhands::font_variant_ligatures::computed_value::T) {
                            self.font_variant_ligatures = v;
                        }
                        /// Set font-variant-ligatures from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_ligatures_from(&mut self, other: &Self) {
                            self.font_variant_ligatures = other.font_variant_ligatures.clone();
                        }
                    /// Reset font-variant-ligatures from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_ligatures(&mut self, other: &Self) {
                        self.copy_font_variant_ligatures_from(other)
                    }

                    /// Get the computed value for font-variant-ligatures.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_ligatures(&self) -> longhands::font_variant_ligatures::computed_value::T {
                        self.font_variant_ligatures.clone()
                    }
                        /// Set font-variant-numeric.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_numeric(&mut self, v: longhands::font_variant_numeric::computed_value::T) {
                            self.font_variant_numeric = v;
                        }
                        /// Set font-variant-numeric from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_numeric_from(&mut self, other: &Self) {
                            self.font_variant_numeric = other.font_variant_numeric.clone();
                        }
                    /// Reset font-variant-numeric from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_numeric(&mut self, other: &Self) {
                        self.copy_font_variant_numeric_from(other)
                    }

                    /// Get the computed value for font-variant-numeric.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_numeric(&self) -> longhands::font_variant_numeric::computed_value::T {
                        self.font_variant_numeric.clone()
                    }
                        /// Set font-variant-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variant_position(&mut self, v: longhands::font_variant_position::computed_value::T) {
                            self.font_variant_position = v;
                        }
                        /// Set font-variant-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variant_position_from(&mut self, other: &Self) {
                            self.font_variant_position = other.font_variant_position.clone();
                        }
                    /// Reset font-variant-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variant_position(&mut self, other: &Self) {
                        self.copy_font_variant_position_from(other)
                    }

                    /// Get the computed value for font-variant-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variant_position(&self) -> longhands::font_variant_position::computed_value::T {
                        self.font_variant_position.clone()
                    }
                        /// Set font-feature-settings.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_feature_settings(&mut self, v: longhands::font_feature_settings::computed_value::T) {
                            self.font_feature_settings = v;
                        }
                        /// Set font-feature-settings from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_feature_settings_from(&mut self, other: &Self) {
                            self.font_feature_settings = other.font_feature_settings.clone();
                        }
                    /// Reset font-feature-settings from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_feature_settings(&mut self, other: &Self) {
                        self.copy_font_feature_settings_from(other)
                    }

                    /// Get the computed value for font-feature-settings.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_feature_settings(&self) -> longhands::font_feature_settings::computed_value::T {
                        self.font_feature_settings.clone()
                    }
                        /// Set font-variation-settings.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_variation_settings(&mut self, v: longhands::font_variation_settings::computed_value::T) {
                            self.font_variation_settings = v;
                        }
                        /// Set font-variation-settings from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_variation_settings_from(&mut self, other: &Self) {
                            self.font_variation_settings = other.font_variation_settings.clone();
                        }
                    /// Reset font-variation-settings from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_variation_settings(&mut self, other: &Self) {
                        self.copy_font_variation_settings_from(other)
                    }

                    /// Get the computed value for font-variation-settings.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_variation_settings(&self) -> longhands::font_variation_settings::computed_value::T {
                        self.font_variation_settings.clone()
                    }
                        /// Set font-language-override.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_language_override(&mut self, v: longhands::font_language_override::computed_value::T) {
                            self.font_language_override = v;
                        }
                        /// Set font-language-override from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_language_override_from(&mut self, other: &Self) {
                            self.font_language_override = other.font_language_override.clone();
                        }
                    /// Reset font-language-override from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_language_override(&mut self, other: &Self) {
                        self.copy_font_language_override_from(other)
                    }

                    /// Get the computed value for font-language-override.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_language_override(&self) -> longhands::font_language_override::computed_value::T {
                        self.font_language_override.clone()
                    }
                        /// Set font-optical-sizing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_optical_sizing(&mut self, v: longhands::font_optical_sizing::computed_value::T) {
                            self.font_optical_sizing = v;
                        }
                        /// Set font-optical-sizing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_optical_sizing_from(&mut self, other: &Self) {
                            self.font_optical_sizing = other.font_optical_sizing.clone();
                        }
                    /// Reset font-optical-sizing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_optical_sizing(&mut self, other: &Self) {
                        self.copy_font_optical_sizing_from(other)
                    }

                    /// Get the computed value for font-optical-sizing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_optical_sizing(&self) -> longhands::font_optical_sizing::computed_value::T {
                        self.font_optical_sizing.clone()
                    }
                        /// Set font-palette.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_font_palette(&mut self, v: longhands::font_palette::computed_value::T) {
                            self.font_palette = v;
                        }
                        /// Set font-palette from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_font_palette_from(&mut self, other: &Self) {
                            self.font_palette = other.font_palette.clone();
                        }
                    /// Reset font-palette from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_font_palette(&mut self, other: &Self) {
                        self.copy_font_palette_from(other)
                    }

                    /// Get the computed value for font-palette.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_font_palette(&self) -> longhands::font_palette::computed_value::T {
                        self.font_palette.clone()
                    }
                        /// Set -x-lang.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_lang(&mut self, v: longhands::_x_lang::computed_value::T) {
                            self._x_lang = v;
                        }
                        /// Set -x-lang from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_lang_from(&mut self, other: &Self) {
                            self._x_lang = other._x_lang.clone();
                        }
                    /// Reset -x-lang from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_lang(&mut self, other: &Self) {
                        self.copy__x_lang_from(other)
                    }

                    /// Get the computed value for -x-lang.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_lang(&self) -> longhands::_x_lang::computed_value::T {
                        self._x_lang.clone()
                    }
                        /// Set math-depth.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_math_depth(&mut self, v: longhands::math_depth::computed_value::T) {
                            self.math_depth = v;
                        }
                        /// Set math-depth from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_math_depth_from(&mut self, other: &Self) {
                            self.math_depth = other.math_depth.clone();
                        }
                    /// Reset math-depth from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_math_depth(&mut self, other: &Self) {
                        self.copy_math_depth_from(other)
                    }

                    /// Get the computed value for math-depth.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_math_depth(&self) -> longhands::math_depth::computed_value::T {
                        self.math_depth.clone()
                    }
                        /// Set math-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_math_style(&mut self, v: longhands::math_style::computed_value::T) {
                            self.math_style = v;
                        }
                        /// Set math-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_math_style_from(&mut self, other: &Self) {
                            self.math_style = other.math_style.clone();
                        }
                    /// Reset math-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_math_style(&mut self, other: &Self) {
                        self.copy_math_style_from(other)
                    }

                    /// Get the computed value for math-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_math_style(&self) -> longhands::math_style::computed_value::T {
                        self.math_style.clone()
                    }
                        /// Set -moz-math-variant.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_math_variant(&mut self, v: longhands::_moz_math_variant::computed_value::T) {
                            self._moz_math_variant = v;
                        }
                        /// Set -moz-math-variant from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_math_variant_from(&mut self, other: &Self) {
                            self._moz_math_variant = other._moz_math_variant.clone();
                        }
                    /// Reset -moz-math-variant from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_math_variant(&mut self, other: &Self) {
                        self.copy__moz_math_variant_from(other)
                    }

                    /// Get the computed value for -moz-math-variant.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_math_variant(&self) -> longhands::_moz_math_variant::computed_value::T {
                        self._moz_math_variant.clone()
                    }
                        /// Set -x-text-scale.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_text_scale(&mut self, v: longhands::_x_text_scale::computed_value::T) {
                            self._x_text_scale = v;
                        }
                        /// Set -x-text-scale from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_text_scale_from(&mut self, other: &Self) {
                            self._x_text_scale = other._x_text_scale.clone();
                        }
                    /// Reset -x-text-scale from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_text_scale(&mut self, other: &Self) {
                        self.copy__x_text_scale_from(other)
                    }

                    /// Get the computed value for -x-text-scale.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_text_scale(&self) -> longhands::_x_text_scale::computed_value::T {
                        self._x_text_scale.clone()
                    }
                        /// Set line-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_line_height(&mut self, v: longhands::line_height::computed_value::T) {
                            self.line_height = v;
                        }
                        /// Set line-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_line_height_from(&mut self, other: &Self) {
                            self.line_height = other.line_height.clone();
                        }
                    /// Reset line-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_line_height(&mut self, other: &Self) {
                        self.copy_line_height_from(other)
                    }

                    /// Get the computed value for line-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_line_height(&self) -> longhands::line_height::computed_value::T {
                        self.line_height.clone()
                    }
                        /// Set -moz-osx-font-smoothing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_osx_font_smoothing(&mut self, v: longhands::_moz_osx_font_smoothing::computed_value::T) {
                            self._moz_osx_font_smoothing = v;
                        }
                        /// Set -moz-osx-font-smoothing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_osx_font_smoothing_from(&mut self, other: &Self) {
                            self._moz_osx_font_smoothing = other._moz_osx_font_smoothing.clone();
                        }
                    /// Reset -moz-osx-font-smoothing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_osx_font_smoothing(&mut self, other: &Self) {
                        self.copy__moz_osx_font_smoothing_from(other)
                    }

                    /// Get the computed value for -moz-osx-font-smoothing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_osx_font_smoothing(&self) -> longhands::_moz_osx_font_smoothing::computed_value::T {
                        self._moz_osx_font_smoothing.clone()
                    }
                        /// Set -moz-min-font-size-ratio.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_min_font_size_ratio(&mut self, v: longhands::_moz_min_font_size_ratio::computed_value::T) {
                            self._moz_min_font_size_ratio = v;
                        }
                        /// Set -moz-min-font-size-ratio from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_min_font_size_ratio_from(&mut self, other: &Self) {
                            self._moz_min_font_size_ratio = other._moz_min_font_size_ratio.clone();
                        }
                    /// Reset -moz-min-font-size-ratio from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_min_font_size_ratio(&mut self, other: &Self) {
                        self.copy__moz_min_font_size_ratio_from(other)
                    }

                    /// Get the computed value for -moz-min-font-size-ratio.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_min_font_size_ratio(&self) -> longhands::_moz_min_font_size_ratio::computed_value::T {
                        self._moz_min_font_size_ratio.clone()
                    }
                /// Computes a font hash in order to be able to cache fonts
                /// effectively in GFX and layout.
                pub fn compute_font_hash(&mut self) {
                    // Corresponds to the fields in
                    // `gfx::font_template::FontTemplateDescriptor`.
                    let mut hasher: FxHasher = Default::default();
                    self.font_weight.hash(&mut hasher);
                    self.font_stretch.hash(&mut hasher);
                    self.font_style.hash(&mut hasher);
                    self.font_family.hash(&mut hasher);
                    self.hash = hasher.finish()
                }

                /// (Servo does not handle MathML, so this just calls copy_font_size_from)
                pub fn inherit_font_size_from(&mut self, parent: &Self,
                                              _: Option<NonNegativeLength>,
                                              _: &Device) {
                    self.copy_font_size_from(parent);
                }
                /// (Servo does not handle MathML, so this just calls set_font_size)
                pub fn apply_font_size(&mut self,
                                       v: longhands::font_size::computed_value::T,
                                       _: &Self,
                                       _: &Device) -> Option<NonNegativeLength> {
                    self.set_font_size(v);
                    None
                }
                /// (Servo does not handle MathML, so this does nothing)
                pub fn apply_unconstrained_font_size(&mut self, _: NonNegativeLength) {
                }

        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedBox style struct.
        pub struct InheritedBox {
                    /// The visibility computed value.
                    pub visibility: longhands::visibility::computed_value::T,
                    /// The writing-mode computed value.
                    pub writing_mode: longhands::writing_mode::computed_value::T,
                    /// The direction computed value.
                    pub direction: longhands::direction::computed_value::T,
                    /// The -moz-box-collapse computed value.
                    pub _moz_box_collapse: longhands::_moz_box_collapse::computed_value::T,
                    /// The text-orientation computed value.
                    pub text_orientation: longhands::text_orientation::computed_value::T,
                    /// The print-color-adjust computed value.
                    pub print_color_adjust: longhands::print_color_adjust::computed_value::T,
                    /// The image-rendering computed value.
                    pub image_rendering: longhands::image_rendering::computed_value::T,
                    /// The image-orientation computed value.
                    pub image_orientation: longhands::image_orientation::computed_value::T,
        }

        impl InheritedBox {
                        /// Set visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_visibility(&mut self, v: longhands::visibility::computed_value::T) {
                            self.visibility = v;
                        }
                        /// Set visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_visibility_from(&mut self, other: &Self) {
                            self.visibility = other.visibility.clone();
                        }
                    /// Reset visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_visibility(&mut self, other: &Self) {
                        self.copy_visibility_from(other)
                    }

                    /// Get the computed value for visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_visibility(&self) -> longhands::visibility::computed_value::T {
                        self.visibility.clone()
                    }
                        /// Set writing-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_writing_mode(&mut self, v: longhands::writing_mode::computed_value::T) {
                            self.writing_mode = v;
                        }
                        /// Set writing-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_writing_mode_from(&mut self, other: &Self) {
                            self.writing_mode = other.writing_mode.clone();
                        }
                    /// Reset writing-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_writing_mode(&mut self, other: &Self) {
                        self.copy_writing_mode_from(other)
                    }

                    /// Get the computed value for writing-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_writing_mode(&self) -> longhands::writing_mode::computed_value::T {
                        self.writing_mode.clone()
                    }
                        /// Set direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_direction(&mut self, v: longhands::direction::computed_value::T) {
                            self.direction = v;
                        }
                        /// Set direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_direction_from(&mut self, other: &Self) {
                            self.direction = other.direction.clone();
                        }
                    /// Reset direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_direction(&mut self, other: &Self) {
                        self.copy_direction_from(other)
                    }

                    /// Get the computed value for direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_direction(&self) -> longhands::direction::computed_value::T {
                        self.direction.clone()
                    }
                        /// Set -moz-box-collapse.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_collapse(&mut self, v: longhands::_moz_box_collapse::computed_value::T) {
                            self._moz_box_collapse = v;
                        }
                        /// Set -moz-box-collapse from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_collapse_from(&mut self, other: &Self) {
                            self._moz_box_collapse = other._moz_box_collapse.clone();
                        }
                    /// Reset -moz-box-collapse from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_collapse(&mut self, other: &Self) {
                        self.copy__moz_box_collapse_from(other)
                    }

                    /// Get the computed value for -moz-box-collapse.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_collapse(&self) -> longhands::_moz_box_collapse::computed_value::T {
                        self._moz_box_collapse.clone()
                    }
                        /// Set text-orientation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_orientation(&mut self, v: longhands::text_orientation::computed_value::T) {
                            self.text_orientation = v;
                        }
                        /// Set text-orientation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_orientation_from(&mut self, other: &Self) {
                            self.text_orientation = other.text_orientation.clone();
                        }
                    /// Reset text-orientation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_orientation(&mut self, other: &Self) {
                        self.copy_text_orientation_from(other)
                    }

                    /// Get the computed value for text-orientation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_orientation(&self) -> longhands::text_orientation::computed_value::T {
                        self.text_orientation.clone()
                    }
                        /// Set print-color-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_print_color_adjust(&mut self, v: longhands::print_color_adjust::computed_value::T) {
                            self.print_color_adjust = v;
                        }
                        /// Set print-color-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_print_color_adjust_from(&mut self, other: &Self) {
                            self.print_color_adjust = other.print_color_adjust.clone();
                        }
                    /// Reset print-color-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_print_color_adjust(&mut self, other: &Self) {
                        self.copy_print_color_adjust_from(other)
                    }

                    /// Get the computed value for print-color-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_print_color_adjust(&self) -> longhands::print_color_adjust::computed_value::T {
                        self.print_color_adjust.clone()
                    }
                        /// Set image-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_image_rendering(&mut self, v: longhands::image_rendering::computed_value::T) {
                            self.image_rendering = v;
                        }
                        /// Set image-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_image_rendering_from(&mut self, other: &Self) {
                            self.image_rendering = other.image_rendering.clone();
                        }
                    /// Reset image-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_image_rendering(&mut self, other: &Self) {
                        self.copy_image_rendering_from(other)
                    }

                    /// Get the computed value for image-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_image_rendering(&self) -> longhands::image_rendering::computed_value::T {
                        self.image_rendering.clone()
                    }
                        /// Set image-orientation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_image_orientation(&mut self, v: longhands::image_orientation::computed_value::T) {
                            self.image_orientation = v;
                        }
                        /// Set image-orientation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_image_orientation_from(&mut self, other: &Self) {
                            self.image_orientation = other.image_orientation.clone();
                        }
                    /// Reset image-orientation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_image_orientation(&mut self, other: &Self) {
                        self.copy_image_orientation_from(other)
                    }

                    /// Get the computed value for image-orientation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_image_orientation(&self) -> longhands::image_orientation::computed_value::T {
                        self.image_orientation.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedSVG style struct.
        pub struct InheritedSVG {
                    /// The dominant-baseline computed value.
                    pub dominant_baseline: longhands::dominant_baseline::computed_value::T,
                    /// The text-anchor computed value.
                    pub text_anchor: longhands::text_anchor::computed_value::T,
                    /// The color-interpolation computed value.
                    pub color_interpolation: longhands::color_interpolation::computed_value::T,
                    /// The color-interpolation-filters computed value.
                    pub color_interpolation_filters: longhands::color_interpolation_filters::computed_value::T,
                    /// The fill computed value.
                    pub fill: longhands::fill::computed_value::T,
                    /// The fill-opacity computed value.
                    pub fill_opacity: longhands::fill_opacity::computed_value::T,
                    /// The fill-rule computed value.
                    pub fill_rule: longhands::fill_rule::computed_value::T,
                    /// The shape-rendering computed value.
                    pub shape_rendering: longhands::shape_rendering::computed_value::T,
                    /// The stroke computed value.
                    pub stroke: longhands::stroke::computed_value::T,
                    /// The stroke-width computed value.
                    pub stroke_width: longhands::stroke_width::computed_value::T,
                    /// The stroke-linecap computed value.
                    pub stroke_linecap: longhands::stroke_linecap::computed_value::T,
                    /// The stroke-linejoin computed value.
                    pub stroke_linejoin: longhands::stroke_linejoin::computed_value::T,
                    /// The stroke-miterlimit computed value.
                    pub stroke_miterlimit: longhands::stroke_miterlimit::computed_value::T,
                    /// The stroke-opacity computed value.
                    pub stroke_opacity: longhands::stroke_opacity::computed_value::T,
                    /// The stroke-dasharray computed value.
                    pub stroke_dasharray: longhands::stroke_dasharray::computed_value::T,
                    /// The stroke-dashoffset computed value.
                    pub stroke_dashoffset: longhands::stroke_dashoffset::computed_value::T,
                    /// The clip-rule computed value.
                    pub clip_rule: longhands::clip_rule::computed_value::T,
                    /// The marker-start computed value.
                    pub marker_start: longhands::marker_start::computed_value::T,
                    /// The marker-mid computed value.
                    pub marker_mid: longhands::marker_mid::computed_value::T,
                    /// The marker-end computed value.
                    pub marker_end: longhands::marker_end::computed_value::T,
                    /// The paint-order computed value.
                    pub paint_order: longhands::paint_order::computed_value::T,
                    /// The -moz-context-properties computed value.
                    pub _moz_context_properties: longhands::_moz_context_properties::computed_value::T,
        }

        impl InheritedSVG {
                        /// Set dominant-baseline.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_dominant_baseline(&mut self, v: longhands::dominant_baseline::computed_value::T) {
                            self.dominant_baseline = v;
                        }
                        /// Set dominant-baseline from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_dominant_baseline_from(&mut self, other: &Self) {
                            self.dominant_baseline = other.dominant_baseline.clone();
                        }
                    /// Reset dominant-baseline from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_dominant_baseline(&mut self, other: &Self) {
                        self.copy_dominant_baseline_from(other)
                    }

                    /// Get the computed value for dominant-baseline.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_dominant_baseline(&self) -> longhands::dominant_baseline::computed_value::T {
                        self.dominant_baseline.clone()
                    }
                        /// Set text-anchor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_anchor(&mut self, v: longhands::text_anchor::computed_value::T) {
                            self.text_anchor = v;
                        }
                        /// Set text-anchor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_anchor_from(&mut self, other: &Self) {
                            self.text_anchor = other.text_anchor.clone();
                        }
                    /// Reset text-anchor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_anchor(&mut self, other: &Self) {
                        self.copy_text_anchor_from(other)
                    }

                    /// Get the computed value for text-anchor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_anchor(&self) -> longhands::text_anchor::computed_value::T {
                        self.text_anchor.clone()
                    }
                        /// Set color-interpolation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_interpolation(&mut self, v: longhands::color_interpolation::computed_value::T) {
                            self.color_interpolation = v;
                        }
                        /// Set color-interpolation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_interpolation_from(&mut self, other: &Self) {
                            self.color_interpolation = other.color_interpolation.clone();
                        }
                    /// Reset color-interpolation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_interpolation(&mut self, other: &Self) {
                        self.copy_color_interpolation_from(other)
                    }

                    /// Get the computed value for color-interpolation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_interpolation(&self) -> longhands::color_interpolation::computed_value::T {
                        self.color_interpolation.clone()
                    }
                        /// Set color-interpolation-filters.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_interpolation_filters(&mut self, v: longhands::color_interpolation_filters::computed_value::T) {
                            self.color_interpolation_filters = v;
                        }
                        /// Set color-interpolation-filters from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_interpolation_filters_from(&mut self, other: &Self) {
                            self.color_interpolation_filters = other.color_interpolation_filters.clone();
                        }
                    /// Reset color-interpolation-filters from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_interpolation_filters(&mut self, other: &Self) {
                        self.copy_color_interpolation_filters_from(other)
                    }

                    /// Get the computed value for color-interpolation-filters.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_interpolation_filters(&self) -> longhands::color_interpolation_filters::computed_value::T {
                        self.color_interpolation_filters.clone()
                    }
                        /// Set fill.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill(&mut self, v: longhands::fill::computed_value::T) {
                            self.fill = v;
                        }
                        /// Set fill from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_from(&mut self, other: &Self) {
                            self.fill = other.fill.clone();
                        }
                    /// Reset fill from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill(&mut self, other: &Self) {
                        self.copy_fill_from(other)
                    }

                    /// Get the computed value for fill.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill(&self) -> longhands::fill::computed_value::T {
                        self.fill.clone()
                    }
                        /// Set fill-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill_opacity(&mut self, v: longhands::fill_opacity::computed_value::T) {
                            self.fill_opacity = v;
                        }
                        /// Set fill-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_opacity_from(&mut self, other: &Self) {
                            self.fill_opacity = other.fill_opacity.clone();
                        }
                    /// Reset fill-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill_opacity(&mut self, other: &Self) {
                        self.copy_fill_opacity_from(other)
                    }

                    /// Get the computed value for fill-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill_opacity(&self) -> longhands::fill_opacity::computed_value::T {
                        self.fill_opacity.clone()
                    }
                        /// Set fill-rule.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_fill_rule(&mut self, v: longhands::fill_rule::computed_value::T) {
                            self.fill_rule = v;
                        }
                        /// Set fill-rule from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_fill_rule_from(&mut self, other: &Self) {
                            self.fill_rule = other.fill_rule.clone();
                        }
                    /// Reset fill-rule from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_fill_rule(&mut self, other: &Self) {
                        self.copy_fill_rule_from(other)
                    }

                    /// Get the computed value for fill-rule.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_fill_rule(&self) -> longhands::fill_rule::computed_value::T {
                        self.fill_rule.clone()
                    }
                        /// Set shape-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_shape_rendering(&mut self, v: longhands::shape_rendering::computed_value::T) {
                            self.shape_rendering = v;
                        }
                        /// Set shape-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_shape_rendering_from(&mut self, other: &Self) {
                            self.shape_rendering = other.shape_rendering.clone();
                        }
                    /// Reset shape-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_shape_rendering(&mut self, other: &Self) {
                        self.copy_shape_rendering_from(other)
                    }

                    /// Get the computed value for shape-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_shape_rendering(&self) -> longhands::shape_rendering::computed_value::T {
                        self.shape_rendering.clone()
                    }
                        /// Set stroke.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke(&mut self, v: longhands::stroke::computed_value::T) {
                            self.stroke = v;
                        }
                        /// Set stroke from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_from(&mut self, other: &Self) {
                            self.stroke = other.stroke.clone();
                        }
                    /// Reset stroke from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke(&mut self, other: &Self) {
                        self.copy_stroke_from(other)
                    }

                    /// Get the computed value for stroke.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke(&self) -> longhands::stroke::computed_value::T {
                        self.stroke.clone()
                    }
                        /// Set stroke-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_width(&mut self, v: longhands::stroke_width::computed_value::T) {
                            self.stroke_width = v;
                        }
                        /// Set stroke-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_width_from(&mut self, other: &Self) {
                            self.stroke_width = other.stroke_width.clone();
                        }
                    /// Reset stroke-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_width(&mut self, other: &Self) {
                        self.copy_stroke_width_from(other)
                    }

                    /// Get the computed value for stroke-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_width(&self) -> longhands::stroke_width::computed_value::T {
                        self.stroke_width.clone()
                    }
                        /// Set stroke-linecap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_linecap(&mut self, v: longhands::stroke_linecap::computed_value::T) {
                            self.stroke_linecap = v;
                        }
                        /// Set stroke-linecap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_linecap_from(&mut self, other: &Self) {
                            self.stroke_linecap = other.stroke_linecap.clone();
                        }
                    /// Reset stroke-linecap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_linecap(&mut self, other: &Self) {
                        self.copy_stroke_linecap_from(other)
                    }

                    /// Get the computed value for stroke-linecap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_linecap(&self) -> longhands::stroke_linecap::computed_value::T {
                        self.stroke_linecap.clone()
                    }
                        /// Set stroke-linejoin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_linejoin(&mut self, v: longhands::stroke_linejoin::computed_value::T) {
                            self.stroke_linejoin = v;
                        }
                        /// Set stroke-linejoin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_linejoin_from(&mut self, other: &Self) {
                            self.stroke_linejoin = other.stroke_linejoin.clone();
                        }
                    /// Reset stroke-linejoin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_linejoin(&mut self, other: &Self) {
                        self.copy_stroke_linejoin_from(other)
                    }

                    /// Get the computed value for stroke-linejoin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_linejoin(&self) -> longhands::stroke_linejoin::computed_value::T {
                        self.stroke_linejoin.clone()
                    }
                        /// Set stroke-miterlimit.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_miterlimit(&mut self, v: longhands::stroke_miterlimit::computed_value::T) {
                            self.stroke_miterlimit = v;
                        }
                        /// Set stroke-miterlimit from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_miterlimit_from(&mut self, other: &Self) {
                            self.stroke_miterlimit = other.stroke_miterlimit.clone();
                        }
                    /// Reset stroke-miterlimit from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_miterlimit(&mut self, other: &Self) {
                        self.copy_stroke_miterlimit_from(other)
                    }

                    /// Get the computed value for stroke-miterlimit.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_miterlimit(&self) -> longhands::stroke_miterlimit::computed_value::T {
                        self.stroke_miterlimit.clone()
                    }
                        /// Set stroke-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_opacity(&mut self, v: longhands::stroke_opacity::computed_value::T) {
                            self.stroke_opacity = v;
                        }
                        /// Set stroke-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_opacity_from(&mut self, other: &Self) {
                            self.stroke_opacity = other.stroke_opacity.clone();
                        }
                    /// Reset stroke-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_opacity(&mut self, other: &Self) {
                        self.copy_stroke_opacity_from(other)
                    }

                    /// Get the computed value for stroke-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_opacity(&self) -> longhands::stroke_opacity::computed_value::T {
                        self.stroke_opacity.clone()
                    }
                        /// Set stroke-dasharray.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_dasharray(&mut self, v: longhands::stroke_dasharray::computed_value::T) {
                            self.stroke_dasharray = v;
                        }
                        /// Set stroke-dasharray from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_dasharray_from(&mut self, other: &Self) {
                            self.stroke_dasharray = other.stroke_dasharray.clone();
                        }
                    /// Reset stroke-dasharray from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_dasharray(&mut self, other: &Self) {
                        self.copy_stroke_dasharray_from(other)
                    }

                    /// Get the computed value for stroke-dasharray.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_dasharray(&self) -> longhands::stroke_dasharray::computed_value::T {
                        self.stroke_dasharray.clone()
                    }
                        /// Set stroke-dashoffset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stroke_dashoffset(&mut self, v: longhands::stroke_dashoffset::computed_value::T) {
                            self.stroke_dashoffset = v;
                        }
                        /// Set stroke-dashoffset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stroke_dashoffset_from(&mut self, other: &Self) {
                            self.stroke_dashoffset = other.stroke_dashoffset.clone();
                        }
                    /// Reset stroke-dashoffset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stroke_dashoffset(&mut self, other: &Self) {
                        self.copy_stroke_dashoffset_from(other)
                    }

                    /// Get the computed value for stroke-dashoffset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stroke_dashoffset(&self) -> longhands::stroke_dashoffset::computed_value::T {
                        self.stroke_dashoffset.clone()
                    }
                        /// Set clip-rule.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip_rule(&mut self, v: longhands::clip_rule::computed_value::T) {
                            self.clip_rule = v;
                        }
                        /// Set clip-rule from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_rule_from(&mut self, other: &Self) {
                            self.clip_rule = other.clip_rule.clone();
                        }
                    /// Reset clip-rule from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip_rule(&mut self, other: &Self) {
                        self.copy_clip_rule_from(other)
                    }

                    /// Get the computed value for clip-rule.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip_rule(&self) -> longhands::clip_rule::computed_value::T {
                        self.clip_rule.clone()
                    }
                        /// Set marker-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_start(&mut self, v: longhands::marker_start::computed_value::T) {
                            self.marker_start = v;
                        }
                        /// Set marker-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_start_from(&mut self, other: &Self) {
                            self.marker_start = other.marker_start.clone();
                        }
                    /// Reset marker-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_start(&mut self, other: &Self) {
                        self.copy_marker_start_from(other)
                    }

                    /// Get the computed value for marker-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_start(&self) -> longhands::marker_start::computed_value::T {
                        self.marker_start.clone()
                    }
                        /// Set marker-mid.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_mid(&mut self, v: longhands::marker_mid::computed_value::T) {
                            self.marker_mid = v;
                        }
                        /// Set marker-mid from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_mid_from(&mut self, other: &Self) {
                            self.marker_mid = other.marker_mid.clone();
                        }
                    /// Reset marker-mid from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_mid(&mut self, other: &Self) {
                        self.copy_marker_mid_from(other)
                    }

                    /// Get the computed value for marker-mid.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_mid(&self) -> longhands::marker_mid::computed_value::T {
                        self.marker_mid.clone()
                    }
                        /// Set marker-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_marker_end(&mut self, v: longhands::marker_end::computed_value::T) {
                            self.marker_end = v;
                        }
                        /// Set marker-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_marker_end_from(&mut self, other: &Self) {
                            self.marker_end = other.marker_end.clone();
                        }
                    /// Reset marker-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_marker_end(&mut self, other: &Self) {
                        self.copy_marker_end_from(other)
                    }

                    /// Get the computed value for marker-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_marker_end(&self) -> longhands::marker_end::computed_value::T {
                        self.marker_end.clone()
                    }
                        /// Set paint-order.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_paint_order(&mut self, v: longhands::paint_order::computed_value::T) {
                            self.paint_order = v;
                        }
                        /// Set paint-order from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_paint_order_from(&mut self, other: &Self) {
                            self.paint_order = other.paint_order.clone();
                        }
                    /// Reset paint-order from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_paint_order(&mut self, other: &Self) {
                        self.copy_paint_order_from(other)
                    }

                    /// Get the computed value for paint-order.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_paint_order(&self) -> longhands::paint_order::computed_value::T {
                        self.paint_order.clone()
                    }
                        /// Set -moz-context-properties.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_context_properties(&mut self, v: longhands::_moz_context_properties::computed_value::T) {
                            self._moz_context_properties = v;
                        }
                        /// Set -moz-context-properties from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_context_properties_from(&mut self, other: &Self) {
                            self._moz_context_properties = other._moz_context_properties.clone();
                        }
                    /// Reset -moz-context-properties from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_context_properties(&mut self, other: &Self) {
                        self.copy__moz_context_properties_from(other)
                    }

                    /// Get the computed value for -moz-context-properties.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_context_properties(&self) -> longhands::_moz_context_properties::computed_value::T {
                        self._moz_context_properties.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedTable style struct.
        pub struct InheritedTable {
                    /// The border-collapse computed value.
                    pub border_collapse: longhands::border_collapse::computed_value::T,
                    /// The empty-cells computed value.
                    pub empty_cells: longhands::empty_cells::computed_value::T,
                    /// The caption-side computed value.
                    pub caption_side: longhands::caption_side::computed_value::T,
                    /// The border-spacing computed value.
                    pub border_spacing: longhands::border_spacing::computed_value::T,
        }

        impl InheritedTable {
                        /// Set border-collapse.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_collapse(&mut self, v: longhands::border_collapse::computed_value::T) {
                            self.border_collapse = v;
                        }
                        /// Set border-collapse from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_collapse_from(&mut self, other: &Self) {
                            self.border_collapse = other.border_collapse.clone();
                        }
                    /// Reset border-collapse from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_collapse(&mut self, other: &Self) {
                        self.copy_border_collapse_from(other)
                    }

                    /// Get the computed value for border-collapse.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_collapse(&self) -> longhands::border_collapse::computed_value::T {
                        self.border_collapse.clone()
                    }
                        /// Set empty-cells.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_empty_cells(&mut self, v: longhands::empty_cells::computed_value::T) {
                            self.empty_cells = v;
                        }
                        /// Set empty-cells from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_empty_cells_from(&mut self, other: &Self) {
                            self.empty_cells = other.empty_cells.clone();
                        }
                    /// Reset empty-cells from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_empty_cells(&mut self, other: &Self) {
                        self.copy_empty_cells_from(other)
                    }

                    /// Get the computed value for empty-cells.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_empty_cells(&self) -> longhands::empty_cells::computed_value::T {
                        self.empty_cells.clone()
                    }
                        /// Set caption-side.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_caption_side(&mut self, v: longhands::caption_side::computed_value::T) {
                            self.caption_side = v;
                        }
                        /// Set caption-side from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_caption_side_from(&mut self, other: &Self) {
                            self.caption_side = other.caption_side.clone();
                        }
                    /// Reset caption-side from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_caption_side(&mut self, other: &Self) {
                        self.copy_caption_side_from(other)
                    }

                    /// Get the computed value for caption-side.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_caption_side(&self) -> longhands::caption_side::computed_value::T {
                        self.caption_side.clone()
                    }
                        /// Set border-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_border_spacing(&mut self, v: longhands::border_spacing::computed_value::T) {
                            self.border_spacing = v;
                        }
                        /// Set border-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_border_spacing_from(&mut self, other: &Self) {
                            self.border_spacing = other.border_spacing.clone();
                        }
                    /// Reset border-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_border_spacing(&mut self, other: &Self) {
                        self.copy_border_spacing_from(other)
                    }

                    /// Get the computed value for border-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_border_spacing(&self) -> longhands::border_spacing::computed_value::T {
                        self.border_spacing.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedText style struct.
        pub struct InheritedText {
                    /// The color computed value.
                    pub color: longhands::color::computed_value::T,
                    /// The text-transform computed value.
                    pub text_transform: longhands::text_transform::computed_value::T,
                    /// The hyphens computed value.
                    pub hyphens: longhands::hyphens::computed_value::T,
                    /// The -moz-text-size-adjust computed value.
                    pub _moz_text_size_adjust: longhands::_moz_text_size_adjust::computed_value::T,
                    /// The text-indent computed value.
                    pub text_indent: longhands::text_indent::computed_value::T,
                    /// The overflow-wrap computed value.
                    pub overflow_wrap: longhands::overflow_wrap::computed_value::T,
                    /// The word-break computed value.
                    pub word_break: longhands::word_break::computed_value::T,
                    /// The text-justify computed value.
                    pub text_justify: longhands::text_justify::computed_value::T,
                    /// The text-align-last computed value.
                    pub text_align_last: longhands::text_align_last::computed_value::T,
                    /// The text-align computed value.
                    pub text_align: longhands::text_align::computed_value::T,
                    /// The letter-spacing computed value.
                    pub letter_spacing: longhands::letter_spacing::computed_value::T,
                    /// The word-spacing computed value.
                    pub word_spacing: longhands::word_spacing::computed_value::T,
                    /// The white-space-collapse computed value.
                    pub white_space_collapse: longhands::white_space_collapse::computed_value::T,
                    /// The text-shadow computed value.
                    pub text_shadow: longhands::text_shadow::computed_value::T,
                    /// The text-emphasis-style computed value.
                    pub text_emphasis_style: longhands::text_emphasis_style::computed_value::T,
                    /// The text-emphasis-position computed value.
                    pub text_emphasis_position: longhands::text_emphasis_position::computed_value::T,
                    /// The text-emphasis-color computed value.
                    pub text_emphasis_color: longhands::text_emphasis_color::computed_value::T,
                    /// The tab-size computed value.
                    pub tab_size: longhands::tab_size::computed_value::T,
                    /// The line-break computed value.
                    pub line_break: longhands::line_break::computed_value::T,
                    /// The -webkit-text-fill-color computed value.
                    pub _webkit_text_fill_color: longhands::_webkit_text_fill_color::computed_value::T,
                    /// The -webkit-text-stroke-color computed value.
                    pub _webkit_text_stroke_color: longhands::_webkit_text_stroke_color::computed_value::T,
                    /// The -webkit-text-stroke-width computed value.
                    pub _webkit_text_stroke_width: longhands::_webkit_text_stroke_width::computed_value::T,
                    /// The ruby-align computed value.
                    pub ruby_align: longhands::ruby_align::computed_value::T,
                    /// The ruby-position computed value.
                    pub ruby_position: longhands::ruby_position::computed_value::T,
                    /// The text-combine-upright computed value.
                    pub text_combine_upright: longhands::text_combine_upright::computed_value::T,
                    /// The text-rendering computed value.
                    pub text_rendering: longhands::text_rendering::computed_value::T,
                    /// The -moz-control-character-visibility computed value.
                    pub _moz_control_character_visibility: longhands::_moz_control_character_visibility::computed_value::T,
                    /// The text-underline-offset computed value.
                    pub text_underline_offset: longhands::text_underline_offset::computed_value::T,
                    /// The text-underline-position computed value.
                    pub text_underline_position: longhands::text_underline_position::computed_value::T,
                    /// The text-decoration-skip-ink computed value.
                    pub text_decoration_skip_ink: longhands::text_decoration_skip_ink::computed_value::T,
                    /// The hyphenate-character computed value.
                    pub hyphenate_character: longhands::hyphenate_character::computed_value::T,
                    /// The forced-color-adjust computed value.
                    pub forced_color_adjust: longhands::forced_color_adjust::computed_value::T,
                    /// The -webkit-text-security computed value.
                    pub _webkit_text_security: longhands::_webkit_text_security::computed_value::T,
                    /// The text-wrap-mode computed value.
                    pub text_wrap_mode: longhands::text_wrap_mode::computed_value::T,
                    /// The text-wrap-style computed value.
                    pub text_wrap_style: longhands::text_wrap_style::computed_value::T,
                /// The "used" text-decorations that apply to this box.
                ///
                /// FIXME(emilio): This is technically a box-tree concept, and
                /// would be nice to move away from style.
                pub text_decorations_in_effect: crate::values::computed::text::TextDecorationsInEffect,
        }

        impl InheritedText {
                        /// Set color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color(&mut self, v: longhands::color::computed_value::T) {
                            self.color = v;
                        }
                        /// Set color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_from(&mut self, other: &Self) {
                            self.color = other.color.clone();
                        }
                    /// Reset color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color(&mut self, other: &Self) {
                        self.copy_color_from(other)
                    }

                    /// Get the computed value for color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color(&self) -> longhands::color::computed_value::T {
                        self.color.clone()
                    }
                        /// Set text-transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_transform(&mut self, v: longhands::text_transform::computed_value::T) {
                            self.text_transform = v;
                        }
                        /// Set text-transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_transform_from(&mut self, other: &Self) {
                            self.text_transform = other.text_transform.clone();
                        }
                    /// Reset text-transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_transform(&mut self, other: &Self) {
                        self.copy_text_transform_from(other)
                    }

                    /// Get the computed value for text-transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_transform(&self) -> longhands::text_transform::computed_value::T {
                        self.text_transform.clone()
                    }
                        /// Set hyphens.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_hyphens(&mut self, v: longhands::hyphens::computed_value::T) {
                            self.hyphens = v;
                        }
                        /// Set hyphens from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_hyphens_from(&mut self, other: &Self) {
                            self.hyphens = other.hyphens.clone();
                        }
                    /// Reset hyphens from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_hyphens(&mut self, other: &Self) {
                        self.copy_hyphens_from(other)
                    }

                    /// Get the computed value for hyphens.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_hyphens(&self) -> longhands::hyphens::computed_value::T {
                        self.hyphens.clone()
                    }
                        /// Set -moz-text-size-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_text_size_adjust(&mut self, v: longhands::_moz_text_size_adjust::computed_value::T) {
                            self._moz_text_size_adjust = v;
                        }
                        /// Set -moz-text-size-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_text_size_adjust_from(&mut self, other: &Self) {
                            self._moz_text_size_adjust = other._moz_text_size_adjust.clone();
                        }
                    /// Reset -moz-text-size-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_text_size_adjust(&mut self, other: &Self) {
                        self.copy__moz_text_size_adjust_from(other)
                    }

                    /// Get the computed value for -moz-text-size-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_text_size_adjust(&self) -> longhands::_moz_text_size_adjust::computed_value::T {
                        self._moz_text_size_adjust.clone()
                    }
                        /// Set text-indent.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_indent(&mut self, v: longhands::text_indent::computed_value::T) {
                            self.text_indent = v;
                        }
                        /// Set text-indent from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_indent_from(&mut self, other: &Self) {
                            self.text_indent = other.text_indent.clone();
                        }
                    /// Reset text-indent from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_indent(&mut self, other: &Self) {
                        self.copy_text_indent_from(other)
                    }

                    /// Get the computed value for text-indent.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_indent(&self) -> longhands::text_indent::computed_value::T {
                        self.text_indent.clone()
                    }
                        /// Set overflow-wrap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_wrap(&mut self, v: longhands::overflow_wrap::computed_value::T) {
                            self.overflow_wrap = v;
                        }
                        /// Set overflow-wrap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_wrap_from(&mut self, other: &Self) {
                            self.overflow_wrap = other.overflow_wrap.clone();
                        }
                    /// Reset overflow-wrap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_wrap(&mut self, other: &Self) {
                        self.copy_overflow_wrap_from(other)
                    }

                    /// Get the computed value for overflow-wrap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_wrap(&self) -> longhands::overflow_wrap::computed_value::T {
                        self.overflow_wrap.clone()
                    }
                        /// Set word-break.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_word_break(&mut self, v: longhands::word_break::computed_value::T) {
                            self.word_break = v;
                        }
                        /// Set word-break from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_word_break_from(&mut self, other: &Self) {
                            self.word_break = other.word_break.clone();
                        }
                    /// Reset word-break from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_word_break(&mut self, other: &Self) {
                        self.copy_word_break_from(other)
                    }

                    /// Get the computed value for word-break.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_word_break(&self) -> longhands::word_break::computed_value::T {
                        self.word_break.clone()
                    }
                        /// Set text-justify.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_justify(&mut self, v: longhands::text_justify::computed_value::T) {
                            self.text_justify = v;
                        }
                        /// Set text-justify from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_justify_from(&mut self, other: &Self) {
                            self.text_justify = other.text_justify.clone();
                        }
                    /// Reset text-justify from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_justify(&mut self, other: &Self) {
                        self.copy_text_justify_from(other)
                    }

                    /// Get the computed value for text-justify.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_justify(&self) -> longhands::text_justify::computed_value::T {
                        self.text_justify.clone()
                    }
                        /// Set text-align-last.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_align_last(&mut self, v: longhands::text_align_last::computed_value::T) {
                            self.text_align_last = v;
                        }
                        /// Set text-align-last from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_align_last_from(&mut self, other: &Self) {
                            self.text_align_last = other.text_align_last.clone();
                        }
                    /// Reset text-align-last from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_align_last(&mut self, other: &Self) {
                        self.copy_text_align_last_from(other)
                    }

                    /// Get the computed value for text-align-last.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_align_last(&self) -> longhands::text_align_last::computed_value::T {
                        self.text_align_last.clone()
                    }
                        /// Set text-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_align(&mut self, v: longhands::text_align::computed_value::T) {
                            self.text_align = v;
                        }
                        /// Set text-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_align_from(&mut self, other: &Self) {
                            self.text_align = other.text_align.clone();
                        }
                    /// Reset text-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_align(&mut self, other: &Self) {
                        self.copy_text_align_from(other)
                    }

                    /// Get the computed value for text-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_align(&self) -> longhands::text_align::computed_value::T {
                        self.text_align.clone()
                    }
                        /// Set letter-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_letter_spacing(&mut self, v: longhands::letter_spacing::computed_value::T) {
                            self.letter_spacing = v;
                        }
                        /// Set letter-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_letter_spacing_from(&mut self, other: &Self) {
                            self.letter_spacing = other.letter_spacing.clone();
                        }
                    /// Reset letter-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_letter_spacing(&mut self, other: &Self) {
                        self.copy_letter_spacing_from(other)
                    }

                    /// Get the computed value for letter-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_letter_spacing(&self) -> longhands::letter_spacing::computed_value::T {
                        self.letter_spacing.clone()
                    }
                        /// Set word-spacing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_word_spacing(&mut self, v: longhands::word_spacing::computed_value::T) {
                            self.word_spacing = v;
                        }
                        /// Set word-spacing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_word_spacing_from(&mut self, other: &Self) {
                            self.word_spacing = other.word_spacing.clone();
                        }
                    /// Reset word-spacing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_word_spacing(&mut self, other: &Self) {
                        self.copy_word_spacing_from(other)
                    }

                    /// Get the computed value for word-spacing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_word_spacing(&self) -> longhands::word_spacing::computed_value::T {
                        self.word_spacing.clone()
                    }
                        /// Set white-space-collapse.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_white_space_collapse(&mut self, v: longhands::white_space_collapse::computed_value::T) {
                            self.white_space_collapse = v;
                        }
                        /// Set white-space-collapse from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_white_space_collapse_from(&mut self, other: &Self) {
                            self.white_space_collapse = other.white_space_collapse.clone();
                        }
                    /// Reset white-space-collapse from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_white_space_collapse(&mut self, other: &Self) {
                        self.copy_white_space_collapse_from(other)
                    }

                    /// Get the computed value for white-space-collapse.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_white_space_collapse(&self) -> longhands::white_space_collapse::computed_value::T {
                        self.white_space_collapse.clone()
                    }
                        /// Set text-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_shadow(&mut self, v: longhands::text_shadow::computed_value::T) {
                            self.text_shadow = v;
                        }
                        /// Set text-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_shadow_from(&mut self, other: &Self) {
                            self.text_shadow = other.text_shadow.clone();
                        }
                    /// Reset text-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_shadow(&mut self, other: &Self) {
                        self.copy_text_shadow_from(other)
                    }

                    /// Get the computed value for text-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_shadow(&self) -> longhands::text_shadow::computed_value::T {
                        self.text_shadow.clone()
                    }
                        /// Set text-emphasis-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_style(&mut self, v: longhands::text_emphasis_style::computed_value::T) {
                            self.text_emphasis_style = v;
                        }
                        /// Set text-emphasis-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_style_from(&mut self, other: &Self) {
                            self.text_emphasis_style = other.text_emphasis_style.clone();
                        }
                    /// Reset text-emphasis-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_style(&mut self, other: &Self) {
                        self.copy_text_emphasis_style_from(other)
                    }

                    /// Get the computed value for text-emphasis-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_style(&self) -> longhands::text_emphasis_style::computed_value::T {
                        self.text_emphasis_style.clone()
                    }
                        /// Set text-emphasis-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_position(&mut self, v: longhands::text_emphasis_position::computed_value::T) {
                            self.text_emphasis_position = v;
                        }
                        /// Set text-emphasis-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_position_from(&mut self, other: &Self) {
                            self.text_emphasis_position = other.text_emphasis_position.clone();
                        }
                    /// Reset text-emphasis-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_position(&mut self, other: &Self) {
                        self.copy_text_emphasis_position_from(other)
                    }

                    /// Get the computed value for text-emphasis-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_position(&self) -> longhands::text_emphasis_position::computed_value::T {
                        self.text_emphasis_position.clone()
                    }
                        /// Set text-emphasis-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_emphasis_color(&mut self, v: longhands::text_emphasis_color::computed_value::T) {
                            self.text_emphasis_color = v;
                        }
                        /// Set text-emphasis-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_emphasis_color_from(&mut self, other: &Self) {
                            self.text_emphasis_color = other.text_emphasis_color.clone();
                        }
                    /// Reset text-emphasis-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_emphasis_color(&mut self, other: &Self) {
                        self.copy_text_emphasis_color_from(other)
                    }

                    /// Get the computed value for text-emphasis-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_emphasis_color(&self) -> longhands::text_emphasis_color::computed_value::T {
                        self.text_emphasis_color.clone()
                    }
                        /// Set tab-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_tab_size(&mut self, v: longhands::tab_size::computed_value::T) {
                            self.tab_size = v;
                        }
                        /// Set tab-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_tab_size_from(&mut self, other: &Self) {
                            self.tab_size = other.tab_size.clone();
                        }
                    /// Reset tab-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_tab_size(&mut self, other: &Self) {
                        self.copy_tab_size_from(other)
                    }

                    /// Get the computed value for tab-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_tab_size(&self) -> longhands::tab_size::computed_value::T {
                        self.tab_size.clone()
                    }
                        /// Set line-break.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_line_break(&mut self, v: longhands::line_break::computed_value::T) {
                            self.line_break = v;
                        }
                        /// Set line-break from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_line_break_from(&mut self, other: &Self) {
                            self.line_break = other.line_break.clone();
                        }
                    /// Reset line-break from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_line_break(&mut self, other: &Self) {
                        self.copy_line_break_from(other)
                    }

                    /// Get the computed value for line-break.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_line_break(&self) -> longhands::line_break::computed_value::T {
                        self.line_break.clone()
                    }
                        /// Set -webkit-text-fill-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_fill_color(&mut self, v: longhands::_webkit_text_fill_color::computed_value::T) {
                            self._webkit_text_fill_color = v;
                        }
                        /// Set -webkit-text-fill-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_fill_color_from(&mut self, other: &Self) {
                            self._webkit_text_fill_color = other._webkit_text_fill_color.clone();
                        }
                    /// Reset -webkit-text-fill-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_fill_color(&mut self, other: &Self) {
                        self.copy__webkit_text_fill_color_from(other)
                    }

                    /// Get the computed value for -webkit-text-fill-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_fill_color(&self) -> longhands::_webkit_text_fill_color::computed_value::T {
                        self._webkit_text_fill_color.clone()
                    }
                        /// Set -webkit-text-stroke-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_stroke_color(&mut self, v: longhands::_webkit_text_stroke_color::computed_value::T) {
                            self._webkit_text_stroke_color = v;
                        }
                        /// Set -webkit-text-stroke-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_stroke_color_from(&mut self, other: &Self) {
                            self._webkit_text_stroke_color = other._webkit_text_stroke_color.clone();
                        }
                    /// Reset -webkit-text-stroke-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_stroke_color(&mut self, other: &Self) {
                        self.copy__webkit_text_stroke_color_from(other)
                    }

                    /// Get the computed value for -webkit-text-stroke-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_stroke_color(&self) -> longhands::_webkit_text_stroke_color::computed_value::T {
                        self._webkit_text_stroke_color.clone()
                    }
                        /// Set -webkit-text-stroke-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_stroke_width(&mut self, v: longhands::_webkit_text_stroke_width::computed_value::T) {
                            self._webkit_text_stroke_width = v;
                        }
                        /// Set -webkit-text-stroke-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_stroke_width_from(&mut self, other: &Self) {
                            self._webkit_text_stroke_width = other._webkit_text_stroke_width.clone();
                        }
                    /// Reset -webkit-text-stroke-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_stroke_width(&mut self, other: &Self) {
                        self.copy__webkit_text_stroke_width_from(other)
                    }

                    /// Get the computed value for -webkit-text-stroke-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_stroke_width(&self) -> longhands::_webkit_text_stroke_width::computed_value::T {
                        self._webkit_text_stroke_width.clone()
                    }
                        /// Set ruby-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ruby_align(&mut self, v: longhands::ruby_align::computed_value::T) {
                            self.ruby_align = v;
                        }
                        /// Set ruby-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ruby_align_from(&mut self, other: &Self) {
                            self.ruby_align = other.ruby_align.clone();
                        }
                    /// Reset ruby-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ruby_align(&mut self, other: &Self) {
                        self.copy_ruby_align_from(other)
                    }

                    /// Get the computed value for ruby-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ruby_align(&self) -> longhands::ruby_align::computed_value::T {
                        self.ruby_align.clone()
                    }
                        /// Set ruby-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ruby_position(&mut self, v: longhands::ruby_position::computed_value::T) {
                            self.ruby_position = v;
                        }
                        /// Set ruby-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ruby_position_from(&mut self, other: &Self) {
                            self.ruby_position = other.ruby_position.clone();
                        }
                    /// Reset ruby-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ruby_position(&mut self, other: &Self) {
                        self.copy_ruby_position_from(other)
                    }

                    /// Get the computed value for ruby-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ruby_position(&self) -> longhands::ruby_position::computed_value::T {
                        self.ruby_position.clone()
                    }
                        /// Set text-combine-upright.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_combine_upright(&mut self, v: longhands::text_combine_upright::computed_value::T) {
                            self.text_combine_upright = v;
                        }
                        /// Set text-combine-upright from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_combine_upright_from(&mut self, other: &Self) {
                            self.text_combine_upright = other.text_combine_upright.clone();
                        }
                    /// Reset text-combine-upright from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_combine_upright(&mut self, other: &Self) {
                        self.copy_text_combine_upright_from(other)
                    }

                    /// Get the computed value for text-combine-upright.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_combine_upright(&self) -> longhands::text_combine_upright::computed_value::T {
                        self.text_combine_upright.clone()
                    }
                        /// Set text-rendering.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_rendering(&mut self, v: longhands::text_rendering::computed_value::T) {
                            self.text_rendering = v;
                        }
                        /// Set text-rendering from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_rendering_from(&mut self, other: &Self) {
                            self.text_rendering = other.text_rendering.clone();
                        }
                    /// Reset text-rendering from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_rendering(&mut self, other: &Self) {
                        self.copy_text_rendering_from(other)
                    }

                    /// Get the computed value for text-rendering.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_rendering(&self) -> longhands::text_rendering::computed_value::T {
                        self.text_rendering.clone()
                    }
                        /// Set -moz-control-character-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_control_character_visibility(&mut self, v: longhands::_moz_control_character_visibility::computed_value::T) {
                            self._moz_control_character_visibility = v;
                        }
                        /// Set -moz-control-character-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_control_character_visibility_from(&mut self, other: &Self) {
                            self._moz_control_character_visibility = other._moz_control_character_visibility.clone();
                        }
                    /// Reset -moz-control-character-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_control_character_visibility(&mut self, other: &Self) {
                        self.copy__moz_control_character_visibility_from(other)
                    }

                    /// Get the computed value for -moz-control-character-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_control_character_visibility(&self) -> longhands::_moz_control_character_visibility::computed_value::T {
                        self._moz_control_character_visibility.clone()
                    }
                        /// Set text-underline-offset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_underline_offset(&mut self, v: longhands::text_underline_offset::computed_value::T) {
                            self.text_underline_offset = v;
                        }
                        /// Set text-underline-offset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_underline_offset_from(&mut self, other: &Self) {
                            self.text_underline_offset = other.text_underline_offset.clone();
                        }
                    /// Reset text-underline-offset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_underline_offset(&mut self, other: &Self) {
                        self.copy_text_underline_offset_from(other)
                    }

                    /// Get the computed value for text-underline-offset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_underline_offset(&self) -> longhands::text_underline_offset::computed_value::T {
                        self.text_underline_offset.clone()
                    }
                        /// Set text-underline-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_underline_position(&mut self, v: longhands::text_underline_position::computed_value::T) {
                            self.text_underline_position = v;
                        }
                        /// Set text-underline-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_underline_position_from(&mut self, other: &Self) {
                            self.text_underline_position = other.text_underline_position.clone();
                        }
                    /// Reset text-underline-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_underline_position(&mut self, other: &Self) {
                        self.copy_text_underline_position_from(other)
                    }

                    /// Get the computed value for text-underline-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_underline_position(&self) -> longhands::text_underline_position::computed_value::T {
                        self.text_underline_position.clone()
                    }
                        /// Set text-decoration-skip-ink.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_skip_ink(&mut self, v: longhands::text_decoration_skip_ink::computed_value::T) {
                            self.text_decoration_skip_ink = v;
                        }
                        /// Set text-decoration-skip-ink from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_skip_ink_from(&mut self, other: &Self) {
                            self.text_decoration_skip_ink = other.text_decoration_skip_ink.clone();
                        }
                    /// Reset text-decoration-skip-ink from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_skip_ink(&mut self, other: &Self) {
                        self.copy_text_decoration_skip_ink_from(other)
                    }

                    /// Get the computed value for text-decoration-skip-ink.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_skip_ink(&self) -> longhands::text_decoration_skip_ink::computed_value::T {
                        self.text_decoration_skip_ink.clone()
                    }
                        /// Set hyphenate-character.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_hyphenate_character(&mut self, v: longhands::hyphenate_character::computed_value::T) {
                            self.hyphenate_character = v;
                        }
                        /// Set hyphenate-character from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_hyphenate_character_from(&mut self, other: &Self) {
                            self.hyphenate_character = other.hyphenate_character.clone();
                        }
                    /// Reset hyphenate-character from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_hyphenate_character(&mut self, other: &Self) {
                        self.copy_hyphenate_character_from(other)
                    }

                    /// Get the computed value for hyphenate-character.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_hyphenate_character(&self) -> longhands::hyphenate_character::computed_value::T {
                        self.hyphenate_character.clone()
                    }
                        /// Set forced-color-adjust.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_forced_color_adjust(&mut self, v: longhands::forced_color_adjust::computed_value::T) {
                            self.forced_color_adjust = v;
                        }
                        /// Set forced-color-adjust from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_forced_color_adjust_from(&mut self, other: &Self) {
                            self.forced_color_adjust = other.forced_color_adjust.clone();
                        }
                    /// Reset forced-color-adjust from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_forced_color_adjust(&mut self, other: &Self) {
                        self.copy_forced_color_adjust_from(other)
                    }

                    /// Get the computed value for forced-color-adjust.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_forced_color_adjust(&self) -> longhands::forced_color_adjust::computed_value::T {
                        self.forced_color_adjust.clone()
                    }
                        /// Set -webkit-text-security.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__webkit_text_security(&mut self, v: longhands::_webkit_text_security::computed_value::T) {
                            self._webkit_text_security = v;
                        }
                        /// Set -webkit-text-security from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__webkit_text_security_from(&mut self, other: &Self) {
                            self._webkit_text_security = other._webkit_text_security.clone();
                        }
                    /// Reset -webkit-text-security from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__webkit_text_security(&mut self, other: &Self) {
                        self.copy__webkit_text_security_from(other)
                    }

                    /// Get the computed value for -webkit-text-security.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__webkit_text_security(&self) -> longhands::_webkit_text_security::computed_value::T {
                        self._webkit_text_security.clone()
                    }
                        /// Set text-wrap-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_wrap_mode(&mut self, v: longhands::text_wrap_mode::computed_value::T) {
                            self.text_wrap_mode = v;
                        }
                        /// Set text-wrap-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_wrap_mode_from(&mut self, other: &Self) {
                            self.text_wrap_mode = other.text_wrap_mode.clone();
                        }
                    /// Reset text-wrap-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_wrap_mode(&mut self, other: &Self) {
                        self.copy_text_wrap_mode_from(other)
                    }

                    /// Get the computed value for text-wrap-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_wrap_mode(&self) -> longhands::text_wrap_mode::computed_value::T {
                        self.text_wrap_mode.clone()
                    }
                        /// Set text-wrap-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_wrap_style(&mut self, v: longhands::text_wrap_style::computed_value::T) {
                            self.text_wrap_style = v;
                        }
                        /// Set text-wrap-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_wrap_style_from(&mut self, other: &Self) {
                            self.text_wrap_style = other.text_wrap_style.clone();
                        }
                    /// Reset text-wrap-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_wrap_style(&mut self, other: &Self) {
                        self.copy_text_wrap_style_from(other)
                    }

                    /// Get the computed value for text-wrap-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_wrap_style(&self) -> longhands::text_wrap_style::computed_value::T {
                        self.text_wrap_style.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The InheritedUI style struct.
        pub struct InheritedUI {
                    /// The cursor computed value.
                    pub cursor: longhands::cursor::computed_value::T,
                    /// The pointer-events computed value.
                    pub pointer_events: longhands::pointer_events::computed_value::T,
                    /// The -moz-inert computed value.
                    pub _moz_inert: longhands::_moz_inert::computed_value::T,
                    /// The -moz-user-input computed value.
                    pub _moz_user_input: longhands::_moz_user_input::computed_value::T,
                    /// The -moz-user-modify computed value.
                    pub _moz_user_modify: longhands::_moz_user_modify::computed_value::T,
                    /// The -moz-user-focus computed value.
                    pub _moz_user_focus: longhands::_moz_user_focus::computed_value::T,
                    /// The caret-color computed value.
                    pub caret_color: longhands::caret_color::computed_value::T,
                    /// The accent-color computed value.
                    pub accent_color: longhands::accent_color::computed_value::T,
                    /// The color-scheme computed value.
                    pub color_scheme: longhands::color_scheme::computed_value::T,
                    /// The scrollbar-color computed value.
                    pub scrollbar_color: longhands::scrollbar_color::computed_value::T,
                    /// The -moz-theme computed value.
                    pub _moz_theme: longhands::_moz_theme::computed_value::T,
        }

        impl InheritedUI {
                        /// Set cursor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_cursor(&mut self, v: longhands::cursor::computed_value::T) {
                            self.cursor = v;
                        }
                        /// Set cursor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_cursor_from(&mut self, other: &Self) {
                            self.cursor = other.cursor.clone();
                        }
                    /// Reset cursor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_cursor(&mut self, other: &Self) {
                        self.copy_cursor_from(other)
                    }

                    /// Get the computed value for cursor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_cursor(&self) -> longhands::cursor::computed_value::T {
                        self.cursor.clone()
                    }
                        /// Set pointer-events.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_pointer_events(&mut self, v: longhands::pointer_events::computed_value::T) {
                            self.pointer_events = v;
                        }
                        /// Set pointer-events from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_pointer_events_from(&mut self, other: &Self) {
                            self.pointer_events = other.pointer_events.clone();
                        }
                    /// Reset pointer-events from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_pointer_events(&mut self, other: &Self) {
                        self.copy_pointer_events_from(other)
                    }

                    /// Get the computed value for pointer-events.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_pointer_events(&self) -> longhands::pointer_events::computed_value::T {
                        self.pointer_events.clone()
                    }
                        /// Set -moz-inert.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_inert(&mut self, v: longhands::_moz_inert::computed_value::T) {
                            self._moz_inert = v;
                        }
                        /// Set -moz-inert from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_inert_from(&mut self, other: &Self) {
                            self._moz_inert = other._moz_inert.clone();
                        }
                    /// Reset -moz-inert from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_inert(&mut self, other: &Self) {
                        self.copy__moz_inert_from(other)
                    }

                    /// Get the computed value for -moz-inert.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_inert(&self) -> longhands::_moz_inert::computed_value::T {
                        self._moz_inert.clone()
                    }
                        /// Set -moz-user-input.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_input(&mut self, v: longhands::_moz_user_input::computed_value::T) {
                            self._moz_user_input = v;
                        }
                        /// Set -moz-user-input from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_input_from(&mut self, other: &Self) {
                            self._moz_user_input = other._moz_user_input.clone();
                        }
                    /// Reset -moz-user-input from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_input(&mut self, other: &Self) {
                        self.copy__moz_user_input_from(other)
                    }

                    /// Get the computed value for -moz-user-input.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_input(&self) -> longhands::_moz_user_input::computed_value::T {
                        self._moz_user_input.clone()
                    }
                        /// Set -moz-user-modify.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_modify(&mut self, v: longhands::_moz_user_modify::computed_value::T) {
                            self._moz_user_modify = v;
                        }
                        /// Set -moz-user-modify from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_modify_from(&mut self, other: &Self) {
                            self._moz_user_modify = other._moz_user_modify.clone();
                        }
                    /// Reset -moz-user-modify from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_modify(&mut self, other: &Self) {
                        self.copy__moz_user_modify_from(other)
                    }

                    /// Get the computed value for -moz-user-modify.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_modify(&self) -> longhands::_moz_user_modify::computed_value::T {
                        self._moz_user_modify.clone()
                    }
                        /// Set -moz-user-focus.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_user_focus(&mut self, v: longhands::_moz_user_focus::computed_value::T) {
                            self._moz_user_focus = v;
                        }
                        /// Set -moz-user-focus from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_user_focus_from(&mut self, other: &Self) {
                            self._moz_user_focus = other._moz_user_focus.clone();
                        }
                    /// Reset -moz-user-focus from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_user_focus(&mut self, other: &Self) {
                        self.copy__moz_user_focus_from(other)
                    }

                    /// Get the computed value for -moz-user-focus.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_user_focus(&self) -> longhands::_moz_user_focus::computed_value::T {
                        self._moz_user_focus.clone()
                    }
                        /// Set caret-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_caret_color(&mut self, v: longhands::caret_color::computed_value::T) {
                            self.caret_color = v;
                        }
                        /// Set caret-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_caret_color_from(&mut self, other: &Self) {
                            self.caret_color = other.caret_color.clone();
                        }
                    /// Reset caret-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_caret_color(&mut self, other: &Self) {
                        self.copy_caret_color_from(other)
                    }

                    /// Get the computed value for caret-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_caret_color(&self) -> longhands::caret_color::computed_value::T {
                        self.caret_color.clone()
                    }
                        /// Set accent-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_accent_color(&mut self, v: longhands::accent_color::computed_value::T) {
                            self.accent_color = v;
                        }
                        /// Set accent-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_accent_color_from(&mut self, other: &Self) {
                            self.accent_color = other.accent_color.clone();
                        }
                    /// Reset accent-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_accent_color(&mut self, other: &Self) {
                        self.copy_accent_color_from(other)
                    }

                    /// Get the computed value for accent-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_accent_color(&self) -> longhands::accent_color::computed_value::T {
                        self.accent_color.clone()
                    }
                        /// Set color-scheme.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_color_scheme(&mut self, v: longhands::color_scheme::computed_value::T) {
                            self.color_scheme = v;
                        }
                        /// Set color-scheme from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_color_scheme_from(&mut self, other: &Self) {
                            self.color_scheme = other.color_scheme.clone();
                        }
                    /// Reset color-scheme from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_color_scheme(&mut self, other: &Self) {
                        self.copy_color_scheme_from(other)
                    }

                    /// Get the computed value for color-scheme.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_color_scheme(&self) -> longhands::color_scheme::computed_value::T {
                        self.color_scheme.clone()
                    }
                        /// Set scrollbar-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scrollbar_color(&mut self, v: longhands::scrollbar_color::computed_value::T) {
                            self.scrollbar_color = v;
                        }
                        /// Set scrollbar-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scrollbar_color_from(&mut self, other: &Self) {
                            self.scrollbar_color = other.scrollbar_color.clone();
                        }
                    /// Reset scrollbar-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scrollbar_color(&mut self, other: &Self) {
                        self.copy_scrollbar_color_from(other)
                    }

                    /// Get the computed value for scrollbar-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scrollbar_color(&self) -> longhands::scrollbar_color::computed_value::T {
                        self.scrollbar_color.clone()
                    }
                        /// Set -moz-theme.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_theme(&mut self, v: longhands::_moz_theme::computed_value::T) {
                            self._moz_theme = v;
                        }
                        /// Set -moz-theme from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_theme_from(&mut self, other: &Self) {
                            self._moz_theme = other._moz_theme.clone();
                        }
                    /// Reset -moz-theme from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_theme(&mut self, other: &Self) {
                        self.copy__moz_theme_from(other)
                    }

                    /// Get the computed value for -moz-theme.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_theme(&self) -> longhands::_moz_theme::computed_value::T {
                        self._moz_theme.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The List style struct.
        pub struct List {
                    /// The list-style-position computed value.
                    pub list_style_position: longhands::list_style_position::computed_value::T,
                    /// The list-style-type computed value.
                    pub list_style_type: longhands::list_style_type::computed_value::T,
                    /// The list-style-image computed value.
                    pub list_style_image: longhands::list_style_image::computed_value::T,
                    /// The quotes computed value.
                    pub quotes: longhands::quotes::computed_value::T,
        }

        impl List {
                        /// Set list-style-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_position(&mut self, v: longhands::list_style_position::computed_value::T) {
                            self.list_style_position = v;
                        }
                        /// Set list-style-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_position_from(&mut self, other: &Self) {
                            self.list_style_position = other.list_style_position.clone();
                        }
                    /// Reset list-style-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_position(&mut self, other: &Self) {
                        self.copy_list_style_position_from(other)
                    }

                    /// Get the computed value for list-style-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_position(&self) -> longhands::list_style_position::computed_value::T {
                        self.list_style_position.clone()
                    }
                        /// Set list-style-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_type(&mut self, v: longhands::list_style_type::computed_value::T) {
                            self.list_style_type = v;
                        }
                        /// Set list-style-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_type_from(&mut self, other: &Self) {
                            self.list_style_type = other.list_style_type.clone();
                        }
                    /// Reset list-style-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_type(&mut self, other: &Self) {
                        self.copy_list_style_type_from(other)
                    }

                    /// Get the computed value for list-style-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_type(&self) -> longhands::list_style_type::computed_value::T {
                        self.list_style_type.clone()
                    }
                        /// Set list-style-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_list_style_image(&mut self, v: longhands::list_style_image::computed_value::T) {
                            self.list_style_image = v;
                        }
                        /// Set list-style-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_list_style_image_from(&mut self, other: &Self) {
                            self.list_style_image = other.list_style_image.clone();
                        }
                    /// Reset list-style-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_list_style_image(&mut self, other: &Self) {
                        self.copy_list_style_image_from(other)
                    }

                    /// Get the computed value for list-style-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_list_style_image(&self) -> longhands::list_style_image::computed_value::T {
                        self.list_style_image.clone()
                    }
                        /// Set quotes.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_quotes(&mut self, v: longhands::quotes::computed_value::T) {
                            self.quotes = v;
                        }
                        /// Set quotes from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_quotes_from(&mut self, other: &Self) {
                            self.quotes = other.quotes.clone();
                        }
                    /// Reset quotes from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_quotes(&mut self, other: &Self) {
                        self.copy_quotes_from(other)
                    }

                    /// Get the computed value for quotes.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_quotes(&self) -> longhands::quotes::computed_value::T {
                        self.quotes.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Margin style struct.
        pub struct Margin {
                    /// The margin-top computed value.
                    pub margin_top: longhands::margin_top::computed_value::T,
                    /// The margin-right computed value.
                    pub margin_right: longhands::margin_right::computed_value::T,
                    /// The margin-bottom computed value.
                    pub margin_bottom: longhands::margin_bottom::computed_value::T,
                    /// The margin-left computed value.
                    pub margin_left: longhands::margin_left::computed_value::T,
                    /// The overflow-clip-margin computed value.
                    pub overflow_clip_margin: longhands::overflow_clip_margin::computed_value::T,
                    /// The scroll-margin-top computed value.
                    pub scroll_margin_top: longhands::scroll_margin_top::computed_value::T,
                    /// The scroll-margin-right computed value.
                    pub scroll_margin_right: longhands::scroll_margin_right::computed_value::T,
                    /// The scroll-margin-bottom computed value.
                    pub scroll_margin_bottom: longhands::scroll_margin_bottom::computed_value::T,
                    /// The scroll-margin-left computed value.
                    pub scroll_margin_left: longhands::scroll_margin_left::computed_value::T,
        }

        impl Margin {
                        /// Set margin-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_top(&mut self, v: longhands::margin_top::computed_value::T) {
                            self.margin_top = v;
                        }
                        /// Set margin-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_top_from(&mut self, other: &Self) {
                            self.margin_top = other.margin_top.clone();
                        }
                    /// Reset margin-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_top(&mut self, other: &Self) {
                        self.copy_margin_top_from(other)
                    }

                    /// Get the computed value for margin-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_top(&self) -> longhands::margin_top::computed_value::T {
                        self.margin_top.clone()
                    }
                        /// Set margin-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_right(&mut self, v: longhands::margin_right::computed_value::T) {
                            self.margin_right = v;
                        }
                        /// Set margin-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_right_from(&mut self, other: &Self) {
                            self.margin_right = other.margin_right.clone();
                        }
                    /// Reset margin-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_right(&mut self, other: &Self) {
                        self.copy_margin_right_from(other)
                    }

                    /// Get the computed value for margin-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_right(&self) -> longhands::margin_right::computed_value::T {
                        self.margin_right.clone()
                    }
                        /// Set margin-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_bottom(&mut self, v: longhands::margin_bottom::computed_value::T) {
                            self.margin_bottom = v;
                        }
                        /// Set margin-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_bottom_from(&mut self, other: &Self) {
                            self.margin_bottom = other.margin_bottom.clone();
                        }
                    /// Reset margin-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_bottom(&mut self, other: &Self) {
                        self.copy_margin_bottom_from(other)
                    }

                    /// Get the computed value for margin-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_bottom(&self) -> longhands::margin_bottom::computed_value::T {
                        self.margin_bottom.clone()
                    }
                        /// Set margin-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_margin_left(&mut self, v: longhands::margin_left::computed_value::T) {
                            self.margin_left = v;
                        }
                        /// Set margin-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_margin_left_from(&mut self, other: &Self) {
                            self.margin_left = other.margin_left.clone();
                        }
                    /// Reset margin-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_margin_left(&mut self, other: &Self) {
                        self.copy_margin_left_from(other)
                    }

                    /// Get the computed value for margin-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_margin_left(&self) -> longhands::margin_left::computed_value::T {
                        self.margin_left.clone()
                    }
                        /// Set overflow-clip-margin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_overflow_clip_margin(&mut self, v: longhands::overflow_clip_margin::computed_value::T) {
                            self.overflow_clip_margin = v;
                        }
                        /// Set overflow-clip-margin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_overflow_clip_margin_from(&mut self, other: &Self) {
                            self.overflow_clip_margin = other.overflow_clip_margin.clone();
                        }
                    /// Reset overflow-clip-margin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_overflow_clip_margin(&mut self, other: &Self) {
                        self.copy_overflow_clip_margin_from(other)
                    }

                    /// Get the computed value for overflow-clip-margin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_overflow_clip_margin(&self) -> longhands::overflow_clip_margin::computed_value::T {
                        self.overflow_clip_margin.clone()
                    }
                        /// Set scroll-margin-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_margin_top(&mut self, v: longhands::scroll_margin_top::computed_value::T) {
                            self.scroll_margin_top = v;
                        }
                        /// Set scroll-margin-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_margin_top_from(&mut self, other: &Self) {
                            self.scroll_margin_top = other.scroll_margin_top.clone();
                        }
                    /// Reset scroll-margin-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_margin_top(&mut self, other: &Self) {
                        self.copy_scroll_margin_top_from(other)
                    }

                    /// Get the computed value for scroll-margin-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_margin_top(&self) -> longhands::scroll_margin_top::computed_value::T {
                        self.scroll_margin_top.clone()
                    }
                        /// Set scroll-margin-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_margin_right(&mut self, v: longhands::scroll_margin_right::computed_value::T) {
                            self.scroll_margin_right = v;
                        }
                        /// Set scroll-margin-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_margin_right_from(&mut self, other: &Self) {
                            self.scroll_margin_right = other.scroll_margin_right.clone();
                        }
                    /// Reset scroll-margin-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_margin_right(&mut self, other: &Self) {
                        self.copy_scroll_margin_right_from(other)
                    }

                    /// Get the computed value for scroll-margin-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_margin_right(&self) -> longhands::scroll_margin_right::computed_value::T {
                        self.scroll_margin_right.clone()
                    }
                        /// Set scroll-margin-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_margin_bottom(&mut self, v: longhands::scroll_margin_bottom::computed_value::T) {
                            self.scroll_margin_bottom = v;
                        }
                        /// Set scroll-margin-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_margin_bottom_from(&mut self, other: &Self) {
                            self.scroll_margin_bottom = other.scroll_margin_bottom.clone();
                        }
                    /// Reset scroll-margin-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_margin_bottom(&mut self, other: &Self) {
                        self.copy_scroll_margin_bottom_from(other)
                    }

                    /// Get the computed value for scroll-margin-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_margin_bottom(&self) -> longhands::scroll_margin_bottom::computed_value::T {
                        self.scroll_margin_bottom.clone()
                    }
                        /// Set scroll-margin-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_margin_left(&mut self, v: longhands::scroll_margin_left::computed_value::T) {
                            self.scroll_margin_left = v;
                        }
                        /// Set scroll-margin-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_margin_left_from(&mut self, other: &Self) {
                            self.scroll_margin_left = other.scroll_margin_left.clone();
                        }
                    /// Reset scroll-margin-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_margin_left(&mut self, other: &Self) {
                        self.copy_scroll_margin_left_from(other)
                    }

                    /// Get the computed value for scroll-margin-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_margin_left(&self) -> longhands::scroll_margin_left::computed_value::T {
                        self.scroll_margin_left.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Outline style struct.
        pub struct Outline {
                    /// The outline-color computed value.
                    pub outline_color: longhands::outline_color::computed_value::T,
                    /// The outline-style computed value.
                    pub outline_style: longhands::outline_style::computed_value::T,
                    /// The outline-width computed value.
                    pub outline_width: longhands::outline_width::computed_value::T,
                    /// The outline-offset computed value.
                    pub outline_offset: longhands::outline_offset::computed_value::T,
        }

        impl Outline {
                        /// Set outline-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_color(&mut self, v: longhands::outline_color::computed_value::T) {
                            self.outline_color = v;
                        }
                        /// Set outline-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_color_from(&mut self, other: &Self) {
                            self.outline_color = other.outline_color.clone();
                        }
                    /// Reset outline-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_color(&mut self, other: &Self) {
                        self.copy_outline_color_from(other)
                    }

                    /// Get the computed value for outline-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_color(&self) -> longhands::outline_color::computed_value::T {
                        self.outline_color.clone()
                    }
                        /// Set outline-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_style(&mut self, v: longhands::outline_style::computed_value::T) {
                            self.outline_style = v;
                        }
                        /// Set outline-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_style_from(&mut self, other: &Self) {
                            self.outline_style = other.outline_style.clone();
                        }
                    /// Reset outline-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_style(&mut self, other: &Self) {
                        self.copy_outline_style_from(other)
                    }

                    /// Get the computed value for outline-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_style(&self) -> longhands::outline_style::computed_value::T {
                        self.outline_style.clone()
                    }
                        /// Set outline-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_width(&mut self, v: longhands::outline_width::computed_value::T) {
                            self.outline_width = v;
                        }
                        /// Set outline-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_width_from(&mut self, other: &Self) {
                            self.outline_width = other.outline_width.clone();
                        }
                    /// Reset outline-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_width(&mut self, other: &Self) {
                        self.copy_outline_width_from(other)
                    }

                    /// Get the computed value for outline-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_width(&self) -> longhands::outline_width::computed_value::T {
                        self.outline_width.clone()
                    }
                        /// Set outline-offset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_outline_offset(&mut self, v: longhands::outline_offset::computed_value::T) {
                            self.outline_offset = v;
                        }
                        /// Set outline-offset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_outline_offset_from(&mut self, other: &Self) {
                            self.outline_offset = other.outline_offset.clone();
                        }
                    /// Reset outline-offset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_outline_offset(&mut self, other: &Self) {
                        self.copy_outline_offset_from(other)
                    }

                    /// Get the computed value for outline-offset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_outline_offset(&self) -> longhands::outline_offset::computed_value::T {
                        self.outline_offset.clone()
                    }
                /// Whether the outline-width property is non-zero.
                #[inline]
                pub fn outline_has_nonzero_width(&self) -> bool {
                    use crate::Zero;
                    !self.outline_width.is_zero()
                }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Padding style struct.
        pub struct Padding {
                    /// The padding-top computed value.
                    pub padding_top: longhands::padding_top::computed_value::T,
                    /// The padding-right computed value.
                    pub padding_right: longhands::padding_right::computed_value::T,
                    /// The padding-bottom computed value.
                    pub padding_bottom: longhands::padding_bottom::computed_value::T,
                    /// The padding-left computed value.
                    pub padding_left: longhands::padding_left::computed_value::T,
                    /// The scroll-padding-top computed value.
                    pub scroll_padding_top: longhands::scroll_padding_top::computed_value::T,
                    /// The scroll-padding-right computed value.
                    pub scroll_padding_right: longhands::scroll_padding_right::computed_value::T,
                    /// The scroll-padding-bottom computed value.
                    pub scroll_padding_bottom: longhands::scroll_padding_bottom::computed_value::T,
                    /// The scroll-padding-left computed value.
                    pub scroll_padding_left: longhands::scroll_padding_left::computed_value::T,
        }

        impl Padding {
                        /// Set padding-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_top(&mut self, v: longhands::padding_top::computed_value::T) {
                            self.padding_top = v;
                        }
                        /// Set padding-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_top_from(&mut self, other: &Self) {
                            self.padding_top = other.padding_top.clone();
                        }
                    /// Reset padding-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_top(&mut self, other: &Self) {
                        self.copy_padding_top_from(other)
                    }

                    /// Get the computed value for padding-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_top(&self) -> longhands::padding_top::computed_value::T {
                        self.padding_top.clone()
                    }
                        /// Set padding-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_right(&mut self, v: longhands::padding_right::computed_value::T) {
                            self.padding_right = v;
                        }
                        /// Set padding-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_right_from(&mut self, other: &Self) {
                            self.padding_right = other.padding_right.clone();
                        }
                    /// Reset padding-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_right(&mut self, other: &Self) {
                        self.copy_padding_right_from(other)
                    }

                    /// Get the computed value for padding-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_right(&self) -> longhands::padding_right::computed_value::T {
                        self.padding_right.clone()
                    }
                        /// Set padding-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_bottom(&mut self, v: longhands::padding_bottom::computed_value::T) {
                            self.padding_bottom = v;
                        }
                        /// Set padding-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_bottom_from(&mut self, other: &Self) {
                            self.padding_bottom = other.padding_bottom.clone();
                        }
                    /// Reset padding-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_bottom(&mut self, other: &Self) {
                        self.copy_padding_bottom_from(other)
                    }

                    /// Get the computed value for padding-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_bottom(&self) -> longhands::padding_bottom::computed_value::T {
                        self.padding_bottom.clone()
                    }
                        /// Set padding-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_padding_left(&mut self, v: longhands::padding_left::computed_value::T) {
                            self.padding_left = v;
                        }
                        /// Set padding-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_padding_left_from(&mut self, other: &Self) {
                            self.padding_left = other.padding_left.clone();
                        }
                    /// Reset padding-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_padding_left(&mut self, other: &Self) {
                        self.copy_padding_left_from(other)
                    }

                    /// Get the computed value for padding-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_padding_left(&self) -> longhands::padding_left::computed_value::T {
                        self.padding_left.clone()
                    }
                        /// Set scroll-padding-top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_padding_top(&mut self, v: longhands::scroll_padding_top::computed_value::T) {
                            self.scroll_padding_top = v;
                        }
                        /// Set scroll-padding-top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_padding_top_from(&mut self, other: &Self) {
                            self.scroll_padding_top = other.scroll_padding_top.clone();
                        }
                    /// Reset scroll-padding-top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_padding_top(&mut self, other: &Self) {
                        self.copy_scroll_padding_top_from(other)
                    }

                    /// Get the computed value for scroll-padding-top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_padding_top(&self) -> longhands::scroll_padding_top::computed_value::T {
                        self.scroll_padding_top.clone()
                    }
                        /// Set scroll-padding-right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_padding_right(&mut self, v: longhands::scroll_padding_right::computed_value::T) {
                            self.scroll_padding_right = v;
                        }
                        /// Set scroll-padding-right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_padding_right_from(&mut self, other: &Self) {
                            self.scroll_padding_right = other.scroll_padding_right.clone();
                        }
                    /// Reset scroll-padding-right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_padding_right(&mut self, other: &Self) {
                        self.copy_scroll_padding_right_from(other)
                    }

                    /// Get the computed value for scroll-padding-right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_padding_right(&self) -> longhands::scroll_padding_right::computed_value::T {
                        self.scroll_padding_right.clone()
                    }
                        /// Set scroll-padding-bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_padding_bottom(&mut self, v: longhands::scroll_padding_bottom::computed_value::T) {
                            self.scroll_padding_bottom = v;
                        }
                        /// Set scroll-padding-bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_padding_bottom_from(&mut self, other: &Self) {
                            self.scroll_padding_bottom = other.scroll_padding_bottom.clone();
                        }
                    /// Reset scroll-padding-bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_padding_bottom(&mut self, other: &Self) {
                        self.copy_scroll_padding_bottom_from(other)
                    }

                    /// Get the computed value for scroll-padding-bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_padding_bottom(&self) -> longhands::scroll_padding_bottom::computed_value::T {
                        self.scroll_padding_bottom.clone()
                    }
                        /// Set scroll-padding-left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_padding_left(&mut self, v: longhands::scroll_padding_left::computed_value::T) {
                            self.scroll_padding_left = v;
                        }
                        /// Set scroll-padding-left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_padding_left_from(&mut self, other: &Self) {
                            self.scroll_padding_left = other.scroll_padding_left.clone();
                        }
                    /// Reset scroll-padding-left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_padding_left(&mut self, other: &Self) {
                        self.copy_scroll_padding_left_from(other)
                    }

                    /// Get the computed value for scroll-padding-left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_padding_left(&self) -> longhands::scroll_padding_left::computed_value::T {
                        self.scroll_padding_left.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Page style struct.
        pub struct Page {
                    /// The size computed value.
                    pub size: longhands::size::computed_value::T,
                    /// The page computed value.
                    pub page: longhands::page::computed_value::T,
                    /// The page-orientation computed value.
                    pub page_orientation: longhands::page_orientation::computed_value::T,
        }

        impl Page {
                        /// Set size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_size(&mut self, v: longhands::size::computed_value::T) {
                            self.size = v;
                        }
                        /// Set size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_size_from(&mut self, other: &Self) {
                            self.size = other.size.clone();
                        }
                    /// Reset size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_size(&mut self, other: &Self) {
                        self.copy_size_from(other)
                    }

                    /// Get the computed value for size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_size(&self) -> longhands::size::computed_value::T {
                        self.size.clone()
                    }
                        /// Set page.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page(&mut self, v: longhands::page::computed_value::T) {
                            self.page = v;
                        }
                        /// Set page from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_from(&mut self, other: &Self) {
                            self.page = other.page.clone();
                        }
                    /// Reset page from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page(&mut self, other: &Self) {
                        self.copy_page_from(other)
                    }

                    /// Get the computed value for page.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page(&self) -> longhands::page::computed_value::T {
                        self.page.clone()
                    }
                        /// Set page-orientation.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_page_orientation(&mut self, v: longhands::page_orientation::computed_value::T) {
                            self.page_orientation = v;
                        }
                        /// Set page-orientation from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_page_orientation_from(&mut self, other: &Self) {
                            self.page_orientation = other.page_orientation.clone();
                        }
                    /// Reset page-orientation from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_page_orientation(&mut self, other: &Self) {
                        self.copy_page_orientation_from(other)
                    }

                    /// Get the computed value for page-orientation.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_page_orientation(&self) -> longhands::page_orientation::computed_value::T {
                        self.page_orientation.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Position style struct.
        pub struct Position {
                    /// The top computed value.
                    pub top: longhands::top::computed_value::T,
                    /// The right computed value.
                    pub right: longhands::right::computed_value::T,
                    /// The bottom computed value.
                    pub bottom: longhands::bottom::computed_value::T,
                    /// The left computed value.
                    pub left: longhands::left::computed_value::T,
                    /// The z-index computed value.
                    pub z_index: longhands::z_index::computed_value::T,
                    /// The flex-direction computed value.
                    pub flex_direction: longhands::flex_direction::computed_value::T,
                    /// The flex-wrap computed value.
                    pub flex_wrap: longhands::flex_wrap::computed_value::T,
                    /// The justify-content computed value.
                    pub justify_content: longhands::justify_content::computed_value::T,
                    /// The align-content computed value.
                    pub align_content: longhands::align_content::computed_value::T,
                    /// The align-items computed value.
                    pub align_items: longhands::align_items::computed_value::T,
                    /// The justify-items computed value.
                    pub justify_items: longhands::justify_items::computed_value::T,
                    /// The flex-grow computed value.
                    pub flex_grow: longhands::flex_grow::computed_value::T,
                    /// The flex-shrink computed value.
                    pub flex_shrink: longhands::flex_shrink::computed_value::T,
                    /// The align-self computed value.
                    pub align_self: longhands::align_self::computed_value::T,
                    /// The justify-self computed value.
                    pub justify_self: longhands::justify_self::computed_value::T,
                    /// The order computed value.
                    pub order: longhands::order::computed_value::T,
                    /// The flex-basis computed value.
                    pub flex_basis: longhands::flex_basis::computed_value::T,
                    /// The height computed value.
                    pub height: longhands::height::computed_value::T,
                    /// The min-height computed value.
                    pub min_height: longhands::min_height::computed_value::T,
                    /// The max-height computed value.
                    pub max_height: longhands::max_height::computed_value::T,
                    /// The width computed value.
                    pub width: longhands::width::computed_value::T,
                    /// The min-width computed value.
                    pub min_width: longhands::min_width::computed_value::T,
                    /// The max-width computed value.
                    pub max_width: longhands::max_width::computed_value::T,
                    /// The position-anchor computed value.
                    pub position_anchor: longhands::position_anchor::computed_value::T,
                    /// The position-visibility computed value.
                    pub position_visibility: longhands::position_visibility::computed_value::T,
                    /// The inset-area computed value.
                    pub inset_area: longhands::inset_area::computed_value::T,
                    /// The position-try-options computed value.
                    pub position_try_options: longhands::position_try_options::computed_value::T,
                    /// The position-try-order computed value.
                    pub position_try_order: longhands::position_try_order::computed_value::T,
                    /// The box-sizing computed value.
                    pub box_sizing: longhands::box_sizing::computed_value::T,
                    /// The object-fit computed value.
                    pub object_fit: longhands::object_fit::computed_value::T,
                    /// The object-position computed value.
                    pub object_position: longhands::object_position::computed_value::T,
                    /// The grid-row-start computed value.
                    pub grid_row_start: longhands::grid_row_start::computed_value::T,
                    /// The grid-row-end computed value.
                    pub grid_row_end: longhands::grid_row_end::computed_value::T,
                    /// The grid-auto-rows computed value.
                    pub grid_auto_rows: longhands::grid_auto_rows::computed_value::T,
                    /// The grid-template-rows computed value.
                    pub grid_template_rows: longhands::grid_template_rows::computed_value::T,
                    /// The grid-column-start computed value.
                    pub grid_column_start: longhands::grid_column_start::computed_value::T,
                    /// The grid-column-end computed value.
                    pub grid_column_end: longhands::grid_column_end::computed_value::T,
                    /// The grid-auto-columns computed value.
                    pub grid_auto_columns: longhands::grid_auto_columns::computed_value::T,
                    /// The grid-template-columns computed value.
                    pub grid_template_columns: longhands::grid_template_columns::computed_value::T,
                    /// The masonry-auto-flow computed value.
                    pub masonry_auto_flow: longhands::masonry_auto_flow::computed_value::T,
                    /// The grid-auto-flow computed value.
                    pub grid_auto_flow: longhands::grid_auto_flow::computed_value::T,
                    /// The grid-template-areas computed value.
                    pub grid_template_areas: longhands::grid_template_areas::computed_value::T,
                    /// The column-gap computed value.
                    pub column_gap: longhands::column_gap::computed_value::T,
                    /// The row-gap computed value.
                    pub row_gap: longhands::row_gap::computed_value::T,
                    /// The aspect-ratio computed value.
                    pub aspect_ratio: longhands::aspect_ratio::computed_value::T,
                    /// The contain-intrinsic-height computed value.
                    pub contain_intrinsic_height: longhands::contain_intrinsic_height::computed_value::T,
                    /// The contain-intrinsic-width computed value.
                    pub contain_intrinsic_width: longhands::contain_intrinsic_width::computed_value::T,
        }

        impl Position {
                        /// Set top.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_top(&mut self, v: longhands::top::computed_value::T) {
                            self.top = v;
                        }
                        /// Set top from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_top_from(&mut self, other: &Self) {
                            self.top = other.top.clone();
                        }
                    /// Reset top from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_top(&mut self, other: &Self) {
                        self.copy_top_from(other)
                    }

                    /// Get the computed value for top.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_top(&self) -> longhands::top::computed_value::T {
                        self.top.clone()
                    }
                        /// Set right.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_right(&mut self, v: longhands::right::computed_value::T) {
                            self.right = v;
                        }
                        /// Set right from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_right_from(&mut self, other: &Self) {
                            self.right = other.right.clone();
                        }
                    /// Reset right from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_right(&mut self, other: &Self) {
                        self.copy_right_from(other)
                    }

                    /// Get the computed value for right.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_right(&self) -> longhands::right::computed_value::T {
                        self.right.clone()
                    }
                        /// Set bottom.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_bottom(&mut self, v: longhands::bottom::computed_value::T) {
                            self.bottom = v;
                        }
                        /// Set bottom from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_bottom_from(&mut self, other: &Self) {
                            self.bottom = other.bottom.clone();
                        }
                    /// Reset bottom from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_bottom(&mut self, other: &Self) {
                        self.copy_bottom_from(other)
                    }

                    /// Get the computed value for bottom.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_bottom(&self) -> longhands::bottom::computed_value::T {
                        self.bottom.clone()
                    }
                        /// Set left.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_left(&mut self, v: longhands::left::computed_value::T) {
                            self.left = v;
                        }
                        /// Set left from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_left_from(&mut self, other: &Self) {
                            self.left = other.left.clone();
                        }
                    /// Reset left from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_left(&mut self, other: &Self) {
                        self.copy_left_from(other)
                    }

                    /// Get the computed value for left.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_left(&self) -> longhands::left::computed_value::T {
                        self.left.clone()
                    }
                        /// Set z-index.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_z_index(&mut self, v: longhands::z_index::computed_value::T) {
                            self.z_index = v;
                        }
                        /// Set z-index from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_z_index_from(&mut self, other: &Self) {
                            self.z_index = other.z_index.clone();
                        }
                    /// Reset z-index from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_z_index(&mut self, other: &Self) {
                        self.copy_z_index_from(other)
                    }

                    /// Get the computed value for z-index.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_z_index(&self) -> longhands::z_index::computed_value::T {
                        self.z_index.clone()
                    }
                        /// Set flex-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_direction(&mut self, v: longhands::flex_direction::computed_value::T) {
                            self.flex_direction = v;
                        }
                        /// Set flex-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_direction_from(&mut self, other: &Self) {
                            self.flex_direction = other.flex_direction.clone();
                        }
                    /// Reset flex-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_direction(&mut self, other: &Self) {
                        self.copy_flex_direction_from(other)
                    }

                    /// Get the computed value for flex-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_direction(&self) -> longhands::flex_direction::computed_value::T {
                        self.flex_direction.clone()
                    }
                        /// Set flex-wrap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_wrap(&mut self, v: longhands::flex_wrap::computed_value::T) {
                            self.flex_wrap = v;
                        }
                        /// Set flex-wrap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_wrap_from(&mut self, other: &Self) {
                            self.flex_wrap = other.flex_wrap.clone();
                        }
                    /// Reset flex-wrap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_wrap(&mut self, other: &Self) {
                        self.copy_flex_wrap_from(other)
                    }

                    /// Get the computed value for flex-wrap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_wrap(&self) -> longhands::flex_wrap::computed_value::T {
                        self.flex_wrap.clone()
                    }
                        /// Set justify-content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_content(&mut self, v: longhands::justify_content::computed_value::T) {
                            self.justify_content = v;
                        }
                        /// Set justify-content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_content_from(&mut self, other: &Self) {
                            self.justify_content = other.justify_content.clone();
                        }
                    /// Reset justify-content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_content(&mut self, other: &Self) {
                        self.copy_justify_content_from(other)
                    }

                    /// Get the computed value for justify-content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_content(&self) -> longhands::justify_content::computed_value::T {
                        self.justify_content.clone()
                    }
                        /// Set align-content.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_content(&mut self, v: longhands::align_content::computed_value::T) {
                            self.align_content = v;
                        }
                        /// Set align-content from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_content_from(&mut self, other: &Self) {
                            self.align_content = other.align_content.clone();
                        }
                    /// Reset align-content from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_content(&mut self, other: &Self) {
                        self.copy_align_content_from(other)
                    }

                    /// Get the computed value for align-content.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_content(&self) -> longhands::align_content::computed_value::T {
                        self.align_content.clone()
                    }
                        /// Set align-items.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_items(&mut self, v: longhands::align_items::computed_value::T) {
                            self.align_items = v;
                        }
                        /// Set align-items from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_items_from(&mut self, other: &Self) {
                            self.align_items = other.align_items.clone();
                        }
                    /// Reset align-items from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_items(&mut self, other: &Self) {
                        self.copy_align_items_from(other)
                    }

                    /// Get the computed value for align-items.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_items(&self) -> longhands::align_items::computed_value::T {
                        self.align_items.clone()
                    }
                        /// Set justify-items.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_items(&mut self, v: longhands::justify_items::computed_value::T) {
                            self.justify_items = v;
                        }
                        /// Set justify-items from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_items_from(&mut self, other: &Self) {
                            self.justify_items = other.justify_items.clone();
                        }
                    /// Reset justify-items from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_items(&mut self, other: &Self) {
                        self.copy_justify_items_from(other)
                    }

                    /// Get the computed value for justify-items.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_items(&self) -> longhands::justify_items::computed_value::T {
                        self.justify_items.clone()
                    }
                        /// Set flex-grow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_grow(&mut self, v: longhands::flex_grow::computed_value::T) {
                            self.flex_grow = v;
                        }
                        /// Set flex-grow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_grow_from(&mut self, other: &Self) {
                            self.flex_grow = other.flex_grow.clone();
                        }
                    /// Reset flex-grow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_grow(&mut self, other: &Self) {
                        self.copy_flex_grow_from(other)
                    }

                    /// Get the computed value for flex-grow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_grow(&self) -> longhands::flex_grow::computed_value::T {
                        self.flex_grow.clone()
                    }
                        /// Set flex-shrink.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_shrink(&mut self, v: longhands::flex_shrink::computed_value::T) {
                            self.flex_shrink = v;
                        }
                        /// Set flex-shrink from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_shrink_from(&mut self, other: &Self) {
                            self.flex_shrink = other.flex_shrink.clone();
                        }
                    /// Reset flex-shrink from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_shrink(&mut self, other: &Self) {
                        self.copy_flex_shrink_from(other)
                    }

                    /// Get the computed value for flex-shrink.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_shrink(&self) -> longhands::flex_shrink::computed_value::T {
                        self.flex_shrink.clone()
                    }
                        /// Set align-self.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_align_self(&mut self, v: longhands::align_self::computed_value::T) {
                            self.align_self = v;
                        }
                        /// Set align-self from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_align_self_from(&mut self, other: &Self) {
                            self.align_self = other.align_self.clone();
                        }
                    /// Reset align-self from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_align_self(&mut self, other: &Self) {
                        self.copy_align_self_from(other)
                    }

                    /// Get the computed value for align-self.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_align_self(&self) -> longhands::align_self::computed_value::T {
                        self.align_self.clone()
                    }
                        /// Set justify-self.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_justify_self(&mut self, v: longhands::justify_self::computed_value::T) {
                            self.justify_self = v;
                        }
                        /// Set justify-self from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_justify_self_from(&mut self, other: &Self) {
                            self.justify_self = other.justify_self.clone();
                        }
                    /// Reset justify-self from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_justify_self(&mut self, other: &Self) {
                        self.copy_justify_self_from(other)
                    }

                    /// Get the computed value for justify-self.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_justify_self(&self) -> longhands::justify_self::computed_value::T {
                        self.justify_self.clone()
                    }
                        /// Set order.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_order(&mut self, v: longhands::order::computed_value::T) {
                            self.order = v;
                        }
                        /// Set order from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_order_from(&mut self, other: &Self) {
                            self.order = other.order.clone();
                        }
                    /// Reset order from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_order(&mut self, other: &Self) {
                        self.copy_order_from(other)
                    }

                    /// Get the computed value for order.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_order(&self) -> longhands::order::computed_value::T {
                        self.order.clone()
                    }
                        /// Set flex-basis.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flex_basis(&mut self, v: longhands::flex_basis::computed_value::T) {
                            self.flex_basis = v;
                        }
                        /// Set flex-basis from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flex_basis_from(&mut self, other: &Self) {
                            self.flex_basis = other.flex_basis.clone();
                        }
                    /// Reset flex-basis from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flex_basis(&mut self, other: &Self) {
                        self.copy_flex_basis_from(other)
                    }

                    /// Get the computed value for flex-basis.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flex_basis(&self) -> longhands::flex_basis::computed_value::T {
                        self.flex_basis.clone()
                    }
                        /// Set height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_height(&mut self, v: longhands::height::computed_value::T) {
                            self.height = v;
                        }
                        /// Set height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_height_from(&mut self, other: &Self) {
                            self.height = other.height.clone();
                        }
                    /// Reset height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_height(&mut self, other: &Self) {
                        self.copy_height_from(other)
                    }

                    /// Get the computed value for height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_height(&self) -> longhands::height::computed_value::T {
                        self.height.clone()
                    }
                        /// Set min-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_min_height(&mut self, v: longhands::min_height::computed_value::T) {
                            self.min_height = v;
                        }
                        /// Set min-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_min_height_from(&mut self, other: &Self) {
                            self.min_height = other.min_height.clone();
                        }
                    /// Reset min-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_min_height(&mut self, other: &Self) {
                        self.copy_min_height_from(other)
                    }

                    /// Get the computed value for min-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_min_height(&self) -> longhands::min_height::computed_value::T {
                        self.min_height.clone()
                    }
                        /// Set max-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_max_height(&mut self, v: longhands::max_height::computed_value::T) {
                            self.max_height = v;
                        }
                        /// Set max-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_max_height_from(&mut self, other: &Self) {
                            self.max_height = other.max_height.clone();
                        }
                    /// Reset max-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_max_height(&mut self, other: &Self) {
                        self.copy_max_height_from(other)
                    }

                    /// Get the computed value for max-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_max_height(&self) -> longhands::max_height::computed_value::T {
                        self.max_height.clone()
                    }
                        /// Set width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_width(&mut self, v: longhands::width::computed_value::T) {
                            self.width = v;
                        }
                        /// Set width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_width_from(&mut self, other: &Self) {
                            self.width = other.width.clone();
                        }
                    /// Reset width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_width(&mut self, other: &Self) {
                        self.copy_width_from(other)
                    }

                    /// Get the computed value for width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_width(&self) -> longhands::width::computed_value::T {
                        self.width.clone()
                    }
                        /// Set min-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_min_width(&mut self, v: longhands::min_width::computed_value::T) {
                            self.min_width = v;
                        }
                        /// Set min-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_min_width_from(&mut self, other: &Self) {
                            self.min_width = other.min_width.clone();
                        }
                    /// Reset min-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_min_width(&mut self, other: &Self) {
                        self.copy_min_width_from(other)
                    }

                    /// Get the computed value for min-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_min_width(&self) -> longhands::min_width::computed_value::T {
                        self.min_width.clone()
                    }
                        /// Set max-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_max_width(&mut self, v: longhands::max_width::computed_value::T) {
                            self.max_width = v;
                        }
                        /// Set max-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_max_width_from(&mut self, other: &Self) {
                            self.max_width = other.max_width.clone();
                        }
                    /// Reset max-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_max_width(&mut self, other: &Self) {
                        self.copy_max_width_from(other)
                    }

                    /// Get the computed value for max-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_max_width(&self) -> longhands::max_width::computed_value::T {
                        self.max_width.clone()
                    }
                        /// Set position-anchor.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_position_anchor(&mut self, v: longhands::position_anchor::computed_value::T) {
                            self.position_anchor = v;
                        }
                        /// Set position-anchor from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_position_anchor_from(&mut self, other: &Self) {
                            self.position_anchor = other.position_anchor.clone();
                        }
                    /// Reset position-anchor from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_position_anchor(&mut self, other: &Self) {
                        self.copy_position_anchor_from(other)
                    }

                    /// Get the computed value for position-anchor.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_position_anchor(&self) -> longhands::position_anchor::computed_value::T {
                        self.position_anchor.clone()
                    }
                        /// Set position-visibility.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_position_visibility(&mut self, v: longhands::position_visibility::computed_value::T) {
                            self.position_visibility = v;
                        }
                        /// Set position-visibility from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_position_visibility_from(&mut self, other: &Self) {
                            self.position_visibility = other.position_visibility.clone();
                        }
                    /// Reset position-visibility from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_position_visibility(&mut self, other: &Self) {
                        self.copy_position_visibility_from(other)
                    }

                    /// Get the computed value for position-visibility.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_position_visibility(&self) -> longhands::position_visibility::computed_value::T {
                        self.position_visibility.clone()
                    }
                        /// Set inset-area.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_inset_area(&mut self, v: longhands::inset_area::computed_value::T) {
                            self.inset_area = v;
                        }
                        /// Set inset-area from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_inset_area_from(&mut self, other: &Self) {
                            self.inset_area = other.inset_area.clone();
                        }
                    /// Reset inset-area from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_inset_area(&mut self, other: &Self) {
                        self.copy_inset_area_from(other)
                    }

                    /// Get the computed value for inset-area.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_inset_area(&self) -> longhands::inset_area::computed_value::T {
                        self.inset_area.clone()
                    }
                        /// Set position-try-options.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_position_try_options(&mut self, v: longhands::position_try_options::computed_value::T) {
                            self.position_try_options = v;
                        }
                        /// Set position-try-options from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_position_try_options_from(&mut self, other: &Self) {
                            self.position_try_options = other.position_try_options.clone();
                        }
                    /// Reset position-try-options from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_position_try_options(&mut self, other: &Self) {
                        self.copy_position_try_options_from(other)
                    }

                    /// Get the computed value for position-try-options.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_position_try_options(&self) -> longhands::position_try_options::computed_value::T {
                        self.position_try_options.clone()
                    }
                        /// Set position-try-order.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_position_try_order(&mut self, v: longhands::position_try_order::computed_value::T) {
                            self.position_try_order = v;
                        }
                        /// Set position-try-order from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_position_try_order_from(&mut self, other: &Self) {
                            self.position_try_order = other.position_try_order.clone();
                        }
                    /// Reset position-try-order from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_position_try_order(&mut self, other: &Self) {
                        self.copy_position_try_order_from(other)
                    }

                    /// Get the computed value for position-try-order.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_position_try_order(&self) -> longhands::position_try_order::computed_value::T {
                        self.position_try_order.clone()
                    }
                        /// Set box-sizing.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_box_sizing(&mut self, v: longhands::box_sizing::computed_value::T) {
                            self.box_sizing = v;
                        }
                        /// Set box-sizing from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_box_sizing_from(&mut self, other: &Self) {
                            self.box_sizing = other.box_sizing.clone();
                        }
                    /// Reset box-sizing from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_box_sizing(&mut self, other: &Self) {
                        self.copy_box_sizing_from(other)
                    }

                    /// Get the computed value for box-sizing.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_box_sizing(&self) -> longhands::box_sizing::computed_value::T {
                        self.box_sizing.clone()
                    }
                        /// Set object-fit.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_object_fit(&mut self, v: longhands::object_fit::computed_value::T) {
                            self.object_fit = v;
                        }
                        /// Set object-fit from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_object_fit_from(&mut self, other: &Self) {
                            self.object_fit = other.object_fit.clone();
                        }
                    /// Reset object-fit from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_object_fit(&mut self, other: &Self) {
                        self.copy_object_fit_from(other)
                    }

                    /// Get the computed value for object-fit.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_object_fit(&self) -> longhands::object_fit::computed_value::T {
                        self.object_fit.clone()
                    }
                        /// Set object-position.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_object_position(&mut self, v: longhands::object_position::computed_value::T) {
                            self.object_position = v;
                        }
                        /// Set object-position from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_object_position_from(&mut self, other: &Self) {
                            self.object_position = other.object_position.clone();
                        }
                    /// Reset object-position from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_object_position(&mut self, other: &Self) {
                        self.copy_object_position_from(other)
                    }

                    /// Get the computed value for object-position.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_object_position(&self) -> longhands::object_position::computed_value::T {
                        self.object_position.clone()
                    }
                        /// Set grid-row-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_start(&mut self, v: longhands::grid_row_start::computed_value::T) {
                            self.grid_row_start = v;
                        }
                        /// Set grid-row-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_start_from(&mut self, other: &Self) {
                            self.grid_row_start = other.grid_row_start.clone();
                        }
                    /// Reset grid-row-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_start(&mut self, other: &Self) {
                        self.copy_grid_row_start_from(other)
                    }

                    /// Get the computed value for grid-row-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_start(&self) -> longhands::grid_row_start::computed_value::T {
                        self.grid_row_start.clone()
                    }
                        /// Set grid-row-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_row_end(&mut self, v: longhands::grid_row_end::computed_value::T) {
                            self.grid_row_end = v;
                        }
                        /// Set grid-row-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_row_end_from(&mut self, other: &Self) {
                            self.grid_row_end = other.grid_row_end.clone();
                        }
                    /// Reset grid-row-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_row_end(&mut self, other: &Self) {
                        self.copy_grid_row_end_from(other)
                    }

                    /// Get the computed value for grid-row-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_row_end(&self) -> longhands::grid_row_end::computed_value::T {
                        self.grid_row_end.clone()
                    }
                        /// Set grid-auto-rows.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_rows(&mut self, v: longhands::grid_auto_rows::computed_value::T) {
                            self.grid_auto_rows = v;
                        }
                        /// Set grid-auto-rows from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_rows_from(&mut self, other: &Self) {
                            self.grid_auto_rows = other.grid_auto_rows.clone();
                        }
                    /// Reset grid-auto-rows from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_rows(&mut self, other: &Self) {
                        self.copy_grid_auto_rows_from(other)
                    }

                    /// Get the computed value for grid-auto-rows.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_rows(&self) -> longhands::grid_auto_rows::computed_value::T {
                        self.grid_auto_rows.clone()
                    }
                        /// Set grid-template-rows.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_rows(&mut self, v: longhands::grid_template_rows::computed_value::T) {
                            self.grid_template_rows = v;
                        }
                        /// Set grid-template-rows from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_rows_from(&mut self, other: &Self) {
                            self.grid_template_rows = other.grid_template_rows.clone();
                        }
                    /// Reset grid-template-rows from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_rows(&mut self, other: &Self) {
                        self.copy_grid_template_rows_from(other)
                    }

                    /// Get the computed value for grid-template-rows.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_rows(&self) -> longhands::grid_template_rows::computed_value::T {
                        self.grid_template_rows.clone()
                    }
                        /// Set grid-column-start.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_start(&mut self, v: longhands::grid_column_start::computed_value::T) {
                            self.grid_column_start = v;
                        }
                        /// Set grid-column-start from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_start_from(&mut self, other: &Self) {
                            self.grid_column_start = other.grid_column_start.clone();
                        }
                    /// Reset grid-column-start from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_start(&mut self, other: &Self) {
                        self.copy_grid_column_start_from(other)
                    }

                    /// Get the computed value for grid-column-start.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_start(&self) -> longhands::grid_column_start::computed_value::T {
                        self.grid_column_start.clone()
                    }
                        /// Set grid-column-end.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_column_end(&mut self, v: longhands::grid_column_end::computed_value::T) {
                            self.grid_column_end = v;
                        }
                        /// Set grid-column-end from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_column_end_from(&mut self, other: &Self) {
                            self.grid_column_end = other.grid_column_end.clone();
                        }
                    /// Reset grid-column-end from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_column_end(&mut self, other: &Self) {
                        self.copy_grid_column_end_from(other)
                    }

                    /// Get the computed value for grid-column-end.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_column_end(&self) -> longhands::grid_column_end::computed_value::T {
                        self.grid_column_end.clone()
                    }
                        /// Set grid-auto-columns.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_columns(&mut self, v: longhands::grid_auto_columns::computed_value::T) {
                            self.grid_auto_columns = v;
                        }
                        /// Set grid-auto-columns from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_columns_from(&mut self, other: &Self) {
                            self.grid_auto_columns = other.grid_auto_columns.clone();
                        }
                    /// Reset grid-auto-columns from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_columns(&mut self, other: &Self) {
                        self.copy_grid_auto_columns_from(other)
                    }

                    /// Get the computed value for grid-auto-columns.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_columns(&self) -> longhands::grid_auto_columns::computed_value::T {
                        self.grid_auto_columns.clone()
                    }
                        /// Set grid-template-columns.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_columns(&mut self, v: longhands::grid_template_columns::computed_value::T) {
                            self.grid_template_columns = v;
                        }
                        /// Set grid-template-columns from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_columns_from(&mut self, other: &Self) {
                            self.grid_template_columns = other.grid_template_columns.clone();
                        }
                    /// Reset grid-template-columns from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_columns(&mut self, other: &Self) {
                        self.copy_grid_template_columns_from(other)
                    }

                    /// Get the computed value for grid-template-columns.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_columns(&self) -> longhands::grid_template_columns::computed_value::T {
                        self.grid_template_columns.clone()
                    }
                        /// Set masonry-auto-flow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_masonry_auto_flow(&mut self, v: longhands::masonry_auto_flow::computed_value::T) {
                            self.masonry_auto_flow = v;
                        }
                        /// Set masonry-auto-flow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_masonry_auto_flow_from(&mut self, other: &Self) {
                            self.masonry_auto_flow = other.masonry_auto_flow.clone();
                        }
                    /// Reset masonry-auto-flow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_masonry_auto_flow(&mut self, other: &Self) {
                        self.copy_masonry_auto_flow_from(other)
                    }

                    /// Get the computed value for masonry-auto-flow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_masonry_auto_flow(&self) -> longhands::masonry_auto_flow::computed_value::T {
                        self.masonry_auto_flow.clone()
                    }
                        /// Set grid-auto-flow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_auto_flow(&mut self, v: longhands::grid_auto_flow::computed_value::T) {
                            self.grid_auto_flow = v;
                        }
                        /// Set grid-auto-flow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_auto_flow_from(&mut self, other: &Self) {
                            self.grid_auto_flow = other.grid_auto_flow.clone();
                        }
                    /// Reset grid-auto-flow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_auto_flow(&mut self, other: &Self) {
                        self.copy_grid_auto_flow_from(other)
                    }

                    /// Get the computed value for grid-auto-flow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_auto_flow(&self) -> longhands::grid_auto_flow::computed_value::T {
                        self.grid_auto_flow.clone()
                    }
                        /// Set grid-template-areas.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_grid_template_areas(&mut self, v: longhands::grid_template_areas::computed_value::T) {
                            self.grid_template_areas = v;
                        }
                        /// Set grid-template-areas from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_grid_template_areas_from(&mut self, other: &Self) {
                            self.grid_template_areas = other.grid_template_areas.clone();
                        }
                    /// Reset grid-template-areas from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_grid_template_areas(&mut self, other: &Self) {
                        self.copy_grid_template_areas_from(other)
                    }

                    /// Get the computed value for grid-template-areas.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_grid_template_areas(&self) -> longhands::grid_template_areas::computed_value::T {
                        self.grid_template_areas.clone()
                    }
                        /// Set column-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_column_gap(&mut self, v: longhands::column_gap::computed_value::T) {
                            self.column_gap = v;
                        }
                        /// Set column-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_column_gap_from(&mut self, other: &Self) {
                            self.column_gap = other.column_gap.clone();
                        }
                    /// Reset column-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_column_gap(&mut self, other: &Self) {
                        self.copy_column_gap_from(other)
                    }

                    /// Get the computed value for column-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_column_gap(&self) -> longhands::column_gap::computed_value::T {
                        self.column_gap.clone()
                    }
                        /// Set row-gap.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_row_gap(&mut self, v: longhands::row_gap::computed_value::T) {
                            self.row_gap = v;
                        }
                        /// Set row-gap from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_row_gap_from(&mut self, other: &Self) {
                            self.row_gap = other.row_gap.clone();
                        }
                    /// Reset row-gap from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_row_gap(&mut self, other: &Self) {
                        self.copy_row_gap_from(other)
                    }

                    /// Get the computed value for row-gap.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_row_gap(&self) -> longhands::row_gap::computed_value::T {
                        self.row_gap.clone()
                    }
                        /// Set aspect-ratio.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_aspect_ratio(&mut self, v: longhands::aspect_ratio::computed_value::T) {
                            self.aspect_ratio = v;
                        }
                        /// Set aspect-ratio from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_aspect_ratio_from(&mut self, other: &Self) {
                            self.aspect_ratio = other.aspect_ratio.clone();
                        }
                    /// Reset aspect-ratio from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_aspect_ratio(&mut self, other: &Self) {
                        self.copy_aspect_ratio_from(other)
                    }

                    /// Get the computed value for aspect-ratio.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_aspect_ratio(&self) -> longhands::aspect_ratio::computed_value::T {
                        self.aspect_ratio.clone()
                    }
                        /// Set contain-intrinsic-height.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_contain_intrinsic_height(&mut self, v: longhands::contain_intrinsic_height::computed_value::T) {
                            self.contain_intrinsic_height = v;
                        }
                        /// Set contain-intrinsic-height from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_contain_intrinsic_height_from(&mut self, other: &Self) {
                            self.contain_intrinsic_height = other.contain_intrinsic_height.clone();
                        }
                    /// Reset contain-intrinsic-height from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_contain_intrinsic_height(&mut self, other: &Self) {
                        self.copy_contain_intrinsic_height_from(other)
                    }

                    /// Get the computed value for contain-intrinsic-height.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_contain_intrinsic_height(&self) -> longhands::contain_intrinsic_height::computed_value::T {
                        self.contain_intrinsic_height.clone()
                    }
                        /// Set contain-intrinsic-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_contain_intrinsic_width(&mut self, v: longhands::contain_intrinsic_width::computed_value::T) {
                            self.contain_intrinsic_width = v;
                        }
                        /// Set contain-intrinsic-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_contain_intrinsic_width_from(&mut self, other: &Self) {
                            self.contain_intrinsic_width = other.contain_intrinsic_width.clone();
                        }
                    /// Reset contain-intrinsic-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_contain_intrinsic_width(&mut self, other: &Self) {
                        self.copy_contain_intrinsic_width_from(other)
                    }

                    /// Get the computed value for contain-intrinsic-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_contain_intrinsic_width(&self) -> longhands::contain_intrinsic_width::computed_value::T {
                        self.contain_intrinsic_width.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The SVG style struct.
        pub struct SVG {
                    /// The vector-effect computed value.
                    pub vector_effect: longhands::vector_effect::computed_value::T,
                    /// The stop-color computed value.
                    pub stop_color: longhands::stop_color::computed_value::T,
                    /// The stop-opacity computed value.
                    pub stop_opacity: longhands::stop_opacity::computed_value::T,
                    /// The flood-color computed value.
                    pub flood_color: longhands::flood_color::computed_value::T,
                    /// The flood-opacity computed value.
                    pub flood_opacity: longhands::flood_opacity::computed_value::T,
                    /// The lighting-color computed value.
                    pub lighting_color: longhands::lighting_color::computed_value::T,
                    /// The mask-type computed value.
                    pub mask_type: longhands::mask_type::computed_value::T,
                    /// The clip-path computed value.
                    pub clip_path: longhands::clip_path::computed_value::T,
                    /// The mask-mode computed value.
                    pub mask_mode: longhands::mask_mode::computed_value::T,
                    /// The mask-repeat computed value.
                    pub mask_repeat: longhands::mask_repeat::computed_value::T,
                    /// The mask-position-x computed value.
                    pub mask_position_x: longhands::mask_position_x::computed_value::T,
                    /// The mask-position-y computed value.
                    pub mask_position_y: longhands::mask_position_y::computed_value::T,
                    /// The mask-clip computed value.
                    pub mask_clip: longhands::mask_clip::computed_value::T,
                    /// The mask-origin computed value.
                    pub mask_origin: longhands::mask_origin::computed_value::T,
                    /// The mask-size computed value.
                    pub mask_size: longhands::mask_size::computed_value::T,
                    /// The mask-composite computed value.
                    pub mask_composite: longhands::mask_composite::computed_value::T,
                    /// The mask-image computed value.
                    pub mask_image: longhands::mask_image::computed_value::T,
                    /// The x computed value.
                    pub x: longhands::x::computed_value::T,
                    /// The y computed value.
                    pub y: longhands::y::computed_value::T,
                    /// The cx computed value.
                    pub cx: longhands::cx::computed_value::T,
                    /// The cy computed value.
                    pub cy: longhands::cy::computed_value::T,
                    /// The rx computed value.
                    pub rx: longhands::rx::computed_value::T,
                    /// The ry computed value.
                    pub ry: longhands::ry::computed_value::T,
                    /// The r computed value.
                    pub r: longhands::r::computed_value::T,
                    /// The d computed value.
                    pub d: longhands::d::computed_value::T,
        }

        impl SVG {
                        /// Set vector-effect.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_vector_effect(&mut self, v: longhands::vector_effect::computed_value::T) {
                            self.vector_effect = v;
                        }
                        /// Set vector-effect from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_vector_effect_from(&mut self, other: &Self) {
                            self.vector_effect = other.vector_effect.clone();
                        }
                    /// Reset vector-effect from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_vector_effect(&mut self, other: &Self) {
                        self.copy_vector_effect_from(other)
                    }

                    /// Get the computed value for vector-effect.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_vector_effect(&self) -> longhands::vector_effect::computed_value::T {
                        self.vector_effect.clone()
                    }
                        /// Set stop-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stop_color(&mut self, v: longhands::stop_color::computed_value::T) {
                            self.stop_color = v;
                        }
                        /// Set stop-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stop_color_from(&mut self, other: &Self) {
                            self.stop_color = other.stop_color.clone();
                        }
                    /// Reset stop-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stop_color(&mut self, other: &Self) {
                        self.copy_stop_color_from(other)
                    }

                    /// Get the computed value for stop-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stop_color(&self) -> longhands::stop_color::computed_value::T {
                        self.stop_color.clone()
                    }
                        /// Set stop-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_stop_opacity(&mut self, v: longhands::stop_opacity::computed_value::T) {
                            self.stop_opacity = v;
                        }
                        /// Set stop-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_stop_opacity_from(&mut self, other: &Self) {
                            self.stop_opacity = other.stop_opacity.clone();
                        }
                    /// Reset stop-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_stop_opacity(&mut self, other: &Self) {
                        self.copy_stop_opacity_from(other)
                    }

                    /// Get the computed value for stop-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_stop_opacity(&self) -> longhands::stop_opacity::computed_value::T {
                        self.stop_opacity.clone()
                    }
                        /// Set flood-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flood_color(&mut self, v: longhands::flood_color::computed_value::T) {
                            self.flood_color = v;
                        }
                        /// Set flood-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flood_color_from(&mut self, other: &Self) {
                            self.flood_color = other.flood_color.clone();
                        }
                    /// Reset flood-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flood_color(&mut self, other: &Self) {
                        self.copy_flood_color_from(other)
                    }

                    /// Get the computed value for flood-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flood_color(&self) -> longhands::flood_color::computed_value::T {
                        self.flood_color.clone()
                    }
                        /// Set flood-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_flood_opacity(&mut self, v: longhands::flood_opacity::computed_value::T) {
                            self.flood_opacity = v;
                        }
                        /// Set flood-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_flood_opacity_from(&mut self, other: &Self) {
                            self.flood_opacity = other.flood_opacity.clone();
                        }
                    /// Reset flood-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_flood_opacity(&mut self, other: &Self) {
                        self.copy_flood_opacity_from(other)
                    }

                    /// Get the computed value for flood-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_flood_opacity(&self) -> longhands::flood_opacity::computed_value::T {
                        self.flood_opacity.clone()
                    }
                        /// Set lighting-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_lighting_color(&mut self, v: longhands::lighting_color::computed_value::T) {
                            self.lighting_color = v;
                        }
                        /// Set lighting-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_lighting_color_from(&mut self, other: &Self) {
                            self.lighting_color = other.lighting_color.clone();
                        }
                    /// Reset lighting-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_lighting_color(&mut self, other: &Self) {
                        self.copy_lighting_color_from(other)
                    }

                    /// Get the computed value for lighting-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_lighting_color(&self) -> longhands::lighting_color::computed_value::T {
                        self.lighting_color.clone()
                    }
                        /// Set mask-type.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_type(&mut self, v: longhands::mask_type::computed_value::T) {
                            self.mask_type = v;
                        }
                        /// Set mask-type from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_type_from(&mut self, other: &Self) {
                            self.mask_type = other.mask_type.clone();
                        }
                    /// Reset mask-type from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_type(&mut self, other: &Self) {
                        self.copy_mask_type_from(other)
                    }

                    /// Get the computed value for mask-type.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_type(&self) -> longhands::mask_type::computed_value::T {
                        self.mask_type.clone()
                    }
                        /// Set clip-path.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_clip_path(&mut self, v: longhands::clip_path::computed_value::T) {
                            self.clip_path = v;
                        }
                        /// Set clip-path from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_clip_path_from(&mut self, other: &Self) {
                            self.clip_path = other.clip_path.clone();
                        }
                    /// Reset clip-path from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_clip_path(&mut self, other: &Self) {
                        self.copy_clip_path_from(other)
                    }

                    /// Get the computed value for clip-path.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_clip_path(&self) -> longhands::clip_path::computed_value::T {
                        self.clip_path.clone()
                    }
                        /// Set mask-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_mode(&mut self, v: longhands::mask_mode::computed_value::T) {
                            self.mask_mode = v;
                        }
                        /// Set mask-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_mode_from(&mut self, other: &Self) {
                            self.mask_mode = other.mask_mode.clone();
                        }
                    /// Reset mask-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_mode(&mut self, other: &Self) {
                        self.copy_mask_mode_from(other)
                    }

                    /// Get the computed value for mask-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_mode(&self) -> longhands::mask_mode::computed_value::T {
                        self.mask_mode.clone()
                    }
                        /// Set mask-repeat.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_repeat(&mut self, v: longhands::mask_repeat::computed_value::T) {
                            self.mask_repeat = v;
                        }
                        /// Set mask-repeat from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_repeat_from(&mut self, other: &Self) {
                            self.mask_repeat = other.mask_repeat.clone();
                        }
                    /// Reset mask-repeat from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_repeat(&mut self, other: &Self) {
                        self.copy_mask_repeat_from(other)
                    }

                    /// Get the computed value for mask-repeat.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_repeat(&self) -> longhands::mask_repeat::computed_value::T {
                        self.mask_repeat.clone()
                    }
                        /// Set mask-position-x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_position_x(&mut self, v: longhands::mask_position_x::computed_value::T) {
                            self.mask_position_x = v;
                        }
                        /// Set mask-position-x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_position_x_from(&mut self, other: &Self) {
                            self.mask_position_x = other.mask_position_x.clone();
                        }
                    /// Reset mask-position-x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_position_x(&mut self, other: &Self) {
                        self.copy_mask_position_x_from(other)
                    }

                    /// Get the computed value for mask-position-x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_position_x(&self) -> longhands::mask_position_x::computed_value::T {
                        self.mask_position_x.clone()
                    }
                        /// Set mask-position-y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_position_y(&mut self, v: longhands::mask_position_y::computed_value::T) {
                            self.mask_position_y = v;
                        }
                        /// Set mask-position-y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_position_y_from(&mut self, other: &Self) {
                            self.mask_position_y = other.mask_position_y.clone();
                        }
                    /// Reset mask-position-y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_position_y(&mut self, other: &Self) {
                        self.copy_mask_position_y_from(other)
                    }

                    /// Get the computed value for mask-position-y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_position_y(&self) -> longhands::mask_position_y::computed_value::T {
                        self.mask_position_y.clone()
                    }
                        /// Set mask-clip.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_clip(&mut self, v: longhands::mask_clip::computed_value::T) {
                            self.mask_clip = v;
                        }
                        /// Set mask-clip from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_clip_from(&mut self, other: &Self) {
                            self.mask_clip = other.mask_clip.clone();
                        }
                    /// Reset mask-clip from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_clip(&mut self, other: &Self) {
                        self.copy_mask_clip_from(other)
                    }

                    /// Get the computed value for mask-clip.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_clip(&self) -> longhands::mask_clip::computed_value::T {
                        self.mask_clip.clone()
                    }
                        /// Set mask-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_origin(&mut self, v: longhands::mask_origin::computed_value::T) {
                            self.mask_origin = v;
                        }
                        /// Set mask-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_origin_from(&mut self, other: &Self) {
                            self.mask_origin = other.mask_origin.clone();
                        }
                    /// Reset mask-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_origin(&mut self, other: &Self) {
                        self.copy_mask_origin_from(other)
                    }

                    /// Get the computed value for mask-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_origin(&self) -> longhands::mask_origin::computed_value::T {
                        self.mask_origin.clone()
                    }
                        /// Set mask-size.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_size(&mut self, v: longhands::mask_size::computed_value::T) {
                            self.mask_size = v;
                        }
                        /// Set mask-size from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_size_from(&mut self, other: &Self) {
                            self.mask_size = other.mask_size.clone();
                        }
                    /// Reset mask-size from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_size(&mut self, other: &Self) {
                        self.copy_mask_size_from(other)
                    }

                    /// Get the computed value for mask-size.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_size(&self) -> longhands::mask_size::computed_value::T {
                        self.mask_size.clone()
                    }
                        /// Set mask-composite.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_composite(&mut self, v: longhands::mask_composite::computed_value::T) {
                            self.mask_composite = v;
                        }
                        /// Set mask-composite from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_composite_from(&mut self, other: &Self) {
                            self.mask_composite = other.mask_composite.clone();
                        }
                    /// Reset mask-composite from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_composite(&mut self, other: &Self) {
                        self.copy_mask_composite_from(other)
                    }

                    /// Get the computed value for mask-composite.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_composite(&self) -> longhands::mask_composite::computed_value::T {
                        self.mask_composite.clone()
                    }
                        /// Set mask-image.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_mask_image(&mut self, v: longhands::mask_image::computed_value::T) {
                            self.mask_image = v;
                        }
                        /// Set mask-image from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_mask_image_from(&mut self, other: &Self) {
                            self.mask_image = other.mask_image.clone();
                        }
                    /// Reset mask-image from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_mask_image(&mut self, other: &Self) {
                        self.copy_mask_image_from(other)
                    }

                    /// Get the computed value for mask-image.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_mask_image(&self) -> longhands::mask_image::computed_value::T {
                        self.mask_image.clone()
                    }
                        /// Set x.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_x(&mut self, v: longhands::x::computed_value::T) {
                            self.x = v;
                        }
                        /// Set x from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_x_from(&mut self, other: &Self) {
                            self.x = other.x.clone();
                        }
                    /// Reset x from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_x(&mut self, other: &Self) {
                        self.copy_x_from(other)
                    }

                    /// Get the computed value for x.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_x(&self) -> longhands::x::computed_value::T {
                        self.x.clone()
                    }
                        /// Set y.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_y(&mut self, v: longhands::y::computed_value::T) {
                            self.y = v;
                        }
                        /// Set y from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_y_from(&mut self, other: &Self) {
                            self.y = other.y.clone();
                        }
                    /// Reset y from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_y(&mut self, other: &Self) {
                        self.copy_y_from(other)
                    }

                    /// Get the computed value for y.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_y(&self) -> longhands::y::computed_value::T {
                        self.y.clone()
                    }
                        /// Set cx.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_cx(&mut self, v: longhands::cx::computed_value::T) {
                            self.cx = v;
                        }
                        /// Set cx from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_cx_from(&mut self, other: &Self) {
                            self.cx = other.cx.clone();
                        }
                    /// Reset cx from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_cx(&mut self, other: &Self) {
                        self.copy_cx_from(other)
                    }

                    /// Get the computed value for cx.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_cx(&self) -> longhands::cx::computed_value::T {
                        self.cx.clone()
                    }
                        /// Set cy.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_cy(&mut self, v: longhands::cy::computed_value::T) {
                            self.cy = v;
                        }
                        /// Set cy from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_cy_from(&mut self, other: &Self) {
                            self.cy = other.cy.clone();
                        }
                    /// Reset cy from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_cy(&mut self, other: &Self) {
                        self.copy_cy_from(other)
                    }

                    /// Get the computed value for cy.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_cy(&self) -> longhands::cy::computed_value::T {
                        self.cy.clone()
                    }
                        /// Set rx.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_rx(&mut self, v: longhands::rx::computed_value::T) {
                            self.rx = v;
                        }
                        /// Set rx from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_rx_from(&mut self, other: &Self) {
                            self.rx = other.rx.clone();
                        }
                    /// Reset rx from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_rx(&mut self, other: &Self) {
                        self.copy_rx_from(other)
                    }

                    /// Get the computed value for rx.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_rx(&self) -> longhands::rx::computed_value::T {
                        self.rx.clone()
                    }
                        /// Set ry.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ry(&mut self, v: longhands::ry::computed_value::T) {
                            self.ry = v;
                        }
                        /// Set ry from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ry_from(&mut self, other: &Self) {
                            self.ry = other.ry.clone();
                        }
                    /// Reset ry from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ry(&mut self, other: &Self) {
                        self.copy_ry_from(other)
                    }

                    /// Get the computed value for ry.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ry(&self) -> longhands::ry::computed_value::T {
                        self.ry.clone()
                    }
                        /// Set r.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_r(&mut self, v: longhands::r::computed_value::T) {
                            self.r = v;
                        }
                        /// Set r from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_r_from(&mut self, other: &Self) {
                            self.r = other.r.clone();
                        }
                    /// Reset r from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_r(&mut self, other: &Self) {
                        self.copy_r_from(other)
                    }

                    /// Get the computed value for r.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_r(&self) -> longhands::r::computed_value::T {
                        self.r.clone()
                    }
                        /// Set d.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_d(&mut self, v: longhands::d::computed_value::T) {
                            self.d = v;
                        }
                        /// Set d from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_d_from(&mut self, other: &Self) {
                            self.d = other.d.clone();
                        }
                    /// Reset d from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_d(&mut self, other: &Self) {
                        self.copy_d_from(other)
                    }

                    /// Get the computed value for d.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_d(&self) -> longhands::d::computed_value::T {
                        self.d.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Table style struct.
        pub struct Table {
                    /// The table-layout computed value.
                    pub table_layout: longhands::table_layout::computed_value::T,
                    /// The -x-span computed value.
                    pub _x_span: longhands::_x_span::computed_value::T,
        }

        impl Table {
                        /// Set table-layout.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_table_layout(&mut self, v: longhands::table_layout::computed_value::T) {
                            self.table_layout = v;
                        }
                        /// Set table-layout from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_table_layout_from(&mut self, other: &Self) {
                            self.table_layout = other.table_layout.clone();
                        }
                    /// Reset table-layout from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_table_layout(&mut self, other: &Self) {
                        self.copy_table_layout_from(other)
                    }

                    /// Get the computed value for table-layout.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_table_layout(&self) -> longhands::table_layout::computed_value::T {
                        self.table_layout.clone()
                    }
                        /// Set -x-span.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__x_span(&mut self, v: longhands::_x_span::computed_value::T) {
                            self._x_span = v;
                        }
                        /// Set -x-span from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__x_span_from(&mut self, other: &Self) {
                            self._x_span = other._x_span.clone();
                        }
                    /// Reset -x-span from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__x_span(&mut self, other: &Self) {
                        self.copy__x_span_from(other)
                    }

                    /// Get the computed value for -x-span.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__x_span(&self) -> longhands::_x_span::computed_value::T {
                        self._x_span.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The Text style struct.
        pub struct Text {
                    /// The text-overflow computed value.
                    pub text_overflow: longhands::text_overflow::computed_value::T,
                    /// The unicode-bidi computed value.
                    pub unicode_bidi: longhands::unicode_bidi::computed_value::T,
                    /// The text-decoration-line computed value.
                    pub text_decoration_line: longhands::text_decoration_line::computed_value::T,
                    /// The text-decoration-style computed value.
                    pub text_decoration_style: longhands::text_decoration_style::computed_value::T,
                    /// The text-decoration-color computed value.
                    pub text_decoration_color: longhands::text_decoration_color::computed_value::T,
                    /// The initial-letter computed value.
                    pub initial_letter: longhands::initial_letter::computed_value::T,
                    /// The text-decoration-thickness computed value.
                    pub text_decoration_thickness: longhands::text_decoration_thickness::computed_value::T,
        }

        impl Text {
                        /// Set text-overflow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_overflow(&mut self, v: longhands::text_overflow::computed_value::T) {
                            self.text_overflow = v;
                        }
                        /// Set text-overflow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_overflow_from(&mut self, other: &Self) {
                            self.text_overflow = other.text_overflow.clone();
                        }
                    /// Reset text-overflow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_overflow(&mut self, other: &Self) {
                        self.copy_text_overflow_from(other)
                    }

                    /// Get the computed value for text-overflow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_overflow(&self) -> longhands::text_overflow::computed_value::T {
                        self.text_overflow.clone()
                    }
                        /// Set unicode-bidi.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_unicode_bidi(&mut self, v: longhands::unicode_bidi::computed_value::T) {
                            self.unicode_bidi = v;
                        }
                        /// Set unicode-bidi from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_unicode_bidi_from(&mut self, other: &Self) {
                            self.unicode_bidi = other.unicode_bidi.clone();
                        }
                    /// Reset unicode-bidi from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_unicode_bidi(&mut self, other: &Self) {
                        self.copy_unicode_bidi_from(other)
                    }

                    /// Get the computed value for unicode-bidi.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_unicode_bidi(&self) -> longhands::unicode_bidi::computed_value::T {
                        self.unicode_bidi.clone()
                    }
                        /// Set text-decoration-line.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_line(&mut self, v: longhands::text_decoration_line::computed_value::T) {
                            self.text_decoration_line = v;
                        }
                        /// Set text-decoration-line from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_line_from(&mut self, other: &Self) {
                            self.text_decoration_line = other.text_decoration_line.clone();
                        }
                    /// Reset text-decoration-line from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_line(&mut self, other: &Self) {
                        self.copy_text_decoration_line_from(other)
                    }

                    /// Get the computed value for text-decoration-line.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_line(&self) -> longhands::text_decoration_line::computed_value::T {
                        self.text_decoration_line.clone()
                    }
                        /// Set text-decoration-style.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_style(&mut self, v: longhands::text_decoration_style::computed_value::T) {
                            self.text_decoration_style = v;
                        }
                        /// Set text-decoration-style from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_style_from(&mut self, other: &Self) {
                            self.text_decoration_style = other.text_decoration_style.clone();
                        }
                    /// Reset text-decoration-style from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_style(&mut self, other: &Self) {
                        self.copy_text_decoration_style_from(other)
                    }

                    /// Get the computed value for text-decoration-style.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_style(&self) -> longhands::text_decoration_style::computed_value::T {
                        self.text_decoration_style.clone()
                    }
                        /// Set text-decoration-color.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_color(&mut self, v: longhands::text_decoration_color::computed_value::T) {
                            self.text_decoration_color = v;
                        }
                        /// Set text-decoration-color from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_color_from(&mut self, other: &Self) {
                            self.text_decoration_color = other.text_decoration_color.clone();
                        }
                    /// Reset text-decoration-color from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_color(&mut self, other: &Self) {
                        self.copy_text_decoration_color_from(other)
                    }

                    /// Get the computed value for text-decoration-color.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_color(&self) -> longhands::text_decoration_color::computed_value::T {
                        self.text_decoration_color.clone()
                    }
                        /// Set initial-letter.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_initial_letter(&mut self, v: longhands::initial_letter::computed_value::T) {
                            self.initial_letter = v;
                        }
                        /// Set initial-letter from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_initial_letter_from(&mut self, other: &Self) {
                            self.initial_letter = other.initial_letter.clone();
                        }
                    /// Reset initial-letter from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_initial_letter(&mut self, other: &Self) {
                        self.copy_initial_letter_from(other)
                    }

                    /// Get the computed value for initial-letter.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_initial_letter(&self) -> longhands::initial_letter::computed_value::T {
                        self.initial_letter.clone()
                    }
                        /// Set text-decoration-thickness.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_text_decoration_thickness(&mut self, v: longhands::text_decoration_thickness::computed_value::T) {
                            self.text_decoration_thickness = v;
                        }
                        /// Set text-decoration-thickness from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_text_decoration_thickness_from(&mut self, other: &Self) {
                            self.text_decoration_thickness = other.text_decoration_thickness.clone();
                        }
                    /// Reset text-decoration-thickness from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_text_decoration_thickness(&mut self, other: &Self) {
                        self.copy_text_decoration_thickness_from(other)
                    }

                    /// Get the computed value for text-decoration-thickness.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_text_decoration_thickness(&self) -> longhands::text_decoration_thickness::computed_value::T {
                        self.text_decoration_thickness.clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The UI style struct.
        pub struct UI {
                    /// The ime-mode computed value.
                    pub ime_mode: longhands::ime_mode::computed_value::T,
                    /// The scrollbar-width computed value.
                    pub scrollbar_width: longhands::scrollbar_width::computed_value::T,
                    /// The user-select computed value.
                    pub user_select: longhands::user_select::computed_value::T,
                    /// The -moz-window-dragging computed value.
                    pub _moz_window_dragging: longhands::_moz_window_dragging::computed_value::T,
                    /// The -moz-window-shadow computed value.
                    pub _moz_window_shadow: longhands::_moz_window_shadow::computed_value::T,
                    /// The -moz-window-opacity computed value.
                    pub _moz_window_opacity: longhands::_moz_window_opacity::computed_value::T,
                    /// The -moz-window-transform computed value.
                    pub _moz_window_transform: longhands::_moz_window_transform::computed_value::T,
                    /// The -moz-window-transform-origin computed value.
                    pub _moz_window_transform_origin: longhands::_moz_window_transform_origin::computed_value::T,
                    /// The -moz-window-input-region-margin computed value.
                    pub _moz_window_input_region_margin: longhands::_moz_window_input_region_margin::computed_value::T,
                    /// The -moz-subtree-hidden-only-visually computed value.
                    pub _moz_subtree_hidden_only_visually: longhands::_moz_subtree_hidden_only_visually::computed_value::T,
                    /// The -moz-force-broken-image-icon computed value.
                    pub _moz_force_broken_image_icon: longhands::_moz_force_broken_image_icon::computed_value::T,
                    /// The transition-duration computed value.
                    pub transition_duration: longhands::transition_duration::computed_value::T,
                    /// The transition-timing-function computed value.
                    pub transition_timing_function: longhands::transition_timing_function::computed_value::T,
                    /// The transition-property computed value.
                    pub transition_property: longhands::transition_property::computed_value::T,
                    /// The transition-delay computed value.
                    pub transition_delay: longhands::transition_delay::computed_value::T,
                    /// The transition-behavior computed value.
                    pub transition_behavior: longhands::transition_behavior::computed_value::T,
                    /// The animation-name computed value.
                    pub animation_name: longhands::animation_name::computed_value::T,
                    /// The animation-duration computed value.
                    pub animation_duration: longhands::animation_duration::computed_value::T,
                    /// The animation-timing-function computed value.
                    pub animation_timing_function: longhands::animation_timing_function::computed_value::T,
                    /// The animation-iteration-count computed value.
                    pub animation_iteration_count: longhands::animation_iteration_count::computed_value::T,
                    /// The animation-direction computed value.
                    pub animation_direction: longhands::animation_direction::computed_value::T,
                    /// The animation-play-state computed value.
                    pub animation_play_state: longhands::animation_play_state::computed_value::T,
                    /// The animation-fill-mode computed value.
                    pub animation_fill_mode: longhands::animation_fill_mode::computed_value::T,
                    /// The animation-composition computed value.
                    pub animation_composition: longhands::animation_composition::computed_value::T,
                    /// The animation-delay computed value.
                    pub animation_delay: longhands::animation_delay::computed_value::T,
                    /// The animation-timeline computed value.
                    pub animation_timeline: longhands::animation_timeline::computed_value::T,
                    /// The scroll-timeline-name computed value.
                    pub scroll_timeline_name: longhands::scroll_timeline_name::computed_value::T,
                    /// The scroll-timeline-axis computed value.
                    pub scroll_timeline_axis: longhands::scroll_timeline_axis::computed_value::T,
                    /// The view-timeline-name computed value.
                    pub view_timeline_name: longhands::view_timeline_name::computed_value::T,
                    /// The view-timeline-axis computed value.
                    pub view_timeline_axis: longhands::view_timeline_axis::computed_value::T,
                    /// The view-timeline-inset computed value.
                    pub view_timeline_inset: longhands::view_timeline_inset::computed_value::T,
        }

        impl UI {
                        /// Set ime-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_ime_mode(&mut self, v: longhands::ime_mode::computed_value::T) {
                            self.ime_mode = v;
                        }
                        /// Set ime-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_ime_mode_from(&mut self, other: &Self) {
                            self.ime_mode = other.ime_mode.clone();
                        }
                    /// Reset ime-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_ime_mode(&mut self, other: &Self) {
                        self.copy_ime_mode_from(other)
                    }

                    /// Get the computed value for ime-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_ime_mode(&self) -> longhands::ime_mode::computed_value::T {
                        self.ime_mode.clone()
                    }
                        /// Set scrollbar-width.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scrollbar_width(&mut self, v: longhands::scrollbar_width::computed_value::T) {
                            self.scrollbar_width = v;
                        }
                        /// Set scrollbar-width from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scrollbar_width_from(&mut self, other: &Self) {
                            self.scrollbar_width = other.scrollbar_width.clone();
                        }
                    /// Reset scrollbar-width from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scrollbar_width(&mut self, other: &Self) {
                        self.copy_scrollbar_width_from(other)
                    }

                    /// Get the computed value for scrollbar-width.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scrollbar_width(&self) -> longhands::scrollbar_width::computed_value::T {
                        self.scrollbar_width.clone()
                    }
                        /// Set user-select.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_user_select(&mut self, v: longhands::user_select::computed_value::T) {
                            self.user_select = v;
                        }
                        /// Set user-select from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_user_select_from(&mut self, other: &Self) {
                            self.user_select = other.user_select.clone();
                        }
                    /// Reset user-select from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_user_select(&mut self, other: &Self) {
                        self.copy_user_select_from(other)
                    }

                    /// Get the computed value for user-select.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_user_select(&self) -> longhands::user_select::computed_value::T {
                        self.user_select.clone()
                    }
                        /// Set -moz-window-dragging.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_dragging(&mut self, v: longhands::_moz_window_dragging::computed_value::T) {
                            self._moz_window_dragging = v;
                        }
                        /// Set -moz-window-dragging from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_dragging_from(&mut self, other: &Self) {
                            self._moz_window_dragging = other._moz_window_dragging.clone();
                        }
                    /// Reset -moz-window-dragging from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_dragging(&mut self, other: &Self) {
                        self.copy__moz_window_dragging_from(other)
                    }

                    /// Get the computed value for -moz-window-dragging.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_dragging(&self) -> longhands::_moz_window_dragging::computed_value::T {
                        self._moz_window_dragging.clone()
                    }
                        /// Set -moz-window-shadow.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_shadow(&mut self, v: longhands::_moz_window_shadow::computed_value::T) {
                            self._moz_window_shadow = v;
                        }
                        /// Set -moz-window-shadow from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_shadow_from(&mut self, other: &Self) {
                            self._moz_window_shadow = other._moz_window_shadow.clone();
                        }
                    /// Reset -moz-window-shadow from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_shadow(&mut self, other: &Self) {
                        self.copy__moz_window_shadow_from(other)
                    }

                    /// Get the computed value for -moz-window-shadow.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_shadow(&self) -> longhands::_moz_window_shadow::computed_value::T {
                        self._moz_window_shadow.clone()
                    }
                        /// Set -moz-window-opacity.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_opacity(&mut self, v: longhands::_moz_window_opacity::computed_value::T) {
                            self._moz_window_opacity = v;
                        }
                        /// Set -moz-window-opacity from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_opacity_from(&mut self, other: &Self) {
                            self._moz_window_opacity = other._moz_window_opacity.clone();
                        }
                    /// Reset -moz-window-opacity from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_opacity(&mut self, other: &Self) {
                        self.copy__moz_window_opacity_from(other)
                    }

                    /// Get the computed value for -moz-window-opacity.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_opacity(&self) -> longhands::_moz_window_opacity::computed_value::T {
                        self._moz_window_opacity.clone()
                    }
                        /// Set -moz-window-transform.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_transform(&mut self, v: longhands::_moz_window_transform::computed_value::T) {
                            self._moz_window_transform = v;
                        }
                        /// Set -moz-window-transform from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_transform_from(&mut self, other: &Self) {
                            self._moz_window_transform = other._moz_window_transform.clone();
                        }
                    /// Reset -moz-window-transform from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_transform(&mut self, other: &Self) {
                        self.copy__moz_window_transform_from(other)
                    }

                    /// Get the computed value for -moz-window-transform.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_transform(&self) -> longhands::_moz_window_transform::computed_value::T {
                        self._moz_window_transform.clone()
                    }
                        /// Set -moz-window-transform-origin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_transform_origin(&mut self, v: longhands::_moz_window_transform_origin::computed_value::T) {
                            self._moz_window_transform_origin = v;
                        }
                        /// Set -moz-window-transform-origin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_transform_origin_from(&mut self, other: &Self) {
                            self._moz_window_transform_origin = other._moz_window_transform_origin.clone();
                        }
                    /// Reset -moz-window-transform-origin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_transform_origin(&mut self, other: &Self) {
                        self.copy__moz_window_transform_origin_from(other)
                    }

                    /// Get the computed value for -moz-window-transform-origin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_transform_origin(&self) -> longhands::_moz_window_transform_origin::computed_value::T {
                        self._moz_window_transform_origin.clone()
                    }
                        /// Set -moz-window-input-region-margin.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_window_input_region_margin(&mut self, v: longhands::_moz_window_input_region_margin::computed_value::T) {
                            self._moz_window_input_region_margin = v;
                        }
                        /// Set -moz-window-input-region-margin from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_window_input_region_margin_from(&mut self, other: &Self) {
                            self._moz_window_input_region_margin = other._moz_window_input_region_margin.clone();
                        }
                    /// Reset -moz-window-input-region-margin from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_window_input_region_margin(&mut self, other: &Self) {
                        self.copy__moz_window_input_region_margin_from(other)
                    }

                    /// Get the computed value for -moz-window-input-region-margin.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_window_input_region_margin(&self) -> longhands::_moz_window_input_region_margin::computed_value::T {
                        self._moz_window_input_region_margin.clone()
                    }
                        /// Set -moz-subtree-hidden-only-visually.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_subtree_hidden_only_visually(&mut self, v: longhands::_moz_subtree_hidden_only_visually::computed_value::T) {
                            self._moz_subtree_hidden_only_visually = v;
                        }
                        /// Set -moz-subtree-hidden-only-visually from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_subtree_hidden_only_visually_from(&mut self, other: &Self) {
                            self._moz_subtree_hidden_only_visually = other._moz_subtree_hidden_only_visually.clone();
                        }
                    /// Reset -moz-subtree-hidden-only-visually from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_subtree_hidden_only_visually(&mut self, other: &Self) {
                        self.copy__moz_subtree_hidden_only_visually_from(other)
                    }

                    /// Get the computed value for -moz-subtree-hidden-only-visually.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_subtree_hidden_only_visually(&self) -> longhands::_moz_subtree_hidden_only_visually::computed_value::T {
                        self._moz_subtree_hidden_only_visually.clone()
                    }
                        /// Set -moz-force-broken-image-icon.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_force_broken_image_icon(&mut self, v: longhands::_moz_force_broken_image_icon::computed_value::T) {
                            self._moz_force_broken_image_icon = v;
                        }
                        /// Set -moz-force-broken-image-icon from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_force_broken_image_icon_from(&mut self, other: &Self) {
                            self._moz_force_broken_image_icon = other._moz_force_broken_image_icon.clone();
                        }
                    /// Reset -moz-force-broken-image-icon from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_force_broken_image_icon(&mut self, other: &Self) {
                        self.copy__moz_force_broken_image_icon_from(other)
                    }

                    /// Get the computed value for -moz-force-broken-image-icon.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_force_broken_image_icon(&self) -> longhands::_moz_force_broken_image_icon::computed_value::T {
                        self._moz_force_broken_image_icon.clone()
                    }
                        /// Set transition-duration.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_duration(&mut self, v: longhands::transition_duration::computed_value::T) {
                            self.transition_duration = v;
                        }
                        /// Set transition-duration from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_duration_from(&mut self, other: &Self) {
                            self.transition_duration = other.transition_duration.clone();
                        }
                    /// Reset transition-duration from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_duration(&mut self, other: &Self) {
                        self.copy_transition_duration_from(other)
                    }

                    /// Get the computed value for transition-duration.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_duration(&self) -> longhands::transition_duration::computed_value::T {
                        self.transition_duration.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_duration_count(&self) -> usize {
                        self.transition_duration.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_duration_at(&self, index: usize)
                        -> longhands::transition_duration::computed_value::SingleComputedValue {
                        self.transition_duration.0[index].clone()
                    }
                        /// Set transition-timing-function.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_timing_function(&mut self, v: longhands::transition_timing_function::computed_value::T) {
                            self.transition_timing_function = v;
                        }
                        /// Set transition-timing-function from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_timing_function_from(&mut self, other: &Self) {
                            self.transition_timing_function = other.transition_timing_function.clone();
                        }
                    /// Reset transition-timing-function from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_timing_function(&mut self, other: &Self) {
                        self.copy_transition_timing_function_from(other)
                    }

                    /// Get the computed value for transition-timing-function.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_timing_function(&self) -> longhands::transition_timing_function::computed_value::T {
                        self.transition_timing_function.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_timing_function_count(&self) -> usize {
                        self.transition_timing_function.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_timing_function_at(&self, index: usize)
                        -> longhands::transition_timing_function::computed_value::SingleComputedValue {
                        self.transition_timing_function.0[index].clone()
                    }
                        /// Set transition-property.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_property(&mut self, v: longhands::transition_property::computed_value::T) {
                            self.transition_property = v;
                        }
                        /// Set transition-property from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_property_from(&mut self, other: &Self) {
                            self.transition_property = other.transition_property.clone();
                        }
                    /// Reset transition-property from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_property(&mut self, other: &Self) {
                        self.copy_transition_property_from(other)
                    }

                    /// Get the computed value for transition-property.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_property(&self) -> longhands::transition_property::computed_value::T {
                        self.transition_property.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_property_count(&self) -> usize {
                        self.transition_property.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_property_at(&self, index: usize)
                        -> longhands::transition_property::computed_value::SingleComputedValue {
                        self.transition_property.0[index].clone()
                    }
                        /// Set transition-delay.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_delay(&mut self, v: longhands::transition_delay::computed_value::T) {
                            self.transition_delay = v;
                        }
                        /// Set transition-delay from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_delay_from(&mut self, other: &Self) {
                            self.transition_delay = other.transition_delay.clone();
                        }
                    /// Reset transition-delay from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_delay(&mut self, other: &Self) {
                        self.copy_transition_delay_from(other)
                    }

                    /// Get the computed value for transition-delay.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_delay(&self) -> longhands::transition_delay::computed_value::T {
                        self.transition_delay.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_delay_count(&self) -> usize {
                        self.transition_delay.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_delay_at(&self, index: usize)
                        -> longhands::transition_delay::computed_value::SingleComputedValue {
                        self.transition_delay.0[index].clone()
                    }
                        /// Set transition-behavior.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_transition_behavior(&mut self, v: longhands::transition_behavior::computed_value::T) {
                            self.transition_behavior = v;
                        }
                        /// Set transition-behavior from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_transition_behavior_from(&mut self, other: &Self) {
                            self.transition_behavior = other.transition_behavior.clone();
                        }
                    /// Reset transition-behavior from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_transition_behavior(&mut self, other: &Self) {
                        self.copy_transition_behavior_from(other)
                    }

                    /// Get the computed value for transition-behavior.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_transition_behavior(&self) -> longhands::transition_behavior::computed_value::T {
                        self.transition_behavior.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn transition_behavior_count(&self) -> usize {
                        self.transition_behavior.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn transition_behavior_at(&self, index: usize)
                        -> longhands::transition_behavior::computed_value::SingleComputedValue {
                        self.transition_behavior.0[index].clone()
                    }
                        /// Set animation-name.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_name(&mut self, v: longhands::animation_name::computed_value::T) {
                            self.animation_name = v;
                        }
                        /// Set animation-name from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_name_from(&mut self, other: &Self) {
                            self.animation_name = other.animation_name.clone();
                        }
                    /// Reset animation-name from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_name(&mut self, other: &Self) {
                        self.copy_animation_name_from(other)
                    }

                    /// Get the computed value for animation-name.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_name(&self) -> longhands::animation_name::computed_value::T {
                        self.animation_name.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_name_count(&self) -> usize {
                        self.animation_name.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_name_at(&self, index: usize)
                        -> longhands::animation_name::computed_value::SingleComputedValue {
                        self.animation_name.0[index].clone()
                    }
                        /// Set animation-duration.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_duration(&mut self, v: longhands::animation_duration::computed_value::T) {
                            self.animation_duration = v;
                        }
                        /// Set animation-duration from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_duration_from(&mut self, other: &Self) {
                            self.animation_duration = other.animation_duration.clone();
                        }
                    /// Reset animation-duration from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_duration(&mut self, other: &Self) {
                        self.copy_animation_duration_from(other)
                    }

                    /// Get the computed value for animation-duration.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_duration(&self) -> longhands::animation_duration::computed_value::T {
                        self.animation_duration.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_duration_count(&self) -> usize {
                        self.animation_duration.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_duration_at(&self, index: usize)
                        -> longhands::animation_duration::computed_value::SingleComputedValue {
                        self.animation_duration.0[index].clone()
                    }
                        /// Set animation-timing-function.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_timing_function(&mut self, v: longhands::animation_timing_function::computed_value::T) {
                            self.animation_timing_function = v;
                        }
                        /// Set animation-timing-function from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_timing_function_from(&mut self, other: &Self) {
                            self.animation_timing_function = other.animation_timing_function.clone();
                        }
                    /// Reset animation-timing-function from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_timing_function(&mut self, other: &Self) {
                        self.copy_animation_timing_function_from(other)
                    }

                    /// Get the computed value for animation-timing-function.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_timing_function(&self) -> longhands::animation_timing_function::computed_value::T {
                        self.animation_timing_function.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_timing_function_count(&self) -> usize {
                        self.animation_timing_function.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_timing_function_at(&self, index: usize)
                        -> longhands::animation_timing_function::computed_value::SingleComputedValue {
                        self.animation_timing_function.0[index].clone()
                    }
                        /// Set animation-iteration-count.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_iteration_count(&mut self, v: longhands::animation_iteration_count::computed_value::T) {
                            self.animation_iteration_count = v;
                        }
                        /// Set animation-iteration-count from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_iteration_count_from(&mut self, other: &Self) {
                            self.animation_iteration_count = other.animation_iteration_count.clone();
                        }
                    /// Reset animation-iteration-count from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_iteration_count(&mut self, other: &Self) {
                        self.copy_animation_iteration_count_from(other)
                    }

                    /// Get the computed value for animation-iteration-count.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_iteration_count(&self) -> longhands::animation_iteration_count::computed_value::T {
                        self.animation_iteration_count.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_iteration_count_count(&self) -> usize {
                        self.animation_iteration_count.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_iteration_count_at(&self, index: usize)
                        -> longhands::animation_iteration_count::computed_value::SingleComputedValue {
                        self.animation_iteration_count.0[index].clone()
                    }
                        /// Set animation-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_direction(&mut self, v: longhands::animation_direction::computed_value::T) {
                            self.animation_direction = v;
                        }
                        /// Set animation-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_direction_from(&mut self, other: &Self) {
                            self.animation_direction = other.animation_direction.clone();
                        }
                    /// Reset animation-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_direction(&mut self, other: &Self) {
                        self.copy_animation_direction_from(other)
                    }

                    /// Get the computed value for animation-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_direction(&self) -> longhands::animation_direction::computed_value::T {
                        self.animation_direction.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_direction_count(&self) -> usize {
                        self.animation_direction.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_direction_at(&self, index: usize)
                        -> longhands::animation_direction::computed_value::SingleComputedValue {
                        self.animation_direction.0[index].clone()
                    }
                        /// Set animation-play-state.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_play_state(&mut self, v: longhands::animation_play_state::computed_value::T) {
                            self.animation_play_state = v;
                        }
                        /// Set animation-play-state from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_play_state_from(&mut self, other: &Self) {
                            self.animation_play_state = other.animation_play_state.clone();
                        }
                    /// Reset animation-play-state from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_play_state(&mut self, other: &Self) {
                        self.copy_animation_play_state_from(other)
                    }

                    /// Get the computed value for animation-play-state.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_play_state(&self) -> longhands::animation_play_state::computed_value::T {
                        self.animation_play_state.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_play_state_count(&self) -> usize {
                        self.animation_play_state.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_play_state_at(&self, index: usize)
                        -> longhands::animation_play_state::computed_value::SingleComputedValue {
                        self.animation_play_state.0[index].clone()
                    }
                        /// Set animation-fill-mode.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_fill_mode(&mut self, v: longhands::animation_fill_mode::computed_value::T) {
                            self.animation_fill_mode = v;
                        }
                        /// Set animation-fill-mode from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_fill_mode_from(&mut self, other: &Self) {
                            self.animation_fill_mode = other.animation_fill_mode.clone();
                        }
                    /// Reset animation-fill-mode from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_fill_mode(&mut self, other: &Self) {
                        self.copy_animation_fill_mode_from(other)
                    }

                    /// Get the computed value for animation-fill-mode.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_fill_mode(&self) -> longhands::animation_fill_mode::computed_value::T {
                        self.animation_fill_mode.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_fill_mode_count(&self) -> usize {
                        self.animation_fill_mode.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_fill_mode_at(&self, index: usize)
                        -> longhands::animation_fill_mode::computed_value::SingleComputedValue {
                        self.animation_fill_mode.0[index].clone()
                    }
                        /// Set animation-composition.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_composition(&mut self, v: longhands::animation_composition::computed_value::T) {
                            self.animation_composition = v;
                        }
                        /// Set animation-composition from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_composition_from(&mut self, other: &Self) {
                            self.animation_composition = other.animation_composition.clone();
                        }
                    /// Reset animation-composition from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_composition(&mut self, other: &Self) {
                        self.copy_animation_composition_from(other)
                    }

                    /// Get the computed value for animation-composition.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_composition(&self) -> longhands::animation_composition::computed_value::T {
                        self.animation_composition.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_composition_count(&self) -> usize {
                        self.animation_composition.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_composition_at(&self, index: usize)
                        -> longhands::animation_composition::computed_value::SingleComputedValue {
                        self.animation_composition.0[index].clone()
                    }
                        /// Set animation-delay.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_delay(&mut self, v: longhands::animation_delay::computed_value::T) {
                            self.animation_delay = v;
                        }
                        /// Set animation-delay from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_delay_from(&mut self, other: &Self) {
                            self.animation_delay = other.animation_delay.clone();
                        }
                    /// Reset animation-delay from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_delay(&mut self, other: &Self) {
                        self.copy_animation_delay_from(other)
                    }

                    /// Get the computed value for animation-delay.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_delay(&self) -> longhands::animation_delay::computed_value::T {
                        self.animation_delay.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_delay_count(&self) -> usize {
                        self.animation_delay.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_delay_at(&self, index: usize)
                        -> longhands::animation_delay::computed_value::SingleComputedValue {
                        self.animation_delay.0[index].clone()
                    }
                        /// Set animation-timeline.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_animation_timeline(&mut self, v: longhands::animation_timeline::computed_value::T) {
                            self.animation_timeline = v;
                        }
                        /// Set animation-timeline from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_animation_timeline_from(&mut self, other: &Self) {
                            self.animation_timeline = other.animation_timeline.clone();
                        }
                    /// Reset animation-timeline from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_animation_timeline(&mut self, other: &Self) {
                        self.copy_animation_timeline_from(other)
                    }

                    /// Get the computed value for animation-timeline.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_animation_timeline(&self) -> longhands::animation_timeline::computed_value::T {
                        self.animation_timeline.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn animation_timeline_count(&self) -> usize {
                        self.animation_timeline.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn animation_timeline_at(&self, index: usize)
                        -> longhands::animation_timeline::computed_value::SingleComputedValue {
                        self.animation_timeline.0[index].clone()
                    }
                        /// Set scroll-timeline-name.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_timeline_name(&mut self, v: longhands::scroll_timeline_name::computed_value::T) {
                            self.scroll_timeline_name = v;
                        }
                        /// Set scroll-timeline-name from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_timeline_name_from(&mut self, other: &Self) {
                            self.scroll_timeline_name = other.scroll_timeline_name.clone();
                        }
                    /// Reset scroll-timeline-name from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_timeline_name(&mut self, other: &Self) {
                        self.copy_scroll_timeline_name_from(other)
                    }

                    /// Get the computed value for scroll-timeline-name.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_timeline_name(&self) -> longhands::scroll_timeline_name::computed_value::T {
                        self.scroll_timeline_name.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn scroll_timeline_name_count(&self) -> usize {
                        self.scroll_timeline_name.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn scroll_timeline_name_at(&self, index: usize)
                        -> longhands::scroll_timeline_name::computed_value::SingleComputedValue {
                        self.scroll_timeline_name.0[index].clone()
                    }
                        /// Set scroll-timeline-axis.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_scroll_timeline_axis(&mut self, v: longhands::scroll_timeline_axis::computed_value::T) {
                            self.scroll_timeline_axis = v;
                        }
                        /// Set scroll-timeline-axis from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_scroll_timeline_axis_from(&mut self, other: &Self) {
                            self.scroll_timeline_axis = other.scroll_timeline_axis.clone();
                        }
                    /// Reset scroll-timeline-axis from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_scroll_timeline_axis(&mut self, other: &Self) {
                        self.copy_scroll_timeline_axis_from(other)
                    }

                    /// Get the computed value for scroll-timeline-axis.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_scroll_timeline_axis(&self) -> longhands::scroll_timeline_axis::computed_value::T {
                        self.scroll_timeline_axis.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn scroll_timeline_axis_count(&self) -> usize {
                        self.scroll_timeline_axis.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn scroll_timeline_axis_at(&self, index: usize)
                        -> longhands::scroll_timeline_axis::computed_value::SingleComputedValue {
                        self.scroll_timeline_axis.0[index].clone()
                    }
                        /// Set view-timeline-name.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_view_timeline_name(&mut self, v: longhands::view_timeline_name::computed_value::T) {
                            self.view_timeline_name = v;
                        }
                        /// Set view-timeline-name from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_view_timeline_name_from(&mut self, other: &Self) {
                            self.view_timeline_name = other.view_timeline_name.clone();
                        }
                    /// Reset view-timeline-name from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_view_timeline_name(&mut self, other: &Self) {
                        self.copy_view_timeline_name_from(other)
                    }

                    /// Get the computed value for view-timeline-name.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_view_timeline_name(&self) -> longhands::view_timeline_name::computed_value::T {
                        self.view_timeline_name.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn view_timeline_name_count(&self) -> usize {
                        self.view_timeline_name.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn view_timeline_name_at(&self, index: usize)
                        -> longhands::view_timeline_name::computed_value::SingleComputedValue {
                        self.view_timeline_name.0[index].clone()
                    }
                        /// Set view-timeline-axis.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_view_timeline_axis(&mut self, v: longhands::view_timeline_axis::computed_value::T) {
                            self.view_timeline_axis = v;
                        }
                        /// Set view-timeline-axis from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_view_timeline_axis_from(&mut self, other: &Self) {
                            self.view_timeline_axis = other.view_timeline_axis.clone();
                        }
                    /// Reset view-timeline-axis from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_view_timeline_axis(&mut self, other: &Self) {
                        self.copy_view_timeline_axis_from(other)
                    }

                    /// Get the computed value for view-timeline-axis.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_view_timeline_axis(&self) -> longhands::view_timeline_axis::computed_value::T {
                        self.view_timeline_axis.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn view_timeline_axis_count(&self) -> usize {
                        self.view_timeline_axis.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn view_timeline_axis_at(&self, index: usize)
                        -> longhands::view_timeline_axis::computed_value::SingleComputedValue {
                        self.view_timeline_axis.0[index].clone()
                    }
                        /// Set view-timeline-inset.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set_view_timeline_inset(&mut self, v: longhands::view_timeline_inset::computed_value::T) {
                            self.view_timeline_inset = v;
                        }
                        /// Set view-timeline-inset from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy_view_timeline_inset_from(&mut self, other: &Self) {
                            self.view_timeline_inset = other.view_timeline_inset.clone();
                        }
                    /// Reset view-timeline-inset from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset_view_timeline_inset(&mut self, other: &Self) {
                        self.copy_view_timeline_inset_from(other)
                    }

                    /// Get the computed value for view-timeline-inset.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone_view_timeline_inset(&self) -> longhands::view_timeline_inset::computed_value::T {
                        self.view_timeline_inset.clone()
                    }
                    /// If this longhand is indexed, get the number of elements.
                    #[allow(non_snake_case)]
                    pub fn view_timeline_inset_count(&self) -> usize {
                        self.view_timeline_inset.0.len()
                    }

                    /// If this longhand is indexed, get the element at given
                    /// index.
                    #[allow(non_snake_case)]
                    pub fn view_timeline_inset_at(&self, index: usize)
                        -> longhands::view_timeline_inset::computed_value::SingleComputedValue {
                        self.view_timeline_inset.0[index].clone()
                    }
        }

        #[derive(Clone, Debug, MallocSizeOf, PartialEq)]
        /// The XUL style struct.
        pub struct XUL {
                    /// The -moz-box-align computed value.
                    pub _moz_box_align: longhands::_moz_box_align::computed_value::T,
                    /// The -moz-box-direction computed value.
                    pub _moz_box_direction: longhands::_moz_box_direction::computed_value::T,
                    /// The -moz-box-flex computed value.
                    pub _moz_box_flex: longhands::_moz_box_flex::computed_value::T,
                    /// The -moz-box-orient computed value.
                    pub _moz_box_orient: longhands::_moz_box_orient::computed_value::T,
                    /// The -moz-box-pack computed value.
                    pub _moz_box_pack: longhands::_moz_box_pack::computed_value::T,
                    /// The -moz-box-ordinal-group computed value.
                    pub _moz_box_ordinal_group: longhands::_moz_box_ordinal_group::computed_value::T,
        }

        impl XUL {
                        /// Set -moz-box-align.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_align(&mut self, v: longhands::_moz_box_align::computed_value::T) {
                            self._moz_box_align = v;
                        }
                        /// Set -moz-box-align from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_align_from(&mut self, other: &Self) {
                            self._moz_box_align = other._moz_box_align.clone();
                        }
                    /// Reset -moz-box-align from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_align(&mut self, other: &Self) {
                        self.copy__moz_box_align_from(other)
                    }

                    /// Get the computed value for -moz-box-align.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_align(&self) -> longhands::_moz_box_align::computed_value::T {
                        self._moz_box_align.clone()
                    }
                        /// Set -moz-box-direction.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_direction(&mut self, v: longhands::_moz_box_direction::computed_value::T) {
                            self._moz_box_direction = v;
                        }
                        /// Set -moz-box-direction from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_direction_from(&mut self, other: &Self) {
                            self._moz_box_direction = other._moz_box_direction.clone();
                        }
                    /// Reset -moz-box-direction from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_direction(&mut self, other: &Self) {
                        self.copy__moz_box_direction_from(other)
                    }

                    /// Get the computed value for -moz-box-direction.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_direction(&self) -> longhands::_moz_box_direction::computed_value::T {
                        self._moz_box_direction.clone()
                    }
                        /// Set -moz-box-flex.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_flex(&mut self, v: longhands::_moz_box_flex::computed_value::T) {
                            self._moz_box_flex = v;
                        }
                        /// Set -moz-box-flex from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_flex_from(&mut self, other: &Self) {
                            self._moz_box_flex = other._moz_box_flex.clone();
                        }
                    /// Reset -moz-box-flex from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_flex(&mut self, other: &Self) {
                        self.copy__moz_box_flex_from(other)
                    }

                    /// Get the computed value for -moz-box-flex.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_flex(&self) -> longhands::_moz_box_flex::computed_value::T {
                        self._moz_box_flex.clone()
                    }
                        /// Set -moz-box-orient.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_orient(&mut self, v: longhands::_moz_box_orient::computed_value::T) {
                            self._moz_box_orient = v;
                        }
                        /// Set -moz-box-orient from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_orient_from(&mut self, other: &Self) {
                            self._moz_box_orient = other._moz_box_orient.clone();
                        }
                    /// Reset -moz-box-orient from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_orient(&mut self, other: &Self) {
                        self.copy__moz_box_orient_from(other)
                    }

                    /// Get the computed value for -moz-box-orient.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_orient(&self) -> longhands::_moz_box_orient::computed_value::T {
                        self._moz_box_orient.clone()
                    }
                        /// Set -moz-box-pack.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_pack(&mut self, v: longhands::_moz_box_pack::computed_value::T) {
                            self._moz_box_pack = v;
                        }
                        /// Set -moz-box-pack from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_pack_from(&mut self, other: &Self) {
                            self._moz_box_pack = other._moz_box_pack.clone();
                        }
                    /// Reset -moz-box-pack from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_pack(&mut self, other: &Self) {
                        self.copy__moz_box_pack_from(other)
                    }

                    /// Get the computed value for -moz-box-pack.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_pack(&self) -> longhands::_moz_box_pack::computed_value::T {
                        self._moz_box_pack.clone()
                    }
                        /// Set -moz-box-ordinal-group.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn set__moz_box_ordinal_group(&mut self, v: longhands::_moz_box_ordinal_group::computed_value::T) {
                            self._moz_box_ordinal_group = v;
                        }
                        /// Set -moz-box-ordinal-group from other struct.
                        #[allow(non_snake_case)]
                        #[inline]
                        pub fn copy__moz_box_ordinal_group_from(&mut self, other: &Self) {
                            self._moz_box_ordinal_group = other._moz_box_ordinal_group.clone();
                        }
                    /// Reset -moz-box-ordinal-group from the initial struct.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn reset__moz_box_ordinal_group(&mut self, other: &Self) {
                        self.copy__moz_box_ordinal_group_from(other)
                    }

                    /// Get the computed value for -moz-box-ordinal-group.
                    #[allow(non_snake_case)]
                    #[inline]
                    pub fn clone__moz_box_ordinal_group(&self) -> longhands::_moz_box_ordinal_group::computed_value::T {
                        self._moz_box_ordinal_group.clone()
                    }
        }

}

    impl style_structs::Background {

    }

    impl style_structs::Border {

    }

    impl style_structs::Box {

    }

    impl style_structs::Column {

            /// Whether this is a multicol style.
            #[cfg(feature = "servo")]
            pub fn is_multicol(&self) -> bool {
                !self.column_width.is_auto() || !self.column_count.is_auto()
            }
    }

    impl style_structs::Counters {

    }

    impl style_structs::Effects {

    }

    impl style_structs::Font {

    }

    impl style_structs::InheritedBox {

    }

    impl style_structs::InheritedSVG {

    }

    impl style_structs::InheritedTable {

    }

    impl style_structs::InheritedText {

    }

    impl style_structs::InheritedUI {

    }

    impl style_structs::List {

    }

    impl style_structs::Margin {

    }

    impl style_structs::Outline {

    }

    impl style_structs::Padding {

    }

    impl style_structs::Page {

    }

    impl style_structs::Position {

    }

    impl style_structs::SVG {

    }

    impl style_structs::Table {

    }

    impl style_structs::Text {

    }

    impl style_structs::UI {
                /// Iterate over the values of transition-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_duration_iter(&self) -> TransitionDurationIter {
                    TransitionDurationIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_duration_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_duration_mod(&self, index: usize)
                    -> longhands::transition_duration::computed_value::SingleComputedValue {
                    self.transition_duration_at(index % self.transition_duration_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_transition_duration(
                    &self,
                ) -> longhands::transition_duration::computed_value::T {
                    longhands::transition_duration::computed_value::List(
                        self.transition_duration_iter().collect()
                    )
                }
                /// Iterate over the values of transition-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_timing_function_iter(&self) -> TransitionTimingFunctionIter {
                    TransitionTimingFunctionIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_timing_function_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_timing_function_mod(&self, index: usize)
                    -> longhands::transition_timing_function::computed_value::SingleComputedValue {
                    self.transition_timing_function_at(index % self.transition_timing_function_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_transition_timing_function(
                    &self,
                ) -> longhands::transition_timing_function::computed_value::T {
                    longhands::transition_timing_function::computed_value::List(
                        self.transition_timing_function_iter().collect()
                    )
                }
                /// Iterate over the values of transition-property.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_property_iter(&self) -> TransitionPropertyIter {
                    TransitionPropertyIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_property_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-property.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_property_mod(&self, index: usize)
                    -> longhands::transition_property::computed_value::SingleComputedValue {
                    self.transition_property_at(index % self.transition_property_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_transition_property(
                    &self,
                ) -> longhands::transition_property::computed_value::T {
                    longhands::transition_property::computed_value::List(
                        self.transition_property_iter().collect()
                    )
                }
                /// Iterate over the values of transition-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_delay_iter(&self) -> TransitionDelayIter {
                    TransitionDelayIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_delay_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_delay_mod(&self, index: usize)
                    -> longhands::transition_delay::computed_value::SingleComputedValue {
                    self.transition_delay_at(index % self.transition_delay_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_transition_delay(
                    &self,
                ) -> longhands::transition_delay::computed_value::T {
                    longhands::transition_delay::computed_value::List(
                        self.transition_delay_iter().collect()
                    )
                }
                /// Iterate over the values of transition-behavior.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_behavior_iter(&self) -> TransitionBehaviorIter {
                    TransitionBehaviorIter {
                        style_struct: self,
                        current: 0,
                        max: self.transition_behavior_count(),
                    }
                }

                /// Get a value mod `index` for the property transition-behavior.
                #[allow(non_snake_case)]
                #[inline]
                pub fn transition_behavior_mod(&self, index: usize)
                    -> longhands::transition_behavior::computed_value::SingleComputedValue {
                    self.transition_behavior_at(index % self.transition_behavior_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_transition_behavior(
                    &self,
                ) -> longhands::transition_behavior::computed_value::T {
                    longhands::transition_behavior::computed_value::List(
                        self.transition_behavior_iter().collect()
                    )
                }
                /// Iterate over the values of animation-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_name_iter(&self) -> AnimationNameIter {
                    AnimationNameIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_name_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_name_mod(&self, index: usize)
                    -> longhands::animation_name::computed_value::SingleComputedValue {
                    self.animation_name_at(index % self.animation_name_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_name(
                    &self,
                ) -> longhands::animation_name::computed_value::T {
                    longhands::animation_name::computed_value::List(
                        self.animation_name_iter().collect()
                    )
                }
                /// Iterate over the values of animation-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_duration_iter(&self) -> AnimationDurationIter {
                    AnimationDurationIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_duration_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-duration.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_duration_mod(&self, index: usize)
                    -> longhands::animation_duration::computed_value::SingleComputedValue {
                    self.animation_duration_at(index % self.animation_duration_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_duration(
                    &self,
                ) -> longhands::animation_duration::computed_value::T {
                    longhands::animation_duration::computed_value::List(
                        self.animation_duration_iter().collect()
                    )
                }
                /// Iterate over the values of animation-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timing_function_iter(&self) -> AnimationTimingFunctionIter {
                    AnimationTimingFunctionIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_timing_function_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-timing-function.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timing_function_mod(&self, index: usize)
                    -> longhands::animation_timing_function::computed_value::SingleComputedValue {
                    self.animation_timing_function_at(index % self.animation_timing_function_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_timing_function(
                    &self,
                ) -> longhands::animation_timing_function::computed_value::T {
                    longhands::animation_timing_function::computed_value::List(
                        self.animation_timing_function_iter().collect()
                    )
                }
                /// Iterate over the values of animation-iteration-count.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_iteration_count_iter(&self) -> AnimationIterationCountIter {
                    AnimationIterationCountIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_iteration_count_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-iteration-count.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_iteration_count_mod(&self, index: usize)
                    -> longhands::animation_iteration_count::computed_value::SingleComputedValue {
                    self.animation_iteration_count_at(index % self.animation_iteration_count_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_iteration_count(
                    &self,
                ) -> longhands::animation_iteration_count::computed_value::T {
                    longhands::animation_iteration_count::computed_value::List(
                        self.animation_iteration_count_iter().collect()
                    )
                }
                /// Iterate over the values of animation-direction.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_direction_iter(&self) -> AnimationDirectionIter {
                    AnimationDirectionIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_direction_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-direction.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_direction_mod(&self, index: usize)
                    -> longhands::animation_direction::computed_value::SingleComputedValue {
                    self.animation_direction_at(index % self.animation_direction_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_direction(
                    &self,
                ) -> longhands::animation_direction::computed_value::T {
                    longhands::animation_direction::computed_value::List(
                        self.animation_direction_iter().collect()
                    )
                }
                /// Iterate over the values of animation-play-state.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_play_state_iter(&self) -> AnimationPlayStateIter {
                    AnimationPlayStateIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_play_state_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-play-state.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_play_state_mod(&self, index: usize)
                    -> longhands::animation_play_state::computed_value::SingleComputedValue {
                    self.animation_play_state_at(index % self.animation_play_state_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_play_state(
                    &self,
                ) -> longhands::animation_play_state::computed_value::T {
                    longhands::animation_play_state::computed_value::List(
                        self.animation_play_state_iter().collect()
                    )
                }
                /// Iterate over the values of animation-fill-mode.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_fill_mode_iter(&self) -> AnimationFillModeIter {
                    AnimationFillModeIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_fill_mode_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-fill-mode.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_fill_mode_mod(&self, index: usize)
                    -> longhands::animation_fill_mode::computed_value::SingleComputedValue {
                    self.animation_fill_mode_at(index % self.animation_fill_mode_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_fill_mode(
                    &self,
                ) -> longhands::animation_fill_mode::computed_value::T {
                    longhands::animation_fill_mode::computed_value::List(
                        self.animation_fill_mode_iter().collect()
                    )
                }
                /// Iterate over the values of animation-composition.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_composition_iter(&self) -> AnimationCompositionIter {
                    AnimationCompositionIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_composition_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-composition.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_composition_mod(&self, index: usize)
                    -> longhands::animation_composition::computed_value::SingleComputedValue {
                    self.animation_composition_at(index % self.animation_composition_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_composition(
                    &self,
                ) -> longhands::animation_composition::computed_value::T {
                    longhands::animation_composition::computed_value::List(
                        self.animation_composition_iter().collect()
                    )
                }
                /// Iterate over the values of animation-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_delay_iter(&self) -> AnimationDelayIter {
                    AnimationDelayIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_delay_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-delay.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_delay_mod(&self, index: usize)
                    -> longhands::animation_delay::computed_value::SingleComputedValue {
                    self.animation_delay_at(index % self.animation_delay_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_delay(
                    &self,
                ) -> longhands::animation_delay::computed_value::T {
                    longhands::animation_delay::computed_value::List(
                        self.animation_delay_iter().collect()
                    )
                }
                /// Iterate over the values of animation-timeline.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timeline_iter(&self) -> AnimationTimelineIter {
                    AnimationTimelineIter {
                        style_struct: self,
                        current: 0,
                        max: self.animation_timeline_count(),
                    }
                }

                /// Get a value mod `index` for the property animation-timeline.
                #[allow(non_snake_case)]
                #[inline]
                pub fn animation_timeline_mod(&self, index: usize)
                    -> longhands::animation_timeline::computed_value::SingleComputedValue {
                    self.animation_timeline_at(index % self.animation_timeline_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_animation_timeline(
                    &self,
                ) -> longhands::animation_timeline::computed_value::T {
                    longhands::animation_timeline::computed_value::List(
                        self.animation_timeline_iter().collect()
                    )
                }
                /// Iterate over the values of scroll-timeline-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn scroll_timeline_name_iter(&self) -> ScrollTimelineNameIter {
                    ScrollTimelineNameIter {
                        style_struct: self,
                        current: 0,
                        max: self.scroll_timeline_name_count(),
                    }
                }

                /// Get a value mod `index` for the property scroll-timeline-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn scroll_timeline_name_mod(&self, index: usize)
                    -> longhands::scroll_timeline_name::computed_value::SingleComputedValue {
                    self.scroll_timeline_name_at(index % self.scroll_timeline_name_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_scroll_timeline_name(
                    &self,
                ) -> longhands::scroll_timeline_name::computed_value::T {
                    longhands::scroll_timeline_name::computed_value::List(
                        self.scroll_timeline_name_iter().collect()
                    )
                }
                /// Iterate over the values of scroll-timeline-axis.
                #[allow(non_snake_case)]
                #[inline]
                pub fn scroll_timeline_axis_iter(&self) -> ScrollTimelineAxisIter {
                    ScrollTimelineAxisIter {
                        style_struct: self,
                        current: 0,
                        max: self.scroll_timeline_axis_count(),
                    }
                }

                /// Get a value mod `index` for the property scroll-timeline-axis.
                #[allow(non_snake_case)]
                #[inline]
                pub fn scroll_timeline_axis_mod(&self, index: usize)
                    -> longhands::scroll_timeline_axis::computed_value::SingleComputedValue {
                    self.scroll_timeline_axis_at(index % self.scroll_timeline_axis_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_scroll_timeline_axis(
                    &self,
                ) -> longhands::scroll_timeline_axis::computed_value::T {
                    longhands::scroll_timeline_axis::computed_value::List(
                        self.scroll_timeline_axis_iter().collect()
                    )
                }
                /// Iterate over the values of view-timeline-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn view_timeline_name_iter(&self) -> ViewTimelineNameIter {
                    ViewTimelineNameIter {
                        style_struct: self,
                        current: 0,
                        max: self.view_timeline_name_count(),
                    }
                }

                /// Get a value mod `index` for the property view-timeline-name.
                #[allow(non_snake_case)]
                #[inline]
                pub fn view_timeline_name_mod(&self, index: usize)
                    -> longhands::view_timeline_name::computed_value::SingleComputedValue {
                    self.view_timeline_name_at(index % self.view_timeline_name_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_view_timeline_name(
                    &self,
                ) -> longhands::view_timeline_name::computed_value::T {
                    longhands::view_timeline_name::computed_value::List(
                        self.view_timeline_name_iter().collect()
                    )
                }
                /// Iterate over the values of view-timeline-axis.
                #[allow(non_snake_case)]
                #[inline]
                pub fn view_timeline_axis_iter(&self) -> ViewTimelineAxisIter {
                    ViewTimelineAxisIter {
                        style_struct: self,
                        current: 0,
                        max: self.view_timeline_axis_count(),
                    }
                }

                /// Get a value mod `index` for the property view-timeline-axis.
                #[allow(non_snake_case)]
                #[inline]
                pub fn view_timeline_axis_mod(&self, index: usize)
                    -> longhands::view_timeline_axis::computed_value::SingleComputedValue {
                    self.view_timeline_axis_at(index % self.view_timeline_axis_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_view_timeline_axis(
                    &self,
                ) -> longhands::view_timeline_axis::computed_value::T {
                    longhands::view_timeline_axis::computed_value::List(
                        self.view_timeline_axis_iter().collect()
                    )
                }
                /// Iterate over the values of view-timeline-inset.
                #[allow(non_snake_case)]
                #[inline]
                pub fn view_timeline_inset_iter(&self) -> ViewTimelineInsetIter {
                    ViewTimelineInsetIter {
                        style_struct: self,
                        current: 0,
                        max: self.view_timeline_inset_count(),
                    }
                }

                /// Get a value mod `index` for the property view-timeline-inset.
                #[allow(non_snake_case)]
                #[inline]
                pub fn view_timeline_inset_mod(&self, index: usize)
                    -> longhands::view_timeline_inset::computed_value::SingleComputedValue {
                    self.view_timeline_inset_at(index % self.view_timeline_inset_count())
                }

                /// Clone the computed value for the property.
                #[allow(non_snake_case)]
                #[inline]
                #[cfg(feature = "gecko")]
                pub fn clone_view_timeline_inset(
                    &self,
                ) -> longhands::view_timeline_inset::computed_value::T {
                    longhands::view_timeline_inset::computed_value::List(
                        self.view_timeline_inset_iter().collect()
                    )
                }

            /// Returns whether there is any animation specified with
            /// animation-name other than `none`.
            pub fn specifies_animations(&self) -> bool {
                self.animation_name_iter().any(|name| !name.is_none())
            }

            /// Returns whether there are any transitions specified.
            #[cfg(feature = "servo")]
            pub fn specifies_transitions(&self) -> bool {
                (0..self.transition_property_count()).any(|index| {
                    let combined_duration =
                        self.transition_duration_mod(index).seconds().max(0.) +
                        self.transition_delay_mod(index).seconds();
                    combined_duration > 0.
                })
            }

            /// Returns whether there is any named progress timeline specified with
            /// scroll-timeline-name other than `none`.
            pub fn specifies_scroll_timelines(&self) -> bool {
                self.scroll_timeline_name_iter().any(|name| !name.is_none())
            }

            /// Returns whether there is any named progress timeline specified with
            /// view-timeline-name other than `none`.
            pub fn specifies_view_timelines(&self) -> bool {
                self.view_timeline_name_iter().any(|name| !name.is_none())
            }

            /// Returns true if animation properties are equal between styles, but without
            /// considering keyframe data and animation-timeline.
            #[cfg(feature = "servo")]
            pub fn animations_equals(&self, other: &Self) -> bool {
                self.animation_name_iter().eq(other.animation_name_iter()) &&
                self.animation_delay_iter().eq(other.animation_delay_iter()) &&
                self.animation_direction_iter().eq(other.animation_direction_iter()) &&
                self.animation_duration_iter().eq(other.animation_duration_iter()) &&
                self.animation_fill_mode_iter().eq(other.animation_fill_mode_iter()) &&
                self.animation_iteration_count_iter().eq(other.animation_iteration_count_iter()) &&
                self.animation_play_state_iter().eq(other.animation_play_state_iter()) &&
                self.animation_timing_function_iter().eq(other.animation_timing_function_iter())
            }

    }

            /// An iterator over the values of the transition-duration properties.
            pub struct TransitionDurationIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionDurationIter<'a> {
                type Item = longhands::transition_duration::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_duration_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-timing-function properties.
            pub struct TransitionTimingFunctionIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionTimingFunctionIter<'a> {
                type Item = longhands::transition_timing_function::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_timing_function_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-property properties.
            pub struct TransitionPropertyIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionPropertyIter<'a> {
                type Item = longhands::transition_property::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_property_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-delay properties.
            pub struct TransitionDelayIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionDelayIter<'a> {
                type Item = longhands::transition_delay::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_delay_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the transition-behavior properties.
            pub struct TransitionBehaviorIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for TransitionBehaviorIter<'a> {
                type Item = longhands::transition_behavior::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.transition_behavior_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-name properties.
            pub struct AnimationNameIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationNameIter<'a> {
                type Item = longhands::animation_name::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_name_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-duration properties.
            pub struct AnimationDurationIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDurationIter<'a> {
                type Item = longhands::animation_duration::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_duration_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-timing-function properties.
            pub struct AnimationTimingFunctionIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationTimingFunctionIter<'a> {
                type Item = longhands::animation_timing_function::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_timing_function_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-iteration-count properties.
            pub struct AnimationIterationCountIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationIterationCountIter<'a> {
                type Item = longhands::animation_iteration_count::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_iteration_count_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-direction properties.
            pub struct AnimationDirectionIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDirectionIter<'a> {
                type Item = longhands::animation_direction::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_direction_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-play-state properties.
            pub struct AnimationPlayStateIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationPlayStateIter<'a> {
                type Item = longhands::animation_play_state::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_play_state_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-fill-mode properties.
            pub struct AnimationFillModeIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationFillModeIter<'a> {
                type Item = longhands::animation_fill_mode::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_fill_mode_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-composition properties.
            pub struct AnimationCompositionIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationCompositionIter<'a> {
                type Item = longhands::animation_composition::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_composition_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-delay properties.
            pub struct AnimationDelayIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationDelayIter<'a> {
                type Item = longhands::animation_delay::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_delay_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the animation-timeline properties.
            pub struct AnimationTimelineIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for AnimationTimelineIter<'a> {
                type Item = longhands::animation_timeline::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.animation_timeline_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the scroll-timeline-name properties.
            pub struct ScrollTimelineNameIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for ScrollTimelineNameIter<'a> {
                type Item = longhands::scroll_timeline_name::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.scroll_timeline_name_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the scroll-timeline-axis properties.
            pub struct ScrollTimelineAxisIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for ScrollTimelineAxisIter<'a> {
                type Item = longhands::scroll_timeline_axis::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.scroll_timeline_axis_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the view-timeline-name properties.
            pub struct ViewTimelineNameIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for ViewTimelineNameIter<'a> {
                type Item = longhands::view_timeline_name::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.view_timeline_name_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the view-timeline-axis properties.
            pub struct ViewTimelineAxisIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for ViewTimelineAxisIter<'a> {
                type Item = longhands::view_timeline_axis::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.view_timeline_axis_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
            /// An iterator over the values of the view-timeline-inset properties.
            pub struct ViewTimelineInsetIter<'a> {
                style_struct: &'a style_structs::UI,
                current: usize,
                max: usize,
            }

            impl<'a> Iterator for ViewTimelineInsetIter<'a> {
                type Item = longhands::view_timeline_inset::computed_value::SingleComputedValue;

                fn next(&mut self) -> Option<Self::Item> {
                    self.current += 1;
                    if self.current <= self.max {
                        Some(self.style_struct.view_timeline_inset_at(self.current - 1))
                    } else {
                        None
                    }
                }
            }
    impl style_structs::XUL {

    }



#[cfg(feature = "gecko")]
pub use super::gecko::{ComputedValues, ComputedValuesInner};

#[cfg(feature = "servo")]
#[cfg_attr(feature = "servo", derive(Clone, Debug))]
/// Actual data of ComputedValues, to match up with Gecko
pub struct ComputedValuesInner {
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inherited_box: Arc<style_structs::InheritedBox>,
        inherited_svg: Arc<style_structs::InheritedSVG>,
        inherited_table: Arc<style_structs::InheritedTable>,
        inherited_text: Arc<style_structs::InheritedText>,
        inherited_ui: Arc<style_structs::InheritedUI>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        page: Arc<style_structs::Page>,
        position: Arc<style_structs::Position>,
        svg: Arc<style_structs::SVG>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        xul: Arc<style_structs::XUL>,
    custom_properties: crate::custom_properties::ComputedCustomProperties,

    /// The writing mode of this computed values struct.
    pub writing_mode: WritingMode,

    /// The effective zoom value.
    pub effective_zoom: Zoom,

    /// A set of flags we use to store misc information regarding this style.
    pub flags: ComputedValueFlags,

    /// The rule node representing the ordered list of rules matched for this
    /// node.  Can be None for default values and text nodes.  This is
    /// essentially an optimization to avoid referencing the root rule node.
    pub rules: Option<StrongRuleNode>,

    /// The element's computed values if visited, only computed if there's a
    /// relevant link for this element. A element's "relevant link" is the
    /// element being matched if it is a link or the nearest ancestor link.
    visited_style: Option<Arc<ComputedValues>>,
}

/// The struct that Servo uses to represent computed values.
///
/// This struct contains an immutable atomically-reference-counted pointer to
/// every kind of style struct.
///
/// When needed, the structs may be copied in order to get mutated.
#[cfg(feature = "servo")]
#[cfg_attr(feature = "servo", derive(Clone, Debug))]
pub struct ComputedValues {
    /// The actual computed values
    ///
    /// In Gecko the outer ComputedValues is actually a ComputedStyle, whereas
    /// ComputedValuesInner is the core set of computed values.
    ///
    /// We maintain this distinction in servo to reduce the amount of special
    /// casing.
    inner: ComputedValuesInner,

    /// The pseudo-element that we're using.
    pseudo: Option<PseudoElement>,
}

impl ComputedValues {
    /// Returns the pseudo-element that this style represents.
    #[cfg(feature = "servo")]
    pub fn pseudo(&self) -> Option<&PseudoElement> {
        self.pseudo.as_ref()
    }

    /// Returns true if this is the style for a pseudo-element.
    #[cfg(feature = "servo")]
    pub fn is_pseudo_style(&self) -> bool {
        self.pseudo().is_some()
    }

    /// Returns whether this style's display value is equal to contents.
    pub fn is_display_contents(&self) -> bool {
        self.clone_display().is_contents()
    }

    /// Gets a reference to the rule node. Panic if no rule node exists.
    pub fn rules(&self) -> &StrongRuleNode {
        self.rules.as_ref().unwrap()
    }

    /// Returns the visited rules, if applicable.
    pub fn visited_rules(&self) -> Option<&StrongRuleNode> {
        self.visited_style().and_then(|s| s.rules.as_ref())
    }

    /// Gets a reference to the custom properties map (if one exists).
    pub fn custom_properties(&self) -> &crate::custom_properties::ComputedCustomProperties {
        &self.custom_properties
    }

    /// Returns whether we have the same custom properties as another style.
    pub fn custom_properties_equal(&self, other: &Self) -> bool {
      self.custom_properties() == other.custom_properties()
    }

    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_align_content(
        &self,
    ) -> longhands::align_content::computed_value::T {
        self.get_position().clone_align_content()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_align_items(
        &self,
    ) -> longhands::align_items::computed_value::T {
        self.get_position().clone_align_items()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_align_self(
        &self,
    ) -> longhands::align_self::computed_value::T {
        self.get_position().clone_align_self()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_aspect_ratio(
        &self,
    ) -> longhands::aspect_ratio::computed_value::T {
        self.get_position().clone_aspect_ratio()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_backface_visibility(
        &self,
    ) -> longhands::backface_visibility::computed_value::T {
        self.get_box().clone_backface_visibility()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_baseline_source(
        &self,
    ) -> longhands::baseline_source::computed_value::T {
        self.get_box().clone_baseline_source()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_collapse(
        &self,
    ) -> longhands::border_collapse::computed_value::T {
        self.get_inherited_table().clone_border_collapse()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_image_repeat(
        &self,
    ) -> longhands::border_image_repeat::computed_value::T {
        self.get_border().clone_border_image_repeat()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_box_decoration_break(
        &self,
    ) -> longhands::box_decoration_break::computed_value::T {
        self.get_border().clone_box_decoration_break()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_box_sizing(
        &self,
    ) -> longhands::box_sizing::computed_value::T {
        self.get_position().clone_box_sizing()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_break_inside(
        &self,
    ) -> longhands::break_inside::computed_value::T {
        self.get_box().clone_break_inside()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_caption_side(
        &self,
    ) -> longhands::caption_side::computed_value::T {
        self.get_inherited_table().clone_caption_side()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_clear(
        &self,
    ) -> longhands::clear::computed_value::T {
        self.get_box().clone_clear()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_color_interpolation(
        &self,
    ) -> longhands::color_interpolation::computed_value::T {
        self.get_inherited_svg().clone_color_interpolation()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_color_interpolation_filters(
        &self,
    ) -> longhands::color_interpolation_filters::computed_value::T {
        self.get_inherited_svg().clone_color_interpolation_filters()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_count(
        &self,
    ) -> longhands::column_count::computed_value::T {
        self.get_column().clone_column_count()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_fill(
        &self,
    ) -> longhands::column_fill::computed_value::T {
        self.get_column().clone_column_fill()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_span(
        &self,
    ) -> longhands::column_span::computed_value::T {
        self.get_column().clone_column_span()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_contain(
        &self,
    ) -> longhands::contain::computed_value::T {
        self.get_box().clone_contain()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_container_type(
        &self,
    ) -> longhands::container_type::computed_value::T {
        self.get_box().clone_container_type()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_content_visibility(
        &self,
    ) -> longhands::content_visibility::computed_value::T {
        self.get_box().clone_content_visibility()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_direction(
        &self,
    ) -> longhands::direction::computed_value::T {
        self.get_inherited_box().clone_direction()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_display(
        &self,
    ) -> longhands::display::computed_value::T {
        self.get_box().clone_display()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_dominant_baseline(
        &self,
    ) -> longhands::dominant_baseline::computed_value::T {
        self.get_inherited_svg().clone_dominant_baseline()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_empty_cells(
        &self,
    ) -> longhands::empty_cells::computed_value::T {
        self.get_inherited_table().clone_empty_cells()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_flex_direction(
        &self,
    ) -> longhands::flex_direction::computed_value::T {
        self.get_position().clone_flex_direction()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_flex_wrap(
        &self,
    ) -> longhands::flex_wrap::computed_value::T {
        self.get_position().clone_flex_wrap()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_float(
        &self,
    ) -> longhands::float::computed_value::T {
        self.get_box().clone_float()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_kerning(
        &self,
    ) -> longhands::font_kerning::computed_value::T {
        self.get_font().clone_font_kerning()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_language_override(
        &self,
    ) -> longhands::font_language_override::computed_value::T {
        self.get_font().clone_font_language_override()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_optical_sizing(
        &self,
    ) -> longhands::font_optical_sizing::computed_value::T {
        self.get_font().clone_font_optical_sizing()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_size_adjust(
        &self,
    ) -> longhands::font_size_adjust::computed_value::T {
        self.get_font().clone_font_size_adjust()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_stretch(
        &self,
    ) -> longhands::font_stretch::computed_value::T {
        self.get_font().clone_font_stretch()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_style(
        &self,
    ) -> longhands::font_style::computed_value::T {
        self.get_font().clone_font_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variant_caps(
        &self,
    ) -> longhands::font_variant_caps::computed_value::T {
        self.get_font().clone_font_variant_caps()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variant_east_asian(
        &self,
    ) -> longhands::font_variant_east_asian::computed_value::T {
        self.get_font().clone_font_variant_east_asian()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variant_emoji(
        &self,
    ) -> longhands::font_variant_emoji::computed_value::T {
        self.get_font().clone_font_variant_emoji()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variant_ligatures(
        &self,
    ) -> longhands::font_variant_ligatures::computed_value::T {
        self.get_font().clone_font_variant_ligatures()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variant_numeric(
        &self,
    ) -> longhands::font_variant_numeric::computed_value::T {
        self.get_font().clone_font_variant_numeric()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variant_position(
        &self,
    ) -> longhands::font_variant_position::computed_value::T {
        self.get_font().clone_font_variant_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_weight(
        &self,
    ) -> longhands::font_weight::computed_value::T {
        self.get_font().clone_font_weight()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_forced_color_adjust(
        &self,
    ) -> longhands::forced_color_adjust::computed_value::T {
        self.get_inherited_text().clone_forced_color_adjust()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_auto_flow(
        &self,
    ) -> longhands::grid_auto_flow::computed_value::T {
        self.get_position().clone_grid_auto_flow()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_hyphens(
        &self,
    ) -> longhands::hyphens::computed_value::T {
        self.get_inherited_text().clone_hyphens()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_image_orientation(
        &self,
    ) -> longhands::image_orientation::computed_value::T {
        self.get_inherited_box().clone_image_orientation()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_image_rendering(
        &self,
    ) -> longhands::image_rendering::computed_value::T {
        self.get_inherited_box().clone_image_rendering()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_ime_mode(
        &self,
    ) -> longhands::ime_mode::computed_value::T {
        self.get_ui().clone_ime_mode()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_initial_letter(
        &self,
    ) -> longhands::initial_letter::computed_value::T {
        self.get_text().clone_initial_letter()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_inset_area(
        &self,
    ) -> longhands::inset_area::computed_value::T {
        self.get_position().clone_inset_area()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_isolation(
        &self,
    ) -> longhands::isolation::computed_value::T {
        self.get_box().clone_isolation()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_justify_content(
        &self,
    ) -> longhands::justify_content::computed_value::T {
        self.get_position().clone_justify_content()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_justify_items(
        &self,
    ) -> longhands::justify_items::computed_value::T {
        self.get_position().clone_justify_items()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_justify_self(
        &self,
    ) -> longhands::justify_self::computed_value::T {
        self.get_position().clone_justify_self()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_line_break(
        &self,
    ) -> longhands::line_break::computed_value::T {
        self.get_inherited_text().clone_line_break()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_list_style_position(
        &self,
    ) -> longhands::list_style_position::computed_value::T {
        self.get_list().clone_list_style_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_type(
        &self,
    ) -> longhands::mask_type::computed_value::T {
        self.get_svg().clone_mask_type()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_masonry_auto_flow(
        &self,
    ) -> longhands::masonry_auto_flow::computed_value::T {
        self.get_position().clone_masonry_auto_flow()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_math_depth(
        &self,
    ) -> longhands::math_depth::computed_value::T {
        self.get_font().clone_math_depth()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_math_style(
        &self,
    ) -> longhands::math_style::computed_value::T {
        self.get_font().clone_math_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mix_blend_mode(
        &self,
    ) -> longhands::mix_blend_mode::computed_value::T {
        self.get_effects().clone_mix_blend_mode()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_box_align(
        &self,
    ) -> longhands::_moz_box_align::computed_value::T {
        self.get_xul().clone__moz_box_align()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_box_collapse(
        &self,
    ) -> longhands::_moz_box_collapse::computed_value::T {
        self.get_inherited_box().clone__moz_box_collapse()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_box_direction(
        &self,
    ) -> longhands::_moz_box_direction::computed_value::T {
        self.get_xul().clone__moz_box_direction()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_box_orient(
        &self,
    ) -> longhands::_moz_box_orient::computed_value::T {
        self.get_xul().clone__moz_box_orient()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_box_pack(
        &self,
    ) -> longhands::_moz_box_pack::computed_value::T {
        self.get_xul().clone__moz_box_pack()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_control_character_visibility(
        &self,
    ) -> longhands::_moz_control_character_visibility::computed_value::T {
        self.get_inherited_text().clone__moz_control_character_visibility()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_float_edge(
        &self,
    ) -> longhands::_moz_float_edge::computed_value::T {
        self.get_border().clone__moz_float_edge()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_inert(
        &self,
    ) -> longhands::_moz_inert::computed_value::T {
        self.get_inherited_ui().clone__moz_inert()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_math_variant(
        &self,
    ) -> longhands::_moz_math_variant::computed_value::T {
        self.get_font().clone__moz_math_variant()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_min_font_size_ratio(
        &self,
    ) -> longhands::_moz_min_font_size_ratio::computed_value::T {
        self.get_font().clone__moz_min_font_size_ratio()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_orient(
        &self,
    ) -> longhands::_moz_orient::computed_value::T {
        self.get_box().clone__moz_orient()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_osx_font_smoothing(
        &self,
    ) -> longhands::_moz_osx_font_smoothing::computed_value::T {
        self.get_font().clone__moz_osx_font_smoothing()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_text_size_adjust(
        &self,
    ) -> longhands::_moz_text_size_adjust::computed_value::T {
        self.get_inherited_text().clone__moz_text_size_adjust()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_theme(
        &self,
    ) -> longhands::_moz_theme::computed_value::T {
        self.get_inherited_ui().clone__moz_theme()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_top_layer(
        &self,
    ) -> longhands::_moz_top_layer::computed_value::T {
        self.get_box().clone__moz_top_layer()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_user_focus(
        &self,
    ) -> longhands::_moz_user_focus::computed_value::T {
        self.get_inherited_ui().clone__moz_user_focus()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_user_input(
        &self,
    ) -> longhands::_moz_user_input::computed_value::T {
        self.get_inherited_ui().clone__moz_user_input()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_user_modify(
        &self,
    ) -> longhands::_moz_user_modify::computed_value::T {
        self.get_inherited_ui().clone__moz_user_modify()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_window_dragging(
        &self,
    ) -> longhands::_moz_window_dragging::computed_value::T {
        self.get_ui().clone__moz_window_dragging()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_window_shadow(
        &self,
    ) -> longhands::_moz_window_shadow::computed_value::T {
        self.get_ui().clone__moz_window_shadow()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_object_fit(
        &self,
    ) -> longhands::object_fit::computed_value::T {
        self.get_position().clone_object_fit()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_offset_rotate(
        &self,
    ) -> longhands::offset_rotate::computed_value::T {
        self.get_box().clone_offset_rotate()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_outline_style(
        &self,
    ) -> longhands::outline_style::computed_value::T {
        self.get_outline().clone_outline_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overflow_anchor(
        &self,
    ) -> longhands::overflow_anchor::computed_value::T {
        self.get_box().clone_overflow_anchor()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overflow_wrap(
        &self,
    ) -> longhands::overflow_wrap::computed_value::T {
        self.get_inherited_text().clone_overflow_wrap()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_page_orientation(
        &self,
    ) -> longhands::page_orientation::computed_value::T {
        self.get_page().clone_page_orientation()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_paint_order(
        &self,
    ) -> longhands::paint_order::computed_value::T {
        self.get_inherited_svg().clone_paint_order()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_pointer_events(
        &self,
    ) -> longhands::pointer_events::computed_value::T {
        self.get_inherited_ui().clone_pointer_events()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_position(
        &self,
    ) -> longhands::position::computed_value::T {
        self.get_box().clone_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_position_try_order(
        &self,
    ) -> longhands::position_try_order::computed_value::T {
        self.get_position().clone_position_try_order()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_position_visibility(
        &self,
    ) -> longhands::position_visibility::computed_value::T {
        self.get_position().clone_position_visibility()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_print_color_adjust(
        &self,
    ) -> longhands::print_color_adjust::computed_value::T {
        self.get_inherited_box().clone_print_color_adjust()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_resize(
        &self,
    ) -> longhands::resize::computed_value::T {
        self.get_box().clone_resize()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_ruby_align(
        &self,
    ) -> longhands::ruby_align::computed_value::T {
        self.get_inherited_text().clone_ruby_align()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_ruby_position(
        &self,
    ) -> longhands::ruby_position::computed_value::T {
        self.get_inherited_text().clone_ruby_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_behavior(
        &self,
    ) -> longhands::scroll_behavior::computed_value::T {
        self.get_box().clone_scroll_behavior()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_snap_align(
        &self,
    ) -> longhands::scroll_snap_align::computed_value::T {
        self.get_box().clone_scroll_snap_align()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_snap_stop(
        &self,
    ) -> longhands::scroll_snap_stop::computed_value::T {
        self.get_box().clone_scroll_snap_stop()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_snap_type(
        &self,
    ) -> longhands::scroll_snap_type::computed_value::T {
        self.get_box().clone_scroll_snap_type()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scrollbar_gutter(
        &self,
    ) -> longhands::scrollbar_gutter::computed_value::T {
        self.get_box().clone_scrollbar_gutter()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scrollbar_width(
        &self,
    ) -> longhands::scrollbar_width::computed_value::T {
        self.get_ui().clone_scrollbar_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_shape_rendering(
        &self,
    ) -> longhands::shape_rendering::computed_value::T {
        self.get_inherited_svg().clone_shape_rendering()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke_linecap(
        &self,
    ) -> longhands::stroke_linecap::computed_value::T {
        self.get_inherited_svg().clone_stroke_linecap()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke_linejoin(
        &self,
    ) -> longhands::stroke_linejoin::computed_value::T {
        self.get_inherited_svg().clone_stroke_linejoin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_table_layout(
        &self,
    ) -> longhands::table_layout::computed_value::T {
        self.get_table().clone_table_layout()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_align(
        &self,
    ) -> longhands::text_align::computed_value::T {
        self.get_inherited_text().clone_text_align()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_align_last(
        &self,
    ) -> longhands::text_align_last::computed_value::T {
        self.get_inherited_text().clone_text_align_last()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_anchor(
        &self,
    ) -> longhands::text_anchor::computed_value::T {
        self.get_inherited_svg().clone_text_anchor()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_combine_upright(
        &self,
    ) -> longhands::text_combine_upright::computed_value::T {
        self.get_inherited_text().clone_text_combine_upright()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_decoration_line(
        &self,
    ) -> longhands::text_decoration_line::computed_value::T {
        self.get_text().clone_text_decoration_line()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_decoration_skip_ink(
        &self,
    ) -> longhands::text_decoration_skip_ink::computed_value::T {
        self.get_inherited_text().clone_text_decoration_skip_ink()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_decoration_style(
        &self,
    ) -> longhands::text_decoration_style::computed_value::T {
        self.get_text().clone_text_decoration_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_emphasis_position(
        &self,
    ) -> longhands::text_emphasis_position::computed_value::T {
        self.get_inherited_text().clone_text_emphasis_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_justify(
        &self,
    ) -> longhands::text_justify::computed_value::T {
        self.get_inherited_text().clone_text_justify()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_orientation(
        &self,
    ) -> longhands::text_orientation::computed_value::T {
        self.get_inherited_box().clone_text_orientation()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_rendering(
        &self,
    ) -> longhands::text_rendering::computed_value::T {
        self.get_inherited_text().clone_text_rendering()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_transform(
        &self,
    ) -> longhands::text_transform::computed_value::T {
        self.get_inherited_text().clone_text_transform()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_underline_position(
        &self,
    ) -> longhands::text_underline_position::computed_value::T {
        self.get_inherited_text().clone_text_underline_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_wrap_mode(
        &self,
    ) -> longhands::text_wrap_mode::computed_value::T {
        self.get_inherited_text().clone_text_wrap_mode()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_wrap_style(
        &self,
    ) -> longhands::text_wrap_style::computed_value::T {
        self.get_inherited_text().clone_text_wrap_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_touch_action(
        &self,
    ) -> longhands::touch_action::computed_value::T {
        self.get_box().clone_touch_action()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transform_box(
        &self,
    ) -> longhands::transform_box::computed_value::T {
        self.get_box().clone_transform_box()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transform_style(
        &self,
    ) -> longhands::transform_style::computed_value::T {
        self.get_box().clone_transform_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_unicode_bidi(
        &self,
    ) -> longhands::unicode_bidi::computed_value::T {
        self.get_text().clone_unicode_bidi()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_user_select(
        &self,
    ) -> longhands::user_select::computed_value::T {
        self.get_ui().clone_user_select()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_vector_effect(
        &self,
    ) -> longhands::vector_effect::computed_value::T {
        self.get_svg().clone_vector_effect()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_visibility(
        &self,
    ) -> longhands::visibility::computed_value::T {
        self.get_inherited_box().clone_visibility()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__webkit_line_clamp(
        &self,
    ) -> longhands::_webkit_line_clamp::computed_value::T {
        self.get_box().clone__webkit_line_clamp()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__webkit_text_security(
        &self,
    ) -> longhands::_webkit_text_security::computed_value::T {
        self.get_inherited_text().clone__webkit_text_security()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_white_space_collapse(
        &self,
    ) -> longhands::white_space_collapse::computed_value::T {
        self.get_inherited_text().clone_white_space_collapse()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_word_break(
        &self,
    ) -> longhands::word_break::computed_value::T {
        self.get_inherited_text().clone_word_break()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_writing_mode(
        &self,
    ) -> longhands::writing_mode::computed_value::T {
        self.get_inherited_box().clone_writing_mode()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__x_text_scale(
        &self,
    ) -> longhands::_x_text_scale::computed_value::T {
        self.get_font().clone__x_text_scale()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_z_index(
        &self,
    ) -> longhands::z_index::computed_value::T {
        self.get_position().clone_z_index()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_zoom(
        &self,
    ) -> longhands::zoom::computed_value::T {
        self.get_box().clone_zoom()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_appearance(
        &self,
    ) -> longhands::appearance::computed_value::T {
        self.get_box().clone_appearance()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_default_appearance(
        &self,
    ) -> longhands::_moz_default_appearance::computed_value::T {
        self.get_box().clone__moz_default_appearance()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_force_broken_image_icon(
        &self,
    ) -> longhands::_moz_force_broken_image_icon::computed_value::T {
        self.get_ui().clone__moz_force_broken_image_icon()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_subtree_hidden_only_visually(
        &self,
    ) -> longhands::_moz_subtree_hidden_only_visually::computed_value::T {
        self.get_ui().clone__moz_subtree_hidden_only_visually()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_break_after(
        &self,
    ) -> longhands::break_after::computed_value::T {
        self.get_box().clone_break_after()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_break_before(
        &self,
    ) -> longhands::break_before::computed_value::T {
        self.get_box().clone_break_before()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_clip_rule(
        &self,
    ) -> longhands::clip_rule::computed_value::T {
        self.get_inherited_svg().clone_clip_rule()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_fill_rule(
        &self,
    ) -> longhands::fill_rule::computed_value::T {
        self.get_inherited_svg().clone_fill_rule()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overflow_clip_box_block(
        &self,
    ) -> longhands::overflow_clip_box_block::computed_value::T {
        self.get_box().clone_overflow_clip_box_block()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overflow_clip_box_inline(
        &self,
    ) -> longhands::overflow_clip_box_inline::computed_value::T {
        self.get_box().clone_overflow_clip_box_inline()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_fill_opacity(
        &self,
    ) -> longhands::fill_opacity::computed_value::T {
        self.get_inherited_svg().clone_fill_opacity()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke_opacity(
        &self,
    ) -> longhands::stroke_opacity::computed_value::T {
        self.get_inherited_svg().clone_stroke_opacity()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_box_ordinal_group(
        &self,
    ) -> longhands::_moz_box_ordinal_group::computed_value::T {
        self.get_xul().clone__moz_box_ordinal_group()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_order(
        &self,
    ) -> longhands::order::computed_value::T {
        self.get_position().clone_order()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__x_span(
        &self,
    ) -> longhands::_x_span::computed_value::T {
        self.get_table().clone__x_span()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_position(
        &self,
    ) -> longhands::font_synthesis_position::computed_value::T {
        self.get_font().clone_font_synthesis_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_small_caps(
        &self,
    ) -> longhands::font_synthesis_small_caps::computed_value::T {
        self.get_font().clone_font_synthesis_small_caps()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_style(
        &self,
    ) -> longhands::font_synthesis_style::computed_value::T {
        self.get_font().clone_font_synthesis_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_synthesis_weight(
        &self,
    ) -> longhands::font_synthesis_weight::computed_value::T {
        self.get_font().clone_font_synthesis_weight()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_flex_grow(
        &self,
    ) -> longhands::flex_grow::computed_value::T {
        self.get_position().clone_flex_grow()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_flex_shrink(
        &self,
    ) -> longhands::flex_shrink::computed_value::T {
        self.get_position().clone_flex_shrink()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_box_flex(
        &self,
    ) -> longhands::_moz_box_flex::computed_value::T {
        self.get_xul().clone__moz_box_flex()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke_miterlimit(
        &self,
    ) -> longhands::stroke_miterlimit::computed_value::T {
        self.get_inherited_svg().clone_stroke_miterlimit()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overflow_x(
        &self,
    ) -> longhands::overflow_x::computed_value::T {
        self.get_box().clone_overflow_x()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overflow_y(
        &self,
    ) -> longhands::overflow_y::computed_value::T {
        self.get_box().clone_overflow_y()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overscroll_behavior_x(
        &self,
    ) -> longhands::overscroll_behavior_x::computed_value::T {
        self.get_box().clone_overscroll_behavior_x()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overscroll_behavior_y(
        &self,
    ) -> longhands::overscroll_behavior_y::computed_value::T {
        self.get_box().clone_overscroll_behavior_y()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_flood_opacity(
        &self,
    ) -> longhands::flood_opacity::computed_value::T {
        self.get_svg().clone_flood_opacity()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_window_opacity(
        &self,
    ) -> longhands::_moz_window_opacity::computed_value::T {
        self.get_ui().clone__moz_window_opacity()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_opacity(
        &self,
    ) -> longhands::opacity::computed_value::T {
        self.get_effects().clone_opacity()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_shape_image_threshold(
        &self,
    ) -> longhands::shape_image_threshold::computed_value::T {
        self.get_box().clone_shape_image_threshold()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stop_opacity(
        &self,
    ) -> longhands::stop_opacity::computed_value::T {
        self.get_svg().clone_stop_opacity()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_bottom_style(
        &self,
    ) -> longhands::border_bottom_style::computed_value::T {
        self.get_border().clone_border_bottom_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_left_style(
        &self,
    ) -> longhands::border_left_style::computed_value::T {
        self.get_border().clone_border_left_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_right_style(
        &self,
    ) -> longhands::border_right_style::computed_value::T {
        self.get_border().clone_border_right_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_top_style(
        &self,
    ) -> longhands::border_top_style::computed_value::T {
        self.get_border().clone_border_top_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_rule_style(
        &self,
    ) -> longhands::column_rule_style::computed_value::T {
        self.get_column().clone_column_rule_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_accent_color(
        &self,
    ) -> longhands::accent_color::computed_value::T {
        self.get_inherited_ui().clone_accent_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_anchor_name(
        &self,
    ) -> longhands::anchor_name::computed_value::T {
        self.get_box().clone_anchor_name()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_anchor_scope(
        &self,
    ) -> longhands::anchor_scope::computed_value::T {
        self.get_box().clone_anchor_scope()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_composition(
        &self,
    ) -> longhands::animation_composition::computed_value::T {
        self.get_ui().clone_animation_composition()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_delay(
        &self,
    ) -> longhands::animation_delay::computed_value::T {
        self.get_ui().clone_animation_delay()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_direction(
        &self,
    ) -> longhands::animation_direction::computed_value::T {
        self.get_ui().clone_animation_direction()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_duration(
        &self,
    ) -> longhands::animation_duration::computed_value::T {
        self.get_ui().clone_animation_duration()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_fill_mode(
        &self,
    ) -> longhands::animation_fill_mode::computed_value::T {
        self.get_ui().clone_animation_fill_mode()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_iteration_count(
        &self,
    ) -> longhands::animation_iteration_count::computed_value::T {
        self.get_ui().clone_animation_iteration_count()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_name(
        &self,
    ) -> longhands::animation_name::computed_value::T {
        self.get_ui().clone_animation_name()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_play_state(
        &self,
    ) -> longhands::animation_play_state::computed_value::T {
        self.get_ui().clone_animation_play_state()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_timeline(
        &self,
    ) -> longhands::animation_timeline::computed_value::T {
        self.get_ui().clone_animation_timeline()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_animation_timing_function(
        &self,
    ) -> longhands::animation_timing_function::computed_value::T {
        self.get_ui().clone_animation_timing_function()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_backdrop_filter(
        &self,
    ) -> longhands::backdrop_filter::computed_value::T {
        self.get_effects().clone_backdrop_filter()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_attachment(
        &self,
    ) -> longhands::background_attachment::computed_value::T {
        self.get_background().clone_background_attachment()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_blend_mode(
        &self,
    ) -> longhands::background_blend_mode::computed_value::T {
        self.get_background().clone_background_blend_mode()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_clip(
        &self,
    ) -> longhands::background_clip::computed_value::T {
        self.get_background().clone_background_clip()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_image(
        &self,
    ) -> longhands::background_image::computed_value::T {
        self.get_background().clone_background_image()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_origin(
        &self,
    ) -> longhands::background_origin::computed_value::T {
        self.get_background().clone_background_origin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_position_x(
        &self,
    ) -> longhands::background_position_x::computed_value::T {
        self.get_background().clone_background_position_x()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_position_y(
        &self,
    ) -> longhands::background_position_y::computed_value::T {
        self.get_background().clone_background_position_y()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_repeat(
        &self,
    ) -> longhands::background_repeat::computed_value::T {
        self.get_background().clone_background_repeat()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_size(
        &self,
    ) -> longhands::background_size::computed_value::T {
        self.get_background().clone_background_size()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_image_outset(
        &self,
    ) -> longhands::border_image_outset::computed_value::T {
        self.get_border().clone_border_image_outset()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_image_slice(
        &self,
    ) -> longhands::border_image_slice::computed_value::T {
        self.get_border().clone_border_image_slice()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_image_width(
        &self,
    ) -> longhands::border_image_width::computed_value::T {
        self.get_border().clone_border_image_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_spacing(
        &self,
    ) -> longhands::border_spacing::computed_value::T {
        self.get_inherited_table().clone_border_spacing()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_box_shadow(
        &self,
    ) -> longhands::box_shadow::computed_value::T {
        self.get_effects().clone_box_shadow()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_caret_color(
        &self,
    ) -> longhands::caret_color::computed_value::T {
        self.get_inherited_ui().clone_caret_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_clip(
        &self,
    ) -> longhands::clip::computed_value::T {
        self.get_effects().clone_clip()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_clip_path(
        &self,
    ) -> longhands::clip_path::computed_value::T {
        self.get_svg().clone_clip_path()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_color(
        &self,
    ) -> longhands::color::computed_value::T {
        self.get_inherited_text().clone_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_color_scheme(
        &self,
    ) -> longhands::color_scheme::computed_value::T {
        self.get_inherited_ui().clone_color_scheme()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_width(
        &self,
    ) -> longhands::column_width::computed_value::T {
        self.get_column().clone_column_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_container_name(
        &self,
    ) -> longhands::container_name::computed_value::T {
        self.get_box().clone_container_name()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_content(
        &self,
    ) -> longhands::content::computed_value::T {
        self.get_counters().clone_content()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_counter_increment(
        &self,
    ) -> longhands::counter_increment::computed_value::T {
        self.get_counters().clone_counter_increment()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_counter_reset(
        &self,
    ) -> longhands::counter_reset::computed_value::T {
        self.get_counters().clone_counter_reset()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_counter_set(
        &self,
    ) -> longhands::counter_set::computed_value::T {
        self.get_counters().clone_counter_set()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_cursor(
        &self,
    ) -> longhands::cursor::computed_value::T {
        self.get_inherited_ui().clone_cursor()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_d(
        &self,
    ) -> longhands::d::computed_value::T {
        self.get_svg().clone_d()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_filter(
        &self,
    ) -> longhands::filter::computed_value::T {
        self.get_effects().clone_filter()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_flex_basis(
        &self,
    ) -> longhands::flex_basis::computed_value::T {
        self.get_position().clone_flex_basis()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_family(
        &self,
    ) -> longhands::font_family::computed_value::T {
        self.get_font().clone_font_family()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_feature_settings(
        &self,
    ) -> longhands::font_feature_settings::computed_value::T {
        self.get_font().clone_font_feature_settings()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_palette(
        &self,
    ) -> longhands::font_palette::computed_value::T {
        self.get_font().clone_font_palette()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_size(
        &self,
    ) -> longhands::font_size::computed_value::T {
        self.get_font().clone_font_size()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variant_alternates(
        &self,
    ) -> longhands::font_variant_alternates::computed_value::T {
        self.get_font().clone_font_variant_alternates()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_font_variation_settings(
        &self,
    ) -> longhands::font_variation_settings::computed_value::T {
        self.get_font().clone_font_variation_settings()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_template_areas(
        &self,
    ) -> longhands::grid_template_areas::computed_value::T {
        self.get_position().clone_grid_template_areas()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_hyphenate_character(
        &self,
    ) -> longhands::hyphenate_character::computed_value::T {
        self.get_inherited_text().clone_hyphenate_character()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_letter_spacing(
        &self,
    ) -> longhands::letter_spacing::computed_value::T {
        self.get_inherited_text().clone_letter_spacing()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_line_height(
        &self,
    ) -> longhands::line_height::computed_value::T {
        self.get_font().clone_line_height()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_list_style_type(
        &self,
    ) -> longhands::list_style_type::computed_value::T {
        self.get_list().clone_list_style_type()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_clip(
        &self,
    ) -> longhands::mask_clip::computed_value::T {
        self.get_svg().clone_mask_clip()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_composite(
        &self,
    ) -> longhands::mask_composite::computed_value::T {
        self.get_svg().clone_mask_composite()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_image(
        &self,
    ) -> longhands::mask_image::computed_value::T {
        self.get_svg().clone_mask_image()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_mode(
        &self,
    ) -> longhands::mask_mode::computed_value::T {
        self.get_svg().clone_mask_mode()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_origin(
        &self,
    ) -> longhands::mask_origin::computed_value::T {
        self.get_svg().clone_mask_origin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_position_x(
        &self,
    ) -> longhands::mask_position_x::computed_value::T {
        self.get_svg().clone_mask_position_x()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_position_y(
        &self,
    ) -> longhands::mask_position_y::computed_value::T {
        self.get_svg().clone_mask_position_y()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_repeat(
        &self,
    ) -> longhands::mask_repeat::computed_value::T {
        self.get_svg().clone_mask_repeat()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_mask_size(
        &self,
    ) -> longhands::mask_size::computed_value::T {
        self.get_svg().clone_mask_size()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_context_properties(
        &self,
    ) -> longhands::_moz_context_properties::computed_value::T {
        self.get_inherited_svg().clone__moz_context_properties()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_offset_anchor(
        &self,
    ) -> longhands::offset_anchor::computed_value::T {
        self.get_box().clone_offset_anchor()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_offset_path(
        &self,
    ) -> longhands::offset_path::computed_value::T {
        self.get_box().clone_offset_path()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_offset_position(
        &self,
    ) -> longhands::offset_position::computed_value::T {
        self.get_box().clone_offset_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_page(
        &self,
    ) -> longhands::page::computed_value::T {
        self.get_page().clone_page()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_perspective(
        &self,
    ) -> longhands::perspective::computed_value::T {
        self.get_box().clone_perspective()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_position_anchor(
        &self,
    ) -> longhands::position_anchor::computed_value::T {
        self.get_position().clone_position_anchor()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_position_try_options(
        &self,
    ) -> longhands::position_try_options::computed_value::T {
        self.get_position().clone_position_try_options()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_quotes(
        &self,
    ) -> longhands::quotes::computed_value::T {
        self.get_list().clone_quotes()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_rotate(
        &self,
    ) -> longhands::rotate::computed_value::T {
        self.get_box().clone_rotate()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scale(
        &self,
    ) -> longhands::scale::computed_value::T {
        self.get_box().clone_scale()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_timeline_axis(
        &self,
    ) -> longhands::scroll_timeline_axis::computed_value::T {
        self.get_ui().clone_scroll_timeline_axis()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_timeline_name(
        &self,
    ) -> longhands::scroll_timeline_name::computed_value::T {
        self.get_ui().clone_scroll_timeline_name()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scrollbar_color(
        &self,
    ) -> longhands::scrollbar_color::computed_value::T {
        self.get_inherited_ui().clone_scrollbar_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_shape_outside(
        &self,
    ) -> longhands::shape_outside::computed_value::T {
        self.get_box().clone_shape_outside()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_size(
        &self,
    ) -> longhands::size::computed_value::T {
        self.get_page().clone_size()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke_dasharray(
        &self,
    ) -> longhands::stroke_dasharray::computed_value::T {
        self.get_inherited_svg().clone_stroke_dasharray()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke_dashoffset(
        &self,
    ) -> longhands::stroke_dashoffset::computed_value::T {
        self.get_inherited_svg().clone_stroke_dashoffset()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke_width(
        &self,
    ) -> longhands::stroke_width::computed_value::T {
        self.get_inherited_svg().clone_stroke_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_tab_size(
        &self,
    ) -> longhands::tab_size::computed_value::T {
        self.get_inherited_text().clone_tab_size()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_decoration_thickness(
        &self,
    ) -> longhands::text_decoration_thickness::computed_value::T {
        self.get_text().clone_text_decoration_thickness()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_emphasis_style(
        &self,
    ) -> longhands::text_emphasis_style::computed_value::T {
        self.get_inherited_text().clone_text_emphasis_style()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_indent(
        &self,
    ) -> longhands::text_indent::computed_value::T {
        self.get_inherited_text().clone_text_indent()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_overflow(
        &self,
    ) -> longhands::text_overflow::computed_value::T {
        self.get_text().clone_text_overflow()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_shadow(
        &self,
    ) -> longhands::text_shadow::computed_value::T {
        self.get_inherited_text().clone_text_shadow()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transition_behavior(
        &self,
    ) -> longhands::transition_behavior::computed_value::T {
        self.get_ui().clone_transition_behavior()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transition_delay(
        &self,
    ) -> longhands::transition_delay::computed_value::T {
        self.get_ui().clone_transition_delay()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transition_duration(
        &self,
    ) -> longhands::transition_duration::computed_value::T {
        self.get_ui().clone_transition_duration()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transition_property(
        &self,
    ) -> longhands::transition_property::computed_value::T {
        self.get_ui().clone_transition_property()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transition_timing_function(
        &self,
    ) -> longhands::transition_timing_function::computed_value::T {
        self.get_ui().clone_transition_timing_function()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_translate(
        &self,
    ) -> longhands::translate::computed_value::T {
        self.get_box().clone_translate()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_vertical_align(
        &self,
    ) -> longhands::vertical_align::computed_value::T {
        self.get_box().clone_vertical_align()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_view_timeline_axis(
        &self,
    ) -> longhands::view_timeline_axis::computed_value::T {
        self.get_ui().clone_view_timeline_axis()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_view_timeline_inset(
        &self,
    ) -> longhands::view_timeline_inset::computed_value::T {
        self.get_ui().clone_view_timeline_inset()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_view_timeline_name(
        &self,
    ) -> longhands::view_timeline_name::computed_value::T {
        self.get_ui().clone_view_timeline_name()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__webkit_text_stroke_width(
        &self,
    ) -> longhands::_webkit_text_stroke_width::computed_value::T {
        self.get_inherited_text().clone__webkit_text_stroke_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_will_change(
        &self,
    ) -> longhands::will_change::computed_value::T {
        self.get_box().clone_will_change()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_word_spacing(
        &self,
    ) -> longhands::word_spacing::computed_value::T {
        self.get_inherited_text().clone_word_spacing()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__x_lang(
        &self,
    ) -> longhands::_x_lang::computed_value::T {
        self.get_font().clone__x_lang()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_object_position(
        &self,
    ) -> longhands::object_position::computed_value::T {
        self.get_position().clone_object_position()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_perspective_origin(
        &self,
    ) -> longhands::perspective_origin::computed_value::T {
        self.get_box().clone_perspective_origin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_fill(
        &self,
    ) -> longhands::fill::computed_value::T {
        self.get_inherited_svg().clone_fill()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stroke(
        &self,
    ) -> longhands::stroke::computed_value::T {
        self.get_inherited_svg().clone_stroke()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_window_transform_origin(
        &self,
    ) -> longhands::_moz_window_transform_origin::computed_value::T {
        self.get_ui().clone__moz_window_transform_origin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transform_origin(
        &self,
    ) -> longhands::transform_origin::computed_value::T {
        self.get_box().clone_transform_origin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_template_columns(
        &self,
    ) -> longhands::grid_template_columns::computed_value::T {
        self.get_position().clone_grid_template_columns()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_template_rows(
        &self,
    ) -> longhands::grid_template_rows::computed_value::T {
        self.get_position().clone_grid_template_rows()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_image_source(
        &self,
    ) -> longhands::border_image_source::computed_value::T {
        self.get_border().clone_border_image_source()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_list_style_image(
        &self,
    ) -> longhands::list_style_image::computed_value::T {
        self.get_list().clone_list_style_image()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_auto_columns(
        &self,
    ) -> longhands::grid_auto_columns::computed_value::T {
        self.get_position().clone_grid_auto_columns()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_auto_rows(
        &self,
    ) -> longhands::grid_auto_rows::computed_value::T {
        self.get_position().clone_grid_auto_rows()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_window_transform(
        &self,
    ) -> longhands::_moz_window_transform::computed_value::T {
        self.get_ui().clone__moz_window_transform()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_transform(
        &self,
    ) -> longhands::transform::computed_value::T {
        self.get_box().clone_transform()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_gap(
        &self,
    ) -> longhands::column_gap::computed_value::T {
        self.get_position().clone_column_gap()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_row_gap(
        &self,
    ) -> longhands::row_gap::computed_value::T {
        self.get_position().clone_row_gap()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_marker_end(
        &self,
    ) -> longhands::marker_end::computed_value::T {
        self.get_inherited_svg().clone_marker_end()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_marker_mid(
        &self,
    ) -> longhands::marker_mid::computed_value::T {
        self.get_inherited_svg().clone_marker_mid()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_marker_start(
        &self,
    ) -> longhands::marker_start::computed_value::T {
        self.get_inherited_svg().clone_marker_start()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_contain_intrinsic_height(
        &self,
    ) -> longhands::contain_intrinsic_height::computed_value::T {
        self.get_position().clone_contain_intrinsic_height()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_contain_intrinsic_width(
        &self,
    ) -> longhands::contain_intrinsic_width::computed_value::T {
        self.get_position().clone_contain_intrinsic_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_column_end(
        &self,
    ) -> longhands::grid_column_end::computed_value::T {
        self.get_position().clone_grid_column_end()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_column_start(
        &self,
    ) -> longhands::grid_column_start::computed_value::T {
        self.get_position().clone_grid_column_start()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_row_end(
        &self,
    ) -> longhands::grid_row_end::computed_value::T {
        self.get_position().clone_grid_row_end()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_grid_row_start(
        &self,
    ) -> longhands::grid_row_start::computed_value::T {
        self.get_position().clone_grid_row_start()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_max_height(
        &self,
    ) -> longhands::max_height::computed_value::T {
        self.get_position().clone_max_height()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_max_width(
        &self,
    ) -> longhands::max_width::computed_value::T {
        self.get_position().clone_max_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_cx(
        &self,
    ) -> longhands::cx::computed_value::T {
        self.get_svg().clone_cx()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_cy(
        &self,
    ) -> longhands::cy::computed_value::T {
        self.get_svg().clone_cy()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_offset_distance(
        &self,
    ) -> longhands::offset_distance::computed_value::T {
        self.get_box().clone_offset_distance()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_x(
        &self,
    ) -> longhands::x::computed_value::T {
        self.get_svg().clone_x()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_y(
        &self,
    ) -> longhands::y::computed_value::T {
        self.get_svg().clone_y()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_bottom_left_radius(
        &self,
    ) -> longhands::border_bottom_left_radius::computed_value::T {
        self.get_border().clone_border_bottom_left_radius()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_bottom_right_radius(
        &self,
    ) -> longhands::border_bottom_right_radius::computed_value::T {
        self.get_border().clone_border_bottom_right_radius()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_top_left_radius(
        &self,
    ) -> longhands::border_top_left_radius::computed_value::T {
        self.get_border().clone_border_top_left_radius()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_top_right_radius(
        &self,
    ) -> longhands::border_top_right_radius::computed_value::T {
        self.get_border().clone_border_top_right_radius()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_height(
        &self,
    ) -> longhands::height::computed_value::T {
        self.get_position().clone_height()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_min_height(
        &self,
    ) -> longhands::min_height::computed_value::T {
        self.get_position().clone_min_height()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_min_width(
        &self,
    ) -> longhands::min_width::computed_value::T {
        self.get_position().clone_min_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_width(
        &self,
    ) -> longhands::width::computed_value::T {
        self.get_position().clone_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_bottom_width(
        &self,
    ) -> longhands::border_bottom_width::computed_value::T {
        self.get_border().clone_border_bottom_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_left_width(
        &self,
    ) -> longhands::border_left_width::computed_value::T {
        self.get_border().clone_border_left_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_right_width(
        &self,
    ) -> longhands::border_right_width::computed_value::T {
        self.get_border().clone_border_right_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_top_width(
        &self,
    ) -> longhands::border_top_width::computed_value::T {
        self.get_border().clone_border_top_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_rule_width(
        &self,
    ) -> longhands::column_rule_width::computed_value::T {
        self.get_column().clone_column_rule_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_outline_width(
        &self,
    ) -> longhands::outline_width::computed_value::T {
        self.get_outline().clone_outline_width()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_padding_bottom(
        &self,
    ) -> longhands::padding_bottom::computed_value::T {
        self.get_padding().clone_padding_bottom()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_padding_left(
        &self,
    ) -> longhands::padding_left::computed_value::T {
        self.get_padding().clone_padding_left()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_padding_right(
        &self,
    ) -> longhands::padding_right::computed_value::T {
        self.get_padding().clone_padding_right()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_padding_top(
        &self,
    ) -> longhands::padding_top::computed_value::T {
        self.get_padding().clone_padding_top()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_r(
        &self,
    ) -> longhands::r::computed_value::T {
        self.get_svg().clone_r()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_shape_margin(
        &self,
    ) -> longhands::shape_margin::computed_value::T {
        self.get_box().clone_shape_margin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_rx(
        &self,
    ) -> longhands::rx::computed_value::T {
        self.get_svg().clone_rx()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_ry(
        &self,
    ) -> longhands::ry::computed_value::T {
        self.get_svg().clone_ry()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_bottom(
        &self,
    ) -> longhands::scroll_padding_bottom::computed_value::T {
        self.get_padding().clone_scroll_padding_bottom()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_left(
        &self,
    ) -> longhands::scroll_padding_left::computed_value::T {
        self.get_padding().clone_scroll_padding_left()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_right(
        &self,
    ) -> longhands::scroll_padding_right::computed_value::T {
        self.get_padding().clone_scroll_padding_right()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_padding_top(
        &self,
    ) -> longhands::scroll_padding_top::computed_value::T {
        self.get_padding().clone_scroll_padding_top()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__moz_window_input_region_margin(
        &self,
    ) -> longhands::_moz_window_input_region_margin::computed_value::T {
        self.get_ui().clone__moz_window_input_region_margin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_outline_offset(
        &self,
    ) -> longhands::outline_offset::computed_value::T {
        self.get_outline().clone_outline_offset()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_overflow_clip_margin(
        &self,
    ) -> longhands::overflow_clip_margin::computed_value::T {
        self.get_margin().clone_overflow_clip_margin()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_bottom(
        &self,
    ) -> longhands::scroll_margin_bottom::computed_value::T {
        self.get_margin().clone_scroll_margin_bottom()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_left(
        &self,
    ) -> longhands::scroll_margin_left::computed_value::T {
        self.get_margin().clone_scroll_margin_left()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_right(
        &self,
    ) -> longhands::scroll_margin_right::computed_value::T {
        self.get_margin().clone_scroll_margin_right()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_scroll_margin_top(
        &self,
    ) -> longhands::scroll_margin_top::computed_value::T {
        self.get_margin().clone_scroll_margin_top()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_bottom(
        &self,
    ) -> longhands::bottom::computed_value::T {
        self.get_position().clone_bottom()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_left(
        &self,
    ) -> longhands::left::computed_value::T {
        self.get_position().clone_left()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_margin_bottom(
        &self,
    ) -> longhands::margin_bottom::computed_value::T {
        self.get_margin().clone_margin_bottom()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_margin_left(
        &self,
    ) -> longhands::margin_left::computed_value::T {
        self.get_margin().clone_margin_left()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_margin_right(
        &self,
    ) -> longhands::margin_right::computed_value::T {
        self.get_margin().clone_margin_right()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_margin_top(
        &self,
    ) -> longhands::margin_top::computed_value::T {
        self.get_margin().clone_margin_top()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_right(
        &self,
    ) -> longhands::right::computed_value::T {
        self.get_position().clone_right()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_underline_offset(
        &self,
    ) -> longhands::text_underline_offset::computed_value::T {
        self.get_inherited_text().clone_text_underline_offset()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_top(
        &self,
    ) -> longhands::top::computed_value::T {
        self.get_position().clone_top()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_background_color(
        &self,
    ) -> longhands::background_color::computed_value::T {
        self.get_background().clone_background_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_bottom_color(
        &self,
    ) -> longhands::border_bottom_color::computed_value::T {
        self.get_border().clone_border_bottom_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_left_color(
        &self,
    ) -> longhands::border_left_color::computed_value::T {
        self.get_border().clone_border_left_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_right_color(
        &self,
    ) -> longhands::border_right_color::computed_value::T {
        self.get_border().clone_border_right_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_border_top_color(
        &self,
    ) -> longhands::border_top_color::computed_value::T {
        self.get_border().clone_border_top_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_column_rule_color(
        &self,
    ) -> longhands::column_rule_color::computed_value::T {
        self.get_column().clone_column_rule_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_flood_color(
        &self,
    ) -> longhands::flood_color::computed_value::T {
        self.get_svg().clone_flood_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_lighting_color(
        &self,
    ) -> longhands::lighting_color::computed_value::T {
        self.get_svg().clone_lighting_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_outline_color(
        &self,
    ) -> longhands::outline_color::computed_value::T {
        self.get_outline().clone_outline_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_stop_color(
        &self,
    ) -> longhands::stop_color::computed_value::T {
        self.get_svg().clone_stop_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_decoration_color(
        &self,
    ) -> longhands::text_decoration_color::computed_value::T {
        self.get_text().clone_text_decoration_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone_text_emphasis_color(
        &self,
    ) -> longhands::text_emphasis_color::computed_value::T {
        self.get_inherited_text().clone_text_emphasis_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__webkit_text_fill_color(
        &self,
    ) -> longhands::_webkit_text_fill_color::computed_value::T {
        self.get_inherited_text().clone__webkit_text_fill_color()
    }
    /// Gets the computed value of a given property.
    #[inline(always)]
    #[allow(non_snake_case)]
    pub fn clone__webkit_text_stroke_color(
        &self,
    ) -> longhands::_webkit_text_stroke_color::computed_value::T {
        self.get_inherited_text().clone__webkit_text_stroke_color()
    }

    /// Writes the (resolved or computed) value of the given longhand as a string in `dest`.
    ///
    /// TODO(emilio): We should move all the special resolution from
    /// nsComputedDOMStyle to ToResolvedValue instead.
    pub fn computed_or_resolved_value(
        &self,
        property_id: LonghandId,
        context: Option<&resolved::Context>,
        dest: &mut CssStringWriter,
    ) -> fmt::Result {
        use crate::values::resolved::ToResolvedValue;
        let mut dest = CssWriter::new(dest);
        let property_id = property_id.to_physical(self.writing_mode);
        match property_id {
            
            LonghandId::AlignContent => {
                let value = match property_id {
                    LonghandId::AlignContent => self.clone_align_content(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AlignItems => {
                let value = match property_id {
                    LonghandId::AlignItems => self.clone_align_items(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AlignSelf => {
                let value = match property_id {
                    LonghandId::AlignSelf => self.clone_align_self(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AspectRatio => {
                let value = match property_id {
                    LonghandId::AspectRatio => self.clone_aspect_ratio(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackfaceVisibility => {
                let value = match property_id {
                    LonghandId::BackfaceVisibility => self.clone_backface_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BaselineSource => {
                let value = match property_id {
                    LonghandId::BaselineSource => self.clone_baseline_source(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderCollapse => {
                let value = match property_id {
                    LonghandId::BorderCollapse => self.clone_border_collapse(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderImageRepeat => {
                let value = match property_id {
                    LonghandId::BorderImageRepeat => self.clone_border_image_repeat(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BoxDecorationBreak => {
                let value = match property_id {
                    LonghandId::BoxDecorationBreak => self.clone_box_decoration_break(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BoxSizing => {
                let value = match property_id {
                    LonghandId::BoxSizing => self.clone_box_sizing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BreakInside => {
                let value = match property_id {
                    LonghandId::BreakInside => self.clone_break_inside(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::CaptionSide => {
                let value = match property_id {
                    LonghandId::CaptionSide => self.clone_caption_side(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Clear => {
                let value = match property_id {
                    LonghandId::Clear => self.clone_clear(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColorInterpolation => {
                let value = match property_id {
                    LonghandId::ColorInterpolation => self.clone_color_interpolation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColorInterpolationFilters => {
                let value = match property_id {
                    LonghandId::ColorInterpolationFilters => self.clone_color_interpolation_filters(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColumnCount => {
                let value = match property_id {
                    LonghandId::ColumnCount => self.clone_column_count(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColumnFill => {
                let value = match property_id {
                    LonghandId::ColumnFill => self.clone_column_fill(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColumnSpan => {
                let value = match property_id {
                    LonghandId::ColumnSpan => self.clone_column_span(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Contain => {
                let value = match property_id {
                    LonghandId::Contain => self.clone_contain(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ContainerType => {
                let value = match property_id {
                    LonghandId::ContainerType => self.clone_container_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ContentVisibility => {
                let value = match property_id {
                    LonghandId::ContentVisibility => self.clone_content_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Direction => {
                let value = match property_id {
                    LonghandId::Direction => self.clone_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Display => {
                let value = match property_id {
                    LonghandId::Display => self.clone_display(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::DominantBaseline => {
                let value = match property_id {
                    LonghandId::DominantBaseline => self.clone_dominant_baseline(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::EmptyCells => {
                let value = match property_id {
                    LonghandId::EmptyCells => self.clone_empty_cells(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FlexDirection => {
                let value = match property_id {
                    LonghandId::FlexDirection => self.clone_flex_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FlexWrap => {
                let value = match property_id {
                    LonghandId::FlexWrap => self.clone_flex_wrap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Float => {
                let value = match property_id {
                    LonghandId::Float => self.clone_float(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontKerning => {
                let value = match property_id {
                    LonghandId::FontKerning => self.clone_font_kerning(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontLanguageOverride => {
                let value = match property_id {
                    LonghandId::FontLanguageOverride => self.clone_font_language_override(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontOpticalSizing => {
                let value = match property_id {
                    LonghandId::FontOpticalSizing => self.clone_font_optical_sizing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontSizeAdjust => {
                let value = match property_id {
                    LonghandId::FontSizeAdjust => self.clone_font_size_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontStretch => {
                let value = match property_id {
                    LonghandId::FontStretch => self.clone_font_stretch(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontStyle => {
                let value = match property_id {
                    LonghandId::FontStyle => self.clone_font_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariantCaps => {
                let value = match property_id {
                    LonghandId::FontVariantCaps => self.clone_font_variant_caps(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariantEastAsian => {
                let value = match property_id {
                    LonghandId::FontVariantEastAsian => self.clone_font_variant_east_asian(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariantEmoji => {
                let value = match property_id {
                    LonghandId::FontVariantEmoji => self.clone_font_variant_emoji(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariantLigatures => {
                let value = match property_id {
                    LonghandId::FontVariantLigatures => self.clone_font_variant_ligatures(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariantNumeric => {
                let value = match property_id {
                    LonghandId::FontVariantNumeric => self.clone_font_variant_numeric(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariantPosition => {
                let value = match property_id {
                    LonghandId::FontVariantPosition => self.clone_font_variant_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontWeight => {
                let value = match property_id {
                    LonghandId::FontWeight => self.clone_font_weight(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ForcedColorAdjust => {
                let value = match property_id {
                    LonghandId::ForcedColorAdjust => self.clone_forced_color_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::GridAutoFlow => {
                let value = match property_id {
                    LonghandId::GridAutoFlow => self.clone_grid_auto_flow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Hyphens => {
                let value = match property_id {
                    LonghandId::Hyphens => self.clone_hyphens(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ImageOrientation => {
                let value = match property_id {
                    LonghandId::ImageOrientation => self.clone_image_orientation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ImageRendering => {
                let value = match property_id {
                    LonghandId::ImageRendering => self.clone_image_rendering(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ImeMode => {
                let value = match property_id {
                    LonghandId::ImeMode => self.clone_ime_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::InitialLetter => {
                let value = match property_id {
                    LonghandId::InitialLetter => self.clone_initial_letter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::InsetArea => {
                let value = match property_id {
                    LonghandId::InsetArea => self.clone_inset_area(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Isolation => {
                let value = match property_id {
                    LonghandId::Isolation => self.clone_isolation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::JustifyContent => {
                let value = match property_id {
                    LonghandId::JustifyContent => self.clone_justify_content(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::JustifyItems => {
                let value = match property_id {
                    LonghandId::JustifyItems => self.clone_justify_items(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::JustifySelf => {
                let value = match property_id {
                    LonghandId::JustifySelf => self.clone_justify_self(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::LineBreak => {
                let value = match property_id {
                    LonghandId::LineBreak => self.clone_line_break(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ListStylePosition => {
                let value = match property_id {
                    LonghandId::ListStylePosition => self.clone_list_style_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskType => {
                let value = match property_id {
                    LonghandId::MaskType => self.clone_mask_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MasonryAutoFlow => {
                let value = match property_id {
                    LonghandId::MasonryAutoFlow => self.clone_masonry_auto_flow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MathDepth => {
                let value = match property_id {
                    LonghandId::MathDepth => self.clone_math_depth(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MathStyle => {
                let value = match property_id {
                    LonghandId::MathStyle => self.clone_math_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MixBlendMode => {
                let value = match property_id {
                    LonghandId::MixBlendMode => self.clone_mix_blend_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozBoxAlign => {
                let value = match property_id {
                    LonghandId::MozBoxAlign => self.clone__moz_box_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozBoxCollapse => {
                let value = match property_id {
                    LonghandId::MozBoxCollapse => self.clone__moz_box_collapse(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozBoxDirection => {
                let value = match property_id {
                    LonghandId::MozBoxDirection => self.clone__moz_box_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozBoxOrient => {
                let value = match property_id {
                    LonghandId::MozBoxOrient => self.clone__moz_box_orient(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozBoxPack => {
                let value = match property_id {
                    LonghandId::MozBoxPack => self.clone__moz_box_pack(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozControlCharacterVisibility => {
                let value = match property_id {
                    LonghandId::MozControlCharacterVisibility => self.clone__moz_control_character_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozFloatEdge => {
                let value = match property_id {
                    LonghandId::MozFloatEdge => self.clone__moz_float_edge(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozInert => {
                let value = match property_id {
                    LonghandId::MozInert => self.clone__moz_inert(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozMathVariant => {
                let value = match property_id {
                    LonghandId::MozMathVariant => self.clone__moz_math_variant(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozMinFontSizeRatio => {
                let value = match property_id {
                    LonghandId::MozMinFontSizeRatio => self.clone__moz_min_font_size_ratio(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozOrient => {
                let value = match property_id {
                    LonghandId::MozOrient => self.clone__moz_orient(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozOsxFontSmoothing => {
                let value = match property_id {
                    LonghandId::MozOsxFontSmoothing => self.clone__moz_osx_font_smoothing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozTextSizeAdjust => {
                let value = match property_id {
                    LonghandId::MozTextSizeAdjust => self.clone__moz_text_size_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozTheme => {
                let value = match property_id {
                    LonghandId::MozTheme => self.clone__moz_theme(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozTopLayer => {
                let value = match property_id {
                    LonghandId::MozTopLayer => self.clone__moz_top_layer(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozUserFocus => {
                let value = match property_id {
                    LonghandId::MozUserFocus => self.clone__moz_user_focus(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozUserInput => {
                let value = match property_id {
                    LonghandId::MozUserInput => self.clone__moz_user_input(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozUserModify => {
                let value = match property_id {
                    LonghandId::MozUserModify => self.clone__moz_user_modify(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozWindowDragging => {
                let value = match property_id {
                    LonghandId::MozWindowDragging => self.clone__moz_window_dragging(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozWindowShadow => {
                let value = match property_id {
                    LonghandId::MozWindowShadow => self.clone__moz_window_shadow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ObjectFit => {
                let value = match property_id {
                    LonghandId::ObjectFit => self.clone_object_fit(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OffsetRotate => {
                let value = match property_id {
                    LonghandId::OffsetRotate => self.clone_offset_rotate(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OutlineStyle => {
                let value = match property_id {
                    LonghandId::OutlineStyle => self.clone_outline_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OverflowAnchor => {
                let value = match property_id {
                    LonghandId::OverflowAnchor => self.clone_overflow_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OverflowWrap => {
                let value = match property_id {
                    LonghandId::OverflowWrap => self.clone_overflow_wrap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PageOrientation => {
                let value = match property_id {
                    LonghandId::PageOrientation => self.clone_page_orientation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PaintOrder => {
                let value = match property_id {
                    LonghandId::PaintOrder => self.clone_paint_order(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PointerEvents => {
                let value = match property_id {
                    LonghandId::PointerEvents => self.clone_pointer_events(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Position => {
                let value = match property_id {
                    LonghandId::Position => self.clone_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PositionTryOrder => {
                let value = match property_id {
                    LonghandId::PositionTryOrder => self.clone_position_try_order(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PositionVisibility => {
                let value = match property_id {
                    LonghandId::PositionVisibility => self.clone_position_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PrintColorAdjust => {
                let value = match property_id {
                    LonghandId::PrintColorAdjust => self.clone_print_color_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Resize => {
                let value = match property_id {
                    LonghandId::Resize => self.clone_resize(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::RubyAlign => {
                let value = match property_id {
                    LonghandId::RubyAlign => self.clone_ruby_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::RubyPosition => {
                let value = match property_id {
                    LonghandId::RubyPosition => self.clone_ruby_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollBehavior => {
                let value = match property_id {
                    LonghandId::ScrollBehavior => self.clone_scroll_behavior(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollSnapAlign => {
                let value = match property_id {
                    LonghandId::ScrollSnapAlign => self.clone_scroll_snap_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollSnapStop => {
                let value = match property_id {
                    LonghandId::ScrollSnapStop => self.clone_scroll_snap_stop(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollSnapType => {
                let value = match property_id {
                    LonghandId::ScrollSnapType => self.clone_scroll_snap_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollbarGutter => {
                let value = match property_id {
                    LonghandId::ScrollbarGutter => self.clone_scrollbar_gutter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollbarWidth => {
                let value = match property_id {
                    LonghandId::ScrollbarWidth => self.clone_scrollbar_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ShapeRendering => {
                let value = match property_id {
                    LonghandId::ShapeRendering => self.clone_shape_rendering(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::StrokeLinecap => {
                let value = match property_id {
                    LonghandId::StrokeLinecap => self.clone_stroke_linecap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::StrokeLinejoin => {
                let value = match property_id {
                    LonghandId::StrokeLinejoin => self.clone_stroke_linejoin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TableLayout => {
                let value = match property_id {
                    LonghandId::TableLayout => self.clone_table_layout(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextAlign => {
                let value = match property_id {
                    LonghandId::TextAlign => self.clone_text_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextAlignLast => {
                let value = match property_id {
                    LonghandId::TextAlignLast => self.clone_text_align_last(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextAnchor => {
                let value = match property_id {
                    LonghandId::TextAnchor => self.clone_text_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextCombineUpright => {
                let value = match property_id {
                    LonghandId::TextCombineUpright => self.clone_text_combine_upright(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextDecorationLine => {
                let value = match property_id {
                    LonghandId::TextDecorationLine => self.clone_text_decoration_line(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextDecorationSkipInk => {
                let value = match property_id {
                    LonghandId::TextDecorationSkipInk => self.clone_text_decoration_skip_ink(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextDecorationStyle => {
                let value = match property_id {
                    LonghandId::TextDecorationStyle => self.clone_text_decoration_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextEmphasisPosition => {
                let value = match property_id {
                    LonghandId::TextEmphasisPosition => self.clone_text_emphasis_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextJustify => {
                let value = match property_id {
                    LonghandId::TextJustify => self.clone_text_justify(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextOrientation => {
                let value = match property_id {
                    LonghandId::TextOrientation => self.clone_text_orientation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextRendering => {
                let value = match property_id {
                    LonghandId::TextRendering => self.clone_text_rendering(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextTransform => {
                let value = match property_id {
                    LonghandId::TextTransform => self.clone_text_transform(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextUnderlinePosition => {
                let value = match property_id {
                    LonghandId::TextUnderlinePosition => self.clone_text_underline_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextWrapMode => {
                let value = match property_id {
                    LonghandId::TextWrapMode => self.clone_text_wrap_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextWrapStyle => {
                let value = match property_id {
                    LonghandId::TextWrapStyle => self.clone_text_wrap_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TouchAction => {
                let value = match property_id {
                    LonghandId::TouchAction => self.clone_touch_action(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TransformBox => {
                let value = match property_id {
                    LonghandId::TransformBox => self.clone_transform_box(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TransformStyle => {
                let value = match property_id {
                    LonghandId::TransformStyle => self.clone_transform_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::UnicodeBidi => {
                let value = match property_id {
                    LonghandId::UnicodeBidi => self.clone_unicode_bidi(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::UserSelect => {
                let value = match property_id {
                    LonghandId::UserSelect => self.clone_user_select(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::VectorEffect => {
                let value = match property_id {
                    LonghandId::VectorEffect => self.clone_vector_effect(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Visibility => {
                let value = match property_id {
                    LonghandId::Visibility => self.clone_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WebkitLineClamp => {
                let value = match property_id {
                    LonghandId::WebkitLineClamp => self.clone__webkit_line_clamp(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WebkitTextSecurity => {
                let value = match property_id {
                    LonghandId::WebkitTextSecurity => self.clone__webkit_text_security(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WhiteSpaceCollapse => {
                let value = match property_id {
                    LonghandId::WhiteSpaceCollapse => self.clone_white_space_collapse(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WordBreak => {
                let value = match property_id {
                    LonghandId::WordBreak => self.clone_word_break(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WritingMode => {
                let value = match property_id {
                    LonghandId::WritingMode => self.clone_writing_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::XTextScale => {
                let value = match property_id {
                    LonghandId::XTextScale => self.clone__x_text_scale(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ZIndex => {
                let value = match property_id {
                    LonghandId::ZIndex => self.clone_z_index(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Zoom => {
                let value = match property_id {
                    LonghandId::Zoom => self.clone_zoom(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Appearance |
LonghandId::MozDefaultAppearance => {
                let value = match property_id {
                    LonghandId::Appearance => self.clone_appearance(),
                    LonghandId::MozDefaultAppearance => self.clone__moz_default_appearance(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozForceBrokenImageIcon |
LonghandId::MozSubtreeHiddenOnlyVisually => {
                let value = match property_id {
                    LonghandId::MozForceBrokenImageIcon => self.clone__moz_force_broken_image_icon(),
                    LonghandId::MozSubtreeHiddenOnlyVisually => self.clone__moz_subtree_hidden_only_visually(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BreakAfter |
LonghandId::BreakBefore => {
                let value = match property_id {
                    LonghandId::BreakAfter => self.clone_break_after(),
                    LonghandId::BreakBefore => self.clone_break_before(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ClipRule |
LonghandId::FillRule => {
                let value = match property_id {
                    LonghandId::ClipRule => self.clone_clip_rule(),
                    LonghandId::FillRule => self.clone_fill_rule(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OverflowClipBoxBlock |
LonghandId::OverflowClipBoxInline => {
                let value = match property_id {
                    LonghandId::OverflowClipBoxBlock => self.clone_overflow_clip_box_block(),
                    LonghandId::OverflowClipBoxInline => self.clone_overflow_clip_box_inline(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FillOpacity |
LonghandId::StrokeOpacity => {
                let value = match property_id {
                    LonghandId::FillOpacity => self.clone_fill_opacity(),
                    LonghandId::StrokeOpacity => self.clone_stroke_opacity(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozBoxOrdinalGroup |
LonghandId::Order |
LonghandId::XSpan => {
                let value = match property_id {
                    LonghandId::MozBoxOrdinalGroup => self.clone__moz_box_ordinal_group(),
                    LonghandId::Order => self.clone_order(),
                    LonghandId::XSpan => self.clone__x_span(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontSynthesisPosition |
LonghandId::FontSynthesisSmallCaps |
LonghandId::FontSynthesisStyle |
LonghandId::FontSynthesisWeight => {
                let value = match property_id {
                    LonghandId::FontSynthesisPosition => self.clone_font_synthesis_position(),
                    LonghandId::FontSynthesisSmallCaps => self.clone_font_synthesis_small_caps(),
                    LonghandId::FontSynthesisStyle => self.clone_font_synthesis_style(),
                    LonghandId::FontSynthesisWeight => self.clone_font_synthesis_weight(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FlexGrow |
LonghandId::FlexShrink |
LonghandId::MozBoxFlex |
LonghandId::StrokeMiterlimit => {
                let value = match property_id {
                    LonghandId::FlexGrow => self.clone_flex_grow(),
                    LonghandId::FlexShrink => self.clone_flex_shrink(),
                    LonghandId::MozBoxFlex => self.clone__moz_box_flex(),
                    LonghandId::StrokeMiterlimit => self.clone_stroke_miterlimit(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OverflowBlock |
LonghandId::OverflowInline |
LonghandId::OverflowX |
LonghandId::OverflowY => {
                let value = match property_id {
                    LonghandId::OverflowX => self.clone_overflow_x(),
                    LonghandId::OverflowY => self.clone_overflow_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OverscrollBehaviorBlock |
LonghandId::OverscrollBehaviorInline |
LonghandId::OverscrollBehaviorX |
LonghandId::OverscrollBehaviorY => {
                let value = match property_id {
                    LonghandId::OverscrollBehaviorX => self.clone_overscroll_behavior_x(),
                    LonghandId::OverscrollBehaviorY => self.clone_overscroll_behavior_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FloodOpacity |
LonghandId::MozWindowOpacity |
LonghandId::Opacity |
LonghandId::ShapeImageThreshold |
LonghandId::StopOpacity => {
                let value = match property_id {
                    LonghandId::FloodOpacity => self.clone_flood_opacity(),
                    LonghandId::MozWindowOpacity => self.clone__moz_window_opacity(),
                    LonghandId::Opacity => self.clone_opacity(),
                    LonghandId::ShapeImageThreshold => self.clone_shape_image_threshold(),
                    LonghandId::StopOpacity => self.clone_stop_opacity(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderBlockEndStyle |
LonghandId::BorderBlockStartStyle |
LonghandId::BorderBottomStyle |
LonghandId::BorderInlineEndStyle |
LonghandId::BorderInlineStartStyle |
LonghandId::BorderLeftStyle |
LonghandId::BorderRightStyle |
LonghandId::BorderTopStyle |
LonghandId::ColumnRuleStyle => {
                let value = match property_id {
                    LonghandId::BorderBottomStyle => self.clone_border_bottom_style(),
                    LonghandId::BorderLeftStyle => self.clone_border_left_style(),
                    LonghandId::BorderRightStyle => self.clone_border_right_style(),
                    LonghandId::BorderTopStyle => self.clone_border_top_style(),
                    LonghandId::ColumnRuleStyle => self.clone_column_rule_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AccentColor => {
                let value = match property_id {
                    LonghandId::AccentColor => self.clone_accent_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnchorName => {
                let value = match property_id {
                    LonghandId::AnchorName => self.clone_anchor_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnchorScope => {
                let value = match property_id {
                    LonghandId::AnchorScope => self.clone_anchor_scope(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationComposition => {
                let value = match property_id {
                    LonghandId::AnimationComposition => self.clone_animation_composition(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationDelay => {
                let value = match property_id {
                    LonghandId::AnimationDelay => self.clone_animation_delay(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationDirection => {
                let value = match property_id {
                    LonghandId::AnimationDirection => self.clone_animation_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationDuration => {
                let value = match property_id {
                    LonghandId::AnimationDuration => self.clone_animation_duration(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationFillMode => {
                let value = match property_id {
                    LonghandId::AnimationFillMode => self.clone_animation_fill_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationIterationCount => {
                let value = match property_id {
                    LonghandId::AnimationIterationCount => self.clone_animation_iteration_count(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationName => {
                let value = match property_id {
                    LonghandId::AnimationName => self.clone_animation_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationPlayState => {
                let value = match property_id {
                    LonghandId::AnimationPlayState => self.clone_animation_play_state(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationTimeline => {
                let value = match property_id {
                    LonghandId::AnimationTimeline => self.clone_animation_timeline(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::AnimationTimingFunction => {
                let value = match property_id {
                    LonghandId::AnimationTimingFunction => self.clone_animation_timing_function(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackdropFilter => {
                let value = match property_id {
                    LonghandId::BackdropFilter => self.clone_backdrop_filter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundAttachment => {
                let value = match property_id {
                    LonghandId::BackgroundAttachment => self.clone_background_attachment(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundBlendMode => {
                let value = match property_id {
                    LonghandId::BackgroundBlendMode => self.clone_background_blend_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundClip => {
                let value = match property_id {
                    LonghandId::BackgroundClip => self.clone_background_clip(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundImage => {
                let value = match property_id {
                    LonghandId::BackgroundImage => self.clone_background_image(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundOrigin => {
                let value = match property_id {
                    LonghandId::BackgroundOrigin => self.clone_background_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundPositionX => {
                let value = match property_id {
                    LonghandId::BackgroundPositionX => self.clone_background_position_x(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundPositionY => {
                let value = match property_id {
                    LonghandId::BackgroundPositionY => self.clone_background_position_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundRepeat => {
                let value = match property_id {
                    LonghandId::BackgroundRepeat => self.clone_background_repeat(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundSize => {
                let value = match property_id {
                    LonghandId::BackgroundSize => self.clone_background_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderImageOutset => {
                let value = match property_id {
                    LonghandId::BorderImageOutset => self.clone_border_image_outset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderImageSlice => {
                let value = match property_id {
                    LonghandId::BorderImageSlice => self.clone_border_image_slice(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderImageWidth => {
                let value = match property_id {
                    LonghandId::BorderImageWidth => self.clone_border_image_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderSpacing => {
                let value = match property_id {
                    LonghandId::BorderSpacing => self.clone_border_spacing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BoxShadow => {
                let value = match property_id {
                    LonghandId::BoxShadow => self.clone_box_shadow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::CaretColor => {
                let value = match property_id {
                    LonghandId::CaretColor => self.clone_caret_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Clip => {
                let value = match property_id {
                    LonghandId::Clip => self.clone_clip(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ClipPath => {
                let value = match property_id {
                    LonghandId::ClipPath => self.clone_clip_path(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Color => {
                let value = match property_id {
                    LonghandId::Color => self.clone_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColorScheme => {
                let value = match property_id {
                    LonghandId::ColorScheme => self.clone_color_scheme(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColumnWidth => {
                let value = match property_id {
                    LonghandId::ColumnWidth => self.clone_column_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ContainerName => {
                let value = match property_id {
                    LonghandId::ContainerName => self.clone_container_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Content => {
                let value = match property_id {
                    LonghandId::Content => self.clone_content(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::CounterIncrement => {
                let value = match property_id {
                    LonghandId::CounterIncrement => self.clone_counter_increment(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::CounterReset => {
                let value = match property_id {
                    LonghandId::CounterReset => self.clone_counter_reset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::CounterSet => {
                let value = match property_id {
                    LonghandId::CounterSet => self.clone_counter_set(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Cursor => {
                let value = match property_id {
                    LonghandId::Cursor => self.clone_cursor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::D => {
                let value = match property_id {
                    LonghandId::D => self.clone_d(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Filter => {
                let value = match property_id {
                    LonghandId::Filter => self.clone_filter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FlexBasis => {
                let value = match property_id {
                    LonghandId::FlexBasis => self.clone_flex_basis(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontFamily => {
                let value = match property_id {
                    LonghandId::FontFamily => self.clone_font_family(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontFeatureSettings => {
                let value = match property_id {
                    LonghandId::FontFeatureSettings => self.clone_font_feature_settings(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontPalette => {
                let value = match property_id {
                    LonghandId::FontPalette => self.clone_font_palette(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontSize => {
                let value = match property_id {
                    LonghandId::FontSize => self.clone_font_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariantAlternates => {
                let value = match property_id {
                    LonghandId::FontVariantAlternates => self.clone_font_variant_alternates(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::FontVariationSettings => {
                let value = match property_id {
                    LonghandId::FontVariationSettings => self.clone_font_variation_settings(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::GridTemplateAreas => {
                let value = match property_id {
                    LonghandId::GridTemplateAreas => self.clone_grid_template_areas(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::HyphenateCharacter => {
                let value = match property_id {
                    LonghandId::HyphenateCharacter => self.clone_hyphenate_character(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::LetterSpacing => {
                let value = match property_id {
                    LonghandId::LetterSpacing => self.clone_letter_spacing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::LineHeight => {
                let value = match property_id {
                    LonghandId::LineHeight => self.clone_line_height(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ListStyleType => {
                let value = match property_id {
                    LonghandId::ListStyleType => self.clone_list_style_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskClip => {
                let value = match property_id {
                    LonghandId::MaskClip => self.clone_mask_clip(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskComposite => {
                let value = match property_id {
                    LonghandId::MaskComposite => self.clone_mask_composite(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskImage => {
                let value = match property_id {
                    LonghandId::MaskImage => self.clone_mask_image(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskMode => {
                let value = match property_id {
                    LonghandId::MaskMode => self.clone_mask_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskOrigin => {
                let value = match property_id {
                    LonghandId::MaskOrigin => self.clone_mask_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskPositionX => {
                let value = match property_id {
                    LonghandId::MaskPositionX => self.clone_mask_position_x(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskPositionY => {
                let value = match property_id {
                    LonghandId::MaskPositionY => self.clone_mask_position_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskRepeat => {
                let value = match property_id {
                    LonghandId::MaskRepeat => self.clone_mask_repeat(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaskSize => {
                let value = match property_id {
                    LonghandId::MaskSize => self.clone_mask_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozContextProperties => {
                let value = match property_id {
                    LonghandId::MozContextProperties => self.clone__moz_context_properties(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OffsetAnchor => {
                let value = match property_id {
                    LonghandId::OffsetAnchor => self.clone_offset_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OffsetPath => {
                let value = match property_id {
                    LonghandId::OffsetPath => self.clone_offset_path(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::OffsetPosition => {
                let value = match property_id {
                    LonghandId::OffsetPosition => self.clone_offset_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Page => {
                let value = match property_id {
                    LonghandId::Page => self.clone_page(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Perspective => {
                let value = match property_id {
                    LonghandId::Perspective => self.clone_perspective(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PositionAnchor => {
                let value = match property_id {
                    LonghandId::PositionAnchor => self.clone_position_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PositionTryOptions => {
                let value = match property_id {
                    LonghandId::PositionTryOptions => self.clone_position_try_options(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Quotes => {
                let value = match property_id {
                    LonghandId::Quotes => self.clone_quotes(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Rotate => {
                let value = match property_id {
                    LonghandId::Rotate => self.clone_rotate(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Scale => {
                let value = match property_id {
                    LonghandId::Scale => self.clone_scale(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollTimelineAxis => {
                let value = match property_id {
                    LonghandId::ScrollTimelineAxis => self.clone_scroll_timeline_axis(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollTimelineName => {
                let value = match property_id {
                    LonghandId::ScrollTimelineName => self.clone_scroll_timeline_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ScrollbarColor => {
                let value = match property_id {
                    LonghandId::ScrollbarColor => self.clone_scrollbar_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ShapeOutside => {
                let value = match property_id {
                    LonghandId::ShapeOutside => self.clone_shape_outside(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Size => {
                let value = match property_id {
                    LonghandId::Size => self.clone_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::StrokeDasharray => {
                let value = match property_id {
                    LonghandId::StrokeDasharray => self.clone_stroke_dasharray(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::StrokeDashoffset => {
                let value = match property_id {
                    LonghandId::StrokeDashoffset => self.clone_stroke_dashoffset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::StrokeWidth => {
                let value = match property_id {
                    LonghandId::StrokeWidth => self.clone_stroke_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TabSize => {
                let value = match property_id {
                    LonghandId::TabSize => self.clone_tab_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextDecorationThickness => {
                let value = match property_id {
                    LonghandId::TextDecorationThickness => self.clone_text_decoration_thickness(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextEmphasisStyle => {
                let value = match property_id {
                    LonghandId::TextEmphasisStyle => self.clone_text_emphasis_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextIndent => {
                let value = match property_id {
                    LonghandId::TextIndent => self.clone_text_indent(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextOverflow => {
                let value = match property_id {
                    LonghandId::TextOverflow => self.clone_text_overflow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TextShadow => {
                let value = match property_id {
                    LonghandId::TextShadow => self.clone_text_shadow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TransitionBehavior => {
                let value = match property_id {
                    LonghandId::TransitionBehavior => self.clone_transition_behavior(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TransitionDelay => {
                let value = match property_id {
                    LonghandId::TransitionDelay => self.clone_transition_delay(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TransitionDuration => {
                let value = match property_id {
                    LonghandId::TransitionDuration => self.clone_transition_duration(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TransitionProperty => {
                let value = match property_id {
                    LonghandId::TransitionProperty => self.clone_transition_property(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::TransitionTimingFunction => {
                let value = match property_id {
                    LonghandId::TransitionTimingFunction => self.clone_transition_timing_function(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Translate => {
                let value = match property_id {
                    LonghandId::Translate => self.clone_translate(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::VerticalAlign => {
                let value = match property_id {
                    LonghandId::VerticalAlign => self.clone_vertical_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ViewTimelineAxis => {
                let value = match property_id {
                    LonghandId::ViewTimelineAxis => self.clone_view_timeline_axis(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ViewTimelineInset => {
                let value = match property_id {
                    LonghandId::ViewTimelineInset => self.clone_view_timeline_inset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ViewTimelineName => {
                let value = match property_id {
                    LonghandId::ViewTimelineName => self.clone_view_timeline_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WebkitTextStrokeWidth => {
                let value = match property_id {
                    LonghandId::WebkitTextStrokeWidth => self.clone__webkit_text_stroke_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WillChange => {
                let value = match property_id {
                    LonghandId::WillChange => self.clone_will_change(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::WordSpacing => {
                let value = match property_id {
                    LonghandId::WordSpacing => self.clone_word_spacing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::XLang => {
                let value = match property_id {
                    LonghandId::XLang => self.clone__x_lang(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ObjectPosition |
LonghandId::PerspectiveOrigin => {
                let value = match property_id {
                    LonghandId::ObjectPosition => self.clone_object_position(),
                    LonghandId::PerspectiveOrigin => self.clone_perspective_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Fill |
LonghandId::Stroke => {
                let value = match property_id {
                    LonghandId::Fill => self.clone_fill(),
                    LonghandId::Stroke => self.clone_stroke(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozWindowTransformOrigin |
LonghandId::TransformOrigin => {
                let value = match property_id {
                    LonghandId::MozWindowTransformOrigin => self.clone__moz_window_transform_origin(),
                    LonghandId::TransformOrigin => self.clone_transform_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::GridTemplateColumns |
LonghandId::GridTemplateRows => {
                let value = match property_id {
                    LonghandId::GridTemplateColumns => self.clone_grid_template_columns(),
                    LonghandId::GridTemplateRows => self.clone_grid_template_rows(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderImageSource |
LonghandId::ListStyleImage => {
                let value = match property_id {
                    LonghandId::BorderImageSource => self.clone_border_image_source(),
                    LonghandId::ListStyleImage => self.clone_list_style_image(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::GridAutoColumns |
LonghandId::GridAutoRows => {
                let value = match property_id {
                    LonghandId::GridAutoColumns => self.clone_grid_auto_columns(),
                    LonghandId::GridAutoRows => self.clone_grid_auto_rows(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozWindowTransform |
LonghandId::Transform => {
                let value = match property_id {
                    LonghandId::MozWindowTransform => self.clone__moz_window_transform(),
                    LonghandId::Transform => self.clone_transform(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ColumnGap |
LonghandId::RowGap => {
                let value = match property_id {
                    LonghandId::ColumnGap => self.clone_column_gap(),
                    LonghandId::RowGap => self.clone_row_gap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MarkerEnd |
LonghandId::MarkerMid |
LonghandId::MarkerStart => {
                let value = match property_id {
                    LonghandId::MarkerEnd => self.clone_marker_end(),
                    LonghandId::MarkerMid => self.clone_marker_mid(),
                    LonghandId::MarkerStart => self.clone_marker_start(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::ContainIntrinsicBlockSize |
LonghandId::ContainIntrinsicHeight |
LonghandId::ContainIntrinsicInlineSize |
LonghandId::ContainIntrinsicWidth => {
                let value = match property_id {
                    LonghandId::ContainIntrinsicHeight => self.clone_contain_intrinsic_height(),
                    LonghandId::ContainIntrinsicWidth => self.clone_contain_intrinsic_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::GridColumnEnd |
LonghandId::GridColumnStart |
LonghandId::GridRowEnd |
LonghandId::GridRowStart => {
                let value = match property_id {
                    LonghandId::GridColumnEnd => self.clone_grid_column_end(),
                    LonghandId::GridColumnStart => self.clone_grid_column_start(),
                    LonghandId::GridRowEnd => self.clone_grid_row_end(),
                    LonghandId::GridRowStart => self.clone_grid_row_start(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MaxBlockSize |
LonghandId::MaxHeight |
LonghandId::MaxInlineSize |
LonghandId::MaxWidth => {
                let value = match property_id {
                    LonghandId::MaxHeight => self.clone_max_height(),
                    LonghandId::MaxWidth => self.clone_max_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Cx |
LonghandId::Cy |
LonghandId::OffsetDistance |
LonghandId::X |
LonghandId::Y => {
                let value = match property_id {
                    LonghandId::Cx => self.clone_cx(),
                    LonghandId::Cy => self.clone_cy(),
                    LonghandId::OffsetDistance => self.clone_offset_distance(),
                    LonghandId::X => self.clone_x(),
                    LonghandId::Y => self.clone_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderBottomLeftRadius |
LonghandId::BorderBottomRightRadius |
LonghandId::BorderEndEndRadius |
LonghandId::BorderEndStartRadius |
LonghandId::BorderStartEndRadius |
LonghandId::BorderStartStartRadius |
LonghandId::BorderTopLeftRadius |
LonghandId::BorderTopRightRadius => {
                let value = match property_id {
                    LonghandId::BorderBottomLeftRadius => self.clone_border_bottom_left_radius(),
                    LonghandId::BorderBottomRightRadius => self.clone_border_bottom_right_radius(),
                    LonghandId::BorderTopLeftRadius => self.clone_border_top_left_radius(),
                    LonghandId::BorderTopRightRadius => self.clone_border_top_right_radius(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BlockSize |
LonghandId::Height |
LonghandId::InlineSize |
LonghandId::MinBlockSize |
LonghandId::MinHeight |
LonghandId::MinInlineSize |
LonghandId::MinWidth |
LonghandId::Width => {
                let value = match property_id {
                    LonghandId::Height => self.clone_height(),
                    LonghandId::MinHeight => self.clone_min_height(),
                    LonghandId::MinWidth => self.clone_min_width(),
                    LonghandId::Width => self.clone_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BorderBlockEndWidth |
LonghandId::BorderBlockStartWidth |
LonghandId::BorderBottomWidth |
LonghandId::BorderInlineEndWidth |
LonghandId::BorderInlineStartWidth |
LonghandId::BorderLeftWidth |
LonghandId::BorderRightWidth |
LonghandId::BorderTopWidth |
LonghandId::ColumnRuleWidth |
LonghandId::OutlineWidth => {
                let value = match property_id {
                    LonghandId::BorderBottomWidth => self.clone_border_bottom_width(),
                    LonghandId::BorderLeftWidth => self.clone_border_left_width(),
                    LonghandId::BorderRightWidth => self.clone_border_right_width(),
                    LonghandId::BorderTopWidth => self.clone_border_top_width(),
                    LonghandId::ColumnRuleWidth => self.clone_column_rule_width(),
                    LonghandId::OutlineWidth => self.clone_outline_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::PaddingBlockEnd |
LonghandId::PaddingBlockStart |
LonghandId::PaddingBottom |
LonghandId::PaddingInlineEnd |
LonghandId::PaddingInlineStart |
LonghandId::PaddingLeft |
LonghandId::PaddingRight |
LonghandId::PaddingTop |
LonghandId::R |
LonghandId::ShapeMargin => {
                let value = match property_id {
                    LonghandId::PaddingBottom => self.clone_padding_bottom(),
                    LonghandId::PaddingLeft => self.clone_padding_left(),
                    LonghandId::PaddingRight => self.clone_padding_right(),
                    LonghandId::PaddingTop => self.clone_padding_top(),
                    LonghandId::R => self.clone_r(),
                    LonghandId::ShapeMargin => self.clone_shape_margin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Rx |
LonghandId::Ry |
LonghandId::ScrollPaddingBlockEnd |
LonghandId::ScrollPaddingBlockStart |
LonghandId::ScrollPaddingBottom |
LonghandId::ScrollPaddingInlineEnd |
LonghandId::ScrollPaddingInlineStart |
LonghandId::ScrollPaddingLeft |
LonghandId::ScrollPaddingRight |
LonghandId::ScrollPaddingTop => {
                let value = match property_id {
                    LonghandId::Rx => self.clone_rx(),
                    LonghandId::Ry => self.clone_ry(),
                    LonghandId::ScrollPaddingBottom => self.clone_scroll_padding_bottom(),
                    LonghandId::ScrollPaddingLeft => self.clone_scroll_padding_left(),
                    LonghandId::ScrollPaddingRight => self.clone_scroll_padding_right(),
                    LonghandId::ScrollPaddingTop => self.clone_scroll_padding_top(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::MozWindowInputRegionMargin |
LonghandId::OutlineOffset |
LonghandId::OverflowClipMargin |
LonghandId::ScrollMarginBlockEnd |
LonghandId::ScrollMarginBlockStart |
LonghandId::ScrollMarginBottom |
LonghandId::ScrollMarginInlineEnd |
LonghandId::ScrollMarginInlineStart |
LonghandId::ScrollMarginLeft |
LonghandId::ScrollMarginRight |
LonghandId::ScrollMarginTop => {
                let value = match property_id {
                    LonghandId::MozWindowInputRegionMargin => self.clone__moz_window_input_region_margin(),
                    LonghandId::OutlineOffset => self.clone_outline_offset(),
                    LonghandId::OverflowClipMargin => self.clone_overflow_clip_margin(),
                    LonghandId::ScrollMarginBottom => self.clone_scroll_margin_bottom(),
                    LonghandId::ScrollMarginLeft => self.clone_scroll_margin_left(),
                    LonghandId::ScrollMarginRight => self.clone_scroll_margin_right(),
                    LonghandId::ScrollMarginTop => self.clone_scroll_margin_top(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::Bottom |
LonghandId::InsetBlockEnd |
LonghandId::InsetBlockStart |
LonghandId::InsetInlineEnd |
LonghandId::InsetInlineStart |
LonghandId::Left |
LonghandId::MarginBlockEnd |
LonghandId::MarginBlockStart |
LonghandId::MarginBottom |
LonghandId::MarginInlineEnd |
LonghandId::MarginInlineStart |
LonghandId::MarginLeft |
LonghandId::MarginRight |
LonghandId::MarginTop |
LonghandId::Right |
LonghandId::TextUnderlineOffset |
LonghandId::Top => {
                let value = match property_id {
                    LonghandId::Bottom => self.clone_bottom(),
                    LonghandId::Left => self.clone_left(),
                    LonghandId::MarginBottom => self.clone_margin_bottom(),
                    LonghandId::MarginLeft => self.clone_margin_left(),
                    LonghandId::MarginRight => self.clone_margin_right(),
                    LonghandId::MarginTop => self.clone_margin_top(),
                    LonghandId::Right => self.clone_right(),
                    LonghandId::TextUnderlineOffset => self.clone_text_underline_offset(),
                    LonghandId::Top => self.clone_top(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
            
            LonghandId::BackgroundColor |
LonghandId::BorderBlockEndColor |
LonghandId::BorderBlockStartColor |
LonghandId::BorderBottomColor |
LonghandId::BorderInlineEndColor |
LonghandId::BorderInlineStartColor |
LonghandId::BorderLeftColor |
LonghandId::BorderRightColor |
LonghandId::BorderTopColor |
LonghandId::ColumnRuleColor |
LonghandId::FloodColor |
LonghandId::LightingColor |
LonghandId::OutlineColor |
LonghandId::StopColor |
LonghandId::TextDecorationColor |
LonghandId::TextEmphasisColor |
LonghandId::WebkitTextFillColor |
LonghandId::WebkitTextStrokeColor => {
                let value = match property_id {
                    LonghandId::BackgroundColor => self.clone_background_color(),
                    LonghandId::BorderBottomColor => self.clone_border_bottom_color(),
                    LonghandId::BorderLeftColor => self.clone_border_left_color(),
                    LonghandId::BorderRightColor => self.clone_border_right_color(),
                    LonghandId::BorderTopColor => self.clone_border_top_color(),
                    LonghandId::ColumnRuleColor => self.clone_column_rule_color(),
                    LonghandId::FloodColor => self.clone_flood_color(),
                    LonghandId::LightingColor => self.clone_lighting_color(),
                    LonghandId::OutlineColor => self.clone_outline_color(),
                    LonghandId::StopColor => self.clone_stop_color(),
                    LonghandId::TextDecorationColor => self.clone_text_decoration_color(),
                    LonghandId::TextEmphasisColor => self.clone_text_emphasis_color(),
                    LonghandId::WebkitTextFillColor => self.clone__webkit_text_fill_color(),
                    LonghandId::WebkitTextStrokeColor => self.clone__webkit_text_stroke_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    value.to_resolved_value(c).to_css(&mut dest)
                } else {
                    value.to_css(&mut dest)
                }
            }
        }
    }

    /// Returns the given longhand's resolved value as a property declaration.
    pub fn computed_or_resolved_declaration(
        &self,
        property_id: LonghandId,
        context: Option<&resolved::Context>,
    ) -> PropertyDeclaration {
        use crate::values::resolved::ToResolvedValue;
        use crate::values::computed::ToComputedValue;
        let physical_property_id = property_id.to_physical(self.writing_mode);
        match physical_property_id {
            
            LonghandId::AlignContent => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AlignContent => self.clone_align_content(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AlignContent(specified)
            }
            
            LonghandId::AlignItems => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AlignItems => self.clone_align_items(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AlignItems(specified)
            }
            
            LonghandId::AlignSelf => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AlignSelf => self.clone_align_self(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AlignSelf(specified)
            }
            
            LonghandId::AspectRatio => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AspectRatio => self.clone_aspect_ratio(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AspectRatio(specified)
            }
            
            LonghandId::BackfaceVisibility => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackfaceVisibility => self.clone_backface_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackfaceVisibility(specified)
            }
            
            LonghandId::BaselineSource => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BaselineSource => self.clone_baseline_source(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BaselineSource(specified)
            }
            
            LonghandId::BorderCollapse => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderCollapse => self.clone_border_collapse(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BorderCollapse(specified)
            }
            
            LonghandId::BorderImageRepeat => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderImageRepeat => self.clone_border_image_repeat(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BorderImageRepeat(specified)
            }
            
            LonghandId::BoxDecorationBreak => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BoxDecorationBreak => self.clone_box_decoration_break(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BoxDecorationBreak(specified)
            }
            
            LonghandId::BoxSizing => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BoxSizing => self.clone_box_sizing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BoxSizing(specified)
            }
            
            LonghandId::BreakInside => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BreakInside => self.clone_break_inside(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BreakInside(specified)
            }
            
            LonghandId::CaptionSide => {
                let mut computed_value = match physical_property_id {
                    LonghandId::CaptionSide => self.clone_caption_side(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::CaptionSide(specified)
            }
            
            LonghandId::Clear => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Clear => self.clone_clear(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Clear(specified)
            }
            
            LonghandId::ColorInterpolation => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColorInterpolation => self.clone_color_interpolation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ColorInterpolation(specified)
            }
            
            LonghandId::ColorInterpolationFilters => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColorInterpolationFilters => self.clone_color_interpolation_filters(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ColorInterpolationFilters(specified)
            }
            
            LonghandId::ColumnCount => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColumnCount => self.clone_column_count(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ColumnCount(specified)
            }
            
            LonghandId::ColumnFill => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColumnFill => self.clone_column_fill(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ColumnFill(specified)
            }
            
            LonghandId::ColumnSpan => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColumnSpan => self.clone_column_span(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ColumnSpan(specified)
            }
            
            LonghandId::Contain => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Contain => self.clone_contain(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Contain(specified)
            }
            
            LonghandId::ContainerType => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ContainerType => self.clone_container_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ContainerType(specified)
            }
            
            LonghandId::ContentVisibility => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ContentVisibility => self.clone_content_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ContentVisibility(specified)
            }
            
            LonghandId::Direction => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Direction => self.clone_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Direction(specified)
            }
            
            LonghandId::Display => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Display => self.clone_display(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Display(specified)
            }
            
            LonghandId::DominantBaseline => {
                let mut computed_value = match physical_property_id {
                    LonghandId::DominantBaseline => self.clone_dominant_baseline(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::DominantBaseline(specified)
            }
            
            LonghandId::EmptyCells => {
                let mut computed_value = match physical_property_id {
                    LonghandId::EmptyCells => self.clone_empty_cells(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::EmptyCells(specified)
            }
            
            LonghandId::FlexDirection => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FlexDirection => self.clone_flex_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FlexDirection(specified)
            }
            
            LonghandId::FlexWrap => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FlexWrap => self.clone_flex_wrap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FlexWrap(specified)
            }
            
            LonghandId::Float => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Float => self.clone_float(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Float(specified)
            }
            
            LonghandId::FontKerning => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontKerning => self.clone_font_kerning(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontKerning(specified)
            }
            
            LonghandId::FontLanguageOverride => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontLanguageOverride => self.clone_font_language_override(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontLanguageOverride(specified)
            }
            
            LonghandId::FontOpticalSizing => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontOpticalSizing => self.clone_font_optical_sizing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontOpticalSizing(specified)
            }
            
            LonghandId::FontSizeAdjust => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontSizeAdjust => self.clone_font_size_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontSizeAdjust(specified)
            }
            
            LonghandId::FontStretch => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontStretch => self.clone_font_stretch(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontStretch(specified)
            }
            
            LonghandId::FontStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontStyle => self.clone_font_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontStyle(specified)
            }
            
            LonghandId::FontVariantCaps => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariantCaps => self.clone_font_variant_caps(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariantCaps(specified)
            }
            
            LonghandId::FontVariantEastAsian => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariantEastAsian => self.clone_font_variant_east_asian(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariantEastAsian(specified)
            }
            
            LonghandId::FontVariantEmoji => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariantEmoji => self.clone_font_variant_emoji(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariantEmoji(specified)
            }
            
            LonghandId::FontVariantLigatures => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariantLigatures => self.clone_font_variant_ligatures(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariantLigatures(specified)
            }
            
            LonghandId::FontVariantNumeric => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariantNumeric => self.clone_font_variant_numeric(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariantNumeric(specified)
            }
            
            LonghandId::FontVariantPosition => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariantPosition => self.clone_font_variant_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariantPosition(specified)
            }
            
            LonghandId::FontWeight => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontWeight => self.clone_font_weight(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontWeight(specified)
            }
            
            LonghandId::ForcedColorAdjust => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ForcedColorAdjust => self.clone_forced_color_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ForcedColorAdjust(specified)
            }
            
            LonghandId::GridAutoFlow => {
                let mut computed_value = match physical_property_id {
                    LonghandId::GridAutoFlow => self.clone_grid_auto_flow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::GridAutoFlow(specified)
            }
            
            LonghandId::Hyphens => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Hyphens => self.clone_hyphens(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Hyphens(specified)
            }
            
            LonghandId::ImageOrientation => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ImageOrientation => self.clone_image_orientation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ImageOrientation(specified)
            }
            
            LonghandId::ImageRendering => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ImageRendering => self.clone_image_rendering(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ImageRendering(specified)
            }
            
            LonghandId::ImeMode => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ImeMode => self.clone_ime_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ImeMode(specified)
            }
            
            LonghandId::InitialLetter => {
                let mut computed_value = match physical_property_id {
                    LonghandId::InitialLetter => self.clone_initial_letter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::InitialLetter(specified)
            }
            
            LonghandId::InsetArea => {
                let mut computed_value = match physical_property_id {
                    LonghandId::InsetArea => self.clone_inset_area(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::InsetArea(specified)
            }
            
            LonghandId::Isolation => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Isolation => self.clone_isolation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Isolation(specified)
            }
            
            LonghandId::JustifyContent => {
                let mut computed_value = match physical_property_id {
                    LonghandId::JustifyContent => self.clone_justify_content(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::JustifyContent(specified)
            }
            
            LonghandId::JustifyItems => {
                let mut computed_value = match physical_property_id {
                    LonghandId::JustifyItems => self.clone_justify_items(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::JustifyItems(specified)
            }
            
            LonghandId::JustifySelf => {
                let mut computed_value = match physical_property_id {
                    LonghandId::JustifySelf => self.clone_justify_self(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::JustifySelf(specified)
            }
            
            LonghandId::LineBreak => {
                let mut computed_value = match physical_property_id {
                    LonghandId::LineBreak => self.clone_line_break(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::LineBreak(specified)
            }
            
            LonghandId::ListStylePosition => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ListStylePosition => self.clone_list_style_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ListStylePosition(specified)
            }
            
            LonghandId::MaskType => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskType => self.clone_mask_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskType(specified)
            }
            
            LonghandId::MasonryAutoFlow => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MasonryAutoFlow => self.clone_masonry_auto_flow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MasonryAutoFlow(specified)
            }
            
            LonghandId::MathDepth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MathDepth => self.clone_math_depth(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MathDepth(specified)
            }
            
            LonghandId::MathStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MathStyle => self.clone_math_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MathStyle(specified)
            }
            
            LonghandId::MixBlendMode => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MixBlendMode => self.clone_mix_blend_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MixBlendMode(specified)
            }
            
            LonghandId::MozBoxAlign => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozBoxAlign => self.clone__moz_box_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozBoxAlign(specified)
            }
            
            LonghandId::MozBoxCollapse => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozBoxCollapse => self.clone__moz_box_collapse(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozBoxCollapse(specified)
            }
            
            LonghandId::MozBoxDirection => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozBoxDirection => self.clone__moz_box_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozBoxDirection(specified)
            }
            
            LonghandId::MozBoxOrient => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozBoxOrient => self.clone__moz_box_orient(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozBoxOrient(specified)
            }
            
            LonghandId::MozBoxPack => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozBoxPack => self.clone__moz_box_pack(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozBoxPack(specified)
            }
            
            LonghandId::MozControlCharacterVisibility => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozControlCharacterVisibility => self.clone__moz_control_character_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozControlCharacterVisibility(specified)
            }
            
            LonghandId::MozFloatEdge => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozFloatEdge => self.clone__moz_float_edge(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozFloatEdge(specified)
            }
            
            LonghandId::MozInert => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozInert => self.clone__moz_inert(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozInert(specified)
            }
            
            LonghandId::MozMathVariant => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozMathVariant => self.clone__moz_math_variant(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozMathVariant(specified)
            }
            
            LonghandId::MozMinFontSizeRatio => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozMinFontSizeRatio => self.clone__moz_min_font_size_ratio(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozMinFontSizeRatio(specified)
            }
            
            LonghandId::MozOrient => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozOrient => self.clone__moz_orient(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozOrient(specified)
            }
            
            LonghandId::MozOsxFontSmoothing => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozOsxFontSmoothing => self.clone__moz_osx_font_smoothing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozOsxFontSmoothing(specified)
            }
            
            LonghandId::MozTextSizeAdjust => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozTextSizeAdjust => self.clone__moz_text_size_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozTextSizeAdjust(specified)
            }
            
            LonghandId::MozTheme => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozTheme => self.clone__moz_theme(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozTheme(specified)
            }
            
            LonghandId::MozTopLayer => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozTopLayer => self.clone__moz_top_layer(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozTopLayer(specified)
            }
            
            LonghandId::MozUserFocus => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozUserFocus => self.clone__moz_user_focus(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozUserFocus(specified)
            }
            
            LonghandId::MozUserInput => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozUserInput => self.clone__moz_user_input(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozUserInput(specified)
            }
            
            LonghandId::MozUserModify => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozUserModify => self.clone__moz_user_modify(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozUserModify(specified)
            }
            
            LonghandId::MozWindowDragging => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozWindowDragging => self.clone__moz_window_dragging(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozWindowDragging(specified)
            }
            
            LonghandId::MozWindowShadow => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozWindowShadow => self.clone__moz_window_shadow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozWindowShadow(specified)
            }
            
            LonghandId::ObjectFit => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ObjectFit => self.clone_object_fit(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ObjectFit(specified)
            }
            
            LonghandId::OffsetRotate => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OffsetRotate => self.clone_offset_rotate(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::OffsetRotate(specified)
            }
            
            LonghandId::OutlineStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OutlineStyle => self.clone_outline_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::OutlineStyle(specified)
            }
            
            LonghandId::OverflowAnchor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OverflowAnchor => self.clone_overflow_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::OverflowAnchor(specified)
            }
            
            LonghandId::OverflowWrap => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OverflowWrap => self.clone_overflow_wrap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::OverflowWrap(specified)
            }
            
            LonghandId::PageOrientation => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PageOrientation => self.clone_page_orientation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PageOrientation(specified)
            }
            
            LonghandId::PaintOrder => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PaintOrder => self.clone_paint_order(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PaintOrder(specified)
            }
            
            LonghandId::PointerEvents => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PointerEvents => self.clone_pointer_events(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PointerEvents(specified)
            }
            
            LonghandId::Position => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Position => self.clone_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Position(specified)
            }
            
            LonghandId::PositionTryOrder => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PositionTryOrder => self.clone_position_try_order(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PositionTryOrder(specified)
            }
            
            LonghandId::PositionVisibility => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PositionVisibility => self.clone_position_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PositionVisibility(specified)
            }
            
            LonghandId::PrintColorAdjust => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PrintColorAdjust => self.clone_print_color_adjust(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PrintColorAdjust(specified)
            }
            
            LonghandId::Resize => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Resize => self.clone_resize(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Resize(specified)
            }
            
            LonghandId::RubyAlign => {
                let mut computed_value = match physical_property_id {
                    LonghandId::RubyAlign => self.clone_ruby_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::RubyAlign(specified)
            }
            
            LonghandId::RubyPosition => {
                let mut computed_value = match physical_property_id {
                    LonghandId::RubyPosition => self.clone_ruby_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::RubyPosition(specified)
            }
            
            LonghandId::ScrollBehavior => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollBehavior => self.clone_scroll_behavior(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollBehavior(specified)
            }
            
            LonghandId::ScrollSnapAlign => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollSnapAlign => self.clone_scroll_snap_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollSnapAlign(specified)
            }
            
            LonghandId::ScrollSnapStop => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollSnapStop => self.clone_scroll_snap_stop(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollSnapStop(specified)
            }
            
            LonghandId::ScrollSnapType => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollSnapType => self.clone_scroll_snap_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollSnapType(specified)
            }
            
            LonghandId::ScrollbarGutter => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollbarGutter => self.clone_scrollbar_gutter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollbarGutter(specified)
            }
            
            LonghandId::ScrollbarWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollbarWidth => self.clone_scrollbar_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollbarWidth(specified)
            }
            
            LonghandId::ShapeRendering => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ShapeRendering => self.clone_shape_rendering(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ShapeRendering(specified)
            }
            
            LonghandId::StrokeLinecap => {
                let mut computed_value = match physical_property_id {
                    LonghandId::StrokeLinecap => self.clone_stroke_linecap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::StrokeLinecap(specified)
            }
            
            LonghandId::StrokeLinejoin => {
                let mut computed_value = match physical_property_id {
                    LonghandId::StrokeLinejoin => self.clone_stroke_linejoin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::StrokeLinejoin(specified)
            }
            
            LonghandId::TableLayout => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TableLayout => self.clone_table_layout(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TableLayout(specified)
            }
            
            LonghandId::TextAlign => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextAlign => self.clone_text_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextAlign(specified)
            }
            
            LonghandId::TextAlignLast => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextAlignLast => self.clone_text_align_last(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextAlignLast(specified)
            }
            
            LonghandId::TextAnchor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextAnchor => self.clone_text_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextAnchor(specified)
            }
            
            LonghandId::TextCombineUpright => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextCombineUpright => self.clone_text_combine_upright(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextCombineUpright(specified)
            }
            
            LonghandId::TextDecorationLine => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextDecorationLine => self.clone_text_decoration_line(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextDecorationLine(specified)
            }
            
            LonghandId::TextDecorationSkipInk => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextDecorationSkipInk => self.clone_text_decoration_skip_ink(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextDecorationSkipInk(specified)
            }
            
            LonghandId::TextDecorationStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextDecorationStyle => self.clone_text_decoration_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextDecorationStyle(specified)
            }
            
            LonghandId::TextEmphasisPosition => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextEmphasisPosition => self.clone_text_emphasis_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextEmphasisPosition(specified)
            }
            
            LonghandId::TextJustify => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextJustify => self.clone_text_justify(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextJustify(specified)
            }
            
            LonghandId::TextOrientation => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextOrientation => self.clone_text_orientation(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextOrientation(specified)
            }
            
            LonghandId::TextRendering => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextRendering => self.clone_text_rendering(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextRendering(specified)
            }
            
            LonghandId::TextTransform => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextTransform => self.clone_text_transform(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextTransform(specified)
            }
            
            LonghandId::TextUnderlinePosition => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextUnderlinePosition => self.clone_text_underline_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextUnderlinePosition(specified)
            }
            
            LonghandId::TextWrapMode => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextWrapMode => self.clone_text_wrap_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextWrapMode(specified)
            }
            
            LonghandId::TextWrapStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextWrapStyle => self.clone_text_wrap_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextWrapStyle(specified)
            }
            
            LonghandId::TouchAction => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TouchAction => self.clone_touch_action(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TouchAction(specified)
            }
            
            LonghandId::TransformBox => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TransformBox => self.clone_transform_box(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TransformBox(specified)
            }
            
            LonghandId::TransformStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TransformStyle => self.clone_transform_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TransformStyle(specified)
            }
            
            LonghandId::UnicodeBidi => {
                let mut computed_value = match physical_property_id {
                    LonghandId::UnicodeBidi => self.clone_unicode_bidi(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::UnicodeBidi(specified)
            }
            
            LonghandId::UserSelect => {
                let mut computed_value = match physical_property_id {
                    LonghandId::UserSelect => self.clone_user_select(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::UserSelect(specified)
            }
            
            LonghandId::VectorEffect => {
                let mut computed_value = match physical_property_id {
                    LonghandId::VectorEffect => self.clone_vector_effect(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::VectorEffect(specified)
            }
            
            LonghandId::Visibility => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Visibility => self.clone_visibility(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Visibility(specified)
            }
            
            LonghandId::WebkitLineClamp => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WebkitLineClamp => self.clone__webkit_line_clamp(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WebkitLineClamp(specified)
            }
            
            LonghandId::WebkitTextSecurity => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WebkitTextSecurity => self.clone__webkit_text_security(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WebkitTextSecurity(specified)
            }
            
            LonghandId::WhiteSpaceCollapse => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WhiteSpaceCollapse => self.clone_white_space_collapse(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WhiteSpaceCollapse(specified)
            }
            
            LonghandId::WordBreak => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WordBreak => self.clone_word_break(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WordBreak(specified)
            }
            
            LonghandId::WritingMode => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WritingMode => self.clone_writing_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WritingMode(specified)
            }
            
            LonghandId::XTextScale => {
                let mut computed_value = match physical_property_id {
                    LonghandId::XTextScale => self.clone__x_text_scale(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::XTextScale(specified)
            }
            
            LonghandId::ZIndex => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ZIndex => self.clone_z_index(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ZIndex(specified)
            }
            
            LonghandId::Zoom => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Zoom => self.clone_zoom(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Zoom(specified)
            }
            
            LonghandId::Appearance |
LonghandId::MozDefaultAppearance => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Appearance => self.clone_appearance(),
                    LonghandId::MozDefaultAppearance => self.clone__moz_default_appearance(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Appearance>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::MozForceBrokenImageIcon |
LonghandId::MozSubtreeHiddenOnlyVisually => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozForceBrokenImageIcon => self.clone__moz_force_broken_image_icon(),
                    LonghandId::MozSubtreeHiddenOnlyVisually => self.clone__moz_subtree_hidden_only_visually(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BoolInteger>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::BreakAfter |
LonghandId::BreakBefore => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BreakAfter => self.clone_break_after(),
                    LonghandId::BreakBefore => self.clone_break_before(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BreakBetween>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::ClipRule |
LonghandId::FillRule => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ClipRule => self.clone_clip_rule(),
                    LonghandId::FillRule => self.clone_fill_rule(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::FillRule>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::OverflowClipBoxBlock |
LonghandId::OverflowClipBoxInline => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OverflowClipBoxBlock => self.clone_overflow_clip_box_block(),
                    LonghandId::OverflowClipBoxInline => self.clone_overflow_clip_box_inline(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::OverflowClipBox>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::FillOpacity |
LonghandId::StrokeOpacity => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FillOpacity => self.clone_fill_opacity(),
                    LonghandId::StrokeOpacity => self.clone_stroke_opacity(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::SVGOpacity>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::MozBoxOrdinalGroup |
LonghandId::Order |
LonghandId::XSpan => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozBoxOrdinalGroup => self.clone__moz_box_ordinal_group(),
                    LonghandId::Order => self.clone_order(),
                    LonghandId::XSpan => self.clone__x_span(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Integer>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::FontSynthesisPosition |
LonghandId::FontSynthesisSmallCaps |
LonghandId::FontSynthesisStyle |
LonghandId::FontSynthesisWeight => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontSynthesisPosition => self.clone_font_synthesis_position(),
                    LonghandId::FontSynthesisSmallCaps => self.clone_font_synthesis_small_caps(),
                    LonghandId::FontSynthesisStyle => self.clone_font_synthesis_style(),
                    LonghandId::FontSynthesisWeight => self.clone_font_synthesis_weight(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::FontSynthesis>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::FlexGrow |
LonghandId::FlexShrink |
LonghandId::MozBoxFlex |
LonghandId::StrokeMiterlimit => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FlexGrow => self.clone_flex_grow(),
                    LonghandId::FlexShrink => self.clone_flex_shrink(),
                    LonghandId::MozBoxFlex => self.clone__moz_box_flex(),
                    LonghandId::StrokeMiterlimit => self.clone_stroke_miterlimit(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeNumber>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::OverflowBlock |
LonghandId::OverflowInline |
LonghandId::OverflowX |
LonghandId::OverflowY => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OverflowX => self.clone_overflow_x(),
                    LonghandId::OverflowY => self.clone_overflow_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Overflow>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::OverscrollBehaviorBlock |
LonghandId::OverscrollBehaviorInline |
LonghandId::OverscrollBehaviorX |
LonghandId::OverscrollBehaviorY => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OverscrollBehaviorX => self.clone_overscroll_behavior_x(),
                    LonghandId::OverscrollBehaviorY => self.clone_overscroll_behavior_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::OverscrollBehavior>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::FloodOpacity |
LonghandId::MozWindowOpacity |
LonghandId::Opacity |
LonghandId::ShapeImageThreshold |
LonghandId::StopOpacity => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FloodOpacity => self.clone_flood_opacity(),
                    LonghandId::MozWindowOpacity => self.clone__moz_window_opacity(),
                    LonghandId::Opacity => self.clone_opacity(),
                    LonghandId::ShapeImageThreshold => self.clone_shape_image_threshold(),
                    LonghandId::StopOpacity => self.clone_stop_opacity(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Opacity>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::BorderBlockEndStyle |
LonghandId::BorderBlockStartStyle |
LonghandId::BorderBottomStyle |
LonghandId::BorderInlineEndStyle |
LonghandId::BorderInlineStartStyle |
LonghandId::BorderLeftStyle |
LonghandId::BorderRightStyle |
LonghandId::BorderTopStyle |
LonghandId::ColumnRuleStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderBottomStyle => self.clone_border_bottom_style(),
                    LonghandId::BorderLeftStyle => self.clone_border_left_style(),
                    LonghandId::BorderRightStyle => self.clone_border_right_style(),
                    LonghandId::BorderTopStyle => self.clone_border_top_style(),
                    LonghandId::ColumnRuleStyle => self.clone_column_rule_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BorderStyle>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::AccentColor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AccentColor => self.clone_accent_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AccentColor(specified)
            }
            
            LonghandId::AnchorName => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnchorName => self.clone_anchor_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnchorName(specified)
            }
            
            LonghandId::AnchorScope => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnchorScope => self.clone_anchor_scope(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnchorScope(specified)
            }
            
            LonghandId::AnimationComposition => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationComposition => self.clone_animation_composition(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationComposition(specified)
            }
            
            LonghandId::AnimationDelay => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationDelay => self.clone_animation_delay(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationDelay(specified)
            }
            
            LonghandId::AnimationDirection => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationDirection => self.clone_animation_direction(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationDirection(specified)
            }
            
            LonghandId::AnimationDuration => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationDuration => self.clone_animation_duration(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationDuration(specified)
            }
            
            LonghandId::AnimationFillMode => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationFillMode => self.clone_animation_fill_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationFillMode(specified)
            }
            
            LonghandId::AnimationIterationCount => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationIterationCount => self.clone_animation_iteration_count(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationIterationCount(specified)
            }
            
            LonghandId::AnimationName => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationName => self.clone_animation_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationName(specified)
            }
            
            LonghandId::AnimationPlayState => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationPlayState => self.clone_animation_play_state(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationPlayState(specified)
            }
            
            LonghandId::AnimationTimeline => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationTimeline => self.clone_animation_timeline(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationTimeline(specified)
            }
            
            LonghandId::AnimationTimingFunction => {
                let mut computed_value = match physical_property_id {
                    LonghandId::AnimationTimingFunction => self.clone_animation_timing_function(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::AnimationTimingFunction(specified)
            }
            
            LonghandId::BackdropFilter => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackdropFilter => self.clone_backdrop_filter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackdropFilter(specified)
            }
            
            LonghandId::BackgroundAttachment => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundAttachment => self.clone_background_attachment(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundAttachment(specified)
            }
            
            LonghandId::BackgroundBlendMode => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundBlendMode => self.clone_background_blend_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundBlendMode(specified)
            }
            
            LonghandId::BackgroundClip => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundClip => self.clone_background_clip(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundClip(specified)
            }
            
            LonghandId::BackgroundImage => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundImage => self.clone_background_image(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundImage(specified)
            }
            
            LonghandId::BackgroundOrigin => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundOrigin => self.clone_background_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundOrigin(specified)
            }
            
            LonghandId::BackgroundPositionX => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundPositionX => self.clone_background_position_x(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundPositionX(specified)
            }
            
            LonghandId::BackgroundPositionY => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundPositionY => self.clone_background_position_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundPositionY(specified)
            }
            
            LonghandId::BackgroundRepeat => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundRepeat => self.clone_background_repeat(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundRepeat(specified)
            }
            
            LonghandId::BackgroundSize => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundSize => self.clone_background_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BackgroundSize(specified)
            }
            
            LonghandId::BorderImageOutset => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderImageOutset => self.clone_border_image_outset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::BorderImageOutset(specified)
            }
            
            LonghandId::BorderImageSlice => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderImageSlice => self.clone_border_image_slice(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::BorderImageSlice(specified)
            }
            
            LonghandId::BorderImageWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderImageWidth => self.clone_border_image_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::BorderImageWidth(specified)
            }
            
            LonghandId::BorderSpacing => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderSpacing => self.clone_border_spacing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::BorderSpacing(specified)
            }
            
            LonghandId::BoxShadow => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BoxShadow => self.clone_box_shadow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::BoxShadow(specified)
            }
            
            LonghandId::CaretColor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::CaretColor => self.clone_caret_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::CaretColor(specified)
            }
            
            LonghandId::Clip => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Clip => self.clone_clip(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::Clip(specified)
            }
            
            LonghandId::ClipPath => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ClipPath => self.clone_clip_path(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ClipPath(specified)
            }
            
            LonghandId::Color => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Color => self.clone_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Color(specified)
            }
            
            LonghandId::ColorScheme => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColorScheme => self.clone_color_scheme(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ColorScheme(specified)
            }
            
            LonghandId::ColumnWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColumnWidth => self.clone_column_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ColumnWidth(specified)
            }
            
            LonghandId::ContainerName => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ContainerName => self.clone_container_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ContainerName(specified)
            }
            
            LonghandId::Content => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Content => self.clone_content(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Content(specified)
            }
            
            LonghandId::CounterIncrement => {
                let mut computed_value = match physical_property_id {
                    LonghandId::CounterIncrement => self.clone_counter_increment(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::CounterIncrement(specified)
            }
            
            LonghandId::CounterReset => {
                let mut computed_value = match physical_property_id {
                    LonghandId::CounterReset => self.clone_counter_reset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::CounterReset(specified)
            }
            
            LonghandId::CounterSet => {
                let mut computed_value = match physical_property_id {
                    LonghandId::CounterSet => self.clone_counter_set(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::CounterSet(specified)
            }
            
            LonghandId::Cursor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Cursor => self.clone_cursor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Cursor(specified)
            }
            
            LonghandId::D => {
                let mut computed_value = match physical_property_id {
                    LonghandId::D => self.clone_d(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::D(specified)
            }
            
            LonghandId::Filter => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Filter => self.clone_filter(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Filter(specified)
            }
            
            LonghandId::FlexBasis => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FlexBasis => self.clone_flex_basis(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::FlexBasis(specified)
            }
            
            LonghandId::FontFamily => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontFamily => self.clone_font_family(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontFamily(specified)
            }
            
            LonghandId::FontFeatureSettings => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontFeatureSettings => self.clone_font_feature_settings(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontFeatureSettings(specified)
            }
            
            LonghandId::FontPalette => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontPalette => self.clone_font_palette(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontPalette(specified)
            }
            
            LonghandId::FontSize => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontSize => self.clone_font_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontSize(specified)
            }
            
            LonghandId::FontVariantAlternates => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariantAlternates => self.clone_font_variant_alternates(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariantAlternates(specified)
            }
            
            LonghandId::FontVariationSettings => {
                let mut computed_value = match physical_property_id {
                    LonghandId::FontVariationSettings => self.clone_font_variation_settings(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::FontVariationSettings(specified)
            }
            
            LonghandId::GridTemplateAreas => {
                let mut computed_value = match physical_property_id {
                    LonghandId::GridTemplateAreas => self.clone_grid_template_areas(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::GridTemplateAreas(specified)
            }
            
            LonghandId::HyphenateCharacter => {
                let mut computed_value = match physical_property_id {
                    LonghandId::HyphenateCharacter => self.clone_hyphenate_character(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::HyphenateCharacter(specified)
            }
            
            LonghandId::LetterSpacing => {
                let mut computed_value = match physical_property_id {
                    LonghandId::LetterSpacing => self.clone_letter_spacing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::LetterSpacing(specified)
            }
            
            LonghandId::LineHeight => {
                let mut computed_value = match physical_property_id {
                    LonghandId::LineHeight => self.clone_line_height(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::LineHeight(specified)
            }
            
            LonghandId::ListStyleType => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ListStyleType => self.clone_list_style_type(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ListStyleType(specified)
            }
            
            LonghandId::MaskClip => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskClip => self.clone_mask_clip(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskClip(specified)
            }
            
            LonghandId::MaskComposite => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskComposite => self.clone_mask_composite(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskComposite(specified)
            }
            
            LonghandId::MaskImage => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskImage => self.clone_mask_image(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskImage(specified)
            }
            
            LonghandId::MaskMode => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskMode => self.clone_mask_mode(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskMode(specified)
            }
            
            LonghandId::MaskOrigin => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskOrigin => self.clone_mask_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskOrigin(specified)
            }
            
            LonghandId::MaskPositionX => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskPositionX => self.clone_mask_position_x(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskPositionX(specified)
            }
            
            LonghandId::MaskPositionY => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskPositionY => self.clone_mask_position_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskPositionY(specified)
            }
            
            LonghandId::MaskRepeat => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskRepeat => self.clone_mask_repeat(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskRepeat(specified)
            }
            
            LonghandId::MaskSize => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaskSize => self.clone_mask_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MaskSize(specified)
            }
            
            LonghandId::MozContextProperties => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozContextProperties => self.clone__moz_context_properties(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::MozContextProperties(specified)
            }
            
            LonghandId::OffsetAnchor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OffsetAnchor => self.clone_offset_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::OffsetAnchor(specified)
            }
            
            LonghandId::OffsetPath => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OffsetPath => self.clone_offset_path(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::OffsetPath(specified)
            }
            
            LonghandId::OffsetPosition => {
                let mut computed_value = match physical_property_id {
                    LonghandId::OffsetPosition => self.clone_offset_position(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::OffsetPosition(specified)
            }
            
            LonghandId::Page => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Page => self.clone_page(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Page(specified)
            }
            
            LonghandId::Perspective => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Perspective => self.clone_perspective(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Perspective(specified)
            }
            
            LonghandId::PositionAnchor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PositionAnchor => self.clone_position_anchor(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PositionAnchor(specified)
            }
            
            LonghandId::PositionTryOptions => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PositionTryOptions => self.clone_position_try_options(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::PositionTryOptions(specified)
            }
            
            LonghandId::Quotes => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Quotes => self.clone_quotes(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::Quotes(specified)
            }
            
            LonghandId::Rotate => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Rotate => self.clone_rotate(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::Rotate(specified)
            }
            
            LonghandId::Scale => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Scale => self.clone_scale(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::Scale(specified)
            }
            
            LonghandId::ScrollTimelineAxis => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollTimelineAxis => self.clone_scroll_timeline_axis(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollTimelineAxis(specified)
            }
            
            LonghandId::ScrollTimelineName => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollTimelineName => self.clone_scroll_timeline_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ScrollTimelineName(specified)
            }
            
            LonghandId::ScrollbarColor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ScrollbarColor => self.clone_scrollbar_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::ScrollbarColor(specified)
            }
            
            LonghandId::ShapeOutside => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ShapeOutside => self.clone_shape_outside(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ShapeOutside(specified)
            }
            
            LonghandId::Size => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Size => self.clone_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::Size(specified)
            }
            
            LonghandId::StrokeDasharray => {
                let mut computed_value = match physical_property_id {
                    LonghandId::StrokeDasharray => self.clone_stroke_dasharray(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::StrokeDasharray(specified)
            }
            
            LonghandId::StrokeDashoffset => {
                let mut computed_value = match physical_property_id {
                    LonghandId::StrokeDashoffset => self.clone_stroke_dashoffset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::StrokeDashoffset(specified)
            }
            
            LonghandId::StrokeWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::StrokeWidth => self.clone_stroke_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::StrokeWidth(specified)
            }
            
            LonghandId::TabSize => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TabSize => self.clone_tab_size(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TabSize(specified)
            }
            
            LonghandId::TextDecorationThickness => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextDecorationThickness => self.clone_text_decoration_thickness(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextDecorationThickness(specified)
            }
            
            LonghandId::TextEmphasisStyle => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextEmphasisStyle => self.clone_text_emphasis_style(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextEmphasisStyle(specified)
            }
            
            LonghandId::TextIndent => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextIndent => self.clone_text_indent(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextIndent(specified)
            }
            
            LonghandId::TextOverflow => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextOverflow => self.clone_text_overflow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::TextOverflow(specified)
            }
            
            LonghandId::TextShadow => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TextShadow => self.clone_text_shadow(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TextShadow(specified)
            }
            
            LonghandId::TransitionBehavior => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TransitionBehavior => self.clone_transition_behavior(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TransitionBehavior(specified)
            }
            
            LonghandId::TransitionDelay => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TransitionDelay => self.clone_transition_delay(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TransitionDelay(specified)
            }
            
            LonghandId::TransitionDuration => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TransitionDuration => self.clone_transition_duration(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TransitionDuration(specified)
            }
            
            LonghandId::TransitionProperty => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TransitionProperty => self.clone_transition_property(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TransitionProperty(specified)
            }
            
            LonghandId::TransitionTimingFunction => {
                let mut computed_value = match physical_property_id {
                    LonghandId::TransitionTimingFunction => self.clone_transition_timing_function(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::TransitionTimingFunction(specified)
            }
            
            LonghandId::Translate => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Translate => self.clone_translate(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                PropertyDeclaration::Translate(specified)
            }
            
            LonghandId::VerticalAlign => {
                let mut computed_value = match physical_property_id {
                    LonghandId::VerticalAlign => self.clone_vertical_align(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::VerticalAlign(specified)
            }
            
            LonghandId::ViewTimelineAxis => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ViewTimelineAxis => self.clone_view_timeline_axis(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ViewTimelineAxis(specified)
            }
            
            LonghandId::ViewTimelineInset => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ViewTimelineInset => self.clone_view_timeline_inset(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ViewTimelineInset(specified)
            }
            
            LonghandId::ViewTimelineName => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ViewTimelineName => self.clone_view_timeline_name(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::ViewTimelineName(specified)
            }
            
            LonghandId::WebkitTextStrokeWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WebkitTextStrokeWidth => self.clone__webkit_text_stroke_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WebkitTextStrokeWidth(specified)
            }
            
            LonghandId::WillChange => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WillChange => self.clone_will_change(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WillChange(specified)
            }
            
            LonghandId::WordSpacing => {
                let mut computed_value = match physical_property_id {
                    LonghandId::WordSpacing => self.clone_word_spacing(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::WordSpacing(specified)
            }
            
            LonghandId::XLang => {
                let mut computed_value = match physical_property_id {
                    LonghandId::XLang => self.clone__x_lang(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                PropertyDeclaration::XLang(specified)
            }
            
            LonghandId::ObjectPosition |
LonghandId::PerspectiveOrigin => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ObjectPosition => self.clone_object_position(),
                    LonghandId::PerspectiveOrigin => self.clone_perspective_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::Position>>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::Fill |
LonghandId::Stroke => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Fill => self.clone_fill(),
                    LonghandId::Stroke => self.clone_stroke(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::SVGPaint>>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::MozWindowTransformOrigin |
LonghandId::TransformOrigin => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozWindowTransformOrigin => self.clone__moz_window_transform_origin(),
                    LonghandId::TransformOrigin => self.clone_transform_origin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::TransformOrigin>>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::GridTemplateColumns |
LonghandId::GridTemplateRows => {
                let mut computed_value = match physical_property_id {
                    LonghandId::GridTemplateColumns => self.clone_grid_template_columns(),
                    LonghandId::GridTemplateRows => self.clone_grid_template_rows(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::GridTemplateComponent>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::BorderImageSource |
LonghandId::ListStyleImage => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderImageSource => self.clone_border_image_source(),
                    LonghandId::ListStyleImage => self.clone_list_style_image(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Image>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::GridAutoColumns |
LonghandId::GridAutoRows => {
                let mut computed_value = match physical_property_id {
                    LonghandId::GridAutoColumns => self.clone_grid_auto_columns(),
                    LonghandId::GridAutoRows => self.clone_grid_auto_rows(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::ImplicitGridTracks>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::MozWindowTransform |
LonghandId::Transform => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozWindowTransform => self.clone__moz_window_transform(),
                    LonghandId::Transform => self.clone_transform(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Transform>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::ColumnGap |
LonghandId::RowGap => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ColumnGap => self.clone_column_gap(),
                    LonghandId::RowGap => self.clone_row_gap(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::length::NonNegativeLengthPercentageOrNormal>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::MarkerEnd |
LonghandId::MarkerMid |
LonghandId::MarkerStart => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MarkerEnd => self.clone_marker_end(),
                    LonghandId::MarkerMid => self.clone_marker_mid(),
                    LonghandId::MarkerStart => self.clone_marker_start(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::url::UrlOrNone>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::ContainIntrinsicBlockSize |
LonghandId::ContainIntrinsicHeight |
LonghandId::ContainIntrinsicInlineSize |
LonghandId::ContainIntrinsicWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::ContainIntrinsicHeight => self.clone_contain_intrinsic_height(),
                    LonghandId::ContainIntrinsicWidth => self.clone_contain_intrinsic_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::ContainIntrinsicSize>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::GridColumnEnd |
LonghandId::GridColumnStart |
LonghandId::GridRowEnd |
LonghandId::GridRowStart => {
                let mut computed_value = match physical_property_id {
                    LonghandId::GridColumnEnd => self.clone_grid_column_end(),
                    LonghandId::GridColumnStart => self.clone_grid_column_start(),
                    LonghandId::GridRowEnd => self.clone_grid_row_end(),
                    LonghandId::GridRowStart => self.clone_grid_row_start(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::GridLine>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::MaxBlockSize |
LonghandId::MaxHeight |
LonghandId::MaxInlineSize |
LonghandId::MaxWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MaxHeight => self.clone_max_height(),
                    LonghandId::MaxWidth => self.clone_max_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::MaxSize>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::Cx |
LonghandId::Cy |
LonghandId::OffsetDistance |
LonghandId::X |
LonghandId::Y => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Cx => self.clone_cx(),
                    LonghandId::Cy => self.clone_cy(),
                    LonghandId::OffsetDistance => self.clone_offset_distance(),
                    LonghandId::X => self.clone_x(),
                    LonghandId::Y => self.clone_y(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::BorderBottomLeftRadius |
LonghandId::BorderBottomRightRadius |
LonghandId::BorderEndEndRadius |
LonghandId::BorderEndStartRadius |
LonghandId::BorderStartEndRadius |
LonghandId::BorderStartStartRadius |
LonghandId::BorderTopLeftRadius |
LonghandId::BorderTopRightRadius => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderBottomLeftRadius => self.clone_border_bottom_left_radius(),
                    LonghandId::BorderBottomRightRadius => self.clone_border_bottom_right_radius(),
                    LonghandId::BorderTopLeftRadius => self.clone_border_top_left_radius(),
                    LonghandId::BorderTopRightRadius => self.clone_border_top_right_radius(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                let specified = Box::new(specified);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<Box<crate::values::specified::BorderCornerRadius>>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::BlockSize |
LonghandId::Height |
LonghandId::InlineSize |
LonghandId::MinBlockSize |
LonghandId::MinHeight |
LonghandId::MinInlineSize |
LonghandId::MinWidth |
LonghandId::Width => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Height => self.clone_height(),
                    LonghandId::MinHeight => self.clone_min_height(),
                    LonghandId::MinWidth => self.clone_min_width(),
                    LonghandId::Width => self.clone_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Size>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::BorderBlockEndWidth |
LonghandId::BorderBlockStartWidth |
LonghandId::BorderBottomWidth |
LonghandId::BorderInlineEndWidth |
LonghandId::BorderInlineStartWidth |
LonghandId::BorderLeftWidth |
LonghandId::BorderRightWidth |
LonghandId::BorderTopWidth |
LonghandId::ColumnRuleWidth |
LonghandId::OutlineWidth => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BorderBottomWidth => self.clone_border_bottom_width(),
                    LonghandId::BorderLeftWidth => self.clone_border_left_width(),
                    LonghandId::BorderRightWidth => self.clone_border_right_width(),
                    LonghandId::BorderTopWidth => self.clone_border_top_width(),
                    LonghandId::ColumnRuleWidth => self.clone_column_rule_width(),
                    LonghandId::OutlineWidth => self.clone_outline_width(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::BorderSideWidth>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::PaddingBlockEnd |
LonghandId::PaddingBlockStart |
LonghandId::PaddingBottom |
LonghandId::PaddingInlineEnd |
LonghandId::PaddingInlineStart |
LonghandId::PaddingLeft |
LonghandId::PaddingRight |
LonghandId::PaddingTop |
LonghandId::R |
LonghandId::ShapeMargin => {
                let mut computed_value = match physical_property_id {
                    LonghandId::PaddingBottom => self.clone_padding_bottom(),
                    LonghandId::PaddingLeft => self.clone_padding_left(),
                    LonghandId::PaddingRight => self.clone_padding_right(),
                    LonghandId::PaddingTop => self.clone_padding_top(),
                    LonghandId::R => self.clone_r(),
                    LonghandId::ShapeMargin => self.clone_shape_margin(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentage>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::Rx |
LonghandId::Ry |
LonghandId::ScrollPaddingBlockEnd |
LonghandId::ScrollPaddingBlockStart |
LonghandId::ScrollPaddingBottom |
LonghandId::ScrollPaddingInlineEnd |
LonghandId::ScrollPaddingInlineStart |
LonghandId::ScrollPaddingLeft |
LonghandId::ScrollPaddingRight |
LonghandId::ScrollPaddingTop => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Rx => self.clone_rx(),
                    LonghandId::Ry => self.clone_ry(),
                    LonghandId::ScrollPaddingBottom => self.clone_scroll_padding_bottom(),
                    LonghandId::ScrollPaddingLeft => self.clone_scroll_padding_left(),
                    LonghandId::ScrollPaddingRight => self.clone_scroll_padding_right(),
                    LonghandId::ScrollPaddingTop => self.clone_scroll_padding_top(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::NonNegativeLengthPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::MozWindowInputRegionMargin |
LonghandId::OutlineOffset |
LonghandId::OverflowClipMargin |
LonghandId::ScrollMarginBlockEnd |
LonghandId::ScrollMarginBlockStart |
LonghandId::ScrollMarginBottom |
LonghandId::ScrollMarginInlineEnd |
LonghandId::ScrollMarginInlineStart |
LonghandId::ScrollMarginLeft |
LonghandId::ScrollMarginRight |
LonghandId::ScrollMarginTop => {
                let mut computed_value = match physical_property_id {
                    LonghandId::MozWindowInputRegionMargin => self.clone__moz_window_input_region_margin(),
                    LonghandId::OutlineOffset => self.clone_outline_offset(),
                    LonghandId::OverflowClipMargin => self.clone_overflow_clip_margin(),
                    LonghandId::ScrollMarginBottom => self.clone_scroll_margin_bottom(),
                    LonghandId::ScrollMarginLeft => self.clone_scroll_margin_left(),
                    LonghandId::ScrollMarginRight => self.clone_scroll_margin_right(),
                    LonghandId::ScrollMarginTop => self.clone_scroll_margin_top(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Length>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::Bottom |
LonghandId::InsetBlockEnd |
LonghandId::InsetBlockStart |
LonghandId::InsetInlineEnd |
LonghandId::InsetInlineStart |
LonghandId::Left |
LonghandId::MarginBlockEnd |
LonghandId::MarginBlockStart |
LonghandId::MarginBottom |
LonghandId::MarginInlineEnd |
LonghandId::MarginInlineStart |
LonghandId::MarginLeft |
LonghandId::MarginRight |
LonghandId::MarginTop |
LonghandId::Right |
LonghandId::TextUnderlineOffset |
LonghandId::Top => {
                let mut computed_value = match physical_property_id {
                    LonghandId::Bottom => self.clone_bottom(),
                    LonghandId::Left => self.clone_left(),
                    LonghandId::MarginBottom => self.clone_margin_bottom(),
                    LonghandId::MarginLeft => self.clone_margin_left(),
                    LonghandId::MarginRight => self.clone_margin_right(),
                    LonghandId::MarginTop => self.clone_margin_top(),
                    LonghandId::Right => self.clone_right(),
                    LonghandId::TextUnderlineOffset => self.clone_text_underline_offset(),
                    LonghandId::Top => self.clone_top(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::LengthPercentageOrAuto>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
            
            LonghandId::BackgroundColor |
LonghandId::BorderBlockEndColor |
LonghandId::BorderBlockStartColor |
LonghandId::BorderBottomColor |
LonghandId::BorderInlineEndColor |
LonghandId::BorderInlineStartColor |
LonghandId::BorderLeftColor |
LonghandId::BorderRightColor |
LonghandId::BorderTopColor |
LonghandId::ColumnRuleColor |
LonghandId::FloodColor |
LonghandId::LightingColor |
LonghandId::OutlineColor |
LonghandId::StopColor |
LonghandId::TextDecorationColor |
LonghandId::TextEmphasisColor |
LonghandId::WebkitTextFillColor |
LonghandId::WebkitTextStrokeColor => {
                let mut computed_value = match physical_property_id {
                    LonghandId::BackgroundColor => self.clone_background_color(),
                    LonghandId::BorderBottomColor => self.clone_border_bottom_color(),
                    LonghandId::BorderLeftColor => self.clone_border_left_color(),
                    LonghandId::BorderRightColor => self.clone_border_right_color(),
                    LonghandId::BorderTopColor => self.clone_border_top_color(),
                    LonghandId::ColumnRuleColor => self.clone_column_rule_color(),
                    LonghandId::FloodColor => self.clone_flood_color(),
                    LonghandId::LightingColor => self.clone_lighting_color(),
                    LonghandId::OutlineColor => self.clone_outline_color(),
                    LonghandId::StopColor => self.clone_stop_color(),
                    LonghandId::TextDecorationColor => self.clone_text_decoration_color(),
                    LonghandId::TextEmphasisColor => self.clone_text_emphasis_color(),
                    LonghandId::WebkitTextFillColor => self.clone__webkit_text_fill_color(),
                    LonghandId::WebkitTextStrokeColor => self.clone__webkit_text_stroke_color(),
                    _ => unsafe { debug_unreachable!() },
                };
                if let Some(c) = context {
                    let resolved = computed_value.to_resolved_value(c);
                    computed_value = ToResolvedValue::from_resolved_value(resolved);
                }
                let specified = ToComputedValue::from_computed_value(&computed_value);
                unsafe {
                    let mut out = mem::MaybeUninit::uninit();
                    ptr::write(
                        out.as_mut_ptr() as *mut PropertyDeclarationVariantRepr<crate::values::specified::Color>,
                        PropertyDeclarationVariantRepr {
                            tag: property_id as u16,
                            value: specified,
                        },
                    );
                    out.assume_init()
                }
            }
        }
    }

    /// Resolves the currentColor keyword.
    ///
    /// Any color value from computed values (except for the 'color' property
    /// itself) should go through this method.
    ///
    /// Usage example:
    /// let top_color =
    ///   style.resolve_color(style.get_border().clone_border_top_color());
    #[inline]
    pub fn resolve_color(&self, color: computed::Color) -> crate::color::AbsoluteColor {
        let current_color = self.get_inherited_text().clone_color();
        color.resolve_to_absolute(&current_color)
    }

    /// Returns which longhand properties have different values in the two
    /// ComputedValues.
    #[cfg(feature = "gecko_debug")]
    pub fn differing_properties(&self, other: &ComputedValues) -> LonghandIdSet {
        let mut set = LonghandIdSet::new();
        if self.clone_align_content() != other.clone_align_content() {
            set.insert(LonghandId::AlignContent);
        }
        if self.clone_align_items() != other.clone_align_items() {
            set.insert(LonghandId::AlignItems);
        }
        if self.clone_align_self() != other.clone_align_self() {
            set.insert(LonghandId::AlignSelf);
        }
        if self.clone_aspect_ratio() != other.clone_aspect_ratio() {
            set.insert(LonghandId::AspectRatio);
        }
        if self.clone_backface_visibility() != other.clone_backface_visibility() {
            set.insert(LonghandId::BackfaceVisibility);
        }
        if self.clone_baseline_source() != other.clone_baseline_source() {
            set.insert(LonghandId::BaselineSource);
        }
        if self.clone_border_collapse() != other.clone_border_collapse() {
            set.insert(LonghandId::BorderCollapse);
        }
        if self.clone_border_image_repeat() != other.clone_border_image_repeat() {
            set.insert(LonghandId::BorderImageRepeat);
        }
        if self.clone_box_decoration_break() != other.clone_box_decoration_break() {
            set.insert(LonghandId::BoxDecorationBreak);
        }
        if self.clone_box_sizing() != other.clone_box_sizing() {
            set.insert(LonghandId::BoxSizing);
        }
        if self.clone_break_inside() != other.clone_break_inside() {
            set.insert(LonghandId::BreakInside);
        }
        if self.clone_caption_side() != other.clone_caption_side() {
            set.insert(LonghandId::CaptionSide);
        }
        if self.clone_clear() != other.clone_clear() {
            set.insert(LonghandId::Clear);
        }
        if self.clone_color_interpolation() != other.clone_color_interpolation() {
            set.insert(LonghandId::ColorInterpolation);
        }
        if self.clone_color_interpolation_filters() != other.clone_color_interpolation_filters() {
            set.insert(LonghandId::ColorInterpolationFilters);
        }
        if self.clone_column_count() != other.clone_column_count() {
            set.insert(LonghandId::ColumnCount);
        }
        if self.clone_column_fill() != other.clone_column_fill() {
            set.insert(LonghandId::ColumnFill);
        }
        if self.clone_column_span() != other.clone_column_span() {
            set.insert(LonghandId::ColumnSpan);
        }
        if self.clone_contain() != other.clone_contain() {
            set.insert(LonghandId::Contain);
        }
        if self.clone_container_type() != other.clone_container_type() {
            set.insert(LonghandId::ContainerType);
        }
        if self.clone_content_visibility() != other.clone_content_visibility() {
            set.insert(LonghandId::ContentVisibility);
        }
        if self.clone_direction() != other.clone_direction() {
            set.insert(LonghandId::Direction);
        }
        if self.clone_display() != other.clone_display() {
            set.insert(LonghandId::Display);
        }
        if self.clone_dominant_baseline() != other.clone_dominant_baseline() {
            set.insert(LonghandId::DominantBaseline);
        }
        if self.clone_empty_cells() != other.clone_empty_cells() {
            set.insert(LonghandId::EmptyCells);
        }
        if self.clone_flex_direction() != other.clone_flex_direction() {
            set.insert(LonghandId::FlexDirection);
        }
        if self.clone_flex_wrap() != other.clone_flex_wrap() {
            set.insert(LonghandId::FlexWrap);
        }
        if self.clone_float() != other.clone_float() {
            set.insert(LonghandId::Float);
        }
        if self.clone_font_kerning() != other.clone_font_kerning() {
            set.insert(LonghandId::FontKerning);
        }
        if self.clone_font_language_override() != other.clone_font_language_override() {
            set.insert(LonghandId::FontLanguageOverride);
        }
        if self.clone_font_optical_sizing() != other.clone_font_optical_sizing() {
            set.insert(LonghandId::FontOpticalSizing);
        }
        if self.clone_font_size_adjust() != other.clone_font_size_adjust() {
            set.insert(LonghandId::FontSizeAdjust);
        }
        if self.clone_font_stretch() != other.clone_font_stretch() {
            set.insert(LonghandId::FontStretch);
        }
        if self.clone_font_style() != other.clone_font_style() {
            set.insert(LonghandId::FontStyle);
        }
        if self.clone_font_variant_caps() != other.clone_font_variant_caps() {
            set.insert(LonghandId::FontVariantCaps);
        }
        if self.clone_font_variant_east_asian() != other.clone_font_variant_east_asian() {
            set.insert(LonghandId::FontVariantEastAsian);
        }
        if self.clone_font_variant_emoji() != other.clone_font_variant_emoji() {
            set.insert(LonghandId::FontVariantEmoji);
        }
        if self.clone_font_variant_ligatures() != other.clone_font_variant_ligatures() {
            set.insert(LonghandId::FontVariantLigatures);
        }
        if self.clone_font_variant_numeric() != other.clone_font_variant_numeric() {
            set.insert(LonghandId::FontVariantNumeric);
        }
        if self.clone_font_variant_position() != other.clone_font_variant_position() {
            set.insert(LonghandId::FontVariantPosition);
        }
        if self.clone_font_weight() != other.clone_font_weight() {
            set.insert(LonghandId::FontWeight);
        }
        if self.clone_forced_color_adjust() != other.clone_forced_color_adjust() {
            set.insert(LonghandId::ForcedColorAdjust);
        }
        if self.clone_grid_auto_flow() != other.clone_grid_auto_flow() {
            set.insert(LonghandId::GridAutoFlow);
        }
        if self.clone_hyphens() != other.clone_hyphens() {
            set.insert(LonghandId::Hyphens);
        }
        if self.clone_image_orientation() != other.clone_image_orientation() {
            set.insert(LonghandId::ImageOrientation);
        }
        if self.clone_image_rendering() != other.clone_image_rendering() {
            set.insert(LonghandId::ImageRendering);
        }
        if self.clone_ime_mode() != other.clone_ime_mode() {
            set.insert(LonghandId::ImeMode);
        }
        if self.clone_initial_letter() != other.clone_initial_letter() {
            set.insert(LonghandId::InitialLetter);
        }
        if self.clone_inset_area() != other.clone_inset_area() {
            set.insert(LonghandId::InsetArea);
        }
        if self.clone_isolation() != other.clone_isolation() {
            set.insert(LonghandId::Isolation);
        }
        if self.clone_justify_content() != other.clone_justify_content() {
            set.insert(LonghandId::JustifyContent);
        }
        if self.clone_justify_items() != other.clone_justify_items() {
            set.insert(LonghandId::JustifyItems);
        }
        if self.clone_justify_self() != other.clone_justify_self() {
            set.insert(LonghandId::JustifySelf);
        }
        if self.clone_line_break() != other.clone_line_break() {
            set.insert(LonghandId::LineBreak);
        }
        if self.clone_list_style_position() != other.clone_list_style_position() {
            set.insert(LonghandId::ListStylePosition);
        }
        if self.clone_mask_type() != other.clone_mask_type() {
            set.insert(LonghandId::MaskType);
        }
        if self.clone_masonry_auto_flow() != other.clone_masonry_auto_flow() {
            set.insert(LonghandId::MasonryAutoFlow);
        }
        if self.clone_math_depth() != other.clone_math_depth() {
            set.insert(LonghandId::MathDepth);
        }
        if self.clone_math_style() != other.clone_math_style() {
            set.insert(LonghandId::MathStyle);
        }
        if self.clone_mix_blend_mode() != other.clone_mix_blend_mode() {
            set.insert(LonghandId::MixBlendMode);
        }
        if self.clone__moz_box_align() != other.clone__moz_box_align() {
            set.insert(LonghandId::MozBoxAlign);
        }
        if self.clone__moz_box_collapse() != other.clone__moz_box_collapse() {
            set.insert(LonghandId::MozBoxCollapse);
        }
        if self.clone__moz_box_direction() != other.clone__moz_box_direction() {
            set.insert(LonghandId::MozBoxDirection);
        }
        if self.clone__moz_box_orient() != other.clone__moz_box_orient() {
            set.insert(LonghandId::MozBoxOrient);
        }
        if self.clone__moz_box_pack() != other.clone__moz_box_pack() {
            set.insert(LonghandId::MozBoxPack);
        }
        if self.clone__moz_control_character_visibility() != other.clone__moz_control_character_visibility() {
            set.insert(LonghandId::MozControlCharacterVisibility);
        }
        if self.clone__moz_float_edge() != other.clone__moz_float_edge() {
            set.insert(LonghandId::MozFloatEdge);
        }
        if self.clone__moz_inert() != other.clone__moz_inert() {
            set.insert(LonghandId::MozInert);
        }
        if self.clone__moz_math_variant() != other.clone__moz_math_variant() {
            set.insert(LonghandId::MozMathVariant);
        }
        if self.clone__moz_min_font_size_ratio() != other.clone__moz_min_font_size_ratio() {
            set.insert(LonghandId::MozMinFontSizeRatio);
        }
        if self.clone__moz_orient() != other.clone__moz_orient() {
            set.insert(LonghandId::MozOrient);
        }
        if self.clone__moz_osx_font_smoothing() != other.clone__moz_osx_font_smoothing() {
            set.insert(LonghandId::MozOsxFontSmoothing);
        }
        if self.clone__moz_text_size_adjust() != other.clone__moz_text_size_adjust() {
            set.insert(LonghandId::MozTextSizeAdjust);
        }
        if self.clone__moz_theme() != other.clone__moz_theme() {
            set.insert(LonghandId::MozTheme);
        }
        if self.clone__moz_top_layer() != other.clone__moz_top_layer() {
            set.insert(LonghandId::MozTopLayer);
        }
        if self.clone__moz_user_focus() != other.clone__moz_user_focus() {
            set.insert(LonghandId::MozUserFocus);
        }
        if self.clone__moz_user_input() != other.clone__moz_user_input() {
            set.insert(LonghandId::MozUserInput);
        }
        if self.clone__moz_user_modify() != other.clone__moz_user_modify() {
            set.insert(LonghandId::MozUserModify);
        }
        if self.clone__moz_window_dragging() != other.clone__moz_window_dragging() {
            set.insert(LonghandId::MozWindowDragging);
        }
        if self.clone__moz_window_shadow() != other.clone__moz_window_shadow() {
            set.insert(LonghandId::MozWindowShadow);
        }
        if self.clone_object_fit() != other.clone_object_fit() {
            set.insert(LonghandId::ObjectFit);
        }
        if self.clone_offset_rotate() != other.clone_offset_rotate() {
            set.insert(LonghandId::OffsetRotate);
        }
        if self.clone_outline_style() != other.clone_outline_style() {
            set.insert(LonghandId::OutlineStyle);
        }
        if self.clone_overflow_anchor() != other.clone_overflow_anchor() {
            set.insert(LonghandId::OverflowAnchor);
        }
        if self.clone_overflow_wrap() != other.clone_overflow_wrap() {
            set.insert(LonghandId::OverflowWrap);
        }
        if self.clone_page_orientation() != other.clone_page_orientation() {
            set.insert(LonghandId::PageOrientation);
        }
        if self.clone_paint_order() != other.clone_paint_order() {
            set.insert(LonghandId::PaintOrder);
        }
        if self.clone_pointer_events() != other.clone_pointer_events() {
            set.insert(LonghandId::PointerEvents);
        }
        if self.clone_position() != other.clone_position() {
            set.insert(LonghandId::Position);
        }
        if self.clone_position_try_order() != other.clone_position_try_order() {
            set.insert(LonghandId::PositionTryOrder);
        }
        if self.clone_position_visibility() != other.clone_position_visibility() {
            set.insert(LonghandId::PositionVisibility);
        }
        if self.clone_print_color_adjust() != other.clone_print_color_adjust() {
            set.insert(LonghandId::PrintColorAdjust);
        }
        if self.clone_resize() != other.clone_resize() {
            set.insert(LonghandId::Resize);
        }
        if self.clone_ruby_align() != other.clone_ruby_align() {
            set.insert(LonghandId::RubyAlign);
        }
        if self.clone_ruby_position() != other.clone_ruby_position() {
            set.insert(LonghandId::RubyPosition);
        }
        if self.clone_scroll_behavior() != other.clone_scroll_behavior() {
            set.insert(LonghandId::ScrollBehavior);
        }
        if self.clone_scroll_snap_align() != other.clone_scroll_snap_align() {
            set.insert(LonghandId::ScrollSnapAlign);
        }
        if self.clone_scroll_snap_stop() != other.clone_scroll_snap_stop() {
            set.insert(LonghandId::ScrollSnapStop);
        }
        if self.clone_scroll_snap_type() != other.clone_scroll_snap_type() {
            set.insert(LonghandId::ScrollSnapType);
        }
        if self.clone_scrollbar_gutter() != other.clone_scrollbar_gutter() {
            set.insert(LonghandId::ScrollbarGutter);
        }
        if self.clone_scrollbar_width() != other.clone_scrollbar_width() {
            set.insert(LonghandId::ScrollbarWidth);
        }
        if self.clone_shape_rendering() != other.clone_shape_rendering() {
            set.insert(LonghandId::ShapeRendering);
        }
        if self.clone_stroke_linecap() != other.clone_stroke_linecap() {
            set.insert(LonghandId::StrokeLinecap);
        }
        if self.clone_stroke_linejoin() != other.clone_stroke_linejoin() {
            set.insert(LonghandId::StrokeLinejoin);
        }
        if self.clone_table_layout() != other.clone_table_layout() {
            set.insert(LonghandId::TableLayout);
        }
        if self.clone_text_align() != other.clone_text_align() {
            set.insert(LonghandId::TextAlign);
        }
        if self.clone_text_align_last() != other.clone_text_align_last() {
            set.insert(LonghandId::TextAlignLast);
        }
        if self.clone_text_anchor() != other.clone_text_anchor() {
            set.insert(LonghandId::TextAnchor);
        }
        if self.clone_text_combine_upright() != other.clone_text_combine_upright() {
            set.insert(LonghandId::TextCombineUpright);
        }
        if self.clone_text_decoration_line() != other.clone_text_decoration_line() {
            set.insert(LonghandId::TextDecorationLine);
        }
        if self.clone_text_decoration_skip_ink() != other.clone_text_decoration_skip_ink() {
            set.insert(LonghandId::TextDecorationSkipInk);
        }
        if self.clone_text_decoration_style() != other.clone_text_decoration_style() {
            set.insert(LonghandId::TextDecorationStyle);
        }
        if self.clone_text_emphasis_position() != other.clone_text_emphasis_position() {
            set.insert(LonghandId::TextEmphasisPosition);
        }
        if self.clone_text_justify() != other.clone_text_justify() {
            set.insert(LonghandId::TextJustify);
        }
        if self.clone_text_orientation() != other.clone_text_orientation() {
            set.insert(LonghandId::TextOrientation);
        }
        if self.clone_text_rendering() != other.clone_text_rendering() {
            set.insert(LonghandId::TextRendering);
        }
        if self.clone_text_transform() != other.clone_text_transform() {
            set.insert(LonghandId::TextTransform);
        }
        if self.clone_text_underline_position() != other.clone_text_underline_position() {
            set.insert(LonghandId::TextUnderlinePosition);
        }
        if self.clone_text_wrap_mode() != other.clone_text_wrap_mode() {
            set.insert(LonghandId::TextWrapMode);
        }
        if self.clone_text_wrap_style() != other.clone_text_wrap_style() {
            set.insert(LonghandId::TextWrapStyle);
        }
        if self.clone_touch_action() != other.clone_touch_action() {
            set.insert(LonghandId::TouchAction);
        }
        if self.clone_transform_box() != other.clone_transform_box() {
            set.insert(LonghandId::TransformBox);
        }
        if self.clone_transform_style() != other.clone_transform_style() {
            set.insert(LonghandId::TransformStyle);
        }
        if self.clone_unicode_bidi() != other.clone_unicode_bidi() {
            set.insert(LonghandId::UnicodeBidi);
        }
        if self.clone_user_select() != other.clone_user_select() {
            set.insert(LonghandId::UserSelect);
        }
        if self.clone_vector_effect() != other.clone_vector_effect() {
            set.insert(LonghandId::VectorEffect);
        }
        if self.clone_visibility() != other.clone_visibility() {
            set.insert(LonghandId::Visibility);
        }
        if self.clone__webkit_line_clamp() != other.clone__webkit_line_clamp() {
            set.insert(LonghandId::WebkitLineClamp);
        }
        if self.clone__webkit_text_security() != other.clone__webkit_text_security() {
            set.insert(LonghandId::WebkitTextSecurity);
        }
        if self.clone_white_space_collapse() != other.clone_white_space_collapse() {
            set.insert(LonghandId::WhiteSpaceCollapse);
        }
        if self.clone_word_break() != other.clone_word_break() {
            set.insert(LonghandId::WordBreak);
        }
        if self.clone_writing_mode() != other.clone_writing_mode() {
            set.insert(LonghandId::WritingMode);
        }
        if self.clone__x_text_scale() != other.clone__x_text_scale() {
            set.insert(LonghandId::XTextScale);
        }
        if self.clone_z_index() != other.clone_z_index() {
            set.insert(LonghandId::ZIndex);
        }
        if self.clone_zoom() != other.clone_zoom() {
            set.insert(LonghandId::Zoom);
        }
        if self.clone_appearance() != other.clone_appearance() {
            set.insert(LonghandId::Appearance);
        }
        if self.clone__moz_default_appearance() != other.clone__moz_default_appearance() {
            set.insert(LonghandId::MozDefaultAppearance);
        }
        if self.clone__moz_force_broken_image_icon() != other.clone__moz_force_broken_image_icon() {
            set.insert(LonghandId::MozForceBrokenImageIcon);
        }
        if self.clone__moz_subtree_hidden_only_visually() != other.clone__moz_subtree_hidden_only_visually() {
            set.insert(LonghandId::MozSubtreeHiddenOnlyVisually);
        }
        if self.clone_break_after() != other.clone_break_after() {
            set.insert(LonghandId::BreakAfter);
        }
        if self.clone_break_before() != other.clone_break_before() {
            set.insert(LonghandId::BreakBefore);
        }
        if self.clone_clip_rule() != other.clone_clip_rule() {
            set.insert(LonghandId::ClipRule);
        }
        if self.clone_fill_rule() != other.clone_fill_rule() {
            set.insert(LonghandId::FillRule);
        }
        if self.clone_overflow_clip_box_block() != other.clone_overflow_clip_box_block() {
            set.insert(LonghandId::OverflowClipBoxBlock);
        }
        if self.clone_overflow_clip_box_inline() != other.clone_overflow_clip_box_inline() {
            set.insert(LonghandId::OverflowClipBoxInline);
        }
        if self.clone_fill_opacity() != other.clone_fill_opacity() {
            set.insert(LonghandId::FillOpacity);
        }
        if self.clone_stroke_opacity() != other.clone_stroke_opacity() {
            set.insert(LonghandId::StrokeOpacity);
        }
        if self.clone__moz_box_ordinal_group() != other.clone__moz_box_ordinal_group() {
            set.insert(LonghandId::MozBoxOrdinalGroup);
        }
        if self.clone_order() != other.clone_order() {
            set.insert(LonghandId::Order);
        }
        if self.clone__x_span() != other.clone__x_span() {
            set.insert(LonghandId::XSpan);
        }
        if self.clone_font_synthesis_position() != other.clone_font_synthesis_position() {
            set.insert(LonghandId::FontSynthesisPosition);
        }
        if self.clone_font_synthesis_small_caps() != other.clone_font_synthesis_small_caps() {
            set.insert(LonghandId::FontSynthesisSmallCaps);
        }
        if self.clone_font_synthesis_style() != other.clone_font_synthesis_style() {
            set.insert(LonghandId::FontSynthesisStyle);
        }
        if self.clone_font_synthesis_weight() != other.clone_font_synthesis_weight() {
            set.insert(LonghandId::FontSynthesisWeight);
        }
        if self.clone_flex_grow() != other.clone_flex_grow() {
            set.insert(LonghandId::FlexGrow);
        }
        if self.clone_flex_shrink() != other.clone_flex_shrink() {
            set.insert(LonghandId::FlexShrink);
        }
        if self.clone__moz_box_flex() != other.clone__moz_box_flex() {
            set.insert(LonghandId::MozBoxFlex);
        }
        if self.clone_stroke_miterlimit() != other.clone_stroke_miterlimit() {
            set.insert(LonghandId::StrokeMiterlimit);
        }
        if self.clone_overflow_x() != other.clone_overflow_x() {
            set.insert(LonghandId::OverflowX);
        }
        if self.clone_overflow_y() != other.clone_overflow_y() {
            set.insert(LonghandId::OverflowY);
        }
        if self.clone_overscroll_behavior_x() != other.clone_overscroll_behavior_x() {
            set.insert(LonghandId::OverscrollBehaviorX);
        }
        if self.clone_overscroll_behavior_y() != other.clone_overscroll_behavior_y() {
            set.insert(LonghandId::OverscrollBehaviorY);
        }
        if self.clone_flood_opacity() != other.clone_flood_opacity() {
            set.insert(LonghandId::FloodOpacity);
        }
        if self.clone__moz_window_opacity() != other.clone__moz_window_opacity() {
            set.insert(LonghandId::MozWindowOpacity);
        }
        if self.clone_opacity() != other.clone_opacity() {
            set.insert(LonghandId::Opacity);
        }
        if self.clone_shape_image_threshold() != other.clone_shape_image_threshold() {
            set.insert(LonghandId::ShapeImageThreshold);
        }
        if self.clone_stop_opacity() != other.clone_stop_opacity() {
            set.insert(LonghandId::StopOpacity);
        }
        if self.clone_border_bottom_style() != other.clone_border_bottom_style() {
            set.insert(LonghandId::BorderBottomStyle);
        }
        if self.clone_border_left_style() != other.clone_border_left_style() {
            set.insert(LonghandId::BorderLeftStyle);
        }
        if self.clone_border_right_style() != other.clone_border_right_style() {
            set.insert(LonghandId::BorderRightStyle);
        }
        if self.clone_border_top_style() != other.clone_border_top_style() {
            set.insert(LonghandId::BorderTopStyle);
        }
        if self.clone_column_rule_style() != other.clone_column_rule_style() {
            set.insert(LonghandId::ColumnRuleStyle);
        }
        if self.clone_accent_color() != other.clone_accent_color() {
            set.insert(LonghandId::AccentColor);
        }
        if self.clone_anchor_name() != other.clone_anchor_name() {
            set.insert(LonghandId::AnchorName);
        }
        if self.clone_anchor_scope() != other.clone_anchor_scope() {
            set.insert(LonghandId::AnchorScope);
        }
        if self.clone_animation_composition() != other.clone_animation_composition() {
            set.insert(LonghandId::AnimationComposition);
        }
        if self.clone_animation_delay() != other.clone_animation_delay() {
            set.insert(LonghandId::AnimationDelay);
        }
        if self.clone_animation_direction() != other.clone_animation_direction() {
            set.insert(LonghandId::AnimationDirection);
        }
        if self.clone_animation_duration() != other.clone_animation_duration() {
            set.insert(LonghandId::AnimationDuration);
        }
        if self.clone_animation_fill_mode() != other.clone_animation_fill_mode() {
            set.insert(LonghandId::AnimationFillMode);
        }
        if self.clone_animation_iteration_count() != other.clone_animation_iteration_count() {
            set.insert(LonghandId::AnimationIterationCount);
        }
        if self.clone_animation_name() != other.clone_animation_name() {
            set.insert(LonghandId::AnimationName);
        }
        if self.clone_animation_play_state() != other.clone_animation_play_state() {
            set.insert(LonghandId::AnimationPlayState);
        }
        if self.clone_animation_timeline() != other.clone_animation_timeline() {
            set.insert(LonghandId::AnimationTimeline);
        }
        if self.clone_animation_timing_function() != other.clone_animation_timing_function() {
            set.insert(LonghandId::AnimationTimingFunction);
        }
        if self.clone_backdrop_filter() != other.clone_backdrop_filter() {
            set.insert(LonghandId::BackdropFilter);
        }
        if self.clone_background_attachment() != other.clone_background_attachment() {
            set.insert(LonghandId::BackgroundAttachment);
        }
        if self.clone_background_blend_mode() != other.clone_background_blend_mode() {
            set.insert(LonghandId::BackgroundBlendMode);
        }
        if self.clone_background_clip() != other.clone_background_clip() {
            set.insert(LonghandId::BackgroundClip);
        }
        if self.clone_background_image() != other.clone_background_image() {
            set.insert(LonghandId::BackgroundImage);
        }
        if self.clone_background_origin() != other.clone_background_origin() {
            set.insert(LonghandId::BackgroundOrigin);
        }
        if self.clone_background_position_x() != other.clone_background_position_x() {
            set.insert(LonghandId::BackgroundPositionX);
        }
        if self.clone_background_position_y() != other.clone_background_position_y() {
            set.insert(LonghandId::BackgroundPositionY);
        }
        if self.clone_background_repeat() != other.clone_background_repeat() {
            set.insert(LonghandId::BackgroundRepeat);
        }
        if self.clone_background_size() != other.clone_background_size() {
            set.insert(LonghandId::BackgroundSize);
        }
        if self.clone_border_image_outset() != other.clone_border_image_outset() {
            set.insert(LonghandId::BorderImageOutset);
        }
        if self.clone_border_image_slice() != other.clone_border_image_slice() {
            set.insert(LonghandId::BorderImageSlice);
        }
        if self.clone_border_image_width() != other.clone_border_image_width() {
            set.insert(LonghandId::BorderImageWidth);
        }
        if self.clone_border_spacing() != other.clone_border_spacing() {
            set.insert(LonghandId::BorderSpacing);
        }
        if self.clone_box_shadow() != other.clone_box_shadow() {
            set.insert(LonghandId::BoxShadow);
        }
        if self.clone_caret_color() != other.clone_caret_color() {
            set.insert(LonghandId::CaretColor);
        }
        if self.clone_clip() != other.clone_clip() {
            set.insert(LonghandId::Clip);
        }
        if self.clone_clip_path() != other.clone_clip_path() {
            set.insert(LonghandId::ClipPath);
        }
        if self.clone_color() != other.clone_color() {
            set.insert(LonghandId::Color);
        }
        if self.clone_color_scheme() != other.clone_color_scheme() {
            set.insert(LonghandId::ColorScheme);
        }
        if self.clone_column_width() != other.clone_column_width() {
            set.insert(LonghandId::ColumnWidth);
        }
        if self.clone_container_name() != other.clone_container_name() {
            set.insert(LonghandId::ContainerName);
        }
        if self.clone_content() != other.clone_content() {
            set.insert(LonghandId::Content);
        }
        if self.clone_counter_increment() != other.clone_counter_increment() {
            set.insert(LonghandId::CounterIncrement);
        }
        if self.clone_counter_reset() != other.clone_counter_reset() {
            set.insert(LonghandId::CounterReset);
        }
        if self.clone_counter_set() != other.clone_counter_set() {
            set.insert(LonghandId::CounterSet);
        }
        if self.clone_cursor() != other.clone_cursor() {
            set.insert(LonghandId::Cursor);
        }
        if self.clone_d() != other.clone_d() {
            set.insert(LonghandId::D);
        }
        if self.clone_filter() != other.clone_filter() {
            set.insert(LonghandId::Filter);
        }
        if self.clone_flex_basis() != other.clone_flex_basis() {
            set.insert(LonghandId::FlexBasis);
        }
        if self.clone_font_family() != other.clone_font_family() {
            set.insert(LonghandId::FontFamily);
        }
        if self.clone_font_feature_settings() != other.clone_font_feature_settings() {
            set.insert(LonghandId::FontFeatureSettings);
        }
        if self.clone_font_palette() != other.clone_font_palette() {
            set.insert(LonghandId::FontPalette);
        }
        if self.clone_font_size() != other.clone_font_size() {
            set.insert(LonghandId::FontSize);
        }
        if self.clone_font_variant_alternates() != other.clone_font_variant_alternates() {
            set.insert(LonghandId::FontVariantAlternates);
        }
        if self.clone_font_variation_settings() != other.clone_font_variation_settings() {
            set.insert(LonghandId::FontVariationSettings);
        }
        if self.clone_grid_template_areas() != other.clone_grid_template_areas() {
            set.insert(LonghandId::GridTemplateAreas);
        }
        if self.clone_hyphenate_character() != other.clone_hyphenate_character() {
            set.insert(LonghandId::HyphenateCharacter);
        }
        if self.clone_letter_spacing() != other.clone_letter_spacing() {
            set.insert(LonghandId::LetterSpacing);
        }
        if self.clone_line_height() != other.clone_line_height() {
            set.insert(LonghandId::LineHeight);
        }
        if self.clone_list_style_type() != other.clone_list_style_type() {
            set.insert(LonghandId::ListStyleType);
        }
        if self.clone_mask_clip() != other.clone_mask_clip() {
            set.insert(LonghandId::MaskClip);
        }
        if self.clone_mask_composite() != other.clone_mask_composite() {
            set.insert(LonghandId::MaskComposite);
        }
        if self.clone_mask_image() != other.clone_mask_image() {
            set.insert(LonghandId::MaskImage);
        }
        if self.clone_mask_mode() != other.clone_mask_mode() {
            set.insert(LonghandId::MaskMode);
        }
        if self.clone_mask_origin() != other.clone_mask_origin() {
            set.insert(LonghandId::MaskOrigin);
        }
        if self.clone_mask_position_x() != other.clone_mask_position_x() {
            set.insert(LonghandId::MaskPositionX);
        }
        if self.clone_mask_position_y() != other.clone_mask_position_y() {
            set.insert(LonghandId::MaskPositionY);
        }
        if self.clone_mask_repeat() != other.clone_mask_repeat() {
            set.insert(LonghandId::MaskRepeat);
        }
        if self.clone_mask_size() != other.clone_mask_size() {
            set.insert(LonghandId::MaskSize);
        }
        if self.clone__moz_context_properties() != other.clone__moz_context_properties() {
            set.insert(LonghandId::MozContextProperties);
        }
        if self.clone_offset_anchor() != other.clone_offset_anchor() {
            set.insert(LonghandId::OffsetAnchor);
        }
        if self.clone_offset_path() != other.clone_offset_path() {
            set.insert(LonghandId::OffsetPath);
        }
        if self.clone_offset_position() != other.clone_offset_position() {
            set.insert(LonghandId::OffsetPosition);
        }
        if self.clone_page() != other.clone_page() {
            set.insert(LonghandId::Page);
        }
        if self.clone_perspective() != other.clone_perspective() {
            set.insert(LonghandId::Perspective);
        }
        if self.clone_position_anchor() != other.clone_position_anchor() {
            set.insert(LonghandId::PositionAnchor);
        }
        if self.clone_position_try_options() != other.clone_position_try_options() {
            set.insert(LonghandId::PositionTryOptions);
        }
        if self.clone_quotes() != other.clone_quotes() {
            set.insert(LonghandId::Quotes);
        }
        if self.clone_rotate() != other.clone_rotate() {
            set.insert(LonghandId::Rotate);
        }
        if self.clone_scale() != other.clone_scale() {
            set.insert(LonghandId::Scale);
        }
        if self.clone_scroll_timeline_axis() != other.clone_scroll_timeline_axis() {
            set.insert(LonghandId::ScrollTimelineAxis);
        }
        if self.clone_scroll_timeline_name() != other.clone_scroll_timeline_name() {
            set.insert(LonghandId::ScrollTimelineName);
        }
        if self.clone_scrollbar_color() != other.clone_scrollbar_color() {
            set.insert(LonghandId::ScrollbarColor);
        }
        if self.clone_shape_outside() != other.clone_shape_outside() {
            set.insert(LonghandId::ShapeOutside);
        }
        if self.clone_size() != other.clone_size() {
            set.insert(LonghandId::Size);
        }
        if self.clone_stroke_dasharray() != other.clone_stroke_dasharray() {
            set.insert(LonghandId::StrokeDasharray);
        }
        if self.clone_stroke_dashoffset() != other.clone_stroke_dashoffset() {
            set.insert(LonghandId::StrokeDashoffset);
        }
        if self.clone_stroke_width() != other.clone_stroke_width() {
            set.insert(LonghandId::StrokeWidth);
        }
        if self.clone_tab_size() != other.clone_tab_size() {
            set.insert(LonghandId::TabSize);
        }
        if self.clone_text_decoration_thickness() != other.clone_text_decoration_thickness() {
            set.insert(LonghandId::TextDecorationThickness);
        }
        if self.clone_text_emphasis_style() != other.clone_text_emphasis_style() {
            set.insert(LonghandId::TextEmphasisStyle);
        }
        if self.clone_text_indent() != other.clone_text_indent() {
            set.insert(LonghandId::TextIndent);
        }
        if self.clone_text_overflow() != other.clone_text_overflow() {
            set.insert(LonghandId::TextOverflow);
        }
        if self.clone_text_shadow() != other.clone_text_shadow() {
            set.insert(LonghandId::TextShadow);
        }
        if self.clone_transition_behavior() != other.clone_transition_behavior() {
            set.insert(LonghandId::TransitionBehavior);
        }
        if self.clone_transition_delay() != other.clone_transition_delay() {
            set.insert(LonghandId::TransitionDelay);
        }
        if self.clone_transition_duration() != other.clone_transition_duration() {
            set.insert(LonghandId::TransitionDuration);
        }
        if self.clone_transition_property() != other.clone_transition_property() {
            set.insert(LonghandId::TransitionProperty);
        }
        if self.clone_transition_timing_function() != other.clone_transition_timing_function() {
            set.insert(LonghandId::TransitionTimingFunction);
        }
        if self.clone_translate() != other.clone_translate() {
            set.insert(LonghandId::Translate);
        }
        if self.clone_vertical_align() != other.clone_vertical_align() {
            set.insert(LonghandId::VerticalAlign);
        }
        if self.clone_view_timeline_axis() != other.clone_view_timeline_axis() {
            set.insert(LonghandId::ViewTimelineAxis);
        }
        if self.clone_view_timeline_inset() != other.clone_view_timeline_inset() {
            set.insert(LonghandId::ViewTimelineInset);
        }
        if self.clone_view_timeline_name() != other.clone_view_timeline_name() {
            set.insert(LonghandId::ViewTimelineName);
        }
        if self.clone__webkit_text_stroke_width() != other.clone__webkit_text_stroke_width() {
            set.insert(LonghandId::WebkitTextStrokeWidth);
        }
        if self.clone_will_change() != other.clone_will_change() {
            set.insert(LonghandId::WillChange);
        }
        if self.clone_word_spacing() != other.clone_word_spacing() {
            set.insert(LonghandId::WordSpacing);
        }
        if self.clone__x_lang() != other.clone__x_lang() {
            set.insert(LonghandId::XLang);
        }
        if self.clone_object_position() != other.clone_object_position() {
            set.insert(LonghandId::ObjectPosition);
        }
        if self.clone_perspective_origin() != other.clone_perspective_origin() {
            set.insert(LonghandId::PerspectiveOrigin);
        }
        if self.clone_fill() != other.clone_fill() {
            set.insert(LonghandId::Fill);
        }
        if self.clone_stroke() != other.clone_stroke() {
            set.insert(LonghandId::Stroke);
        }
        if self.clone__moz_window_transform_origin() != other.clone__moz_window_transform_origin() {
            set.insert(LonghandId::MozWindowTransformOrigin);
        }
        if self.clone_transform_origin() != other.clone_transform_origin() {
            set.insert(LonghandId::TransformOrigin);
        }
        if self.clone_grid_template_columns() != other.clone_grid_template_columns() {
            set.insert(LonghandId::GridTemplateColumns);
        }
        if self.clone_grid_template_rows() != other.clone_grid_template_rows() {
            set.insert(LonghandId::GridTemplateRows);
        }
        if self.clone_border_image_source() != other.clone_border_image_source() {
            set.insert(LonghandId::BorderImageSource);
        }
        if self.clone_list_style_image() != other.clone_list_style_image() {
            set.insert(LonghandId::ListStyleImage);
        }
        if self.clone_grid_auto_columns() != other.clone_grid_auto_columns() {
            set.insert(LonghandId::GridAutoColumns);
        }
        if self.clone_grid_auto_rows() != other.clone_grid_auto_rows() {
            set.insert(LonghandId::GridAutoRows);
        }
        if self.clone__moz_window_transform() != other.clone__moz_window_transform() {
            set.insert(LonghandId::MozWindowTransform);
        }
        if self.clone_transform() != other.clone_transform() {
            set.insert(LonghandId::Transform);
        }
        if self.clone_column_gap() != other.clone_column_gap() {
            set.insert(LonghandId::ColumnGap);
        }
        if self.clone_row_gap() != other.clone_row_gap() {
            set.insert(LonghandId::RowGap);
        }
        if self.clone_marker_end() != other.clone_marker_end() {
            set.insert(LonghandId::MarkerEnd);
        }
        if self.clone_marker_mid() != other.clone_marker_mid() {
            set.insert(LonghandId::MarkerMid);
        }
        if self.clone_marker_start() != other.clone_marker_start() {
            set.insert(LonghandId::MarkerStart);
        }
        if self.clone_contain_intrinsic_height() != other.clone_contain_intrinsic_height() {
            set.insert(LonghandId::ContainIntrinsicHeight);
        }
        if self.clone_contain_intrinsic_width() != other.clone_contain_intrinsic_width() {
            set.insert(LonghandId::ContainIntrinsicWidth);
        }
        if self.clone_grid_column_end() != other.clone_grid_column_end() {
            set.insert(LonghandId::GridColumnEnd);
        }
        if self.clone_grid_column_start() != other.clone_grid_column_start() {
            set.insert(LonghandId::GridColumnStart);
        }
        if self.clone_grid_row_end() != other.clone_grid_row_end() {
            set.insert(LonghandId::GridRowEnd);
        }
        if self.clone_grid_row_start() != other.clone_grid_row_start() {
            set.insert(LonghandId::GridRowStart);
        }
        if self.clone_max_height() != other.clone_max_height() {
            set.insert(LonghandId::MaxHeight);
        }
        if self.clone_max_width() != other.clone_max_width() {
            set.insert(LonghandId::MaxWidth);
        }
        if self.clone_cx() != other.clone_cx() {
            set.insert(LonghandId::Cx);
        }
        if self.clone_cy() != other.clone_cy() {
            set.insert(LonghandId::Cy);
        }
        if self.clone_offset_distance() != other.clone_offset_distance() {
            set.insert(LonghandId::OffsetDistance);
        }
        if self.clone_x() != other.clone_x() {
            set.insert(LonghandId::X);
        }
        if self.clone_y() != other.clone_y() {
            set.insert(LonghandId::Y);
        }
        if self.clone_border_bottom_left_radius() != other.clone_border_bottom_left_radius() {
            set.insert(LonghandId::BorderBottomLeftRadius);
        }
        if self.clone_border_bottom_right_radius() != other.clone_border_bottom_right_radius() {
            set.insert(LonghandId::BorderBottomRightRadius);
        }
        if self.clone_border_top_left_radius() != other.clone_border_top_left_radius() {
            set.insert(LonghandId::BorderTopLeftRadius);
        }
        if self.clone_border_top_right_radius() != other.clone_border_top_right_radius() {
            set.insert(LonghandId::BorderTopRightRadius);
        }
        if self.clone_height() != other.clone_height() {
            set.insert(LonghandId::Height);
        }
        if self.clone_min_height() != other.clone_min_height() {
            set.insert(LonghandId::MinHeight);
        }
        if self.clone_min_width() != other.clone_min_width() {
            set.insert(LonghandId::MinWidth);
        }
        if self.clone_width() != other.clone_width() {
            set.insert(LonghandId::Width);
        }
        if self.clone_border_bottom_width() != other.clone_border_bottom_width() {
            set.insert(LonghandId::BorderBottomWidth);
        }
        if self.clone_border_left_width() != other.clone_border_left_width() {
            set.insert(LonghandId::BorderLeftWidth);
        }
        if self.clone_border_right_width() != other.clone_border_right_width() {
            set.insert(LonghandId::BorderRightWidth);
        }
        if self.clone_border_top_width() != other.clone_border_top_width() {
            set.insert(LonghandId::BorderTopWidth);
        }
        if self.clone_column_rule_width() != other.clone_column_rule_width() {
            set.insert(LonghandId::ColumnRuleWidth);
        }
        if self.clone_outline_width() != other.clone_outline_width() {
            set.insert(LonghandId::OutlineWidth);
        }
        if self.clone_padding_bottom() != other.clone_padding_bottom() {
            set.insert(LonghandId::PaddingBottom);
        }
        if self.clone_padding_left() != other.clone_padding_left() {
            set.insert(LonghandId::PaddingLeft);
        }
        if self.clone_padding_right() != other.clone_padding_right() {
            set.insert(LonghandId::PaddingRight);
        }
        if self.clone_padding_top() != other.clone_padding_top() {
            set.insert(LonghandId::PaddingTop);
        }
        if self.clone_r() != other.clone_r() {
            set.insert(LonghandId::R);
        }
        if self.clone_shape_margin() != other.clone_shape_margin() {
            set.insert(LonghandId::ShapeMargin);
        }
        if self.clone_rx() != other.clone_rx() {
            set.insert(LonghandId::Rx);
        }
        if self.clone_ry() != other.clone_ry() {
            set.insert(LonghandId::Ry);
        }
        if self.clone_scroll_padding_bottom() != other.clone_scroll_padding_bottom() {
            set.insert(LonghandId::ScrollPaddingBottom);
        }
        if self.clone_scroll_padding_left() != other.clone_scroll_padding_left() {
            set.insert(LonghandId::ScrollPaddingLeft);
        }
        if self.clone_scroll_padding_right() != other.clone_scroll_padding_right() {
            set.insert(LonghandId::ScrollPaddingRight);
        }
        if self.clone_scroll_padding_top() != other.clone_scroll_padding_top() {
            set.insert(LonghandId::ScrollPaddingTop);
        }
        if self.clone__moz_window_input_region_margin() != other.clone__moz_window_input_region_margin() {
            set.insert(LonghandId::MozWindowInputRegionMargin);
        }
        if self.clone_outline_offset() != other.clone_outline_offset() {
            set.insert(LonghandId::OutlineOffset);
        }
        if self.clone_overflow_clip_margin() != other.clone_overflow_clip_margin() {
            set.insert(LonghandId::OverflowClipMargin);
        }
        if self.clone_scroll_margin_bottom() != other.clone_scroll_margin_bottom() {
            set.insert(LonghandId::ScrollMarginBottom);
        }
        if self.clone_scroll_margin_left() != other.clone_scroll_margin_left() {
            set.insert(LonghandId::ScrollMarginLeft);
        }
        if self.clone_scroll_margin_right() != other.clone_scroll_margin_right() {
            set.insert(LonghandId::ScrollMarginRight);
        }
        if self.clone_scroll_margin_top() != other.clone_scroll_margin_top() {
            set.insert(LonghandId::ScrollMarginTop);
        }
        if self.clone_bottom() != other.clone_bottom() {
            set.insert(LonghandId::Bottom);
        }
        if self.clone_left() != other.clone_left() {
            set.insert(LonghandId::Left);
        }
        if self.clone_margin_bottom() != other.clone_margin_bottom() {
            set.insert(LonghandId::MarginBottom);
        }
        if self.clone_margin_left() != other.clone_margin_left() {
            set.insert(LonghandId::MarginLeft);
        }
        if self.clone_margin_right() != other.clone_margin_right() {
            set.insert(LonghandId::MarginRight);
        }
        if self.clone_margin_top() != other.clone_margin_top() {
            set.insert(LonghandId::MarginTop);
        }
        if self.clone_right() != other.clone_right() {
            set.insert(LonghandId::Right);
        }
        if self.clone_text_underline_offset() != other.clone_text_underline_offset() {
            set.insert(LonghandId::TextUnderlineOffset);
        }
        if self.clone_top() != other.clone_top() {
            set.insert(LonghandId::Top);
        }
        if self.clone_background_color() != other.clone_background_color() {
            set.insert(LonghandId::BackgroundColor);
        }
        if self.clone_border_bottom_color() != other.clone_border_bottom_color() {
            set.insert(LonghandId::BorderBottomColor);
        }
        if self.clone_border_left_color() != other.clone_border_left_color() {
            set.insert(LonghandId::BorderLeftColor);
        }
        if self.clone_border_right_color() != other.clone_border_right_color() {
            set.insert(LonghandId::BorderRightColor);
        }
        if self.clone_border_top_color() != other.clone_border_top_color() {
            set.insert(LonghandId::BorderTopColor);
        }
        if self.clone_column_rule_color() != other.clone_column_rule_color() {
            set.insert(LonghandId::ColumnRuleColor);
        }
        if self.clone_flood_color() != other.clone_flood_color() {
            set.insert(LonghandId::FloodColor);
        }
        if self.clone_lighting_color() != other.clone_lighting_color() {
            set.insert(LonghandId::LightingColor);
        }
        if self.clone_outline_color() != other.clone_outline_color() {
            set.insert(LonghandId::OutlineColor);
        }
        if self.clone_stop_color() != other.clone_stop_color() {
            set.insert(LonghandId::StopColor);
        }
        if self.clone_text_decoration_color() != other.clone_text_decoration_color() {
            set.insert(LonghandId::TextDecorationColor);
        }
        if self.clone_text_emphasis_color() != other.clone_text_emphasis_color() {
            set.insert(LonghandId::TextEmphasisColor);
        }
        if self.clone__webkit_text_fill_color() != other.clone__webkit_text_fill_color() {
            set.insert(LonghandId::WebkitTextFillColor);
        }
        if self.clone__webkit_text_stroke_color() != other.clone__webkit_text_stroke_color() {
            set.insert(LonghandId::WebkitTextStrokeColor);
        }
        set
    }

    /// Create a `TransitionPropertyIterator` for this styles transition properties.
    pub fn transition_properties<'a>(
        &'a self
    ) -> animated_properties::TransitionPropertyIterator<'a> {
        animated_properties::TransitionPropertyIterator::from_style(self)
    }
}

#[cfg(feature = "servo")]
impl ComputedValues {
    /// Create a new refcounted `ComputedValues`
    pub fn new(
        pseudo: Option<&PseudoElement>,
        custom_properties: crate::custom_properties::ComputedCustomProperties,
        writing_mode: WritingMode,
        effective_zoom: computed::Zoom,
        flags: ComputedValueFlags,
        rules: Option<StrongRuleNode>,
        visited_style: Option<Arc<ComputedValues>>,
        background: Arc<style_structs::Background>,
        border: Arc<style_structs::Border>,
        box_: Arc<style_structs::Box>,
        column: Arc<style_structs::Column>,
        counters: Arc<style_structs::Counters>,
        effects: Arc<style_structs::Effects>,
        font: Arc<style_structs::Font>,
        inherited_box: Arc<style_structs::InheritedBox>,
        inherited_svg: Arc<style_structs::InheritedSVG>,
        inherited_table: Arc<style_structs::InheritedTable>,
        inherited_text: Arc<style_structs::InheritedText>,
        inherited_ui: Arc<style_structs::InheritedUI>,
        list: Arc<style_structs::List>,
        margin: Arc<style_structs::Margin>,
        outline: Arc<style_structs::Outline>,
        padding: Arc<style_structs::Padding>,
        page: Arc<style_structs::Page>,
        position: Arc<style_structs::Position>,
        svg: Arc<style_structs::SVG>,
        table: Arc<style_structs::Table>,
        text: Arc<style_structs::Text>,
        ui: Arc<style_structs::UI>,
        xul: Arc<style_structs::XUL>,
    ) -> Arc<Self> {
        Arc::new(Self {
            inner: ComputedValuesInner {
                custom_properties,
                writing_mode,
                rules,
                visited_style,
                effective_zoom,
                flags,
                background,
                border,
                box_,
                column,
                counters,
                effects,
                font,
                inherited_box,
                inherited_svg,
                inherited_table,
                inherited_text,
                inherited_ui,
                list,
                margin,
                outline,
                padding,
                page,
                position,
                svg,
                table,
                text,
                ui,
                xul,
            },
            pseudo: pseudo.cloned(),
        })
    }

    /// Get the initial computed values.
    pub fn initial_values() -> &'static Self { &*INITIAL_SERVO_VALUES }

    /// Serializes the computed value of this property as a string.
    pub fn computed_value_to_string(&self, property: PropertyDeclarationId) -> String {
        match property {
            PropertyDeclarationId::Longhand(id) => {
                let mut s = String::new();
                self.get_longhand_property_value(
                    id,
                    &mut CssWriter::new(&mut s)
                ).unwrap();
                s
            }
            PropertyDeclarationId::Custom(name) => {
                // FIXME(bug 1869476): This should use a stylist to determine
                // whether the name corresponds to an inherited custom property
                // and then choose the inherited/non_inherited map accordingly.
                let p = &self.custom_properties;
                let value = p
                    .inherited
                    .as_ref()
                    .and_then(|map| map.get(name))
                    .or_else(|| p.non_inherited.as_ref().and_then(|map| map.get(name)));
                value.map_or(String::new(), |value| value.to_css_string())
            }
        }
    }
}

#[cfg(feature = "servo")]
impl ops::Deref for ComputedValues {
    type Target = ComputedValuesInner;
    fn deref(&self) -> &ComputedValuesInner {
        &self.inner
    }
}

#[cfg(feature = "servo")]
impl ops::DerefMut for ComputedValues {
    fn deref_mut(&mut self) -> &mut ComputedValuesInner {
        &mut self.inner
    }
}

#[cfg(feature = "servo")]
impl ComputedValuesInner {
    /// Returns the visited style, if any.
    pub fn visited_style(&self) -> Option<&ComputedValues> {
        self.visited_style.as_deref()
    }

        /// Clone the Background struct.
        #[inline]
        pub fn clone_background(&self) -> Arc<style_structs::Background> {
            self.background.clone()
        }

        /// Get a immutable reference to the Background struct.
        #[inline]
        pub fn get_background(&self) -> &style_structs::Background {
            &self.background
        }

        /// Get a mutable reference to the Background struct.
        #[inline]
        pub fn mutate_background(&mut self) -> &mut style_structs::Background {
            Arc::make_mut(&mut self.background)
        }
        /// Clone the Border struct.
        #[inline]
        pub fn clone_border(&self) -> Arc<style_structs::Border> {
            self.border.clone()
        }

        /// Get a immutable reference to the Border struct.
        #[inline]
        pub fn get_border(&self) -> &style_structs::Border {
            &self.border
        }

        /// Get a mutable reference to the Border struct.
        #[inline]
        pub fn mutate_border(&mut self) -> &mut style_structs::Border {
            Arc::make_mut(&mut self.border)
        }
        /// Clone the Box struct.
        #[inline]
        pub fn clone_box(&self) -> Arc<style_structs::Box> {
            self.box_.clone()
        }

        /// Get a immutable reference to the Box struct.
        #[inline]
        pub fn get_box(&self) -> &style_structs::Box {
            &self.box_
        }

        /// Get a mutable reference to the Box struct.
        #[inline]
        pub fn mutate_box(&mut self) -> &mut style_structs::Box {
            Arc::make_mut(&mut self.box_)
        }
        /// Clone the Column struct.
        #[inline]
        pub fn clone_column(&self) -> Arc<style_structs::Column> {
            self.column.clone()
        }

        /// Get a immutable reference to the Column struct.
        #[inline]
        pub fn get_column(&self) -> &style_structs::Column {
            &self.column
        }

        /// Get a mutable reference to the Column struct.
        #[inline]
        pub fn mutate_column(&mut self) -> &mut style_structs::Column {
            Arc::make_mut(&mut self.column)
        }
        /// Clone the Counters struct.
        #[inline]
        pub fn clone_counters(&self) -> Arc<style_structs::Counters> {
            self.counters.clone()
        }

        /// Get a immutable reference to the Counters struct.
        #[inline]
        pub fn get_counters(&self) -> &style_structs::Counters {
            &self.counters
        }

        /// Get a mutable reference to the Counters struct.
        #[inline]
        pub fn mutate_counters(&mut self) -> &mut style_structs::Counters {
            Arc::make_mut(&mut self.counters)
        }
        /// Clone the Effects struct.
        #[inline]
        pub fn clone_effects(&self) -> Arc<style_structs::Effects> {
            self.effects.clone()
        }

        /// Get a immutable reference to the Effects struct.
        #[inline]
        pub fn get_effects(&self) -> &style_structs::Effects {
            &self.effects
        }

        /// Get a mutable reference to the Effects struct.
        #[inline]
        pub fn mutate_effects(&mut self) -> &mut style_structs::Effects {
            Arc::make_mut(&mut self.effects)
        }
        /// Clone the Font struct.
        #[inline]
        pub fn clone_font(&self) -> Arc<style_structs::Font> {
            self.font.clone()
        }

        /// Get a immutable reference to the Font struct.
        #[inline]
        pub fn get_font(&self) -> &style_structs::Font {
            &self.font
        }

        /// Get a mutable reference to the Font struct.
        #[inline]
        pub fn mutate_font(&mut self) -> &mut style_structs::Font {
            Arc::make_mut(&mut self.font)
        }
        /// Clone the InheritedBox struct.
        #[inline]
        pub fn clone_inherited_box(&self) -> Arc<style_structs::InheritedBox> {
            self.inherited_box.clone()
        }

        /// Get a immutable reference to the InheritedBox struct.
        #[inline]
        pub fn get_inherited_box(&self) -> &style_structs::InheritedBox {
            &self.inherited_box
        }

        /// Get a mutable reference to the InheritedBox struct.
        #[inline]
        pub fn mutate_inherited_box(&mut self) -> &mut style_structs::InheritedBox {
            Arc::make_mut(&mut self.inherited_box)
        }
        /// Clone the InheritedSVG struct.
        #[inline]
        pub fn clone_inherited_svg(&self) -> Arc<style_structs::InheritedSVG> {
            self.inherited_svg.clone()
        }

        /// Get a immutable reference to the InheritedSVG struct.
        #[inline]
        pub fn get_inherited_svg(&self) -> &style_structs::InheritedSVG {
            &self.inherited_svg
        }

        /// Get a mutable reference to the InheritedSVG struct.
        #[inline]
        pub fn mutate_inherited_svg(&mut self) -> &mut style_structs::InheritedSVG {
            Arc::make_mut(&mut self.inherited_svg)
        }
        /// Clone the InheritedTable struct.
        #[inline]
        pub fn clone_inherited_table(&self) -> Arc<style_structs::InheritedTable> {
            self.inherited_table.clone()
        }

        /// Get a immutable reference to the InheritedTable struct.
        #[inline]
        pub fn get_inherited_table(&self) -> &style_structs::InheritedTable {
            &self.inherited_table
        }

        /// Get a mutable reference to the InheritedTable struct.
        #[inline]
        pub fn mutate_inherited_table(&mut self) -> &mut style_structs::InheritedTable {
            Arc::make_mut(&mut self.inherited_table)
        }
        /// Clone the InheritedText struct.
        #[inline]
        pub fn clone_inherited_text(&self) -> Arc<style_structs::InheritedText> {
            self.inherited_text.clone()
        }

        /// Get a immutable reference to the InheritedText struct.
        #[inline]
        pub fn get_inherited_text(&self) -> &style_structs::InheritedText {
            &self.inherited_text
        }

        /// Get a mutable reference to the InheritedText struct.
        #[inline]
        pub fn mutate_inherited_text(&mut self) -> &mut style_structs::InheritedText {
            Arc::make_mut(&mut self.inherited_text)
        }
        /// Clone the InheritedUI struct.
        #[inline]
        pub fn clone_inherited_ui(&self) -> Arc<style_structs::InheritedUI> {
            self.inherited_ui.clone()
        }

        /// Get a immutable reference to the InheritedUI struct.
        #[inline]
        pub fn get_inherited_ui(&self) -> &style_structs::InheritedUI {
            &self.inherited_ui
        }

        /// Get a mutable reference to the InheritedUI struct.
        #[inline]
        pub fn mutate_inherited_ui(&mut self) -> &mut style_structs::InheritedUI {
            Arc::make_mut(&mut self.inherited_ui)
        }
        /// Clone the List struct.
        #[inline]
        pub fn clone_list(&self) -> Arc<style_structs::List> {
            self.list.clone()
        }

        /// Get a immutable reference to the List struct.
        #[inline]
        pub fn get_list(&self) -> &style_structs::List {
            &self.list
        }

        /// Get a mutable reference to the List struct.
        #[inline]
        pub fn mutate_list(&mut self) -> &mut style_structs::List {
            Arc::make_mut(&mut self.list)
        }
        /// Clone the Margin struct.
        #[inline]
        pub fn clone_margin(&self) -> Arc<style_structs::Margin> {
            self.margin.clone()
        }

        /// Get a immutable reference to the Margin struct.
        #[inline]
        pub fn get_margin(&self) -> &style_structs::Margin {
            &self.margin
        }

        /// Get a mutable reference to the Margin struct.
        #[inline]
        pub fn mutate_margin(&mut self) -> &mut style_structs::Margin {
            Arc::make_mut(&mut self.margin)
        }
        /// Clone the Outline struct.
        #[inline]
        pub fn clone_outline(&self) -> Arc<style_structs::Outline> {
            self.outline.clone()
        }

        /// Get a immutable reference to the Outline struct.
        #[inline]
        pub fn get_outline(&self) -> &style_structs::Outline {
            &self.outline
        }

        /// Get a mutable reference to the Outline struct.
        #[inline]
        pub fn mutate_outline(&mut self) -> &mut style_structs::Outline {
            Arc::make_mut(&mut self.outline)
        }
        /// Clone the Padding struct.
        #[inline]
        pub fn clone_padding(&self) -> Arc<style_structs::Padding> {
            self.padding.clone()
        }

        /// Get a immutable reference to the Padding struct.
        #[inline]
        pub fn get_padding(&self) -> &style_structs::Padding {
            &self.padding
        }

        /// Get a mutable reference to the Padding struct.
        #[inline]
        pub fn mutate_padding(&mut self) -> &mut style_structs::Padding {
            Arc::make_mut(&mut self.padding)
        }
        /// Clone the Page struct.
        #[inline]
        pub fn clone_page(&self) -> Arc<style_structs::Page> {
            self.page.clone()
        }

        /// Get a immutable reference to the Page struct.
        #[inline]
        pub fn get_page(&self) -> &style_structs::Page {
            &self.page
        }

        /// Get a mutable reference to the Page struct.
        #[inline]
        pub fn mutate_page(&mut self) -> &mut style_structs::Page {
            Arc::make_mut(&mut self.page)
        }
        /// Clone the Position struct.
        #[inline]
        pub fn clone_position(&self) -> Arc<style_structs::Position> {
            self.position.clone()
        }

        /// Get a immutable reference to the Position struct.
        #[inline]
        pub fn get_position(&self) -> &style_structs::Position {
            &self.position
        }

        /// Get a mutable reference to the Position struct.
        #[inline]
        pub fn mutate_position(&mut self) -> &mut style_structs::Position {
            Arc::make_mut(&mut self.position)
        }
        /// Clone the SVG struct.
        #[inline]
        pub fn clone_svg(&self) -> Arc<style_structs::SVG> {
            self.svg.clone()
        }

        /// Get a immutable reference to the SVG struct.
        #[inline]
        pub fn get_svg(&self) -> &style_structs::SVG {
            &self.svg
        }

        /// Get a mutable reference to the SVG struct.
        #[inline]
        pub fn mutate_svg(&mut self) -> &mut style_structs::SVG {
            Arc::make_mut(&mut self.svg)
        }
        /// Clone the Table struct.
        #[inline]
        pub fn clone_table(&self) -> Arc<style_structs::Table> {
            self.table.clone()
        }

        /// Get a immutable reference to the Table struct.
        #[inline]
        pub fn get_table(&self) -> &style_structs::Table {
            &self.table
        }

        /// Get a mutable reference to the Table struct.
        #[inline]
        pub fn mutate_table(&mut self) -> &mut style_structs::Table {
            Arc::make_mut(&mut self.table)
        }
        /// Clone the Text struct.
        #[inline]
        pub fn clone_text(&self) -> Arc<style_structs::Text> {
            self.text.clone()
        }

        /// Get a immutable reference to the Text struct.
        #[inline]
        pub fn get_text(&self) -> &style_structs::Text {
            &self.text
        }

        /// Get a mutable reference to the Text struct.
        #[inline]
        pub fn mutate_text(&mut self) -> &mut style_structs::Text {
            Arc::make_mut(&mut self.text)
        }
        /// Clone the UI struct.
        #[inline]
        pub fn clone_ui(&self) -> Arc<style_structs::UI> {
            self.ui.clone()
        }

        /// Get a immutable reference to the UI struct.
        #[inline]
        pub fn get_ui(&self) -> &style_structs::UI {
            &self.ui
        }

        /// Get a mutable reference to the UI struct.
        #[inline]
        pub fn mutate_ui(&mut self) -> &mut style_structs::UI {
            Arc::make_mut(&mut self.ui)
        }
        /// Clone the XUL struct.
        #[inline]
        pub fn clone_xul(&self) -> Arc<style_structs::XUL> {
            self.xul.clone()
        }

        /// Get a immutable reference to the XUL struct.
        #[inline]
        pub fn get_xul(&self) -> &style_structs::XUL {
            &self.xul
        }

        /// Get a mutable reference to the XUL struct.
        #[inline]
        pub fn mutate_xul(&mut self) -> &mut style_structs::XUL {
            Arc::make_mut(&mut self.xul)
        }

    /// Gets a reference to the rule node. Panic if no rule node exists.
    pub fn rules(&self) -> &StrongRuleNode {
        self.rules.as_ref().unwrap()
    }

    #[inline]
    /// Returns whether the "content" property for the given style is completely
    /// ineffective, and would yield an empty `::before` or `::after`
    /// pseudo-element.
    pub fn ineffective_content_property(&self) -> bool {
        use crate::values::generics::counters::Content;
        match self.get_counters().content {
            Content::Normal | Content::None => true,
            Content::Items(ref items) => items.is_empty(),
        }
    }

    /// Whether the current style or any of its ancestors is multicolumn.
    #[inline]
    pub fn can_be_fragmented(&self) -> bool {
        self.flags.contains(ComputedValueFlags::CAN_BE_FRAGMENTED)
    }

    /// Whether the current style is multicolumn.
    #[inline]
    pub fn is_multicol(&self) -> bool {
        self.get_column().is_multicol()
    }

    /// Get the logical computed inline size.
    #[inline]
    pub fn content_inline_size(&self) -> &computed::Size {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() {
            &position_style.height
        } else {
            &position_style.width
        }
    }

    /// Get the logical computed block size.
    #[inline]
    pub fn content_block_size(&self) -> &computed::Size {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { &position_style.width } else { &position_style.height }
    }

    /// Get the logical computed min inline size.
    #[inline]
    pub fn min_inline_size(&self) -> &computed::Size {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { &position_style.min_height } else { &position_style.min_width }
    }

    /// Get the logical computed min block size.
    #[inline]
    pub fn min_block_size(&self) -> &computed::Size {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { &position_style.min_width } else { &position_style.min_height }
    }

    /// Get the logical computed max inline size.
    #[inline]
    pub fn max_inline_size(&self) -> &computed::MaxSize {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { &position_style.max_height } else { &position_style.max_width }
    }

    /// Get the logical computed max block size.
    #[inline]
    pub fn max_block_size(&self) -> &computed::MaxSize {
        let position_style = self.get_position();
        if self.writing_mode.is_vertical() { &position_style.max_width } else { &position_style.max_height }
    }

    /// Get the logical computed padding for this writing mode.
    #[inline]
    pub fn logical_padding(&self) -> LogicalMargin<&computed::LengthPercentage> {
        let padding_style = self.get_padding();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            &padding_style.padding_top.0,
            &padding_style.padding_right.0,
            &padding_style.padding_bottom.0,
            &padding_style.padding_left.0,
        ))
    }

    /// Get the logical border width
    #[inline]
    pub fn border_width_for_writing_mode(&self, writing_mode: WritingMode) -> LogicalMargin<Au> {
        let border_style = self.get_border();
        LogicalMargin::from_physical(writing_mode, SideOffsets2D::new(
            Au::from(border_style.border_top_width),
            Au::from(border_style.border_right_width),
            Au::from(border_style.border_bottom_width),
            Au::from(border_style.border_left_width),
        ))
    }

    /// Gets the logical computed border widths for this style.
    #[inline]
    pub fn logical_border_width(&self) -> LogicalMargin<Au> {
        self.border_width_for_writing_mode(self.writing_mode)
    }

    /// Gets the logical computed margin from this style.
    #[inline]
    pub fn logical_margin(&self) -> LogicalMargin<&computed::LengthPercentageOrAuto> {
        let margin_style = self.get_margin();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            &margin_style.margin_top,
            &margin_style.margin_right,
            &margin_style.margin_bottom,
            &margin_style.margin_left,
        ))
    }

    /// Gets the logical position from this style.
    #[inline]
    pub fn logical_position(&self) -> LogicalMargin<&computed::LengthPercentageOrAuto> {
        // FIXME(SimonSapin): should be the writing mode of the containing block, maybe?
        let position_style = self.get_position();
        LogicalMargin::from_physical(self.writing_mode, SideOffsets2D::new(
            &position_style.top,
            &position_style.right,
            &position_style.bottom,
            &position_style.left,
        ))
    }

    /// Return true if the effects force the transform style to be Flat
    pub fn overrides_transform_style(&self) -> bool {
        use crate::computed_values::mix_blend_mode::T as MixBlendMode;

        let effects = self.get_effects();
        // TODO(gw): Add clip-path, isolation, mask-image, mask-border-source when supported.
        effects.opacity < 1.0 ||
           !effects.filter.0.is_empty() ||
           !effects.clip.is_auto() ||
           effects.mix_blend_mode != MixBlendMode::Normal
    }

    /// <https://drafts.csswg.org/css-transforms/#grouping-property-values>
    pub fn get_used_transform_style(&self) -> computed_values::transform_style::T {
        use crate::computed_values::transform_style::T as TransformStyle;

        let box_ = self.get_box();

        if self.overrides_transform_style() {
            TransformStyle::Flat
        } else {
            // Return the computed value if not overridden by the above exceptions
            box_.transform_style
        }
    }

    /// Whether given this transform value, the compositor would require a
    /// layer.
    pub fn transform_requires_layer(&self) -> bool {
        use crate::values::generics::transform::TransformOperation;
        // Check if the transform matrix is 2D or 3D
        for transform in &*self.get_box().transform.0 {
            match *transform {
                TransformOperation::Perspective(..) => {
                    return true;
                }
                TransformOperation::Matrix3D(m) => {
                    // See http://dev.w3.org/csswg/css-transforms/#2d-matrix
                    if m.m31 != 0.0 || m.m32 != 0.0 ||
                       m.m13 != 0.0 || m.m23 != 0.0 ||
                       m.m43 != 0.0 || m.m14 != 0.0 ||
                       m.m24 != 0.0 || m.m34 != 0.0 ||
                       m.m33 != 1.0 || m.m44 != 1.0 {
                        return true;
                    }
                }
                TransformOperation::Translate3D(_, _, z) |
                TransformOperation::TranslateZ(z) => {
                    if z.px() != 0. {
                        return true;
                    }
                }
                _ => {}
            }
        }

        // Neither perspective nor transform present
        false
    }
}

/// A reference to a style struct of the parent, or our own style struct.
pub enum StyleStructRef<'a, T: 'static> {
    /// A borrowed struct from the parent, for example, for inheriting style.
    Borrowed(&'a T),
    /// An owned struct, that we've already mutated.
    Owned(UniqueArc<T>),
    /// Temporarily vacated, will panic if accessed
    Vacated,
}

impl<'a, T: 'a> StyleStructRef<'a, T>
where
    T: Clone,
{
    /// Ensure a mutable reference of this value exists, either cloning the
    /// borrowed value, or returning the owned one.
    pub fn mutate(&mut self) -> &mut T {
        if let StyleStructRef::Borrowed(v) = *self {
            *self = StyleStructRef::Owned(UniqueArc::new(v.clone()));
        }

        match *self {
            StyleStructRef::Owned(ref mut v) => v,
            StyleStructRef::Borrowed(..) => unreachable!(),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }

    /// Whether this is pointer-equal to the struct we're going to copy the
    /// value from.
    ///
    /// This is used to avoid allocations when people write stuff like `font:
    /// inherit` or such `all: initial`.
    #[inline]
    pub fn ptr_eq(&self, struct_to_copy_from: &T) -> bool {
        match *self {
            StyleStructRef::Owned(..) => false,
            StyleStructRef::Borrowed(s) => {
                s as *const T == struct_to_copy_from as *const T
            }
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }

    /// Extract a unique Arc from this struct, vacating it.
    ///
    /// The vacated state is a transient one, please put the Arc back
    /// when done via `put()`. This function is to be used to separate
    /// the struct being mutated from the computed context
    pub fn take(&mut self) -> UniqueArc<T> {
        use std::mem::replace;
        let inner = replace(self, StyleStructRef::Vacated);

        match inner {
            StyleStructRef::Owned(arc) => arc,
            StyleStructRef::Borrowed(s) => UniqueArc::new(s.clone()),
            StyleStructRef::Vacated => panic!("Accessed vacated style struct"),
        }
    }

    /// Replace vacated ref with an arc
    pub fn put(&mut self, arc: UniqueArc<T>) {
        debug_assert!(matches!(*self, StyleStructRef::Vacated));
        *self = StyleStructRef::Owned(arc);
    }

    /// Get a mutable reference to the owned struct, or `None` if the struct
    /// hasn't been mutated.
    pub fn get_if_mutated(&mut self) -> Option<&mut T> {
        match *self {
            StyleStructRef::Owned(ref mut v) => Some(v),
            StyleStructRef::Borrowed(..) => None,
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }

    /// Returns an `Arc` to the internal struct, constructing one if
    /// appropriate.
    pub fn build(self) -> Arc<T> {
        match self {
            StyleStructRef::Owned(v) => v.shareable(),
            // SAFETY: We know all style structs are arc-allocated.
            StyleStructRef::Borrowed(v) => unsafe { Arc::from_raw_addrefed(v) },
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }
}

impl<'a, T: 'a> ops::Deref for StyleStructRef<'a, T> {
    type Target = T;

    fn deref(&self) -> &T {
        match *self {
            StyleStructRef::Owned(ref v) => &**v,
            StyleStructRef::Borrowed(v) => v,
            StyleStructRef::Vacated => panic!("Accessed vacated style struct")
        }
    }
}

/// A type used to compute a struct with minimal overhead.
///
/// This allows holding references to the parent/default computed values without
/// actually cloning them, until we either build the style, or mutate the
/// inherited value.
pub struct StyleBuilder<'a> {
    /// The device we're using to compute style.
    ///
    /// This provides access to viewport unit ratios, etc.
    pub device: &'a Device,

    /// The stylist we're using to compute style except for media queries.
    /// device is used in media queries instead.
    pub stylist: Option<&'a Stylist>,

    /// The style we're inheriting from.
    ///
    /// This is effectively
    /// `parent_style.unwrap_or(device.default_computed_values())`.
    inherited_style: &'a ComputedValues,

    /// The style we're getting reset structs from.
    reset_style: &'a ComputedValues,

    /// The rule node representing the ordered list of rules matched for this
    /// node.
    pub rules: Option<StrongRuleNode>,

    /// The computed custom properties.
    pub custom_properties: crate::custom_properties::ComputedCustomProperties,

    /// Non-custom properties that are considered invalid at compute time
    /// due to cyclic dependencies with custom properties.
    /// e.g. `--foo: 1em; font-size: var(--foo)` where `--foo` is registered.
    pub invalid_non_custom_properties: LonghandIdSet,

    /// The pseudo-element this style will represent.
    pub pseudo: Option<&'a PseudoElement>,

    /// Whether we have mutated any reset structs since the the last time
    /// `clear_modified_reset` was called.  This is used to tell whether the
    /// `StyleAdjuster` did any work.
    modified_reset: bool,

    /// Whether this is the style for the root element.
    pub is_root_element: bool,

    /// The writing mode flags.
    ///
    /// TODO(emilio): Make private.
    pub writing_mode: WritingMode,

    /// The effective zoom.
    pub effective_zoom: computed::Zoom,

    /// Flags for the computed value.
    pub flags: Cell<ComputedValueFlags>,

    /// The element's style if visited, only computed if there's a relevant link
    /// for this element.  A element's "relevant link" is the element being
    /// matched if it is a link or the nearest ancestor link.
    pub visited_style: Option<Arc<ComputedValues>>,
        background: StyleStructRef<'a, style_structs::Background>,
        border: StyleStructRef<'a, style_structs::Border>,
        box_: StyleStructRef<'a, style_structs::Box>,
        column: StyleStructRef<'a, style_structs::Column>,
        counters: StyleStructRef<'a, style_structs::Counters>,
        effects: StyleStructRef<'a, style_structs::Effects>,
        font: StyleStructRef<'a, style_structs::Font>,
        inherited_box: StyleStructRef<'a, style_structs::InheritedBox>,
        inherited_svg: StyleStructRef<'a, style_structs::InheritedSVG>,
        inherited_table: StyleStructRef<'a, style_structs::InheritedTable>,
        inherited_text: StyleStructRef<'a, style_structs::InheritedText>,
        inherited_ui: StyleStructRef<'a, style_structs::InheritedUI>,
        list: StyleStructRef<'a, style_structs::List>,
        margin: StyleStructRef<'a, style_structs::Margin>,
        outline: StyleStructRef<'a, style_structs::Outline>,
        padding: StyleStructRef<'a, style_structs::Padding>,
        page: StyleStructRef<'a, style_structs::Page>,
        position: StyleStructRef<'a, style_structs::Position>,
        svg: StyleStructRef<'a, style_structs::SVG>,
        table: StyleStructRef<'a, style_structs::Table>,
        text: StyleStructRef<'a, style_structs::Text>,
        ui: StyleStructRef<'a, style_structs::UI>,
        xul: StyleStructRef<'a, style_structs::XUL>,
}

impl<'a> StyleBuilder<'a> {
    /// Trivially construct a `StyleBuilder`.
    pub fn new(
        device: &'a Device,
        stylist: Option<&'a Stylist>,
        parent_style: Option<&'a ComputedValues>,
        pseudo: Option<&'a PseudoElement>,
        rules: Option<StrongRuleNode>,
        is_root_element: bool,
    ) -> Self {
        let reset_style = device.default_computed_values();
        let inherited_style = parent_style.unwrap_or(reset_style);

        let flags = inherited_style.flags.inherited();
        StyleBuilder {
            device,
            stylist,
            inherited_style,
            reset_style,
            pseudo,
            rules,
            modified_reset: false,
            is_root_element,
            custom_properties: crate::custom_properties::ComputedCustomProperties::default(),
            invalid_non_custom_properties: LonghandIdSet::default(),
            writing_mode: inherited_style.writing_mode,
            effective_zoom: inherited_style.effective_zoom,
            flags: Cell::new(flags),
            visited_style: None,
            background: StyleStructRef::Borrowed(reset_style.get_background()),
            border: StyleStructRef::Borrowed(reset_style.get_border()),
            box_: StyleStructRef::Borrowed(reset_style.get_box()),
            column: StyleStructRef::Borrowed(reset_style.get_column()),
            counters: StyleStructRef::Borrowed(reset_style.get_counters()),
            effects: StyleStructRef::Borrowed(reset_style.get_effects()),
            font: StyleStructRef::Borrowed(inherited_style.get_font()),
            inherited_box: StyleStructRef::Borrowed(inherited_style.get_inherited_box()),
            inherited_svg: StyleStructRef::Borrowed(inherited_style.get_inherited_svg()),
            inherited_table: StyleStructRef::Borrowed(inherited_style.get_inherited_table()),
            inherited_text: StyleStructRef::Borrowed(inherited_style.get_inherited_text()),
            inherited_ui: StyleStructRef::Borrowed(inherited_style.get_inherited_ui()),
            list: StyleStructRef::Borrowed(inherited_style.get_list()),
            margin: StyleStructRef::Borrowed(reset_style.get_margin()),
            outline: StyleStructRef::Borrowed(reset_style.get_outline()),
            padding: StyleStructRef::Borrowed(reset_style.get_padding()),
            page: StyleStructRef::Borrowed(reset_style.get_page()),
            position: StyleStructRef::Borrowed(reset_style.get_position()),
            svg: StyleStructRef::Borrowed(reset_style.get_svg()),
            table: StyleStructRef::Borrowed(reset_style.get_table()),
            text: StyleStructRef::Borrowed(reset_style.get_text()),
            ui: StyleStructRef::Borrowed(reset_style.get_ui()),
            xul: StyleStructRef::Borrowed(reset_style.get_xul()),
        }
    }

    /// NOTE(emilio): This is done so we can compute relative units with respect
    /// to the parent style, but all the early properties / writing-mode / etc
    /// are already set to the right ones on the kid.
    ///
    /// Do _not_ actually call this to construct a style, this should mostly be
    /// used for animations.
    pub fn for_animation(
        device: &'a Device,
        stylist: Option<&'a Stylist>,
        style_to_derive_from: &'a ComputedValues,
        parent_style: Option<&'a ComputedValues>,
    ) -> Self {
        let reset_style = device.default_computed_values();
        let inherited_style = parent_style.unwrap_or(reset_style);
        StyleBuilder {
            device,
            stylist,
            inherited_style,
            reset_style,
            pseudo: None,
            modified_reset: false,
            is_root_element: false,
            rules: None,
            custom_properties: style_to_derive_from.custom_properties().clone(),
            invalid_non_custom_properties: LonghandIdSet::default(),
            writing_mode: style_to_derive_from.writing_mode,
            effective_zoom: style_to_derive_from.effective_zoom,
            flags: Cell::new(style_to_derive_from.flags),
            visited_style: None,
            background: StyleStructRef::Borrowed(
                style_to_derive_from.get_background()
            ),
            border: StyleStructRef::Borrowed(
                style_to_derive_from.get_border()
            ),
            box_: StyleStructRef::Borrowed(
                style_to_derive_from.get_box()
            ),
            column: StyleStructRef::Borrowed(
                style_to_derive_from.get_column()
            ),
            counters: StyleStructRef::Borrowed(
                style_to_derive_from.get_counters()
            ),
            effects: StyleStructRef::Borrowed(
                style_to_derive_from.get_effects()
            ),
            font: StyleStructRef::Borrowed(
                style_to_derive_from.get_font()
            ),
            inherited_box: StyleStructRef::Borrowed(
                style_to_derive_from.get_inherited_box()
            ),
            inherited_svg: StyleStructRef::Borrowed(
                style_to_derive_from.get_inherited_svg()
            ),
            inherited_table: StyleStructRef::Borrowed(
                style_to_derive_from.get_inherited_table()
            ),
            inherited_text: StyleStructRef::Borrowed(
                style_to_derive_from.get_inherited_text()
            ),
            inherited_ui: StyleStructRef::Borrowed(
                style_to_derive_from.get_inherited_ui()
            ),
            list: StyleStructRef::Borrowed(
                style_to_derive_from.get_list()
            ),
            margin: StyleStructRef::Borrowed(
                style_to_derive_from.get_margin()
            ),
            outline: StyleStructRef::Borrowed(
                style_to_derive_from.get_outline()
            ),
            padding: StyleStructRef::Borrowed(
                style_to_derive_from.get_padding()
            ),
            page: StyleStructRef::Borrowed(
                style_to_derive_from.get_page()
            ),
            position: StyleStructRef::Borrowed(
                style_to_derive_from.get_position()
            ),
            svg: StyleStructRef::Borrowed(
                style_to_derive_from.get_svg()
            ),
            table: StyleStructRef::Borrowed(
                style_to_derive_from.get_table()
            ),
            text: StyleStructRef::Borrowed(
                style_to_derive_from.get_text()
            ),
            ui: StyleStructRef::Borrowed(
                style_to_derive_from.get_ui()
            ),
            xul: StyleStructRef::Borrowed(
                style_to_derive_from.get_xul()
            ),
        }
    }

    /// Copy the reset properties from `style`.
    pub fn copy_reset_from(&mut self, style: &'a ComputedValues) {
        self.background =
            StyleStructRef::Borrowed(style.get_background());
        self.border =
            StyleStructRef::Borrowed(style.get_border());
        self.box_ =
            StyleStructRef::Borrowed(style.get_box());
        self.column =
            StyleStructRef::Borrowed(style.get_column());
        self.counters =
            StyleStructRef::Borrowed(style.get_counters());
        self.effects =
            StyleStructRef::Borrowed(style.get_effects());
        self.margin =
            StyleStructRef::Borrowed(style.get_margin());
        self.outline =
            StyleStructRef::Borrowed(style.get_outline());
        self.padding =
            StyleStructRef::Borrowed(style.get_padding());
        self.page =
            StyleStructRef::Borrowed(style.get_page());
        self.position =
            StyleStructRef::Borrowed(style.get_position());
        self.svg =
            StyleStructRef::Borrowed(style.get_svg());
        self.table =
            StyleStructRef::Borrowed(style.get_table());
        self.text =
            StyleStructRef::Borrowed(style.get_text());
        self.ui =
            StyleStructRef::Borrowed(style.get_ui());
        self.xul =
            StyleStructRef::Borrowed(style.get_xul());
    }

    /// Inherit `align_content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_content(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_align_content_from(inherited_struct);
    }

    /// Set the `align_content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_content(
        &mut self,
        value: longhands::align_content::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_align_content(
                value,
            );
    }
    /// Inherit `align_items` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_items(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_align_items_from(inherited_struct);
    }

    /// Set the `align_items` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_items(
        &mut self,
        value: longhands::align_items::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_align_items(
                value,
            );
    }
    /// Inherit `align_self` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_align_self(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_align_self_from(inherited_struct);
    }

    /// Set the `align_self` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_align_self(
        &mut self,
        value: longhands::align_self::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_align_self(
                value,
            );
    }
    /// Inherit `aspect_ratio` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_aspect_ratio(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_aspect_ratio_from(inherited_struct);
    }

    /// Set the `aspect_ratio` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_aspect_ratio(
        &mut self,
        value: longhands::aspect_ratio::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_aspect_ratio(
                value,
            );
    }
    /// Inherit `backface_visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_backface_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_backface_visibility_from(inherited_struct);
    }

    /// Set the `backface_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_backface_visibility(
        &mut self,
        value: longhands::backface_visibility::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_backface_visibility(
                value,
            );
    }
    /// Inherit `baseline_source` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_baseline_source(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_baseline_source_from(inherited_struct);
    }

    /// Set the `baseline_source` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_baseline_source(
        &mut self,
        value: longhands::baseline_source::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_baseline_source(
                value,
            );
    }
    /// Reset `border_collapse` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_collapse(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_table();

        if self.inherited_table.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_table.mutate()
            .reset_border_collapse(reset_struct);
    }

    /// Set the `border_collapse` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_collapse(
        &mut self,
        value: longhands::border_collapse::computed_value::T
    ) {

        self.inherited_table.mutate()
            .set_border_collapse(
                value,
            );
    }
    /// Inherit `border_image_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_image_repeat_from(inherited_struct);
    }

    /// Set the `border_image_repeat` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_repeat(
        &mut self,
        value: longhands::border_image_repeat::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_image_repeat(
                value,
            );
    }
    /// Inherit `box_decoration_break` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_decoration_break(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_box_decoration_break_from(inherited_struct);
    }

    /// Set the `box_decoration_break` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_box_decoration_break(
        &mut self,
        value: longhands::box_decoration_break::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_box_decoration_break(
                value,
            );
    }
    /// Inherit `box_sizing` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_sizing(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_box_sizing_from(inherited_struct);
    }

    /// Set the `box_sizing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_box_sizing(
        &mut self,
        value: longhands::box_sizing::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_box_sizing(
                value,
            );
    }
    /// Inherit `break_inside` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_break_inside(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_break_inside_from(inherited_struct);
    }

    /// Set the `break_inside` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_break_inside(
        &mut self,
        value: longhands::break_inside::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_break_inside(
                value,
            );
    }
    /// Reset `caption_side` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_caption_side(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_table();

        if self.inherited_table.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_table.mutate()
            .reset_caption_side(reset_struct);
    }

    /// Set the `caption_side` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_caption_side(
        &mut self,
        value: longhands::caption_side::computed_value::T
    ) {

        self.inherited_table.mutate()
            .set_caption_side(
                value,
            );
    }
    /// Inherit `clear` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clear(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_clear_from(inherited_struct);
    }

    /// Set the `clear` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clear(
        &mut self,
        value: longhands::clear::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_clear(
                value,
            );
    }
    /// Reset `color_interpolation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_interpolation(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_color_interpolation(reset_struct);
    }

    /// Set the `color_interpolation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_interpolation(
        &mut self,
        value: longhands::color_interpolation::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_color_interpolation(
                value,
            );
    }
    /// Reset `color_interpolation_filters` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_interpolation_filters(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_color_interpolation_filters(reset_struct);
    }

    /// Set the `color_interpolation_filters` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_interpolation_filters(
        &mut self,
        value: longhands::color_interpolation_filters::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_color_interpolation_filters(
                value,
            );
    }
    /// Inherit `column_count` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_count(&mut self) {
        let inherited_struct =
            self.inherited_style.get_column();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.column.ptr_eq(inherited_struct) {
            return;
        }

        self.column.mutate()
            .copy_column_count_from(inherited_struct);
    }

    /// Set the `column_count` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_count(
        &mut self,
        value: longhands::column_count::computed_value::T
    ) {
        self.modified_reset = true;

        self.column.mutate()
            .set_column_count(
                value,
            );
    }
    /// Inherit `column_fill` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_fill(&mut self) {
        let inherited_struct =
            self.inherited_style.get_column();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.column.ptr_eq(inherited_struct) {
            return;
        }

        self.column.mutate()
            .copy_column_fill_from(inherited_struct);
    }

    /// Set the `column_fill` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_fill(
        &mut self,
        value: longhands::column_fill::computed_value::T
    ) {
        self.modified_reset = true;

        self.column.mutate()
            .set_column_fill(
                value,
            );
    }
    /// Inherit `column_span` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_span(&mut self) {
        let inherited_struct =
            self.inherited_style.get_column();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.column.ptr_eq(inherited_struct) {
            return;
        }

        self.column.mutate()
            .copy_column_span_from(inherited_struct);
    }

    /// Set the `column_span` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_span(
        &mut self,
        value: longhands::column_span::computed_value::T
    ) {
        self.modified_reset = true;

        self.column.mutate()
            .set_column_span(
                value,
            );
    }
    /// Inherit `contain` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_contain(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_contain_from(inherited_struct);
    }

    /// Set the `contain` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_contain(
        &mut self,
        value: longhands::contain::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_contain(
                value,
            );
    }
    /// Inherit `container_type` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_container_type(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_container_type_from(inherited_struct);
    }

    /// Set the `container_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_container_type(
        &mut self,
        value: longhands::container_type::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_container_type(
                value,
            );
    }
    /// Inherit `content_visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_content_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_content_visibility_from(inherited_struct);
    }

    /// Set the `content_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_content_visibility(
        &mut self,
        value: longhands::content_visibility::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_content_visibility(
                value,
            );
    }
    /// Reset `direction` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_direction(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset_direction(reset_struct);
    }

    /// Set the `direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_direction(
        &mut self,
        value: longhands::direction::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set_direction(
                value,
            );
    }
    /// Inherit `display` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_display(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);


        self.add_flags(ComputedValueFlags::DISPLAY_DEPENDS_ON_INHERITED_STYLE);

        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_display_from(inherited_struct);
    }

    /// Set the `display` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_display(
        &mut self,
        value: longhands::display::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_display(
                value,
            );
    }
    /// Reset `dominant_baseline` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_dominant_baseline(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_dominant_baseline(reset_struct);
    }

    /// Set the `dominant_baseline` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_dominant_baseline(
        &mut self,
        value: longhands::dominant_baseline::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_dominant_baseline(
                value,
            );
    }
    /// Reset `empty_cells` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_empty_cells(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_table();

        if self.inherited_table.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_table.mutate()
            .reset_empty_cells(reset_struct);
    }

    /// Set the `empty_cells` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_empty_cells(
        &mut self,
        value: longhands::empty_cells::computed_value::T
    ) {

        self.inherited_table.mutate()
            .set_empty_cells(
                value,
            );
    }
    /// Inherit `flex_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_direction(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_flex_direction_from(inherited_struct);
    }

    /// Set the `flex_direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_direction(
        &mut self,
        value: longhands::flex_direction::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_flex_direction(
                value,
            );
    }
    /// Inherit `flex_wrap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_wrap(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_flex_wrap_from(inherited_struct);
    }

    /// Set the `flex_wrap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_wrap(
        &mut self,
        value: longhands::flex_wrap::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_flex_wrap(
                value,
            );
    }
    /// Inherit `float` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_float(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_float_from(inherited_struct);
    }

    /// Set the `float` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_float(
        &mut self,
        value: longhands::float::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_float(
                value,
            );
    }
    /// Reset `font_kerning` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_kerning(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_kerning(reset_struct);
    }

    /// Set the `font_kerning` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_kerning(
        &mut self,
        value: longhands::font_kerning::computed_value::T
    ) {

        self.font.mutate()
            .set_font_kerning(
                value,
            );
    }
    /// Reset `font_language_override` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_language_override(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_language_override(reset_struct);
    }

    /// Set the `font_language_override` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_language_override(
        &mut self,
        value: longhands::font_language_override::computed_value::T
    ) {

        self.font.mutate()
            .set_font_language_override(
                value,
            );
    }
    /// Reset `font_optical_sizing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_optical_sizing(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_optical_sizing(reset_struct);
    }

    /// Set the `font_optical_sizing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_optical_sizing(
        &mut self,
        value: longhands::font_optical_sizing::computed_value::T
    ) {

        self.font.mutate()
            .set_font_optical_sizing(
                value,
            );
    }
    /// Reset `font_size_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_size_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_size_adjust(reset_struct);
    }

    /// Set the `font_size_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_size_adjust(
        &mut self,
        value: longhands::font_size_adjust::computed_value::T
    ) {

        self.font.mutate()
            .set_font_size_adjust(
                value,
            );
    }
    /// Reset `font_stretch` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_stretch(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_stretch(reset_struct);
    }

    /// Set the `font_stretch` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_stretch(
        &mut self,
        value: longhands::font_stretch::computed_value::T
    ) {

        self.font.mutate()
            .set_font_stretch(
                value,
            );
    }
    /// Reset `font_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_style(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_style(reset_struct);
    }

    /// Set the `font_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_style(
        &mut self,
        value: longhands::font_style::computed_value::T
    ) {

        self.font.mutate()
            .set_font_style(
                value,
            );
    }
    /// Reset `font_variant_caps` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_caps(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variant_caps(reset_struct);
    }

    /// Set the `font_variant_caps` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_caps(
        &mut self,
        value: longhands::font_variant_caps::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variant_caps(
                value,
            );
    }
    /// Reset `font_variant_east_asian` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_east_asian(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variant_east_asian(reset_struct);
    }

    /// Set the `font_variant_east_asian` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_east_asian(
        &mut self,
        value: longhands::font_variant_east_asian::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variant_east_asian(
                value,
            );
    }
    /// Reset `font_variant_emoji` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_emoji(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variant_emoji(reset_struct);
    }

    /// Set the `font_variant_emoji` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_emoji(
        &mut self,
        value: longhands::font_variant_emoji::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variant_emoji(
                value,
            );
    }
    /// Reset `font_variant_ligatures` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_ligatures(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variant_ligatures(reset_struct);
    }

    /// Set the `font_variant_ligatures` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_ligatures(
        &mut self,
        value: longhands::font_variant_ligatures::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variant_ligatures(
                value,
            );
    }
    /// Reset `font_variant_numeric` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_numeric(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variant_numeric(reset_struct);
    }

    /// Set the `font_variant_numeric` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_numeric(
        &mut self,
        value: longhands::font_variant_numeric::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variant_numeric(
                value,
            );
    }
    /// Reset `font_variant_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_position(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variant_position(reset_struct);
    }

    /// Set the `font_variant_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_position(
        &mut self,
        value: longhands::font_variant_position::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variant_position(
                value,
            );
    }
    /// Reset `font_weight` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_weight(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_weight(reset_struct);
    }

    /// Set the `font_weight` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_weight(
        &mut self,
        value: longhands::font_weight::computed_value::T
    ) {

        self.font.mutate()
            .set_font_weight(
                value,
            );
    }
    /// Reset `forced_color_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_forced_color_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_forced_color_adjust(reset_struct);
    }

    /// Set the `forced_color_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_forced_color_adjust(
        &mut self,
        value: longhands::forced_color_adjust::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_forced_color_adjust(
                value,
            );
    }
    /// Inherit `grid_auto_flow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_flow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_auto_flow_from(inherited_struct);
    }

    /// Set the `grid_auto_flow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_flow(
        &mut self,
        value: longhands::grid_auto_flow::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_auto_flow(
                value,
            );
    }
    /// Reset `hyphens` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_hyphens(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_hyphens(reset_struct);
    }

    /// Set the `hyphens` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_hyphens(
        &mut self,
        value: longhands::hyphens::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_hyphens(
                value,
            );
    }
    /// Reset `image_orientation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_image_orientation(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset_image_orientation(reset_struct);
    }

    /// Set the `image_orientation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_image_orientation(
        &mut self,
        value: longhands::image_orientation::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set_image_orientation(
                value,
            );
    }
    /// Reset `image_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_image_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset_image_rendering(reset_struct);
    }

    /// Set the `image_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_image_rendering(
        &mut self,
        value: longhands::image_rendering::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set_image_rendering(
                value,
            );
    }
    /// Inherit `ime_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ime_mode(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_ime_mode_from(inherited_struct);
    }

    /// Set the `ime_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ime_mode(
        &mut self,
        value: longhands::ime_mode::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set_ime_mode(
                value,
            );
    }
    /// Inherit `initial_letter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_initial_letter(&mut self) {
        let inherited_struct =
            self.inherited_style.get_text();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.text.ptr_eq(inherited_struct) {
            return;
        }

        self.text.mutate()
            .copy_initial_letter_from(inherited_struct);
    }

    /// Set the `initial_letter` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_initial_letter(
        &mut self,
        value: longhands::initial_letter::computed_value::T
    ) {
        self.modified_reset = true;

        self.text.mutate()
            .set_initial_letter(
                value,
            );
    }
    /// Inherit `inset_area` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_inset_area(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_inset_area_from(inherited_struct);
    }

    /// Set the `inset_area` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_inset_area(
        &mut self,
        value: longhands::inset_area::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_inset_area(
                value,
            );
    }
    /// Inherit `isolation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_isolation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_isolation_from(inherited_struct);
    }

    /// Set the `isolation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_isolation(
        &mut self,
        value: longhands::isolation::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_isolation(
                value,
            );
    }
    /// Inherit `justify_content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_content(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_justify_content_from(inherited_struct);
    }

    /// Set the `justify_content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_content(
        &mut self,
        value: longhands::justify_content::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_justify_content(
                value,
            );
    }
    /// Inherit `justify_items` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_items(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_justify_items_from(inherited_struct);
    }

    /// Set the `justify_items` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_items(
        &mut self,
        value: longhands::justify_items::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_justify_items(
                value,
            );
    }
    /// Inherit `justify_self` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_justify_self(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_justify_self_from(inherited_struct);
    }

    /// Set the `justify_self` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_justify_self(
        &mut self,
        value: longhands::justify_self::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_justify_self(
                value,
            );
    }
    /// Reset `line_break` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_line_break(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_line_break(reset_struct);
    }

    /// Set the `line_break` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_line_break(
        &mut self,
        value: longhands::line_break::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_line_break(
                value,
            );
    }
    /// Reset `list_style_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_position(&mut self) {
        let reset_struct =
            self.reset_style.get_list();

        if self.list.ptr_eq(reset_struct) {
            return;
        }

        self.list.mutate()
            .reset_list_style_position(reset_struct);
    }

    /// Set the `list_style_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_position(
        &mut self,
        value: longhands::list_style_position::computed_value::T
    ) {

        self.list.mutate()
            .set_list_style_position(
                value,
            );
    }
    /// Inherit `mask_type` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_type(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_type_from(inherited_struct);
    }

    /// Set the `mask_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mask_type(
        &mut self,
        value: longhands::mask_type::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_mask_type(
                value,
            );
    }
    /// Inherit `masonry_auto_flow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_masonry_auto_flow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_masonry_auto_flow_from(inherited_struct);
    }

    /// Set the `masonry_auto_flow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_masonry_auto_flow(
        &mut self,
        value: longhands::masonry_auto_flow::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_masonry_auto_flow(
                value,
            );
    }
    /// Reset `math_depth` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_math_depth(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_math_depth(reset_struct);
    }

    /// Set the `math_depth` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_math_depth(
        &mut self,
        value: longhands::math_depth::computed_value::T
    ) {

        self.font.mutate()
            .set_math_depth(
                value,
            );
    }
    /// Reset `math_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_math_style(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_math_style(reset_struct);
    }

    /// Set the `math_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_math_style(
        &mut self,
        value: longhands::math_style::computed_value::T
    ) {

        self.font.mutate()
            .set_math_style(
                value,
            );
    }
    /// Inherit `mix_blend_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mix_blend_mode(&mut self) {
        let inherited_struct =
            self.inherited_style.get_effects();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.effects.ptr_eq(inherited_struct) {
            return;
        }

        self.effects.mutate()
            .copy_mix_blend_mode_from(inherited_struct);
    }

    /// Set the `mix_blend_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_mix_blend_mode(
        &mut self,
        value: longhands::mix_blend_mode::computed_value::T
    ) {
        self.modified_reset = true;

        self.effects.mutate()
            .set_mix_blend_mode(
                value,
            );
    }
    /// Inherit `_moz_box_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_align(&mut self) {
        let inherited_struct =
            self.inherited_style.get_xul();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.xul.ptr_eq(inherited_struct) {
            return;
        }

        self.xul.mutate()
            .copy__moz_box_align_from(inherited_struct);
    }

    /// Set the `_moz_box_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_align(
        &mut self,
        value: longhands::_moz_box_align::computed_value::T
    ) {
        self.modified_reset = true;

        self.xul.mutate()
            .set__moz_box_align(
                value,
            );
    }
    /// Reset `_moz_box_collapse` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_box_collapse(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset__moz_box_collapse(reset_struct);
    }

    /// Set the `_moz_box_collapse` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_collapse(
        &mut self,
        value: longhands::_moz_box_collapse::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set__moz_box_collapse(
                value,
            );
    }
    /// Inherit `_moz_box_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_direction(&mut self) {
        let inherited_struct =
            self.inherited_style.get_xul();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.xul.ptr_eq(inherited_struct) {
            return;
        }

        self.xul.mutate()
            .copy__moz_box_direction_from(inherited_struct);
    }

    /// Set the `_moz_box_direction` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_direction(
        &mut self,
        value: longhands::_moz_box_direction::computed_value::T
    ) {
        self.modified_reset = true;

        self.xul.mutate()
            .set__moz_box_direction(
                value,
            );
    }
    /// Inherit `_moz_box_orient` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_orient(&mut self) {
        let inherited_struct =
            self.inherited_style.get_xul();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.xul.ptr_eq(inherited_struct) {
            return;
        }

        self.xul.mutate()
            .copy__moz_box_orient_from(inherited_struct);
    }

    /// Set the `_moz_box_orient` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_orient(
        &mut self,
        value: longhands::_moz_box_orient::computed_value::T
    ) {
        self.modified_reset = true;

        self.xul.mutate()
            .set__moz_box_orient(
                value,
            );
    }
    /// Inherit `_moz_box_pack` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_pack(&mut self) {
        let inherited_struct =
            self.inherited_style.get_xul();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.xul.ptr_eq(inherited_struct) {
            return;
        }

        self.xul.mutate()
            .copy__moz_box_pack_from(inherited_struct);
    }

    /// Set the `_moz_box_pack` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_pack(
        &mut self,
        value: longhands::_moz_box_pack::computed_value::T
    ) {
        self.modified_reset = true;

        self.xul.mutate()
            .set__moz_box_pack(
                value,
            );
    }
    /// Reset `_moz_control_character_visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_control_character_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset__moz_control_character_visibility(reset_struct);
    }

    /// Set the `_moz_control_character_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_control_character_visibility(
        &mut self,
        value: longhands::_moz_control_character_visibility::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set__moz_control_character_visibility(
                value,
            );
    }
    /// Inherit `_moz_float_edge` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_float_edge(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy__moz_float_edge_from(inherited_struct);
    }

    /// Set the `_moz_float_edge` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_float_edge(
        &mut self,
        value: longhands::_moz_float_edge::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set__moz_float_edge(
                value,
            );
    }
    /// Reset `_moz_inert` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_inert(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset__moz_inert(reset_struct);
    }

    /// Set the `_moz_inert` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_inert(
        &mut self,
        value: longhands::_moz_inert::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set__moz_inert(
                value,
            );
    }
    /// Reset `_moz_math_variant` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_math_variant(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset__moz_math_variant(reset_struct);
    }

    /// Set the `_moz_math_variant` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_math_variant(
        &mut self,
        value: longhands::_moz_math_variant::computed_value::T
    ) {

        self.font.mutate()
            .set__moz_math_variant(
                value,
            );
    }
    /// Reset `_moz_min_font_size_ratio` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_min_font_size_ratio(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset__moz_min_font_size_ratio(reset_struct);
    }

    /// Set the `_moz_min_font_size_ratio` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_min_font_size_ratio(
        &mut self,
        value: longhands::_moz_min_font_size_ratio::computed_value::T
    ) {

        self.font.mutate()
            .set__moz_min_font_size_ratio(
                value,
            );
    }
    /// Inherit `_moz_orient` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_orient(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy__moz_orient_from(inherited_struct);
    }

    /// Set the `_moz_orient` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_orient(
        &mut self,
        value: longhands::_moz_orient::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set__moz_orient(
                value,
            );
    }
    /// Reset `_moz_osx_font_smoothing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_osx_font_smoothing(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset__moz_osx_font_smoothing(reset_struct);
    }

    /// Set the `_moz_osx_font_smoothing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_osx_font_smoothing(
        &mut self,
        value: longhands::_moz_osx_font_smoothing::computed_value::T
    ) {

        self.font.mutate()
            .set__moz_osx_font_smoothing(
                value,
            );
    }
    /// Reset `_moz_text_size_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_text_size_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset__moz_text_size_adjust(reset_struct);
    }

    /// Set the `_moz_text_size_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_text_size_adjust(
        &mut self,
        value: longhands::_moz_text_size_adjust::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set__moz_text_size_adjust(
                value,
            );
    }
    /// Reset `_moz_theme` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_theme(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset__moz_theme(reset_struct);
    }

    /// Set the `_moz_theme` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_theme(
        &mut self,
        value: longhands::_moz_theme::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set__moz_theme(
                value,
            );
    }
    /// Inherit `_moz_top_layer` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_top_layer(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy__moz_top_layer_from(inherited_struct);
    }

    /// Set the `_moz_top_layer` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_top_layer(
        &mut self,
        value: longhands::_moz_top_layer::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set__moz_top_layer(
                value,
            );
    }
    /// Reset `_moz_user_focus` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_focus(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset__moz_user_focus(reset_struct);
    }

    /// Set the `_moz_user_focus` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_focus(
        &mut self,
        value: longhands::_moz_user_focus::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set__moz_user_focus(
                value,
            );
    }
    /// Reset `_moz_user_input` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_input(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset__moz_user_input(reset_struct);
    }

    /// Set the `_moz_user_input` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_input(
        &mut self,
        value: longhands::_moz_user_input::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set__moz_user_input(
                value,
            );
    }
    /// Reset `_moz_user_modify` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_user_modify(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset__moz_user_modify(reset_struct);
    }

    /// Set the `_moz_user_modify` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_user_modify(
        &mut self,
        value: longhands::_moz_user_modify::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set__moz_user_modify(
                value,
            );
    }
    /// Inherit `_moz_window_dragging` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_dragging(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_window_dragging_from(inherited_struct);
    }

    /// Set the `_moz_window_dragging` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_dragging(
        &mut self,
        value: longhands::_moz_window_dragging::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_window_dragging(
                value,
            );
    }
    /// Inherit `_moz_window_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_window_shadow_from(inherited_struct);
    }

    /// Set the `_moz_window_shadow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_shadow(
        &mut self,
        value: longhands::_moz_window_shadow::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_window_shadow(
                value,
            );
    }
    /// Inherit `object_fit` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_object_fit(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_object_fit_from(inherited_struct);
    }

    /// Set the `object_fit` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_object_fit(
        &mut self,
        value: longhands::object_fit::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_object_fit(
                value,
            );
    }
    /// Inherit `offset_rotate` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_rotate(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_offset_rotate_from(inherited_struct);
    }

    /// Set the `offset_rotate` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_rotate(
        &mut self,
        value: longhands::offset_rotate::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_offset_rotate(
                value,
            );
    }
    /// Inherit `outline_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_outline();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.outline.ptr_eq(inherited_struct) {
            return;
        }

        self.outline.mutate()
            .copy_outline_style_from(inherited_struct);
    }

    /// Set the `outline_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_style(
        &mut self,
        value: longhands::outline_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.outline.mutate()
            .set_outline_style(
                value,
            );
    }
    /// Inherit `overflow_anchor` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_anchor(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_overflow_anchor_from(inherited_struct);
    }

    /// Set the `overflow_anchor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_anchor(
        &mut self,
        value: longhands::overflow_anchor::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_overflow_anchor(
                value,
            );
    }
    /// Reset `overflow_wrap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_overflow_wrap(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_overflow_wrap(reset_struct);
    }

    /// Set the `overflow_wrap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_wrap(
        &mut self,
        value: longhands::overflow_wrap::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_overflow_wrap(
                value,
            );
    }
    /// Inherit `page_orientation` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page_orientation(&mut self) {
        let inherited_struct =
            self.inherited_style.get_page();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.page.ptr_eq(inherited_struct) {
            return;
        }

        self.page.mutate()
            .copy_page_orientation_from(inherited_struct);
    }

    /// Set the `page_orientation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page_orientation(
        &mut self,
        value: longhands::page_orientation::computed_value::T
    ) {
        self.modified_reset = true;

        self.page.mutate()
            .set_page_orientation(
                value,
            );
    }
    /// Reset `paint_order` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_paint_order(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_paint_order(reset_struct);
    }

    /// Set the `paint_order` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_paint_order(
        &mut self,
        value: longhands::paint_order::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_paint_order(
                value,
            );
    }
    /// Reset `pointer_events` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_pointer_events(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset_pointer_events(reset_struct);
    }

    /// Set the `pointer_events` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_pointer_events(
        &mut self,
        value: longhands::pointer_events::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set_pointer_events(
                value,
            );
    }
    /// Inherit `position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_position_from(inherited_struct);
    }

    /// Set the `position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_position(
        &mut self,
        value: longhands::position::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_position(
                value,
            );
    }
    /// Inherit `position_try_order` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_position_try_order(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_position_try_order_from(inherited_struct);
    }

    /// Set the `position_try_order` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_position_try_order(
        &mut self,
        value: longhands::position_try_order::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_position_try_order(
                value,
            );
    }
    /// Inherit `position_visibility` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_position_visibility(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_position_visibility_from(inherited_struct);
    }

    /// Set the `position_visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_position_visibility(
        &mut self,
        value: longhands::position_visibility::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_position_visibility(
                value,
            );
    }
    /// Reset `print_color_adjust` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_print_color_adjust(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset_print_color_adjust(reset_struct);
    }

    /// Set the `print_color_adjust` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_print_color_adjust(
        &mut self,
        value: longhands::print_color_adjust::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set_print_color_adjust(
                value,
            );
    }
    /// Inherit `resize` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_resize(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_resize_from(inherited_struct);
    }

    /// Set the `resize` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_resize(
        &mut self,
        value: longhands::resize::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_resize(
                value,
            );
    }
    /// Reset `ruby_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ruby_align(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_ruby_align(reset_struct);
    }

    /// Set the `ruby_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ruby_align(
        &mut self,
        value: longhands::ruby_align::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_ruby_align(
                value,
            );
    }
    /// Reset `ruby_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_ruby_position(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_ruby_position(reset_struct);
    }

    /// Set the `ruby_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ruby_position(
        &mut self,
        value: longhands::ruby_position::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_ruby_position(
                value,
            );
    }
    /// Inherit `scroll_behavior` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_behavior(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_scroll_behavior_from(inherited_struct);
    }

    /// Set the `scroll_behavior` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_behavior(
        &mut self,
        value: longhands::scroll_behavior::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_scroll_behavior(
                value,
            );
    }
    /// Inherit `scroll_snap_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_align(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_scroll_snap_align_from(inherited_struct);
    }

    /// Set the `scroll_snap_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_align(
        &mut self,
        value: longhands::scroll_snap_align::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_scroll_snap_align(
                value,
            );
    }
    /// Inherit `scroll_snap_stop` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_stop(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_scroll_snap_stop_from(inherited_struct);
    }

    /// Set the `scroll_snap_stop` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_stop(
        &mut self,
        value: longhands::scroll_snap_stop::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_scroll_snap_stop(
                value,
            );
    }
    /// Inherit `scroll_snap_type` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_snap_type(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_scroll_snap_type_from(inherited_struct);
    }

    /// Set the `scroll_snap_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_snap_type(
        &mut self,
        value: longhands::scroll_snap_type::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_scroll_snap_type(
                value,
            );
    }
    /// Inherit `scrollbar_gutter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scrollbar_gutter(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_scrollbar_gutter_from(inherited_struct);
    }

    /// Set the `scrollbar_gutter` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scrollbar_gutter(
        &mut self,
        value: longhands::scrollbar_gutter::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_scrollbar_gutter(
                value,
            );
    }
    /// Inherit `scrollbar_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scrollbar_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_scrollbar_width_from(inherited_struct);
    }

    /// Set the `scrollbar_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scrollbar_width(
        &mut self,
        value: longhands::scrollbar_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set_scrollbar_width(
                value,
            );
    }
    /// Reset `shape_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_shape_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_shape_rendering(reset_struct);
    }

    /// Set the `shape_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_rendering(
        &mut self,
        value: longhands::shape_rendering::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_shape_rendering(
                value,
            );
    }
    /// Reset `stroke_linecap` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_linecap(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke_linecap(reset_struct);
    }

    /// Set the `stroke_linecap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_linecap(
        &mut self,
        value: longhands::stroke_linecap::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke_linecap(
                value,
            );
    }
    /// Reset `stroke_linejoin` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_linejoin(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke_linejoin(reset_struct);
    }

    /// Set the `stroke_linejoin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_linejoin(
        &mut self,
        value: longhands::stroke_linejoin::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke_linejoin(
                value,
            );
    }
    /// Inherit `table_layout` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_table_layout(&mut self) {
        let inherited_struct =
            self.inherited_style.get_table();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.table.ptr_eq(inherited_struct) {
            return;
        }

        self.table.mutate()
            .copy_table_layout_from(inherited_struct);
    }

    /// Set the `table_layout` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_table_layout(
        &mut self,
        value: longhands::table_layout::computed_value::T
    ) {
        self.modified_reset = true;

        self.table.mutate()
            .set_table_layout(
                value,
            );
    }
    /// Reset `text_align` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_align(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_align(reset_struct);
    }

    /// Set the `text_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_align(
        &mut self,
        value: longhands::text_align::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_align(
                value,
            );
    }
    /// Reset `text_align_last` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_align_last(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_align_last(reset_struct);
    }

    /// Set the `text_align_last` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_align_last(
        &mut self,
        value: longhands::text_align_last::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_align_last(
                value,
            );
    }
    /// Reset `text_anchor` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_anchor(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_text_anchor(reset_struct);
    }

    /// Set the `text_anchor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_anchor(
        &mut self,
        value: longhands::text_anchor::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_text_anchor(
                value,
            );
    }
    /// Reset `text_combine_upright` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_combine_upright(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_combine_upright(reset_struct);
    }

    /// Set the `text_combine_upright` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_combine_upright(
        &mut self,
        value: longhands::text_combine_upright::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_combine_upright(
                value,
            );
    }
    /// Inherit `text_decoration_line` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_line(&mut self) {
        let inherited_struct =
            self.inherited_style.get_text();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.text.ptr_eq(inherited_struct) {
            return;
        }

        self.text.mutate()
            .copy_text_decoration_line_from(inherited_struct);
    }

    /// Set the `text_decoration_line` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_line(
        &mut self,
        value: longhands::text_decoration_line::computed_value::T
    ) {
        self.modified_reset = true;

        self.text.mutate()
            .set_text_decoration_line(
                value,
            );
    }
    /// Reset `text_decoration_skip_ink` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_decoration_skip_ink(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_decoration_skip_ink(reset_struct);
    }

    /// Set the `text_decoration_skip_ink` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_skip_ink(
        &mut self,
        value: longhands::text_decoration_skip_ink::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_decoration_skip_ink(
                value,
            );
    }
    /// Inherit `text_decoration_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_text();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.text.ptr_eq(inherited_struct) {
            return;
        }

        self.text.mutate()
            .copy_text_decoration_style_from(inherited_struct);
    }

    /// Set the `text_decoration_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_style(
        &mut self,
        value: longhands::text_decoration_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.text.mutate()
            .set_text_decoration_style(
                value,
            );
    }
    /// Reset `text_emphasis_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_position(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_emphasis_position(reset_struct);
    }

    /// Set the `text_emphasis_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_position(
        &mut self,
        value: longhands::text_emphasis_position::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_emphasis_position(
                value,
            );
    }
    /// Reset `text_justify` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_justify(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_justify(reset_struct);
    }

    /// Set the `text_justify` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_justify(
        &mut self,
        value: longhands::text_justify::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_justify(
                value,
            );
    }
    /// Reset `text_orientation` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_orientation(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset_text_orientation(reset_struct);
    }

    /// Set the `text_orientation` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_orientation(
        &mut self,
        value: longhands::text_orientation::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set_text_orientation(
                value,
            );
    }
    /// Reset `text_rendering` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_rendering(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_rendering(reset_struct);
    }

    /// Set the `text_rendering` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_rendering(
        &mut self,
        value: longhands::text_rendering::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_rendering(
                value,
            );
    }
    /// Reset `text_transform` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_transform(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_transform(reset_struct);
    }

    /// Set the `text_transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_transform(
        &mut self,
        value: longhands::text_transform::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_transform(
                value,
            );
    }
    /// Reset `text_underline_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_underline_position(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_underline_position(reset_struct);
    }

    /// Set the `text_underline_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_underline_position(
        &mut self,
        value: longhands::text_underline_position::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_underline_position(
                value,
            );
    }
    /// Reset `text_wrap_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_wrap_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_wrap_mode(reset_struct);
    }

    /// Set the `text_wrap_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_wrap_mode(
        &mut self,
        value: longhands::text_wrap_mode::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_wrap_mode(
                value,
            );
    }
    /// Reset `text_wrap_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_wrap_style(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_wrap_style(reset_struct);
    }

    /// Set the `text_wrap_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_wrap_style(
        &mut self,
        value: longhands::text_wrap_style::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_wrap_style(
                value,
            );
    }
    /// Inherit `touch_action` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_touch_action(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_touch_action_from(inherited_struct);
    }

    /// Set the `touch_action` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_touch_action(
        &mut self,
        value: longhands::touch_action::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_touch_action(
                value,
            );
    }
    /// Inherit `transform_box` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_box(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_transform_box_from(inherited_struct);
    }

    /// Set the `transform_box` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_box(
        &mut self,
        value: longhands::transform_box::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_transform_box(
                value,
            );
    }
    /// Inherit `transform_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_transform_style_from(inherited_struct);
    }

    /// Set the `transform_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_style(
        &mut self,
        value: longhands::transform_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_transform_style(
                value,
            );
    }
    /// Inherit `unicode_bidi` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_unicode_bidi(&mut self) {
        let inherited_struct =
            self.inherited_style.get_text();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.text.ptr_eq(inherited_struct) {
            return;
        }

        self.text.mutate()
            .copy_unicode_bidi_from(inherited_struct);
    }

    /// Set the `unicode_bidi` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_unicode_bidi(
        &mut self,
        value: longhands::unicode_bidi::computed_value::T
    ) {
        self.modified_reset = true;

        self.text.mutate()
            .set_unicode_bidi(
                value,
            );
    }
    /// Inherit `user_select` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_user_select(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_user_select_from(inherited_struct);
    }

    /// Set the `user_select` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_user_select(
        &mut self,
        value: longhands::user_select::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set_user_select(
                value,
            );
    }
    /// Inherit `vector_effect` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_vector_effect(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_vector_effect_from(inherited_struct);
    }

    /// Set the `vector_effect` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_vector_effect(
        &mut self,
        value: longhands::vector_effect::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_vector_effect(
                value,
            );
    }
    /// Reset `visibility` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_visibility(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset_visibility(reset_struct);
    }

    /// Set the `visibility` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_visibility(
        &mut self,
        value: longhands::visibility::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set_visibility(
                value,
            );
    }
    /// Inherit `_webkit_line_clamp` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__webkit_line_clamp(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy__webkit_line_clamp_from(inherited_struct);
    }

    /// Set the `_webkit_line_clamp` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_line_clamp(
        &mut self,
        value: longhands::_webkit_line_clamp::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set__webkit_line_clamp(
                value,
            );
    }
    /// Reset `_webkit_text_security` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_security(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset__webkit_text_security(reset_struct);
    }

    /// Set the `_webkit_text_security` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_security(
        &mut self,
        value: longhands::_webkit_text_security::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set__webkit_text_security(
                value,
            );
    }
    /// Reset `white_space_collapse` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_white_space_collapse(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_white_space_collapse(reset_struct);
    }

    /// Set the `white_space_collapse` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_white_space_collapse(
        &mut self,
        value: longhands::white_space_collapse::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_white_space_collapse(
                value,
            );
    }
    /// Reset `word_break` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_word_break(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_word_break(reset_struct);
    }

    /// Set the `word_break` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_word_break(
        &mut self,
        value: longhands::word_break::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_word_break(
                value,
            );
    }
    /// Reset `writing_mode` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_writing_mode(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_box();

        if self.inherited_box.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_box.mutate()
            .reset_writing_mode(reset_struct);
    }

    /// Set the `writing_mode` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_writing_mode(
        &mut self,
        value: longhands::writing_mode::computed_value::T
    ) {

        self.inherited_box.mutate()
            .set_writing_mode(
                value,
            );
    }
    /// Reset `_x_text_scale` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_text_scale(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset__x_text_scale(reset_struct);
    }

    /// Set the `_x_text_scale` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_text_scale(
        &mut self,
        value: longhands::_x_text_scale::computed_value::T
    ) {

        self.font.mutate()
            .set__x_text_scale(
                value,
            );
    }
    /// Inherit `z_index` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_z_index(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_z_index_from(inherited_struct);
    }

    /// Set the `z_index` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_z_index(
        &mut self,
        value: longhands::z_index::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_z_index(
                value,
            );
    }
    /// Inherit `zoom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_zoom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_zoom_from(inherited_struct);
    }

    /// Set the `zoom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_zoom(
        &mut self,
        value: longhands::zoom::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_zoom(
                value,
            );
    }
    /// Inherit `appearance` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_appearance(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_appearance_from(inherited_struct);
    }

    /// Set the `appearance` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_appearance(
        &mut self,
        value: longhands::appearance::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_appearance(
                value,
            );
    }
    /// Inherit `_moz_default_appearance` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_default_appearance(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy__moz_default_appearance_from(inherited_struct);
    }

    /// Set the `_moz_default_appearance` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_default_appearance(
        &mut self,
        value: longhands::_moz_default_appearance::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set__moz_default_appearance(
                value,
            );
    }
    /// Inherit `_moz_force_broken_image_icon` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_force_broken_image_icon(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_force_broken_image_icon_from(inherited_struct);
    }

    /// Set the `_moz_force_broken_image_icon` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_force_broken_image_icon(
        &mut self,
        value: longhands::_moz_force_broken_image_icon::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_force_broken_image_icon(
                value,
            );
    }
    /// Inherit `_moz_subtree_hidden_only_visually` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_subtree_hidden_only_visually(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_subtree_hidden_only_visually_from(inherited_struct);
    }

    /// Set the `_moz_subtree_hidden_only_visually` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_subtree_hidden_only_visually(
        &mut self,
        value: longhands::_moz_subtree_hidden_only_visually::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_subtree_hidden_only_visually(
                value,
            );
    }
    /// Inherit `break_after` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_break_after(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_break_after_from(inherited_struct);
    }

    /// Set the `break_after` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_break_after(
        &mut self,
        value: longhands::break_after::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_break_after(
                value,
            );
    }
    /// Inherit `break_before` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_break_before(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_break_before_from(inherited_struct);
    }

    /// Set the `break_before` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_break_before(
        &mut self,
        value: longhands::break_before::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_break_before(
                value,
            );
    }
    /// Reset `clip_rule` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_clip_rule(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_clip_rule(reset_struct);
    }

    /// Set the `clip_rule` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip_rule(
        &mut self,
        value: longhands::clip_rule::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_clip_rule(
                value,
            );
    }
    /// Reset `fill_rule` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill_rule(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_fill_rule(reset_struct);
    }

    /// Set the `fill_rule` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill_rule(
        &mut self,
        value: longhands::fill_rule::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_fill_rule(
                value,
            );
    }
    /// Inherit `overflow_clip_box_block` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_clip_box_block(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_overflow_clip_box_block_from(inherited_struct);
    }

    /// Set the `overflow_clip_box_block` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_block(
        &mut self,
        value: longhands::overflow_clip_box_block::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_overflow_clip_box_block(
                value,
            );
    }
    /// Inherit `overflow_clip_box_inline` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_clip_box_inline(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_overflow_clip_box_inline_from(inherited_struct);
    }

    /// Set the `overflow_clip_box_inline` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_clip_box_inline(
        &mut self,
        value: longhands::overflow_clip_box_inline::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_overflow_clip_box_inline(
                value,
            );
    }
    /// Reset `fill_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_fill_opacity(reset_struct);
    }

    /// Set the `fill_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill_opacity(
        &mut self,
        value: longhands::fill_opacity::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_fill_opacity(
                value,
            );
    }
    /// Reset `stroke_opacity` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_opacity(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke_opacity(reset_struct);
    }

    /// Set the `stroke_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_opacity(
        &mut self,
        value: longhands::stroke_opacity::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke_opacity(
                value,
            );
    }
    /// Inherit `_moz_box_ordinal_group` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_ordinal_group(&mut self) {
        let inherited_struct =
            self.inherited_style.get_xul();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.xul.ptr_eq(inherited_struct) {
            return;
        }

        self.xul.mutate()
            .copy__moz_box_ordinal_group_from(inherited_struct);
    }

    /// Set the `_moz_box_ordinal_group` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_ordinal_group(
        &mut self,
        value: longhands::_moz_box_ordinal_group::computed_value::T
    ) {
        self.modified_reset = true;

        self.xul.mutate()
            .set__moz_box_ordinal_group(
                value,
            );
    }
    /// Inherit `order` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_order(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_order_from(inherited_struct);
    }

    /// Set the `order` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_order(
        &mut self,
        value: longhands::order::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_order(
                value,
            );
    }
    /// Inherit `_x_span` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__x_span(&mut self) {
        let inherited_struct =
            self.inherited_style.get_table();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.table.ptr_eq(inherited_struct) {
            return;
        }

        self.table.mutate()
            .copy__x_span_from(inherited_struct);
    }

    /// Set the `_x_span` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_span(
        &mut self,
        value: longhands::_x_span::computed_value::T
    ) {
        self.modified_reset = true;

        self.table.mutate()
            .set__x_span(
                value,
            );
    }
    /// Reset `font_synthesis_position` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_position(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_synthesis_position(reset_struct);
    }

    /// Set the `font_synthesis_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_synthesis_position(
        &mut self,
        value: longhands::font_synthesis_position::computed_value::T
    ) {

        self.font.mutate()
            .set_font_synthesis_position(
                value,
            );
    }
    /// Reset `font_synthesis_small_caps` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_small_caps(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_synthesis_small_caps(reset_struct);
    }

    /// Set the `font_synthesis_small_caps` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_synthesis_small_caps(
        &mut self,
        value: longhands::font_synthesis_small_caps::computed_value::T
    ) {

        self.font.mutate()
            .set_font_synthesis_small_caps(
                value,
            );
    }
    /// Reset `font_synthesis_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_style(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_synthesis_style(reset_struct);
    }

    /// Set the `font_synthesis_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_synthesis_style(
        &mut self,
        value: longhands::font_synthesis_style::computed_value::T
    ) {

        self.font.mutate()
            .set_font_synthesis_style(
                value,
            );
    }
    /// Reset `font_synthesis_weight` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_synthesis_weight(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_synthesis_weight(reset_struct);
    }

    /// Set the `font_synthesis_weight` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_synthesis_weight(
        &mut self,
        value: longhands::font_synthesis_weight::computed_value::T
    ) {

        self.font.mutate()
            .set_font_synthesis_weight(
                value,
            );
    }
    /// Inherit `flex_grow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_grow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_flex_grow_from(inherited_struct);
    }

    /// Set the `flex_grow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_grow(
        &mut self,
        value: longhands::flex_grow::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_flex_grow(
                value,
            );
    }
    /// Inherit `flex_shrink` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_shrink(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_flex_shrink_from(inherited_struct);
    }

    /// Set the `flex_shrink` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_shrink(
        &mut self,
        value: longhands::flex_shrink::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_flex_shrink(
                value,
            );
    }
    /// Inherit `_moz_box_flex` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_box_flex(&mut self) {
        let inherited_struct =
            self.inherited_style.get_xul();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.xul.ptr_eq(inherited_struct) {
            return;
        }

        self.xul.mutate()
            .copy__moz_box_flex_from(inherited_struct);
    }

    /// Set the `_moz_box_flex` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_box_flex(
        &mut self,
        value: longhands::_moz_box_flex::computed_value::T
    ) {
        self.modified_reset = true;

        self.xul.mutate()
            .set__moz_box_flex(
                value,
            );
    }
    /// Reset `stroke_miterlimit` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_miterlimit(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke_miterlimit(reset_struct);
    }

    /// Set the `stroke_miterlimit` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_miterlimit(
        &mut self,
        value: longhands::stroke_miterlimit::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke_miterlimit(
                value,
            );
    }
    /// Inherit `overflow_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_x(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_overflow_x_from(inherited_struct);
    }

    /// Set the `overflow_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_x(
        &mut self,
        value: longhands::overflow_x::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_overflow_x(
                value,
            );
    }
    /// Inherit `overflow_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_y(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_overflow_y_from(inherited_struct);
    }

    /// Set the `overflow_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_y(
        &mut self,
        value: longhands::overflow_y::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_overflow_y(
                value,
            );
    }
    /// Inherit `overscroll_behavior_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overscroll_behavior_x(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_overscroll_behavior_x_from(inherited_struct);
    }

    /// Set the `overscroll_behavior_x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_x(
        &mut self,
        value: longhands::overscroll_behavior_x::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_overscroll_behavior_x(
                value,
            );
    }
    /// Inherit `overscroll_behavior_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overscroll_behavior_y(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_overscroll_behavior_y_from(inherited_struct);
    }

    /// Set the `overscroll_behavior_y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overscroll_behavior_y(
        &mut self,
        value: longhands::overscroll_behavior_y::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_overscroll_behavior_y(
                value,
            );
    }
    /// Inherit `flood_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flood_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_flood_opacity_from(inherited_struct);
    }

    /// Set the `flood_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flood_opacity(
        &mut self,
        value: longhands::flood_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_flood_opacity(
                value,
            );
    }
    /// Inherit `_moz_window_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_window_opacity_from(inherited_struct);
    }

    /// Set the `_moz_window_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_opacity(
        &mut self,
        value: longhands::_moz_window_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_window_opacity(
                value,
            );
    }
    /// Inherit `opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_effects();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.effects.ptr_eq(inherited_struct) {
            return;
        }

        self.effects.mutate()
            .copy_opacity_from(inherited_struct);
    }

    /// Set the `opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_opacity(
        &mut self,
        value: longhands::opacity::computed_value::T
    ) {
        self.modified_reset = true;

        self.effects.mutate()
            .set_opacity(
                value,
            );
    }
    /// Inherit `shape_image_threshold` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_image_threshold(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_shape_image_threshold_from(inherited_struct);
    }

    /// Set the `shape_image_threshold` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_image_threshold(
        &mut self,
        value: longhands::shape_image_threshold::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_shape_image_threshold(
                value,
            );
    }
    /// Inherit `stop_opacity` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stop_opacity(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_stop_opacity_from(inherited_struct);
    }

    /// Set the `stop_opacity` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stop_opacity(
        &mut self,
        value: longhands::stop_opacity::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_stop_opacity(
                value,
            );
    }
    /// Inherit `border_bottom_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_bottom_style_from(inherited_struct);
    }

    /// Set the `border_bottom_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_style(
        &mut self,
        value: longhands::border_bottom_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_bottom_style(
                value,
            );
    }
    /// Inherit `border_left_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_left_style_from(inherited_struct);
    }

    /// Set the `border_left_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_style(
        &mut self,
        value: longhands::border_left_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_left_style(
                value,
            );
    }
    /// Inherit `border_right_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_right_style_from(inherited_struct);
    }

    /// Set the `border_right_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_style(
        &mut self,
        value: longhands::border_right_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_right_style(
                value,
            );
    }
    /// Inherit `border_top_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_top_style_from(inherited_struct);
    }

    /// Set the `border_top_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_style(
        &mut self,
        value: longhands::border_top_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_top_style(
                value,
            );
    }
    /// Inherit `column_rule_style` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_style(&mut self) {
        let inherited_struct =
            self.inherited_style.get_column();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.column.ptr_eq(inherited_struct) {
            return;
        }

        self.column.mutate()
            .copy_column_rule_style_from(inherited_struct);
    }

    /// Set the `column_rule_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_style(
        &mut self,
        value: longhands::column_rule_style::computed_value::T
    ) {
        self.modified_reset = true;

        self.column.mutate()
            .set_column_rule_style(
                value,
            );
    }
    /// Reset `accent_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_accent_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset_accent_color(reset_struct);
    }

    /// Set the `accent_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_accent_color(
        &mut self,
        value: longhands::accent_color::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set_accent_color(
                value,
            );
    }
    /// Inherit `anchor_name` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_anchor_name(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_anchor_name_from(inherited_struct);
    }

    /// Set the `anchor_name` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_anchor_name(
        &mut self,
        value: longhands::anchor_name::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_anchor_name(
                value,
            );
    }
    /// Inherit `anchor_scope` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_anchor_scope(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_anchor_scope_from(inherited_struct);
    }

    /// Set the `anchor_scope` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_anchor_scope(
        &mut self,
        value: longhands::anchor_scope::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_anchor_scope(
                value,
            );
    }
    /// Inherit `animation_composition` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_composition(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_composition_from(inherited_struct);
    }

    /// Inherit `animation_delay` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_delay(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_delay_from(inherited_struct);
    }

    /// Inherit `animation_direction` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_direction(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_direction_from(inherited_struct);
    }

    /// Inherit `animation_duration` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_duration(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_duration_from(inherited_struct);
    }

    /// Inherit `animation_fill_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_fill_mode(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_fill_mode_from(inherited_struct);
    }

    /// Inherit `animation_iteration_count` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_iteration_count(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_iteration_count_from(inherited_struct);
    }

    /// Inherit `animation_name` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_name(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_name_from(inherited_struct);
    }

    /// Inherit `animation_play_state` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_play_state(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_play_state_from(inherited_struct);
    }

    /// Inherit `animation_timeline` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_timeline(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_timeline_from(inherited_struct);
    }

    /// Inherit `animation_timing_function` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_animation_timing_function(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_animation_timing_function_from(inherited_struct);
    }

    /// Inherit `backdrop_filter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_backdrop_filter(&mut self) {
        let inherited_struct =
            self.inherited_style.get_effects();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.effects.ptr_eq(inherited_struct) {
            return;
        }

        self.effects.mutate()
            .copy_backdrop_filter_from(inherited_struct);
    }

    /// Set the `backdrop_filter` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_backdrop_filter(
        &mut self,
        value: longhands::backdrop_filter::computed_value::T
    ) {
        self.modified_reset = true;

        self.effects.mutate()
            .set_backdrop_filter(
                value,
            );
    }
    /// Inherit `background_attachment` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_attachment(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_attachment_from(inherited_struct);
    }

    /// Inherit `background_blend_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_blend_mode(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_blend_mode_from(inherited_struct);
    }

    /// Inherit `background_clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_clip(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_clip_from(inherited_struct);
    }

    /// Inherit `background_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_image(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_image_from(inherited_struct);
    }

    /// Inherit `background_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_origin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_origin_from(inherited_struct);
    }

    /// Inherit `background_position_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_position_x(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_position_x_from(inherited_struct);
    }

    /// Inherit `background_position_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_position_y(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_position_y_from(inherited_struct);
    }

    /// Inherit `background_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_repeat_from(inherited_struct);
    }

    /// Inherit `background_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_size(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_size_from(inherited_struct);
    }

    /// Inherit `border_image_outset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_outset(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_image_outset_from(inherited_struct);
    }

    /// Set the `border_image_outset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_outset(
        &mut self,
        value: longhands::border_image_outset::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_image_outset(
                value,
            );
    }
    /// Inherit `border_image_slice` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_slice(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_image_slice_from(inherited_struct);
    }

    /// Set the `border_image_slice` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_slice(
        &mut self,
        value: longhands::border_image_slice::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_image_slice(
                value,
            );
    }
    /// Inherit `border_image_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_image_width_from(inherited_struct);
    }

    /// Set the `border_image_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_width(
        &mut self,
        value: longhands::border_image_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_image_width(
                value,
            );
    }
    /// Reset `border_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_border_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_table();

        if self.inherited_table.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_table.mutate()
            .reset_border_spacing(reset_struct);
    }

    /// Set the `border_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_spacing(
        &mut self,
        value: longhands::border_spacing::computed_value::T
    ) {

        self.inherited_table.mutate()
            .set_border_spacing(
                value,
            );
    }
    /// Inherit `box_shadow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_box_shadow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_effects();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.effects.ptr_eq(inherited_struct) {
            return;
        }

        self.effects.mutate()
            .copy_box_shadow_from(inherited_struct);
    }

    /// Set the `box_shadow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_box_shadow(
        &mut self,
        value: longhands::box_shadow::computed_value::T
    ) {
        self.modified_reset = true;

        self.effects.mutate()
            .set_box_shadow(
                value,
            );
    }
    /// Reset `caret_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_caret_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset_caret_color(reset_struct);
    }

    /// Set the `caret_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_caret_color(
        &mut self,
        value: longhands::caret_color::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set_caret_color(
                value,
            );
    }
    /// Inherit `clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip(&mut self) {
        let inherited_struct =
            self.inherited_style.get_effects();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.effects.ptr_eq(inherited_struct) {
            return;
        }

        self.effects.mutate()
            .copy_clip_from(inherited_struct);
    }

    /// Set the `clip` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip(
        &mut self,
        value: longhands::clip::computed_value::T
    ) {
        self.modified_reset = true;

        self.effects.mutate()
            .set_clip(
                value,
            );
    }
    /// Inherit `clip_path` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_clip_path(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_clip_path_from(inherited_struct);
    }

    /// Set the `clip_path` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_clip_path(
        &mut self,
        value: longhands::clip_path::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_clip_path(
                value,
            );
    }
    /// Reset `color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_color(reset_struct);
    }

    /// Set the `color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color(
        &mut self,
        value: longhands::color::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_color(
                value,
            );
    }
    /// Reset `color_scheme` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_color_scheme(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset_color_scheme(reset_struct);
    }

    /// Set the `color_scheme` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_color_scheme(
        &mut self,
        value: longhands::color_scheme::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set_color_scheme(
                value,
            );
    }
    /// Inherit `column_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_column();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.column.ptr_eq(inherited_struct) {
            return;
        }

        self.column.mutate()
            .copy_column_width_from(inherited_struct);
    }

    /// Set the `column_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_width(
        &mut self,
        value: longhands::column_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.column.mutate()
            .set_column_width(
                value,
            );
    }
    /// Inherit `container_name` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_container_name(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_container_name_from(inherited_struct);
    }

    /// Set the `container_name` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_container_name(
        &mut self,
        value: longhands::container_name::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_container_name(
                value,
            );
    }
    /// Inherit `content` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_content(&mut self) {
        let inherited_struct =
            self.inherited_style.get_counters();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);

        self.add_flags(ComputedValueFlags::CONTENT_DEPENDS_ON_INHERITED_STYLE);


        if self.counters.ptr_eq(inherited_struct) {
            return;
        }

        self.counters.mutate()
            .copy_content_from(inherited_struct);
    }

    /// Set the `content` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_content(
        &mut self,
        value: longhands::content::computed_value::T
    ) {
        self.modified_reset = true;

        self.counters.mutate()
            .set_content(
                value,
            );
    }
    /// Inherit `counter_increment` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_counter_increment(&mut self) {
        let inherited_struct =
            self.inherited_style.get_counters();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.counters.ptr_eq(inherited_struct) {
            return;
        }

        self.counters.mutate()
            .copy_counter_increment_from(inherited_struct);
    }

    /// Set the `counter_increment` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_counter_increment(
        &mut self,
        value: longhands::counter_increment::computed_value::T
    ) {
        self.modified_reset = true;

        self.counters.mutate()
            .set_counter_increment(
                value,
            );
    }
    /// Inherit `counter_reset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_counter_reset(&mut self) {
        let inherited_struct =
            self.inherited_style.get_counters();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.counters.ptr_eq(inherited_struct) {
            return;
        }

        self.counters.mutate()
            .copy_counter_reset_from(inherited_struct);
    }

    /// Set the `counter_reset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_counter_reset(
        &mut self,
        value: longhands::counter_reset::computed_value::T
    ) {
        self.modified_reset = true;

        self.counters.mutate()
            .set_counter_reset(
                value,
            );
    }
    /// Inherit `counter_set` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_counter_set(&mut self) {
        let inherited_struct =
            self.inherited_style.get_counters();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.counters.ptr_eq(inherited_struct) {
            return;
        }

        self.counters.mutate()
            .copy_counter_set_from(inherited_struct);
    }

    /// Set the `counter_set` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_counter_set(
        &mut self,
        value: longhands::counter_set::computed_value::T
    ) {
        self.modified_reset = true;

        self.counters.mutate()
            .set_counter_set(
                value,
            );
    }
    /// Reset `cursor` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_cursor(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset_cursor(reset_struct);
    }

    /// Set the `cursor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_cursor(
        &mut self,
        value: longhands::cursor::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set_cursor(
                value,
            );
    }
    /// Inherit `d` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_d(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_d_from(inherited_struct);
    }

    /// Set the `d` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_d(
        &mut self,
        value: longhands::d::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_d(
                value,
            );
    }
    /// Inherit `filter` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_filter(&mut self) {
        let inherited_struct =
            self.inherited_style.get_effects();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.effects.ptr_eq(inherited_struct) {
            return;
        }

        self.effects.mutate()
            .copy_filter_from(inherited_struct);
    }

    /// Set the `filter` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_filter(
        &mut self,
        value: longhands::filter::computed_value::T
    ) {
        self.modified_reset = true;

        self.effects.mutate()
            .set_filter(
                value,
            );
    }
    /// Inherit `flex_basis` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flex_basis(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_flex_basis_from(inherited_struct);
    }

    /// Set the `flex_basis` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flex_basis(
        &mut self,
        value: longhands::flex_basis::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_flex_basis(
                value,
            );
    }
    /// Reset `font_family` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_family(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_family(reset_struct);
    }

    /// Set the `font_family` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_family(
        &mut self,
        value: longhands::font_family::computed_value::T
    ) {

        self.font.mutate()
            .set_font_family(
                value,
            );
    }
    /// Reset `font_feature_settings` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_feature_settings(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_feature_settings(reset_struct);
    }

    /// Set the `font_feature_settings` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_feature_settings(
        &mut self,
        value: longhands::font_feature_settings::computed_value::T
    ) {

        self.font.mutate()
            .set_font_feature_settings(
                value,
            );
    }
    /// Reset `font_palette` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_palette(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_palette(reset_struct);
    }

    /// Set the `font_palette` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_palette(
        &mut self,
        value: longhands::font_palette::computed_value::T
    ) {

        self.font.mutate()
            .set_font_palette(
                value,
            );
    }
    /// Reset `font_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_size(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_size(reset_struct);
    }

    /// Set the `font_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_size(
        &mut self,
        value: longhands::font_size::computed_value::T
    ) {

        self.font.mutate()
            .set_font_size(
                value,
            );
    }
    /// Reset `font_variant_alternates` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variant_alternates(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variant_alternates(reset_struct);
    }

    /// Set the `font_variant_alternates` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variant_alternates(
        &mut self,
        value: longhands::font_variant_alternates::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variant_alternates(
                value,
            );
    }
    /// Reset `font_variation_settings` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_font_variation_settings(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_font_variation_settings(reset_struct);
    }

    /// Set the `font_variation_settings` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_font_variation_settings(
        &mut self,
        value: longhands::font_variation_settings::computed_value::T
    ) {

        self.font.mutate()
            .set_font_variation_settings(
                value,
            );
    }
    /// Inherit `grid_template_areas` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_areas(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_template_areas_from(inherited_struct);
    }

    /// Set the `grid_template_areas` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_areas(
        &mut self,
        value: longhands::grid_template_areas::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_template_areas(
                value,
            );
    }
    /// Reset `hyphenate_character` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_hyphenate_character(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_hyphenate_character(reset_struct);
    }

    /// Set the `hyphenate_character` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_hyphenate_character(
        &mut self,
        value: longhands::hyphenate_character::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_hyphenate_character(
                value,
            );
    }
    /// Reset `letter_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_letter_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_letter_spacing(reset_struct);
    }

    /// Set the `letter_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_letter_spacing(
        &mut self,
        value: longhands::letter_spacing::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_letter_spacing(
                value,
            );
    }
    /// Reset `line_height` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_line_height(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset_line_height(reset_struct);
    }

    /// Set the `line_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_line_height(
        &mut self,
        value: longhands::line_height::computed_value::T
    ) {

        self.font.mutate()
            .set_line_height(
                value,
            );
    }
    /// Reset `list_style_type` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_type(&mut self) {
        let reset_struct =
            self.reset_style.get_list();

        if self.list.ptr_eq(reset_struct) {
            return;
        }

        self.list.mutate()
            .reset_list_style_type(reset_struct);
    }

    /// Set the `list_style_type` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_type(
        &mut self,
        value: longhands::list_style_type::computed_value::T
    ) {

        self.list.mutate()
            .set_list_style_type(
                value,
            );
    }
    /// Inherit `mask_clip` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_clip(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_clip_from(inherited_struct);
    }

    /// Inherit `mask_composite` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_composite(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_composite_from(inherited_struct);
    }

    /// Inherit `mask_image` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_image(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_image_from(inherited_struct);
    }

    /// Inherit `mask_mode` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_mode(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_mode_from(inherited_struct);
    }

    /// Inherit `mask_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_origin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_origin_from(inherited_struct);
    }

    /// Inherit `mask_position_x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_position_x(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_position_x_from(inherited_struct);
    }

    /// Inherit `mask_position_y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_position_y(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_position_y_from(inherited_struct);
    }

    /// Inherit `mask_repeat` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_repeat(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_repeat_from(inherited_struct);
    }

    /// Inherit `mask_size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_mask_size(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_mask_size_from(inherited_struct);
    }

    /// Reset `_moz_context_properties` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__moz_context_properties(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset__moz_context_properties(reset_struct);
    }

    /// Set the `_moz_context_properties` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_context_properties(
        &mut self,
        value: longhands::_moz_context_properties::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set__moz_context_properties(
                value,
            );
    }
    /// Inherit `offset_anchor` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_anchor(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_offset_anchor_from(inherited_struct);
    }

    /// Set the `offset_anchor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_anchor(
        &mut self,
        value: longhands::offset_anchor::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_offset_anchor(
                value,
            );
    }
    /// Inherit `offset_path` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_path(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_offset_path_from(inherited_struct);
    }

    /// Set the `offset_path` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_path(
        &mut self,
        value: longhands::offset_path::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_offset_path(
                value,
            );
    }
    /// Inherit `offset_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_offset_position_from(inherited_struct);
    }

    /// Set the `offset_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_position(
        &mut self,
        value: longhands::offset_position::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_offset_position(
                value,
            );
    }
    /// Inherit `page` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_page(&mut self) {
        let inherited_struct =
            self.inherited_style.get_page();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.page.ptr_eq(inherited_struct) {
            return;
        }

        self.page.mutate()
            .copy_page_from(inherited_struct);
    }

    /// Set the `page` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_page(
        &mut self,
        value: longhands::page::computed_value::T
    ) {
        self.modified_reset = true;

        self.page.mutate()
            .set_page(
                value,
            );
    }
    /// Inherit `perspective` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_perspective(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_perspective_from(inherited_struct);
    }

    /// Set the `perspective` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_perspective(
        &mut self,
        value: longhands::perspective::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_perspective(
                value,
            );
    }
    /// Inherit `position_anchor` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_position_anchor(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_position_anchor_from(inherited_struct);
    }

    /// Set the `position_anchor` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_position_anchor(
        &mut self,
        value: longhands::position_anchor::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_position_anchor(
                value,
            );
    }
    /// Inherit `position_try_options` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_position_try_options(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_position_try_options_from(inherited_struct);
    }

    /// Set the `position_try_options` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_position_try_options(
        &mut self,
        value: longhands::position_try_options::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_position_try_options(
                value,
            );
    }
    /// Reset `quotes` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_quotes(&mut self) {
        let reset_struct =
            self.reset_style.get_list();

        if self.list.ptr_eq(reset_struct) {
            return;
        }

        self.list.mutate()
            .reset_quotes(reset_struct);
    }

    /// Set the `quotes` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_quotes(
        &mut self,
        value: longhands::quotes::computed_value::T
    ) {

        self.list.mutate()
            .set_quotes(
                value,
            );
    }
    /// Inherit `rotate` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_rotate(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_rotate_from(inherited_struct);
    }

    /// Set the `rotate` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_rotate(
        &mut self,
        value: longhands::rotate::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_rotate(
                value,
            );
    }
    /// Inherit `scale` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scale(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_scale_from(inherited_struct);
    }

    /// Set the `scale` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scale(
        &mut self,
        value: longhands::scale::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_scale(
                value,
            );
    }
    /// Inherit `scroll_timeline_axis` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_timeline_axis(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_scroll_timeline_axis_from(inherited_struct);
    }

    /// Inherit `scroll_timeline_name` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_timeline_name(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_scroll_timeline_name_from(inherited_struct);
    }

    /// Reset `scrollbar_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_scrollbar_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_ui();

        if self.inherited_ui.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_ui.mutate()
            .reset_scrollbar_color(reset_struct);
    }

    /// Set the `scrollbar_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scrollbar_color(
        &mut self,
        value: longhands::scrollbar_color::computed_value::T
    ) {

        self.inherited_ui.mutate()
            .set_scrollbar_color(
                value,
            );
    }
    /// Inherit `shape_outside` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_outside(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_shape_outside_from(inherited_struct);
    }

    /// Set the `shape_outside` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_outside(
        &mut self,
        value: longhands::shape_outside::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_shape_outside(
                value,
            );
    }
    /// Inherit `size` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_size(&mut self) {
        let inherited_struct =
            self.inherited_style.get_page();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.page.ptr_eq(inherited_struct) {
            return;
        }

        self.page.mutate()
            .copy_size_from(inherited_struct);
    }

    /// Set the `size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_size(
        &mut self,
        value: longhands::size::computed_value::T
    ) {
        self.modified_reset = true;

        self.page.mutate()
            .set_size(
                value,
            );
    }
    /// Reset `stroke_dasharray` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_dasharray(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke_dasharray(reset_struct);
    }

    /// Set the `stroke_dasharray` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_dasharray(
        &mut self,
        value: longhands::stroke_dasharray::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke_dasharray(
                value,
            );
    }
    /// Reset `stroke_dashoffset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_dashoffset(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke_dashoffset(reset_struct);
    }

    /// Set the `stroke_dashoffset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_dashoffset(
        &mut self,
        value: longhands::stroke_dashoffset::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke_dashoffset(
                value,
            );
    }
    /// Reset `stroke_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke_width(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke_width(reset_struct);
    }

    /// Set the `stroke_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke_width(
        &mut self,
        value: longhands::stroke_width::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke_width(
                value,
            );
    }
    /// Reset `tab_size` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_tab_size(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_tab_size(reset_struct);
    }

    /// Set the `tab_size` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_tab_size(
        &mut self,
        value: longhands::tab_size::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_tab_size(
                value,
            );
    }
    /// Inherit `text_decoration_thickness` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_thickness(&mut self) {
        let inherited_struct =
            self.inherited_style.get_text();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.text.ptr_eq(inherited_struct) {
            return;
        }

        self.text.mutate()
            .copy_text_decoration_thickness_from(inherited_struct);
    }

    /// Set the `text_decoration_thickness` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_thickness(
        &mut self,
        value: longhands::text_decoration_thickness::computed_value::T
    ) {
        self.modified_reset = true;

        self.text.mutate()
            .set_text_decoration_thickness(
                value,
            );
    }
    /// Reset `text_emphasis_style` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_style(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_emphasis_style(reset_struct);
    }

    /// Set the `text_emphasis_style` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_style(
        &mut self,
        value: longhands::text_emphasis_style::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_emphasis_style(
                value,
            );
    }
    /// Reset `text_indent` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_indent(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_indent(reset_struct);
    }

    /// Set the `text_indent` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_indent(
        &mut self,
        value: longhands::text_indent::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_indent(
                value,
            );
    }
    /// Inherit `text_overflow` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_overflow(&mut self) {
        let inherited_struct =
            self.inherited_style.get_text();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.text.ptr_eq(inherited_struct) {
            return;
        }

        self.text.mutate()
            .copy_text_overflow_from(inherited_struct);
    }

    /// Set the `text_overflow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_overflow(
        &mut self,
        value: longhands::text_overflow::computed_value::T
    ) {
        self.modified_reset = true;

        self.text.mutate()
            .set_text_overflow(
                value,
            );
    }
    /// Reset `text_shadow` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_shadow(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_shadow(reset_struct);
    }

    /// Set the `text_shadow` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_shadow(
        &mut self,
        value: longhands::text_shadow::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_shadow(
                value,
            );
    }
    /// Inherit `transition_behavior` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_behavior(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_transition_behavior_from(inherited_struct);
    }

    /// Inherit `transition_delay` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_delay(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_transition_delay_from(inherited_struct);
    }

    /// Inherit `transition_duration` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_duration(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_transition_duration_from(inherited_struct);
    }

    /// Inherit `transition_property` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_property(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_transition_property_from(inherited_struct);
    }

    /// Inherit `transition_timing_function` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transition_timing_function(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_transition_timing_function_from(inherited_struct);
    }

    /// Inherit `translate` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_translate(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_translate_from(inherited_struct);
    }

    /// Set the `translate` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_translate(
        &mut self,
        value: longhands::translate::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_translate(
                value,
            );
    }
    /// Inherit `vertical_align` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_vertical_align(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_vertical_align_from(inherited_struct);
    }

    /// Set the `vertical_align` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_vertical_align(
        &mut self,
        value: longhands::vertical_align::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_vertical_align(
                value,
            );
    }
    /// Inherit `view_timeline_axis` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_view_timeline_axis(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_view_timeline_axis_from(inherited_struct);
    }

    /// Inherit `view_timeline_inset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_view_timeline_inset(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_view_timeline_inset_from(inherited_struct);
    }

    /// Inherit `view_timeline_name` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_view_timeline_name(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy_view_timeline_name_from(inherited_struct);
    }

    /// Reset `_webkit_text_stroke_width` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_width(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset__webkit_text_stroke_width(reset_struct);
    }

    /// Set the `_webkit_text_stroke_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_width(
        &mut self,
        value: longhands::_webkit_text_stroke_width::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set__webkit_text_stroke_width(
                value,
            );
    }
    /// Inherit `will_change` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_will_change(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_will_change_from(inherited_struct);
    }

    /// Set the `will_change` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_will_change(
        &mut self,
        value: longhands::will_change::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_will_change(
                value,
            );
    }
    /// Reset `word_spacing` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_word_spacing(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_word_spacing(reset_struct);
    }

    /// Set the `word_spacing` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_word_spacing(
        &mut self,
        value: longhands::word_spacing::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_word_spacing(
                value,
            );
    }
    /// Reset `_x_lang` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__x_lang(&mut self) {
        let reset_struct =
            self.reset_style.get_font();

        if self.font.ptr_eq(reset_struct) {
            return;
        }

        self.font.mutate()
            .reset__x_lang(reset_struct);
    }

    /// Set the `_x_lang` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__x_lang(
        &mut self,
        value: longhands::_x_lang::computed_value::T
    ) {

        self.font.mutate()
            .set__x_lang(
                value,
            );
    }
    /// Inherit `object_position` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_object_position(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_object_position_from(inherited_struct);
    }

    /// Set the `object_position` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_object_position(
        &mut self,
        value: longhands::object_position::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_object_position(
                value,
            );
    }
    /// Inherit `perspective_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_perspective_origin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_perspective_origin_from(inherited_struct);
    }

    /// Set the `perspective_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_perspective_origin(
        &mut self,
        value: longhands::perspective_origin::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_perspective_origin(
                value,
            );
    }
    /// Reset `fill` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_fill(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_fill(reset_struct);
    }

    /// Set the `fill` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_fill(
        &mut self,
        value: longhands::fill::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_fill(
                value,
            );
    }
    /// Reset `stroke` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_stroke(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_stroke(reset_struct);
    }

    /// Set the `stroke` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stroke(
        &mut self,
        value: longhands::stroke::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_stroke(
                value,
            );
    }
    /// Inherit `_moz_window_transform_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_transform_origin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_window_transform_origin_from(inherited_struct);
    }

    /// Set the `_moz_window_transform_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_transform_origin(
        &mut self,
        value: longhands::_moz_window_transform_origin::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_window_transform_origin(
                value,
            );
    }
    /// Inherit `transform_origin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform_origin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_transform_origin_from(inherited_struct);
    }

    /// Set the `transform_origin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform_origin(
        &mut self,
        value: longhands::transform_origin::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_transform_origin(
                value,
            );
    }
    /// Inherit `grid_template_columns` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_columns(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_template_columns_from(inherited_struct);
    }

    /// Set the `grid_template_columns` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_columns(
        &mut self,
        value: longhands::grid_template_columns::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_template_columns(
                value,
            );
    }
    /// Inherit `grid_template_rows` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_template_rows(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_template_rows_from(inherited_struct);
    }

    /// Set the `grid_template_rows` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_template_rows(
        &mut self,
        value: longhands::grid_template_rows::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_template_rows(
                value,
            );
    }
    /// Inherit `border_image_source` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_image_source(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_image_source_from(inherited_struct);
    }

    /// Set the `border_image_source` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_image_source(
        &mut self,
        value: longhands::border_image_source::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_image_source(
                value,
            );
    }
    /// Reset `list_style_image` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_list_style_image(&mut self) {
        let reset_struct =
            self.reset_style.get_list();

        if self.list.ptr_eq(reset_struct) {
            return;
        }

        self.list.mutate()
            .reset_list_style_image(reset_struct);
    }

    /// Set the `list_style_image` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_list_style_image(
        &mut self,
        value: longhands::list_style_image::computed_value::T
    ) {

        self.list.mutate()
            .set_list_style_image(
                value,
            );
    }
    /// Inherit `grid_auto_columns` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_columns(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_auto_columns_from(inherited_struct);
    }

    /// Set the `grid_auto_columns` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_columns(
        &mut self,
        value: longhands::grid_auto_columns::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_auto_columns(
                value,
            );
    }
    /// Inherit `grid_auto_rows` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_auto_rows(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_auto_rows_from(inherited_struct);
    }

    /// Set the `grid_auto_rows` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_auto_rows(
        &mut self,
        value: longhands::grid_auto_rows::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_auto_rows(
                value,
            );
    }
    /// Inherit `_moz_window_transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_transform(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_window_transform_from(inherited_struct);
    }

    /// Set the `_moz_window_transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_transform(
        &mut self,
        value: longhands::_moz_window_transform::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_window_transform(
                value,
            );
    }
    /// Inherit `transform` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_transform(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_transform_from(inherited_struct);
    }

    /// Set the `transform` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_transform(
        &mut self,
        value: longhands::transform::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_transform(
                value,
            );
    }
    /// Inherit `column_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_gap(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_column_gap_from(inherited_struct);
    }

    /// Set the `column_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_gap(
        &mut self,
        value: longhands::column_gap::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_column_gap(
                value,
            );
    }
    /// Inherit `row_gap` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_row_gap(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_row_gap_from(inherited_struct);
    }

    /// Set the `row_gap` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_row_gap(
        &mut self,
        value: longhands::row_gap::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_row_gap(
                value,
            );
    }
    /// Reset `marker_end` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_end(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_marker_end(reset_struct);
    }

    /// Set the `marker_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_end(
        &mut self,
        value: longhands::marker_end::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_marker_end(
                value,
            );
    }
    /// Reset `marker_mid` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_mid(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_marker_mid(reset_struct);
    }

    /// Set the `marker_mid` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_mid(
        &mut self,
        value: longhands::marker_mid::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_marker_mid(
                value,
            );
    }
    /// Reset `marker_start` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_marker_start(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_svg();

        if self.inherited_svg.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_svg.mutate()
            .reset_marker_start(reset_struct);
    }

    /// Set the `marker_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_marker_start(
        &mut self,
        value: longhands::marker_start::computed_value::T
    ) {

        self.inherited_svg.mutate()
            .set_marker_start(
                value,
            );
    }
    /// Inherit `contain_intrinsic_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_contain_intrinsic_height(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_contain_intrinsic_height_from(inherited_struct);
    }

    /// Set the `contain_intrinsic_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_contain_intrinsic_height(
        &mut self,
        value: longhands::contain_intrinsic_height::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_contain_intrinsic_height(
                value,
            );
    }
    /// Inherit `contain_intrinsic_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_contain_intrinsic_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_contain_intrinsic_width_from(inherited_struct);
    }

    /// Set the `contain_intrinsic_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_contain_intrinsic_width(
        &mut self,
        value: longhands::contain_intrinsic_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_contain_intrinsic_width(
                value,
            );
    }
    /// Inherit `grid_column_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_end(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_column_end_from(inherited_struct);
    }

    /// Set the `grid_column_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_end(
        &mut self,
        value: longhands::grid_column_end::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_column_end(
                value,
            );
    }
    /// Inherit `grid_column_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_column_start(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_column_start_from(inherited_struct);
    }

    /// Set the `grid_column_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_column_start(
        &mut self,
        value: longhands::grid_column_start::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_column_start(
                value,
            );
    }
    /// Inherit `grid_row_end` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_end(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_row_end_from(inherited_struct);
    }

    /// Set the `grid_row_end` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_end(
        &mut self,
        value: longhands::grid_row_end::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_row_end(
                value,
            );
    }
    /// Inherit `grid_row_start` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_grid_row_start(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_grid_row_start_from(inherited_struct);
    }

    /// Set the `grid_row_start` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_grid_row_start(
        &mut self,
        value: longhands::grid_row_start::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_grid_row_start(
                value,
            );
    }
    /// Inherit `max_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_height(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_max_height_from(inherited_struct);
    }

    /// Set the `max_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_height(
        &mut self,
        value: longhands::max_height::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_max_height(
                value,
            );
    }
    /// Inherit `max_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_max_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_max_width_from(inherited_struct);
    }

    /// Set the `max_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_max_width(
        &mut self,
        value: longhands::max_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_max_width(
                value,
            );
    }
    /// Inherit `cx` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_cx(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_cx_from(inherited_struct);
    }

    /// Set the `cx` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_cx(
        &mut self,
        value: longhands::cx::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_cx(
                value,
            );
    }
    /// Inherit `cy` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_cy(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_cy_from(inherited_struct);
    }

    /// Set the `cy` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_cy(
        &mut self,
        value: longhands::cy::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_cy(
                value,
            );
    }
    /// Inherit `offset_distance` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_offset_distance(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_offset_distance_from(inherited_struct);
    }

    /// Set the `offset_distance` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_offset_distance(
        &mut self,
        value: longhands::offset_distance::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_offset_distance(
                value,
            );
    }
    /// Inherit `x` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_x(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_x_from(inherited_struct);
    }

    /// Set the `x` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_x(
        &mut self,
        value: longhands::x::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_x(
                value,
            );
    }
    /// Inherit `y` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_y(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_y_from(inherited_struct);
    }

    /// Set the `y` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_y(
        &mut self,
        value: longhands::y::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_y(
                value,
            );
    }
    /// Inherit `border_bottom_left_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_left_radius(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_bottom_left_radius_from(inherited_struct);
    }

    /// Set the `border_bottom_left_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_left_radius(
        &mut self,
        value: longhands::border_bottom_left_radius::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_bottom_left_radius(
                value,
            );
    }
    /// Inherit `border_bottom_right_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_right_radius(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_bottom_right_radius_from(inherited_struct);
    }

    /// Set the `border_bottom_right_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_right_radius(
        &mut self,
        value: longhands::border_bottom_right_radius::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_bottom_right_radius(
                value,
            );
    }
    /// Inherit `border_top_left_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_left_radius(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_top_left_radius_from(inherited_struct);
    }

    /// Set the `border_top_left_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_left_radius(
        &mut self,
        value: longhands::border_top_left_radius::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_top_left_radius(
                value,
            );
    }
    /// Inherit `border_top_right_radius` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_right_radius(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_top_right_radius_from(inherited_struct);
    }

    /// Set the `border_top_right_radius` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_right_radius(
        &mut self,
        value: longhands::border_top_right_radius::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_top_right_radius(
                value,
            );
    }
    /// Inherit `height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_height(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_height_from(inherited_struct);
    }

    /// Set the `height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_height(
        &mut self,
        value: longhands::height::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_height(
                value,
            );
    }
    /// Inherit `min_height` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_height(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_min_height_from(inherited_struct);
    }

    /// Set the `min_height` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_height(
        &mut self,
        value: longhands::min_height::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_min_height(
                value,
            );
    }
    /// Inherit `min_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_min_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_min_width_from(inherited_struct);
    }

    /// Set the `min_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_min_width(
        &mut self,
        value: longhands::min_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_min_width(
                value,
            );
    }
    /// Inherit `width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_width_from(inherited_struct);
    }

    /// Set the `width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_width(
        &mut self,
        value: longhands::width::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_width(
                value,
            );
    }
    /// Inherit `border_bottom_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_bottom_width_from(inherited_struct);
    }

    /// Set the `border_bottom_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_width(
        &mut self,
        value: longhands::border_bottom_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_bottom_width(
                value,
            );
    }
    /// Inherit `border_left_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_left_width_from(inherited_struct);
    }

    /// Set the `border_left_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_width(
        &mut self,
        value: longhands::border_left_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_left_width(
                value,
            );
    }
    /// Inherit `border_right_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_right_width_from(inherited_struct);
    }

    /// Set the `border_right_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_width(
        &mut self,
        value: longhands::border_right_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_right_width(
                value,
            );
    }
    /// Inherit `border_top_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_top_width_from(inherited_struct);
    }

    /// Set the `border_top_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_width(
        &mut self,
        value: longhands::border_top_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_top_width(
                value,
            );
    }
    /// Inherit `column_rule_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_column();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.column.ptr_eq(inherited_struct) {
            return;
        }

        self.column.mutate()
            .copy_column_rule_width_from(inherited_struct);
    }

    /// Set the `column_rule_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_width(
        &mut self,
        value: longhands::column_rule_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.column.mutate()
            .set_column_rule_width(
                value,
            );
    }
    /// Inherit `outline_width` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_width(&mut self) {
        let inherited_struct =
            self.inherited_style.get_outline();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.outline.ptr_eq(inherited_struct) {
            return;
        }

        self.outline.mutate()
            .copy_outline_width_from(inherited_struct);
    }

    /// Set the `outline_width` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_width(
        &mut self,
        value: longhands::outline_width::computed_value::T
    ) {
        self.modified_reset = true;

        self.outline.mutate()
            .set_outline_width(
                value,
            );
    }
    /// Inherit `padding_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_padding_bottom_from(inherited_struct);
    }

    /// Set the `padding_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_bottom(
        &mut self,
        value: longhands::padding_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_padding_bottom(
                value,
            );
    }
    /// Inherit `padding_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_left(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_padding_left_from(inherited_struct);
    }

    /// Set the `padding_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_left(
        &mut self,
        value: longhands::padding_left::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_padding_left(
                value,
            );
    }
    /// Inherit `padding_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_right(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_padding_right_from(inherited_struct);
    }

    /// Set the `padding_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_right(
        &mut self,
        value: longhands::padding_right::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_padding_right(
                value,
            );
    }
    /// Inherit `padding_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_padding_top(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_padding_top_from(inherited_struct);
    }

    /// Set the `padding_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_padding_top(
        &mut self,
        value: longhands::padding_top::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_padding_top(
                value,
            );
    }
    /// Inherit `r` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_r(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_r_from(inherited_struct);
    }

    /// Set the `r` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_r(
        &mut self,
        value: longhands::r::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_r(
                value,
            );
    }
    /// Inherit `shape_margin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_shape_margin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_box();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.box_.ptr_eq(inherited_struct) {
            return;
        }

        self.box_.mutate()
            .copy_shape_margin_from(inherited_struct);
    }

    /// Set the `shape_margin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_shape_margin(
        &mut self,
        value: longhands::shape_margin::computed_value::T
    ) {
        self.modified_reset = true;

        self.box_.mutate()
            .set_shape_margin(
                value,
            );
    }
    /// Inherit `rx` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_rx(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_rx_from(inherited_struct);
    }

    /// Set the `rx` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_rx(
        &mut self,
        value: longhands::rx::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_rx(
                value,
            );
    }
    /// Inherit `ry` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_ry(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_ry_from(inherited_struct);
    }

    /// Set the `ry` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_ry(
        &mut self,
        value: longhands::ry::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_ry(
                value,
            );
    }
    /// Inherit `scroll_padding_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_padding_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_scroll_padding_bottom_from(inherited_struct);
    }

    /// Set the `scroll_padding_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_padding_bottom(
        &mut self,
        value: longhands::scroll_padding_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_scroll_padding_bottom(
                value,
            );
    }
    /// Inherit `scroll_padding_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_padding_left(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_scroll_padding_left_from(inherited_struct);
    }

    /// Set the `scroll_padding_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_padding_left(
        &mut self,
        value: longhands::scroll_padding_left::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_scroll_padding_left(
                value,
            );
    }
    /// Inherit `scroll_padding_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_padding_right(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_scroll_padding_right_from(inherited_struct);
    }

    /// Set the `scroll_padding_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_padding_right(
        &mut self,
        value: longhands::scroll_padding_right::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_scroll_padding_right(
                value,
            );
    }
    /// Inherit `scroll_padding_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_padding_top(&mut self) {
        let inherited_struct =
            self.inherited_style.get_padding();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.padding.ptr_eq(inherited_struct) {
            return;
        }

        self.padding.mutate()
            .copy_scroll_padding_top_from(inherited_struct);
    }

    /// Set the `scroll_padding_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_padding_top(
        &mut self,
        value: longhands::scroll_padding_top::computed_value::T
    ) {
        self.modified_reset = true;

        self.padding.mutate()
            .set_scroll_padding_top(
                value,
            );
    }
    /// Inherit `_moz_window_input_region_margin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit__moz_window_input_region_margin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_ui();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.ui.ptr_eq(inherited_struct) {
            return;
        }

        self.ui.mutate()
            .copy__moz_window_input_region_margin_from(inherited_struct);
    }

    /// Set the `_moz_window_input_region_margin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__moz_window_input_region_margin(
        &mut self,
        value: longhands::_moz_window_input_region_margin::computed_value::T
    ) {
        self.modified_reset = true;

        self.ui.mutate()
            .set__moz_window_input_region_margin(
                value,
            );
    }
    /// Inherit `outline_offset` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_offset(&mut self) {
        let inherited_struct =
            self.inherited_style.get_outline();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.outline.ptr_eq(inherited_struct) {
            return;
        }

        self.outline.mutate()
            .copy_outline_offset_from(inherited_struct);
    }

    /// Set the `outline_offset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_offset(
        &mut self,
        value: longhands::outline_offset::computed_value::T
    ) {
        self.modified_reset = true;

        self.outline.mutate()
            .set_outline_offset(
                value,
            );
    }
    /// Inherit `overflow_clip_margin` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_overflow_clip_margin(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_overflow_clip_margin_from(inherited_struct);
    }

    /// Set the `overflow_clip_margin` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_overflow_clip_margin(
        &mut self,
        value: longhands::overflow_clip_margin::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_overflow_clip_margin(
                value,
            );
    }
    /// Inherit `scroll_margin_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_margin_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_scroll_margin_bottom_from(inherited_struct);
    }

    /// Set the `scroll_margin_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_margin_bottom(
        &mut self,
        value: longhands::scroll_margin_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_scroll_margin_bottom(
                value,
            );
    }
    /// Inherit `scroll_margin_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_margin_left(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_scroll_margin_left_from(inherited_struct);
    }

    /// Set the `scroll_margin_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_margin_left(
        &mut self,
        value: longhands::scroll_margin_left::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_scroll_margin_left(
                value,
            );
    }
    /// Inherit `scroll_margin_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_margin_right(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_scroll_margin_right_from(inherited_struct);
    }

    /// Set the `scroll_margin_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_margin_right(
        &mut self,
        value: longhands::scroll_margin_right::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_scroll_margin_right(
                value,
            );
    }
    /// Inherit `scroll_margin_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_scroll_margin_top(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_scroll_margin_top_from(inherited_struct);
    }

    /// Set the `scroll_margin_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_scroll_margin_top(
        &mut self,
        value: longhands::scroll_margin_top::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_scroll_margin_top(
                value,
            );
    }
    /// Inherit `bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_bottom_from(inherited_struct);
    }

    /// Set the `bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_bottom(
        &mut self,
        value: longhands::bottom::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_bottom(
                value,
            );
    }
    /// Inherit `left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_left(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_left_from(inherited_struct);
    }

    /// Set the `left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_left(
        &mut self,
        value: longhands::left::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_left(
                value,
            );
    }
    /// Inherit `margin_bottom` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_bottom(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_margin_bottom_from(inherited_struct);
    }

    /// Set the `margin_bottom` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_bottom(
        &mut self,
        value: longhands::margin_bottom::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_margin_bottom(
                value,
            );
    }
    /// Inherit `margin_left` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_left(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_margin_left_from(inherited_struct);
    }

    /// Set the `margin_left` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_left(
        &mut self,
        value: longhands::margin_left::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_margin_left(
                value,
            );
    }
    /// Inherit `margin_right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_right(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_margin_right_from(inherited_struct);
    }

    /// Set the `margin_right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_right(
        &mut self,
        value: longhands::margin_right::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_margin_right(
                value,
            );
    }
    /// Inherit `margin_top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_margin_top(&mut self) {
        let inherited_struct =
            self.inherited_style.get_margin();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.margin.ptr_eq(inherited_struct) {
            return;
        }

        self.margin.mutate()
            .copy_margin_top_from(inherited_struct);
    }

    /// Set the `margin_top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_margin_top(
        &mut self,
        value: longhands::margin_top::computed_value::T
    ) {
        self.modified_reset = true;

        self.margin.mutate()
            .set_margin_top(
                value,
            );
    }
    /// Inherit `right` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_right(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_right_from(inherited_struct);
    }

    /// Set the `right` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_right(
        &mut self,
        value: longhands::right::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_right(
                value,
            );
    }
    /// Reset `text_underline_offset` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_underline_offset(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_underline_offset(reset_struct);
    }

    /// Set the `text_underline_offset` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_underline_offset(
        &mut self,
        value: longhands::text_underline_offset::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_underline_offset(
                value,
            );
    }
    /// Inherit `top` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_top(&mut self) {
        let inherited_struct =
            self.inherited_style.get_position();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.position.ptr_eq(inherited_struct) {
            return;
        }

        self.position.mutate()
            .copy_top_from(inherited_struct);
    }

    /// Set the `top` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_top(
        &mut self,
        value: longhands::top::computed_value::T
    ) {
        self.modified_reset = true;

        self.position.mutate()
            .set_top(
                value,
            );
    }
    /// Inherit `background_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_background_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_background();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.background.ptr_eq(inherited_struct) {
            return;
        }

        self.background.mutate()
            .copy_background_color_from(inherited_struct);
    }

    /// Set the `background_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_background_color(
        &mut self,
        value: longhands::background_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.background.mutate()
            .set_background_color(
                value,
            );
    }
    /// Inherit `border_bottom_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_bottom_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_bottom_color_from(inherited_struct);
    }

    /// Set the `border_bottom_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_bottom_color(
        &mut self,
        value: longhands::border_bottom_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_bottom_color(
                value,
            );
    }
    /// Inherit `border_left_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_left_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_left_color_from(inherited_struct);
    }

    /// Set the `border_left_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_left_color(
        &mut self,
        value: longhands::border_left_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_left_color(
                value,
            );
    }
    /// Inherit `border_right_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_right_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_right_color_from(inherited_struct);
    }

    /// Set the `border_right_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_right_color(
        &mut self,
        value: longhands::border_right_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_right_color(
                value,
            );
    }
    /// Inherit `border_top_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_border_top_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_border();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.border.ptr_eq(inherited_struct) {
            return;
        }

        self.border.mutate()
            .copy_border_top_color_from(inherited_struct);
    }

    /// Set the `border_top_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_border_top_color(
        &mut self,
        value: longhands::border_top_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.border.mutate()
            .set_border_top_color(
                value,
            );
    }
    /// Inherit `column_rule_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_column_rule_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_column();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.column.ptr_eq(inherited_struct) {
            return;
        }

        self.column.mutate()
            .copy_column_rule_color_from(inherited_struct);
    }

    /// Set the `column_rule_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_column_rule_color(
        &mut self,
        value: longhands::column_rule_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.column.mutate()
            .set_column_rule_color(
                value,
            );
    }
    /// Inherit `flood_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_flood_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_flood_color_from(inherited_struct);
    }

    /// Set the `flood_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_flood_color(
        &mut self,
        value: longhands::flood_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_flood_color(
                value,
            );
    }
    /// Inherit `lighting_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_lighting_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_lighting_color_from(inherited_struct);
    }

    /// Set the `lighting_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_lighting_color(
        &mut self,
        value: longhands::lighting_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_lighting_color(
                value,
            );
    }
    /// Inherit `outline_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_outline_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_outline();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.outline.ptr_eq(inherited_struct) {
            return;
        }

        self.outline.mutate()
            .copy_outline_color_from(inherited_struct);
    }

    /// Set the `outline_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_outline_color(
        &mut self,
        value: longhands::outline_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.outline.mutate()
            .set_outline_color(
                value,
            );
    }
    /// Inherit `stop_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_stop_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_svg();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.svg.ptr_eq(inherited_struct) {
            return;
        }

        self.svg.mutate()
            .copy_stop_color_from(inherited_struct);
    }

    /// Set the `stop_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_stop_color(
        &mut self,
        value: longhands::stop_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.svg.mutate()
            .set_stop_color(
                value,
            );
    }
    /// Inherit `text_decoration_color` from our parent style.
    #[allow(non_snake_case)]
    pub fn inherit_text_decoration_color(&mut self) {
        let inherited_struct =
            self.inherited_style.get_text();

        self.modified_reset = true;
        self.add_flags(ComputedValueFlags::INHERITS_RESET_STYLE);



        if self.text.ptr_eq(inherited_struct) {
            return;
        }

        self.text.mutate()
            .copy_text_decoration_color_from(inherited_struct);
    }

    /// Set the `text_decoration_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_decoration_color(
        &mut self,
        value: longhands::text_decoration_color::computed_value::T
    ) {
        self.modified_reset = true;

        self.text.mutate()
            .set_text_decoration_color(
                value,
            );
    }
    /// Reset `text_emphasis_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset_text_emphasis_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset_text_emphasis_color(reset_struct);
    }

    /// Set the `text_emphasis_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set_text_emphasis_color(
        &mut self,
        value: longhands::text_emphasis_color::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set_text_emphasis_color(
                value,
            );
    }
    /// Reset `_webkit_text_fill_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_fill_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset__webkit_text_fill_color(reset_struct);
    }

    /// Set the `_webkit_text_fill_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_fill_color(
        &mut self,
        value: longhands::_webkit_text_fill_color::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set__webkit_text_fill_color(
                value,
            );
    }
    /// Reset `_webkit_text_stroke_color` to the initial value.
    #[allow(non_snake_case)]
    pub fn reset__webkit_text_stroke_color(&mut self) {
        let reset_struct =
            self.reset_style.get_inherited_text();

        if self.inherited_text.ptr_eq(reset_struct) {
            return;
        }

        self.inherited_text.mutate()
            .reset__webkit_text_stroke_color(reset_struct);
    }

    /// Set the `_webkit_text_stroke_color` to the computed value `value`.
    #[allow(non_snake_case)]
    pub fn set__webkit_text_stroke_color(
        &mut self,
        value: longhands::_webkit_text_stroke_color::computed_value::T
    ) {

        self.inherited_text.mutate()
            .set__webkit_text_stroke_color(
                value,
            );
    }
    

    /// Inherits style from the parent element, accounting for the default
    /// computed values that need to be provided as well.
    pub fn for_inheritance(
        device: &'a Device,
        stylist: Option<&'a Stylist>,
        parent: Option<&'a ComputedValues>,
        pseudo: Option<&'a PseudoElement>,
    ) -> Self {
        // Rebuild the visited style from the parent, ensuring that it will also
        // not have rules.  This matches the unvisited style that will be
        // produced by this builder.  This assumes that the caller doesn't need
        // to adjust or process visited style, so we can just build visited
        // style here for simplicity.
        let visited_style = parent.and_then(|parent| {
            parent.visited_style().map(|style| {
                Self::for_inheritance(
                    device,
                    stylist,
                    Some(style),
                    pseudo,
                ).build()
            })
        });
        let custom_properties = if let Some(p) = parent { p.custom_properties().clone() } else { crate::custom_properties::ComputedCustomProperties::default() };
        let mut ret = Self::new(
            device,
            stylist,
            parent,
            pseudo,
            /* rules = */ None,
            /* is_root_element = */ false,
        );
        ret.custom_properties = custom_properties;
        ret.visited_style = visited_style;
        ret
    }

    /// Returns whether we have a visited style.
    pub fn has_visited_style(&self) -> bool {
        self.visited_style.is_some()
    }

    /// Returns whether we're a pseudo-elements style.
    pub fn is_pseudo_element(&self) -> bool {
        self.pseudo.map_or(false, |p| !p.is_anon_box())
    }

    /// Returns the style we're getting reset properties from.
    pub fn default_style(&self) -> &'a ComputedValues {
        self.reset_style
    }

        /// Gets an immutable view of the current `Background` style.
        pub fn get_background(&self) -> &style_structs::Background {
            &self.background
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn mutate_background(&mut self) -> &mut style_structs::Background {
            self.modified_reset = true;
            self.background.mutate()
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn take_background(&mut self) -> UniqueArc<style_structs::Background> {
            self.modified_reset = true;
            self.background.take()
        }

        /// Gets a mutable view of the current `Background` style.
        pub fn put_background(&mut self, s: UniqueArc<style_structs::Background>) {
            self.background.put(s)
        }

        /// Gets a mutable view of the current `Background` style,
        /// only if it's been mutated before.
        pub fn get_background_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Background> {
            self.background.get_if_mutated()
        }

        /// Reset the current `Background` style to its default value.
        pub fn reset_background_struct(&mut self) {
            self.background =
                StyleStructRef::Borrowed(self.reset_style.get_background());
        }
        /// Gets an immutable view of the current `Border` style.
        pub fn get_border(&self) -> &style_structs::Border {
            &self.border
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn mutate_border(&mut self) -> &mut style_structs::Border {
            self.modified_reset = true;
            self.border.mutate()
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn take_border(&mut self) -> UniqueArc<style_structs::Border> {
            self.modified_reset = true;
            self.border.take()
        }

        /// Gets a mutable view of the current `Border` style.
        pub fn put_border(&mut self, s: UniqueArc<style_structs::Border>) {
            self.border.put(s)
        }

        /// Gets a mutable view of the current `Border` style,
        /// only if it's been mutated before.
        pub fn get_border_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Border> {
            self.border.get_if_mutated()
        }

        /// Reset the current `Border` style to its default value.
        pub fn reset_border_struct(&mut self) {
            self.border =
                StyleStructRef::Borrowed(self.reset_style.get_border());
        }
        /// Gets an immutable view of the current `Box` style.
        pub fn get_box(&self) -> &style_structs::Box {
            &self.box_
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn mutate_box(&mut self) -> &mut style_structs::Box {
            self.modified_reset = true;
            self.box_.mutate()
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn take_box(&mut self) -> UniqueArc<style_structs::Box> {
            self.modified_reset = true;
            self.box_.take()
        }

        /// Gets a mutable view of the current `Box` style.
        pub fn put_box(&mut self, s: UniqueArc<style_structs::Box>) {
            self.box_.put(s)
        }

        /// Gets a mutable view of the current `Box` style,
        /// only if it's been mutated before.
        pub fn get_box_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Box> {
            self.box_.get_if_mutated()
        }

        /// Reset the current `Box` style to its default value.
        pub fn reset_box_struct(&mut self) {
            self.box_ =
                StyleStructRef::Borrowed(self.reset_style.get_box());
        }
        /// Gets an immutable view of the current `Column` style.
        pub fn get_column(&self) -> &style_structs::Column {
            &self.column
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn mutate_column(&mut self) -> &mut style_structs::Column {
            self.modified_reset = true;
            self.column.mutate()
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn take_column(&mut self) -> UniqueArc<style_structs::Column> {
            self.modified_reset = true;
            self.column.take()
        }

        /// Gets a mutable view of the current `Column` style.
        pub fn put_column(&mut self, s: UniqueArc<style_structs::Column>) {
            self.column.put(s)
        }

        /// Gets a mutable view of the current `Column` style,
        /// only if it's been mutated before.
        pub fn get_column_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Column> {
            self.column.get_if_mutated()
        }

        /// Reset the current `Column` style to its default value.
        pub fn reset_column_struct(&mut self) {
            self.column =
                StyleStructRef::Borrowed(self.reset_style.get_column());
        }
        /// Gets an immutable view of the current `Counters` style.
        pub fn get_counters(&self) -> &style_structs::Counters {
            &self.counters
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn mutate_counters(&mut self) -> &mut style_structs::Counters {
            self.modified_reset = true;
            self.counters.mutate()
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn take_counters(&mut self) -> UniqueArc<style_structs::Counters> {
            self.modified_reset = true;
            self.counters.take()
        }

        /// Gets a mutable view of the current `Counters` style.
        pub fn put_counters(&mut self, s: UniqueArc<style_structs::Counters>) {
            self.counters.put(s)
        }

        /// Gets a mutable view of the current `Counters` style,
        /// only if it's been mutated before.
        pub fn get_counters_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Counters> {
            self.counters.get_if_mutated()
        }

        /// Reset the current `Counters` style to its default value.
        pub fn reset_counters_struct(&mut self) {
            self.counters =
                StyleStructRef::Borrowed(self.reset_style.get_counters());
        }
        /// Gets an immutable view of the current `Effects` style.
        pub fn get_effects(&self) -> &style_structs::Effects {
            &self.effects
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn mutate_effects(&mut self) -> &mut style_structs::Effects {
            self.modified_reset = true;
            self.effects.mutate()
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn take_effects(&mut self) -> UniqueArc<style_structs::Effects> {
            self.modified_reset = true;
            self.effects.take()
        }

        /// Gets a mutable view of the current `Effects` style.
        pub fn put_effects(&mut self, s: UniqueArc<style_structs::Effects>) {
            self.effects.put(s)
        }

        /// Gets a mutable view of the current `Effects` style,
        /// only if it's been mutated before.
        pub fn get_effects_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Effects> {
            self.effects.get_if_mutated()
        }

        /// Reset the current `Effects` style to its default value.
        pub fn reset_effects_struct(&mut self) {
            self.effects =
                StyleStructRef::Borrowed(self.reset_style.get_effects());
        }
        /// Gets an immutable view of the current `Font` style.
        pub fn get_font(&self) -> &style_structs::Font {
            &self.font
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn mutate_font(&mut self) -> &mut style_structs::Font {
            self.font.mutate()
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn take_font(&mut self) -> UniqueArc<style_structs::Font> {
            self.font.take()
        }

        /// Gets a mutable view of the current `Font` style.
        pub fn put_font(&mut self, s: UniqueArc<style_structs::Font>) {
            self.font.put(s)
        }

        /// Gets a mutable view of the current `Font` style,
        /// only if it's been mutated before.
        pub fn get_font_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Font> {
            self.font.get_if_mutated()
        }

        /// Reset the current `Font` style to its default value.
        pub fn reset_font_struct(&mut self) {
            self.font =
                StyleStructRef::Borrowed(self.reset_style.get_font());
        }
        /// Gets an immutable view of the current `InheritedBox` style.
        pub fn get_inherited_box(&self) -> &style_structs::InheritedBox {
            &self.inherited_box
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn mutate_inherited_box(&mut self) -> &mut style_structs::InheritedBox {
            self.inherited_box.mutate()
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn take_inherited_box(&mut self) -> UniqueArc<style_structs::InheritedBox> {
            self.inherited_box.take()
        }

        /// Gets a mutable view of the current `InheritedBox` style.
        pub fn put_inherited_box(&mut self, s: UniqueArc<style_structs::InheritedBox>) {
            self.inherited_box.put(s)
        }

        /// Gets a mutable view of the current `InheritedBox` style,
        /// only if it's been mutated before.
        pub fn get_inherited_box_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedBox> {
            self.inherited_box.get_if_mutated()
        }

        /// Reset the current `InheritedBox` style to its default value.
        pub fn reset_inherited_box_struct(&mut self) {
            self.inherited_box =
                StyleStructRef::Borrowed(self.reset_style.get_inherited_box());
        }
        /// Gets an immutable view of the current `InheritedSVG` style.
        pub fn get_inherited_svg(&self) -> &style_structs::InheritedSVG {
            &self.inherited_svg
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn mutate_inherited_svg(&mut self) -> &mut style_structs::InheritedSVG {
            self.inherited_svg.mutate()
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn take_inherited_svg(&mut self) -> UniqueArc<style_structs::InheritedSVG> {
            self.inherited_svg.take()
        }

        /// Gets a mutable view of the current `InheritedSVG` style.
        pub fn put_inherited_svg(&mut self, s: UniqueArc<style_structs::InheritedSVG>) {
            self.inherited_svg.put(s)
        }

        /// Gets a mutable view of the current `InheritedSVG` style,
        /// only if it's been mutated before.
        pub fn get_inherited_svg_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedSVG> {
            self.inherited_svg.get_if_mutated()
        }

        /// Reset the current `InheritedSVG` style to its default value.
        pub fn reset_inherited_svg_struct(&mut self) {
            self.inherited_svg =
                StyleStructRef::Borrowed(self.reset_style.get_inherited_svg());
        }
        /// Gets an immutable view of the current `InheritedTable` style.
        pub fn get_inherited_table(&self) -> &style_structs::InheritedTable {
            &self.inherited_table
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn mutate_inherited_table(&mut self) -> &mut style_structs::InheritedTable {
            self.inherited_table.mutate()
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn take_inherited_table(&mut self) -> UniqueArc<style_structs::InheritedTable> {
            self.inherited_table.take()
        }

        /// Gets a mutable view of the current `InheritedTable` style.
        pub fn put_inherited_table(&mut self, s: UniqueArc<style_structs::InheritedTable>) {
            self.inherited_table.put(s)
        }

        /// Gets a mutable view of the current `InheritedTable` style,
        /// only if it's been mutated before.
        pub fn get_inherited_table_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedTable> {
            self.inherited_table.get_if_mutated()
        }

        /// Reset the current `InheritedTable` style to its default value.
        pub fn reset_inherited_table_struct(&mut self) {
            self.inherited_table =
                StyleStructRef::Borrowed(self.reset_style.get_inherited_table());
        }
        /// Gets an immutable view of the current `InheritedText` style.
        pub fn get_inherited_text(&self) -> &style_structs::InheritedText {
            &self.inherited_text
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn mutate_inherited_text(&mut self) -> &mut style_structs::InheritedText {
            self.inherited_text.mutate()
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn take_inherited_text(&mut self) -> UniqueArc<style_structs::InheritedText> {
            self.inherited_text.take()
        }

        /// Gets a mutable view of the current `InheritedText` style.
        pub fn put_inherited_text(&mut self, s: UniqueArc<style_structs::InheritedText>) {
            self.inherited_text.put(s)
        }

        /// Gets a mutable view of the current `InheritedText` style,
        /// only if it's been mutated before.
        pub fn get_inherited_text_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedText> {
            self.inherited_text.get_if_mutated()
        }

        /// Reset the current `InheritedText` style to its default value.
        pub fn reset_inherited_text_struct(&mut self) {
            self.inherited_text =
                StyleStructRef::Borrowed(self.reset_style.get_inherited_text());
        }
        /// Gets an immutable view of the current `InheritedUI` style.
        pub fn get_inherited_ui(&self) -> &style_structs::InheritedUI {
            &self.inherited_ui
        }

        /// Gets a mutable view of the current `InheritedUI` style.
        pub fn mutate_inherited_ui(&mut self) -> &mut style_structs::InheritedUI {
            self.inherited_ui.mutate()
        }

        /// Gets a mutable view of the current `InheritedUI` style.
        pub fn take_inherited_ui(&mut self) -> UniqueArc<style_structs::InheritedUI> {
            self.inherited_ui.take()
        }

        /// Gets a mutable view of the current `InheritedUI` style.
        pub fn put_inherited_ui(&mut self, s: UniqueArc<style_structs::InheritedUI>) {
            self.inherited_ui.put(s)
        }

        /// Gets a mutable view of the current `InheritedUI` style,
        /// only if it's been mutated before.
        pub fn get_inherited_ui_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::InheritedUI> {
            self.inherited_ui.get_if_mutated()
        }

        /// Reset the current `InheritedUI` style to its default value.
        pub fn reset_inherited_ui_struct(&mut self) {
            self.inherited_ui =
                StyleStructRef::Borrowed(self.reset_style.get_inherited_ui());
        }
        /// Gets an immutable view of the current `List` style.
        pub fn get_list(&self) -> &style_structs::List {
            &self.list
        }

        /// Gets a mutable view of the current `List` style.
        pub fn mutate_list(&mut self) -> &mut style_structs::List {
            self.list.mutate()
        }

        /// Gets a mutable view of the current `List` style.
        pub fn take_list(&mut self) -> UniqueArc<style_structs::List> {
            self.list.take()
        }

        /// Gets a mutable view of the current `List` style.
        pub fn put_list(&mut self, s: UniqueArc<style_structs::List>) {
            self.list.put(s)
        }

        /// Gets a mutable view of the current `List` style,
        /// only if it's been mutated before.
        pub fn get_list_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::List> {
            self.list.get_if_mutated()
        }

        /// Reset the current `List` style to its default value.
        pub fn reset_list_struct(&mut self) {
            self.list =
                StyleStructRef::Borrowed(self.reset_style.get_list());
        }
        /// Gets an immutable view of the current `Margin` style.
        pub fn get_margin(&self) -> &style_structs::Margin {
            &self.margin
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn mutate_margin(&mut self) -> &mut style_structs::Margin {
            self.modified_reset = true;
            self.margin.mutate()
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn take_margin(&mut self) -> UniqueArc<style_structs::Margin> {
            self.modified_reset = true;
            self.margin.take()
        }

        /// Gets a mutable view of the current `Margin` style.
        pub fn put_margin(&mut self, s: UniqueArc<style_structs::Margin>) {
            self.margin.put(s)
        }

        /// Gets a mutable view of the current `Margin` style,
        /// only if it's been mutated before.
        pub fn get_margin_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Margin> {
            self.margin.get_if_mutated()
        }

        /// Reset the current `Margin` style to its default value.
        pub fn reset_margin_struct(&mut self) {
            self.margin =
                StyleStructRef::Borrowed(self.reset_style.get_margin());
        }
        /// Gets an immutable view of the current `Outline` style.
        pub fn get_outline(&self) -> &style_structs::Outline {
            &self.outline
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn mutate_outline(&mut self) -> &mut style_structs::Outline {
            self.modified_reset = true;
            self.outline.mutate()
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn take_outline(&mut self) -> UniqueArc<style_structs::Outline> {
            self.modified_reset = true;
            self.outline.take()
        }

        /// Gets a mutable view of the current `Outline` style.
        pub fn put_outline(&mut self, s: UniqueArc<style_structs::Outline>) {
            self.outline.put(s)
        }

        /// Gets a mutable view of the current `Outline` style,
        /// only if it's been mutated before.
        pub fn get_outline_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Outline> {
            self.outline.get_if_mutated()
        }

        /// Reset the current `Outline` style to its default value.
        pub fn reset_outline_struct(&mut self) {
            self.outline =
                StyleStructRef::Borrowed(self.reset_style.get_outline());
        }
        /// Gets an immutable view of the current `Padding` style.
        pub fn get_padding(&self) -> &style_structs::Padding {
            &self.padding
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn mutate_padding(&mut self) -> &mut style_structs::Padding {
            self.modified_reset = true;
            self.padding.mutate()
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn take_padding(&mut self) -> UniqueArc<style_structs::Padding> {
            self.modified_reset = true;
            self.padding.take()
        }

        /// Gets a mutable view of the current `Padding` style.
        pub fn put_padding(&mut self, s: UniqueArc<style_structs::Padding>) {
            self.padding.put(s)
        }

        /// Gets a mutable view of the current `Padding` style,
        /// only if it's been mutated before.
        pub fn get_padding_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Padding> {
            self.padding.get_if_mutated()
        }

        /// Reset the current `Padding` style to its default value.
        pub fn reset_padding_struct(&mut self) {
            self.padding =
                StyleStructRef::Borrowed(self.reset_style.get_padding());
        }
        /// Gets an immutable view of the current `Page` style.
        pub fn get_page(&self) -> &style_structs::Page {
            &self.page
        }

        /// Gets a mutable view of the current `Page` style.
        pub fn mutate_page(&mut self) -> &mut style_structs::Page {
            self.modified_reset = true;
            self.page.mutate()
        }

        /// Gets a mutable view of the current `Page` style.
        pub fn take_page(&mut self) -> UniqueArc<style_structs::Page> {
            self.modified_reset = true;
            self.page.take()
        }

        /// Gets a mutable view of the current `Page` style.
        pub fn put_page(&mut self, s: UniqueArc<style_structs::Page>) {
            self.page.put(s)
        }

        /// Gets a mutable view of the current `Page` style,
        /// only if it's been mutated before.
        pub fn get_page_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Page> {
            self.page.get_if_mutated()
        }

        /// Reset the current `Page` style to its default value.
        pub fn reset_page_struct(&mut self) {
            self.page =
                StyleStructRef::Borrowed(self.reset_style.get_page());
        }
        /// Gets an immutable view of the current `Position` style.
        pub fn get_position(&self) -> &style_structs::Position {
            &self.position
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn mutate_position(&mut self) -> &mut style_structs::Position {
            self.modified_reset = true;
            self.position.mutate()
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn take_position(&mut self) -> UniqueArc<style_structs::Position> {
            self.modified_reset = true;
            self.position.take()
        }

        /// Gets a mutable view of the current `Position` style.
        pub fn put_position(&mut self, s: UniqueArc<style_structs::Position>) {
            self.position.put(s)
        }

        /// Gets a mutable view of the current `Position` style,
        /// only if it's been mutated before.
        pub fn get_position_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Position> {
            self.position.get_if_mutated()
        }

        /// Reset the current `Position` style to its default value.
        pub fn reset_position_struct(&mut self) {
            self.position =
                StyleStructRef::Borrowed(self.reset_style.get_position());
        }
        /// Gets an immutable view of the current `SVG` style.
        pub fn get_svg(&self) -> &style_structs::SVG {
            &self.svg
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn mutate_svg(&mut self) -> &mut style_structs::SVG {
            self.modified_reset = true;
            self.svg.mutate()
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn take_svg(&mut self) -> UniqueArc<style_structs::SVG> {
            self.modified_reset = true;
            self.svg.take()
        }

        /// Gets a mutable view of the current `SVG` style.
        pub fn put_svg(&mut self, s: UniqueArc<style_structs::SVG>) {
            self.svg.put(s)
        }

        /// Gets a mutable view of the current `SVG` style,
        /// only if it's been mutated before.
        pub fn get_svg_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::SVG> {
            self.svg.get_if_mutated()
        }

        /// Reset the current `SVG` style to its default value.
        pub fn reset_svg_struct(&mut self) {
            self.svg =
                StyleStructRef::Borrowed(self.reset_style.get_svg());
        }
        /// Gets an immutable view of the current `Table` style.
        pub fn get_table(&self) -> &style_structs::Table {
            &self.table
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn mutate_table(&mut self) -> &mut style_structs::Table {
            self.modified_reset = true;
            self.table.mutate()
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn take_table(&mut self) -> UniqueArc<style_structs::Table> {
            self.modified_reset = true;
            self.table.take()
        }

        /// Gets a mutable view of the current `Table` style.
        pub fn put_table(&mut self, s: UniqueArc<style_structs::Table>) {
            self.table.put(s)
        }

        /// Gets a mutable view of the current `Table` style,
        /// only if it's been mutated before.
        pub fn get_table_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Table> {
            self.table.get_if_mutated()
        }

        /// Reset the current `Table` style to its default value.
        pub fn reset_table_struct(&mut self) {
            self.table =
                StyleStructRef::Borrowed(self.reset_style.get_table());
        }
        /// Gets an immutable view of the current `Text` style.
        pub fn get_text(&self) -> &style_structs::Text {
            &self.text
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn mutate_text(&mut self) -> &mut style_structs::Text {
            self.modified_reset = true;
            self.text.mutate()
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn take_text(&mut self) -> UniqueArc<style_structs::Text> {
            self.modified_reset = true;
            self.text.take()
        }

        /// Gets a mutable view of the current `Text` style.
        pub fn put_text(&mut self, s: UniqueArc<style_structs::Text>) {
            self.text.put(s)
        }

        /// Gets a mutable view of the current `Text` style,
        /// only if it's been mutated before.
        pub fn get_text_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::Text> {
            self.text.get_if_mutated()
        }

        /// Reset the current `Text` style to its default value.
        pub fn reset_text_struct(&mut self) {
            self.text =
                StyleStructRef::Borrowed(self.reset_style.get_text());
        }
        /// Gets an immutable view of the current `UI` style.
        pub fn get_ui(&self) -> &style_structs::UI {
            &self.ui
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn mutate_ui(&mut self) -> &mut style_structs::UI {
            self.modified_reset = true;
            self.ui.mutate()
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn take_ui(&mut self) -> UniqueArc<style_structs::UI> {
            self.modified_reset = true;
            self.ui.take()
        }

        /// Gets a mutable view of the current `UI` style.
        pub fn put_ui(&mut self, s: UniqueArc<style_structs::UI>) {
            self.ui.put(s)
        }

        /// Gets a mutable view of the current `UI` style,
        /// only if it's been mutated before.
        pub fn get_ui_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::UI> {
            self.ui.get_if_mutated()
        }

        /// Reset the current `UI` style to its default value.
        pub fn reset_ui_struct(&mut self) {
            self.ui =
                StyleStructRef::Borrowed(self.reset_style.get_ui());
        }
        /// Gets an immutable view of the current `XUL` style.
        pub fn get_xul(&self) -> &style_structs::XUL {
            &self.xul
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn mutate_xul(&mut self) -> &mut style_structs::XUL {
            self.modified_reset = true;
            self.xul.mutate()
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn take_xul(&mut self) -> UniqueArc<style_structs::XUL> {
            self.modified_reset = true;
            self.xul.take()
        }

        /// Gets a mutable view of the current `XUL` style.
        pub fn put_xul(&mut self, s: UniqueArc<style_structs::XUL>) {
            self.xul.put(s)
        }

        /// Gets a mutable view of the current `XUL` style,
        /// only if it's been mutated before.
        pub fn get_xul_if_mutated(&mut self)
                                                         -> Option<&mut style_structs::XUL> {
            self.xul.get_if_mutated()
        }

        /// Reset the current `XUL` style to its default value.
        pub fn reset_xul_struct(&mut self) {
            self.xul =
                StyleStructRef::Borrowed(self.reset_style.get_xul());
        }
    

    /// Returns whether this computed style represents a floated object.
    pub fn is_floating(&self) -> bool {
        self.get_box().clone_float().is_floating()
    }

    /// Returns whether this computed style represents an absolutely-positioned
    /// object.
    pub fn is_absolutely_positioned(&self) -> bool {
        self.get_box().clone_position().is_absolutely_positioned()
    }

    /// Whether this style has a top-layer style.
    #[cfg(feature = "servo")]
    pub fn in_top_layer(&self) -> bool {
        matches!(self.get_box().clone__servo_top_layer(),
                 longhands::_servo_top_layer::computed_value::T::Top)
    }

    /// Whether this style has a top-layer style.
    #[cfg(feature = "gecko")]
    pub fn in_top_layer(&self) -> bool {
        matches!(self.get_box().clone__moz_top_layer(),
                 longhands::_moz_top_layer::computed_value::T::Top)
    }

    /// Clears the "have any reset structs been modified" flag.
    pub fn clear_modified_reset(&mut self) {
        self.modified_reset = false;
    }

    /// Returns whether we have mutated any reset structs since the the last
    /// time `clear_modified_reset` was called.
    pub fn modified_reset(&self) -> bool {
        self.modified_reset
    }

    /// Return the current flags.
    #[inline]
    pub fn flags(&self) -> ComputedValueFlags {
        self.flags.get()
    }

    /// Add a flag to the current builder.
    #[inline]
    pub fn add_flags(&self, flag: ComputedValueFlags) {
        let flags = self.flags() | flag;
        self.flags.set(flags);
    }

    /// Removes a flag to the current builder.
    #[inline]
    pub fn remove_flags(&self, flag: ComputedValueFlags) {
        let flags = self.flags() & !flag;
        self.flags.set(flags);
    }

    /// Turns this `StyleBuilder` into a proper `ComputedValues` instance.
    pub fn build(self) -> Arc<ComputedValues> {
        ComputedValues::new(
            self.pseudo,
            self.custom_properties,
            self.writing_mode,
            self.effective_zoom,
            self.flags.get(),
            self.rules,
            self.visited_style,
            self.background.build(),
            self.border.build(),
            self.box_.build(),
            self.column.build(),
            self.counters.build(),
            self.effects.build(),
            self.font.build(),
            self.inherited_box.build(),
            self.inherited_svg.build(),
            self.inherited_table.build(),
            self.inherited_text.build(),
            self.inherited_ui.build(),
            self.list.build(),
            self.margin.build(),
            self.outline.build(),
            self.padding.build(),
            self.page.build(),
            self.position.build(),
            self.svg.build(),
            self.table.build(),
            self.text.build(),
            self.ui.build(),
            self.xul.build(),
        )
    }

    /// Get the custom properties map if necessary.
    pub fn custom_properties(&self) -> &crate::custom_properties::ComputedCustomProperties {
        &self.custom_properties
    }


    /// Get the inherited custom properties map.
    pub fn inherited_custom_properties(&self) -> &crate::custom_properties::ComputedCustomProperties {
        &self.inherited_style.custom_properties
    }

    /// Access to various information about our inherited styles.  We don't
    /// expose an inherited ComputedValues directly, because in the
    /// ::first-line case some of the inherited information needs to come from
    /// one ComputedValues instance and some from a different one.

    /// Inherited writing-mode.
    pub fn inherited_writing_mode(&self) -> &WritingMode {
        &self.inherited_style.writing_mode
    }

    /// The effective zoom value that we should multiply absolute lengths by.
    pub fn effective_zoom(&self) -> computed::Zoom {
        self.effective_zoom
    }

    /// The zoom specified on this element.
    pub fn specified_zoom(&self) -> computed::Zoom {
        self.get_box().clone_zoom()
    }

    /// Inherited zoom.
    pub fn inherited_effective_zoom(&self) -> computed::Zoom {
        self.inherited_style.effective_zoom
    }

    /// The computed value flags of our parent.
    #[inline]
    pub fn get_parent_flags(&self) -> ComputedValueFlags {
        self.inherited_style.flags
    }

    /// Calculate the line height, given the currently resolved line-height and font.
    pub fn calc_line_height(
        &self,
        device: &Device,
        line_height_base: LineHeightBase,
        writing_mode: WritingMode,
    ) -> computed::NonNegativeLength {
        use crate::computed_value_flags::ComputedValueFlags;
        let (font, flag) = match line_height_base {
            LineHeightBase::CurrentStyle => (
                self.get_font(),
                ComputedValueFlags::DEPENDS_ON_SELF_FONT_METRICS,
            ),
            LineHeightBase::InheritedStyle => (
                self.get_parent_font(),
                ComputedValueFlags::DEPENDS_ON_INHERITED_FONT_METRICS,
            ),
        };
        let line_height = font.clone_line_height();
        if matches!(line_height, computed::LineHeight::Normal) {
            self.add_flags(flag);
        }
        let lh = device.calc_line_height(&font, writing_mode, None);
        if line_height_base == LineHeightBase::InheritedStyle {
            // Apply our own zoom if our style source is the parent style.
            computed::NonNegativeLength::new(self.get_box().clone_zoom().zoom(lh.px()))
        } else {
            lh
        }
    }

    /// And access to inherited style structs.
        /// Gets our inherited `Background`.  We don't name these
        /// accessors `inherited_background` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_background`
        /// instead.
        pub fn get_parent_background(&self) -> &style_structs::Background {
            self.inherited_style.get_background()
        }
        /// Gets our inherited `Border`.  We don't name these
        /// accessors `inherited_border` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_border`
        /// instead.
        pub fn get_parent_border(&self) -> &style_structs::Border {
            self.inherited_style.get_border()
        }
        /// Gets our inherited `Box`.  We don't name these
        /// accessors `inherited_box` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_box`
        /// instead.
        pub fn get_parent_box(&self) -> &style_structs::Box {
            self.inherited_style.get_box()
        }
        /// Gets our inherited `Column`.  We don't name these
        /// accessors `inherited_column` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_column`
        /// instead.
        pub fn get_parent_column(&self) -> &style_structs::Column {
            self.inherited_style.get_column()
        }
        /// Gets our inherited `Counters`.  We don't name these
        /// accessors `inherited_counters` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_counters`
        /// instead.
        pub fn get_parent_counters(&self) -> &style_structs::Counters {
            self.inherited_style.get_counters()
        }
        /// Gets our inherited `Effects`.  We don't name these
        /// accessors `inherited_effects` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_effects`
        /// instead.
        pub fn get_parent_effects(&self) -> &style_structs::Effects {
            self.inherited_style.get_effects()
        }
        /// Gets our inherited `Font`.  We don't name these
        /// accessors `inherited_font` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_font`
        /// instead.
        pub fn get_parent_font(&self) -> &style_structs::Font {
            self.inherited_style.get_font()
        }
        /// Gets our inherited `InheritedBox`.  We don't name these
        /// accessors `inherited_inherited_box` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inherited_box`
        /// instead.
        pub fn get_parent_inherited_box(&self) -> &style_structs::InheritedBox {
            self.inherited_style.get_inherited_box()
        }
        /// Gets our inherited `InheritedSVG`.  We don't name these
        /// accessors `inherited_inherited_svg` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inherited_svg`
        /// instead.
        pub fn get_parent_inherited_svg(&self) -> &style_structs::InheritedSVG {
            self.inherited_style.get_inherited_svg()
        }
        /// Gets our inherited `InheritedTable`.  We don't name these
        /// accessors `inherited_inherited_table` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inherited_table`
        /// instead.
        pub fn get_parent_inherited_table(&self) -> &style_structs::InheritedTable {
            self.inherited_style.get_inherited_table()
        }
        /// Gets our inherited `InheritedText`.  We don't name these
        /// accessors `inherited_inherited_text` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inherited_text`
        /// instead.
        pub fn get_parent_inherited_text(&self) -> &style_structs::InheritedText {
            self.inherited_style.get_inherited_text()
        }
        /// Gets our inherited `InheritedUI`.  We don't name these
        /// accessors `inherited_inherited_ui` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_inherited_ui`
        /// instead.
        pub fn get_parent_inherited_ui(&self) -> &style_structs::InheritedUI {
            self.inherited_style.get_inherited_ui()
        }
        /// Gets our inherited `List`.  We don't name these
        /// accessors `inherited_list` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_list`
        /// instead.
        pub fn get_parent_list(&self) -> &style_structs::List {
            self.inherited_style.get_list()
        }
        /// Gets our inherited `Margin`.  We don't name these
        /// accessors `inherited_margin` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_margin`
        /// instead.
        pub fn get_parent_margin(&self) -> &style_structs::Margin {
            self.inherited_style.get_margin()
        }
        /// Gets our inherited `Outline`.  We don't name these
        /// accessors `inherited_outline` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_outline`
        /// instead.
        pub fn get_parent_outline(&self) -> &style_structs::Outline {
            self.inherited_style.get_outline()
        }
        /// Gets our inherited `Padding`.  We don't name these
        /// accessors `inherited_padding` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_padding`
        /// instead.
        pub fn get_parent_padding(&self) -> &style_structs::Padding {
            self.inherited_style.get_padding()
        }
        /// Gets our inherited `Page`.  We don't name these
        /// accessors `inherited_page` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_page`
        /// instead.
        pub fn get_parent_page(&self) -> &style_structs::Page {
            self.inherited_style.get_page()
        }
        /// Gets our inherited `Position`.  We don't name these
        /// accessors `inherited_position` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_position`
        /// instead.
        pub fn get_parent_position(&self) -> &style_structs::Position {
            self.inherited_style.get_position()
        }
        /// Gets our inherited `SVG`.  We don't name these
        /// accessors `inherited_svg` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_svg`
        /// instead.
        pub fn get_parent_svg(&self) -> &style_structs::SVG {
            self.inherited_style.get_svg()
        }
        /// Gets our inherited `Table`.  We don't name these
        /// accessors `inherited_table` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_table`
        /// instead.
        pub fn get_parent_table(&self) -> &style_structs::Table {
            self.inherited_style.get_table()
        }
        /// Gets our inherited `Text`.  We don't name these
        /// accessors `inherited_text` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_text`
        /// instead.
        pub fn get_parent_text(&self) -> &style_structs::Text {
            self.inherited_style.get_text()
        }
        /// Gets our inherited `UI`.  We don't name these
        /// accessors `inherited_ui` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_ui`
        /// instead.
        pub fn get_parent_ui(&self) -> &style_structs::UI {
            self.inherited_style.get_ui()
        }
        /// Gets our inherited `XUL`.  We don't name these
        /// accessors `inherited_xul` because we already
        /// have things like "box" vs "inherited_box" as struct names.  Do the
        /// next-best thing and call them `parent_xul`
        /// instead.
        pub fn get_parent_xul(&self) -> &style_structs::XUL {
            self.inherited_style.get_xul()
        }
}

#[cfg(feature = "servo")]
pub use self::lazy_static_module::INITIAL_SERVO_VALUES;

// Use a module to work around #[cfg] on lazy_static! not being applied to every generated item.
#[cfg(feature = "servo")]
#[allow(missing_docs)]
mod lazy_static_module {
    use crate::logical_geometry::WritingMode;
    use crate::computed_value_flags::ComputedValueFlags;
    use servo_arc::Arc;
    use super::{ComputedValues, ComputedValuesInner, longhands, style_structs};

    lazy_static! {
        /// The initial values for all style structs as defined by the specification.
        pub static ref INITIAL_SERVO_VALUES: ComputedValues = ComputedValues {
            inner: ComputedValuesInner {
                    background: Arc::new(style_structs::Background {
                                background_color: longhands::background_color::get_initial_value(),
                                background_image: longhands::background_image::get_initial_value(),
                                background_position_x: longhands::background_position_x::get_initial_value(),
                                background_position_y: longhands::background_position_y::get_initial_value(),
                                background_repeat: longhands::background_repeat::get_initial_value(),
                                background_attachment: longhands::background_attachment::get_initial_value(),
                                background_clip: longhands::background_clip::get_initial_value(),
                                background_origin: longhands::background_origin::get_initial_value(),
                                background_size: longhands::background_size::get_initial_value(),
                                background_blend_mode: longhands::background_blend_mode::get_initial_value(),
                    }),
                    border: Arc::new(style_structs::Border {
                                border_top_color: longhands::border_top_color::get_initial_value(),
                                border_top_style: longhands::border_top_style::get_initial_value(),
                                border_top_width: longhands::border_top_width::get_initial_value(),
                                border_right_color: longhands::border_right_color::get_initial_value(),
                                border_right_style: longhands::border_right_style::get_initial_value(),
                                border_right_width: longhands::border_right_width::get_initial_value(),
                                border_bottom_color: longhands::border_bottom_color::get_initial_value(),
                                border_bottom_style: longhands::border_bottom_style::get_initial_value(),
                                border_bottom_width: longhands::border_bottom_width::get_initial_value(),
                                border_left_color: longhands::border_left_color::get_initial_value(),
                                border_left_style: longhands::border_left_style::get_initial_value(),
                                border_left_width: longhands::border_left_width::get_initial_value(),
                                border_top_left_radius: longhands::border_top_left_radius::get_initial_value(),
                                border_top_right_radius: longhands::border_top_right_radius::get_initial_value(),
                                border_bottom_right_radius: longhands::border_bottom_right_radius::get_initial_value(),
                                border_bottom_left_radius: longhands::border_bottom_left_radius::get_initial_value(),
                                box_decoration_break: longhands::box_decoration_break::get_initial_value(),
                                _moz_float_edge: longhands::_moz_float_edge::get_initial_value(),
                                border_image_source: longhands::border_image_source::get_initial_value(),
                                border_image_outset: longhands::border_image_outset::get_initial_value(),
                                border_image_repeat: longhands::border_image_repeat::get_initial_value(),
                                border_image_width: longhands::border_image_width::get_initial_value(),
                                border_image_slice: longhands::border_image_slice::get_initial_value(),
                    }),
                    box_: Arc::new(style_structs::Box {
                                display: longhands::display::get_initial_value(),
                                _moz_top_layer: longhands::_moz_top_layer::get_initial_value(),
                                position: longhands::position::get_initial_value(),
                                anchor_name: longhands::anchor_name::get_initial_value(),
                                anchor_scope: longhands::anchor_scope::get_initial_value(),
                                float: longhands::float::get_initial_value(),
                                clear: longhands::clear::get_initial_value(),
                                vertical_align: longhands::vertical_align::get_initial_value(),
                                baseline_source: longhands::baseline_source::get_initial_value(),
                                overflow_clip_box_inline: longhands::overflow_clip_box_inline::get_initial_value(),
                                overflow_clip_box_block: longhands::overflow_clip_box_block::get_initial_value(),
                                overflow_y: longhands::overflow_y::get_initial_value(),
                                overflow_x: longhands::overflow_x::get_initial_value(),
                                overflow_anchor: longhands::overflow_anchor::get_initial_value(),
                                transform: longhands::transform::get_initial_value(),
                                rotate: longhands::rotate::get_initial_value(),
                                scale: longhands::scale::get_initial_value(),
                                translate: longhands::translate::get_initial_value(),
                                offset_path: longhands::offset_path::get_initial_value(),
                                offset_distance: longhands::offset_distance::get_initial_value(),
                                offset_rotate: longhands::offset_rotate::get_initial_value(),
                                offset_anchor: longhands::offset_anchor::get_initial_value(),
                                offset_position: longhands::offset_position::get_initial_value(),
                                scroll_behavior: longhands::scroll_behavior::get_initial_value(),
                                scroll_snap_align: longhands::scroll_snap_align::get_initial_value(),
                                scroll_snap_type: longhands::scroll_snap_type::get_initial_value(),
                                scroll_snap_stop: longhands::scroll_snap_stop::get_initial_value(),
                                overscroll_behavior_y: longhands::overscroll_behavior_y::get_initial_value(),
                                overscroll_behavior_x: longhands::overscroll_behavior_x::get_initial_value(),
                                isolation: longhands::isolation::get_initial_value(),
                                break_after: longhands::break_after::get_initial_value(),
                                break_before: longhands::break_before::get_initial_value(),
                                break_inside: longhands::break_inside::get_initial_value(),
                                resize: longhands::resize::get_initial_value(),
                                perspective: longhands::perspective::get_initial_value(),
                                perspective_origin: longhands::perspective_origin::get_initial_value(),
                                backface_visibility: longhands::backface_visibility::get_initial_value(),
                                transform_box: longhands::transform_box::get_initial_value(),
                                transform_style: longhands::transform_style::get_initial_value(),
                                transform_origin: longhands::transform_origin::get_initial_value(),
                                contain: longhands::contain::get_initial_value(),
                                content_visibility: longhands::content_visibility::get_initial_value(),
                                container_type: longhands::container_type::get_initial_value(),
                                container_name: longhands::container_name::get_initial_value(),
                                appearance: longhands::appearance::get_initial_value(),
                                _moz_default_appearance: longhands::_moz_default_appearance::get_initial_value(),
                                _moz_orient: longhands::_moz_orient::get_initial_value(),
                                will_change: longhands::will_change::get_initial_value(),
                                shape_image_threshold: longhands::shape_image_threshold::get_initial_value(),
                                shape_margin: longhands::shape_margin::get_initial_value(),
                                shape_outside: longhands::shape_outside::get_initial_value(),
                                touch_action: longhands::touch_action::get_initial_value(),
                                _webkit_line_clamp: longhands::_webkit_line_clamp::get_initial_value(),
                                scrollbar_gutter: longhands::scrollbar_gutter::get_initial_value(),
                                zoom: longhands::zoom::get_initial_value(),
                            original_display: longhands::display::get_initial_value(),
                    }),
                    column: Arc::new(style_structs::Column {
                                column_width: longhands::column_width::get_initial_value(),
                                column_count: longhands::column_count::get_initial_value(),
                                column_fill: longhands::column_fill::get_initial_value(),
                                column_rule_width: longhands::column_rule_width::get_initial_value(),
                                column_rule_color: longhands::column_rule_color::get_initial_value(),
                                column_span: longhands::column_span::get_initial_value(),
                                column_rule_style: longhands::column_rule_style::get_initial_value(),
                    }),
                    counters: Arc::new(style_structs::Counters {
                                content: longhands::content::get_initial_value(),
                                counter_increment: longhands::counter_increment::get_initial_value(),
                                counter_reset: longhands::counter_reset::get_initial_value(),
                                counter_set: longhands::counter_set::get_initial_value(),
                    }),
                    effects: Arc::new(style_structs::Effects {
                                opacity: longhands::opacity::get_initial_value(),
                                box_shadow: longhands::box_shadow::get_initial_value(),
                                clip: longhands::clip::get_initial_value(),
                                filter: longhands::filter::get_initial_value(),
                                backdrop_filter: longhands::backdrop_filter::get_initial_value(),
                                mix_blend_mode: longhands::mix_blend_mode::get_initial_value(),
                    }),
                    font: Arc::new(style_structs::Font {
                                font_family: longhands::font_family::get_initial_value(),
                                font_style: longhands::font_style::get_initial_value(),
                                font_variant_caps: longhands::font_variant_caps::get_initial_value(),
                                font_weight: longhands::font_weight::get_initial_value(),
                                font_size: longhands::font_size::get_initial_value(),
                                font_size_adjust: longhands::font_size_adjust::get_initial_value(),
                                font_synthesis_weight: longhands::font_synthesis_weight::get_initial_value(),
                                font_synthesis_style: longhands::font_synthesis_style::get_initial_value(),
                                font_synthesis_small_caps: longhands::font_synthesis_small_caps::get_initial_value(),
                                font_synthesis_position: longhands::font_synthesis_position::get_initial_value(),
                                font_stretch: longhands::font_stretch::get_initial_value(),
                                font_kerning: longhands::font_kerning::get_initial_value(),
                                font_variant_alternates: longhands::font_variant_alternates::get_initial_value(),
                                font_variant_east_asian: longhands::font_variant_east_asian::get_initial_value(),
                                font_variant_emoji: longhands::font_variant_emoji::get_initial_value(),
                                font_variant_ligatures: longhands::font_variant_ligatures::get_initial_value(),
                                font_variant_numeric: longhands::font_variant_numeric::get_initial_value(),
                                font_variant_position: longhands::font_variant_position::get_initial_value(),
                                font_feature_settings: longhands::font_feature_settings::get_initial_value(),
                                font_variation_settings: longhands::font_variation_settings::get_initial_value(),
                                font_language_override: longhands::font_language_override::get_initial_value(),
                                font_optical_sizing: longhands::font_optical_sizing::get_initial_value(),
                                font_palette: longhands::font_palette::get_initial_value(),
                                _x_lang: longhands::_x_lang::get_initial_value(),
                                math_depth: longhands::math_depth::get_initial_value(),
                                math_style: longhands::math_style::get_initial_value(),
                                _moz_math_variant: longhands::_moz_math_variant::get_initial_value(),
                                _x_text_scale: longhands::_x_text_scale::get_initial_value(),
                                line_height: longhands::line_height::get_initial_value(),
                                _moz_osx_font_smoothing: longhands::_moz_osx_font_smoothing::get_initial_value(),
                                _moz_min_font_size_ratio: longhands::_moz_min_font_size_ratio::get_initial_value(),
                            hash: 0,
                    }),
                    inherited_box: Arc::new(style_structs::InheritedBox {
                                visibility: longhands::visibility::get_initial_value(),
                                writing_mode: longhands::writing_mode::get_initial_value(),
                                direction: longhands::direction::get_initial_value(),
                                _moz_box_collapse: longhands::_moz_box_collapse::get_initial_value(),
                                text_orientation: longhands::text_orientation::get_initial_value(),
                                print_color_adjust: longhands::print_color_adjust::get_initial_value(),
                                image_rendering: longhands::image_rendering::get_initial_value(),
                                image_orientation: longhands::image_orientation::get_initial_value(),
                    }),
                    inherited_svg: Arc::new(style_structs::InheritedSVG {
                                dominant_baseline: longhands::dominant_baseline::get_initial_value(),
                                text_anchor: longhands::text_anchor::get_initial_value(),
                                color_interpolation: longhands::color_interpolation::get_initial_value(),
                                color_interpolation_filters: longhands::color_interpolation_filters::get_initial_value(),
                                fill: longhands::fill::get_initial_value(),
                                fill_opacity: longhands::fill_opacity::get_initial_value(),
                                fill_rule: longhands::fill_rule::get_initial_value(),
                                shape_rendering: longhands::shape_rendering::get_initial_value(),
                                stroke: longhands::stroke::get_initial_value(),
                                stroke_width: longhands::stroke_width::get_initial_value(),
                                stroke_linecap: longhands::stroke_linecap::get_initial_value(),
                                stroke_linejoin: longhands::stroke_linejoin::get_initial_value(),
                                stroke_miterlimit: longhands::stroke_miterlimit::get_initial_value(),
                                stroke_opacity: longhands::stroke_opacity::get_initial_value(),
                                stroke_dasharray: longhands::stroke_dasharray::get_initial_value(),
                                stroke_dashoffset: longhands::stroke_dashoffset::get_initial_value(),
                                clip_rule: longhands::clip_rule::get_initial_value(),
                                marker_start: longhands::marker_start::get_initial_value(),
                                marker_mid: longhands::marker_mid::get_initial_value(),
                                marker_end: longhands::marker_end::get_initial_value(),
                                paint_order: longhands::paint_order::get_initial_value(),
                                _moz_context_properties: longhands::_moz_context_properties::get_initial_value(),
                    }),
                    inherited_table: Arc::new(style_structs::InheritedTable {
                                border_collapse: longhands::border_collapse::get_initial_value(),
                                empty_cells: longhands::empty_cells::get_initial_value(),
                                caption_side: longhands::caption_side::get_initial_value(),
                                border_spacing: longhands::border_spacing::get_initial_value(),
                    }),
                    inherited_text: Arc::new(style_structs::InheritedText {
                                color: longhands::color::get_initial_value(),
                                text_transform: longhands::text_transform::get_initial_value(),
                                hyphens: longhands::hyphens::get_initial_value(),
                                _moz_text_size_adjust: longhands::_moz_text_size_adjust::get_initial_value(),
                                text_indent: longhands::text_indent::get_initial_value(),
                                overflow_wrap: longhands::overflow_wrap::get_initial_value(),
                                word_break: longhands::word_break::get_initial_value(),
                                text_justify: longhands::text_justify::get_initial_value(),
                                text_align_last: longhands::text_align_last::get_initial_value(),
                                text_align: longhands::text_align::get_initial_value(),
                                letter_spacing: longhands::letter_spacing::get_initial_value(),
                                word_spacing: longhands::word_spacing::get_initial_value(),
                                white_space_collapse: longhands::white_space_collapse::get_initial_value(),
                                text_shadow: longhands::text_shadow::get_initial_value(),
                                text_emphasis_style: longhands::text_emphasis_style::get_initial_value(),
                                text_emphasis_position: longhands::text_emphasis_position::get_initial_value(),
                                text_emphasis_color: longhands::text_emphasis_color::get_initial_value(),
                                tab_size: longhands::tab_size::get_initial_value(),
                                line_break: longhands::line_break::get_initial_value(),
                                _webkit_text_fill_color: longhands::_webkit_text_fill_color::get_initial_value(),
                                _webkit_text_stroke_color: longhands::_webkit_text_stroke_color::get_initial_value(),
                                _webkit_text_stroke_width: longhands::_webkit_text_stroke_width::get_initial_value(),
                                ruby_align: longhands::ruby_align::get_initial_value(),
                                ruby_position: longhands::ruby_position::get_initial_value(),
                                text_combine_upright: longhands::text_combine_upright::get_initial_value(),
                                text_rendering: longhands::text_rendering::get_initial_value(),
                                _moz_control_character_visibility: longhands::_moz_control_character_visibility::get_initial_value(),
                                text_underline_offset: longhands::text_underline_offset::get_initial_value(),
                                text_underline_position: longhands::text_underline_position::get_initial_value(),
                                text_decoration_skip_ink: longhands::text_decoration_skip_ink::get_initial_value(),
                                hyphenate_character: longhands::hyphenate_character::get_initial_value(),
                                forced_color_adjust: longhands::forced_color_adjust::get_initial_value(),
                                _webkit_text_security: longhands::_webkit_text_security::get_initial_value(),
                                text_wrap_mode: longhands::text_wrap_mode::get_initial_value(),
                                text_wrap_style: longhands::text_wrap_style::get_initial_value(),
                            text_decorations_in_effect:
                                crate::values::computed::text::TextDecorationsInEffect::default(),
                    }),
                    inherited_ui: Arc::new(style_structs::InheritedUI {
                                cursor: longhands::cursor::get_initial_value(),
                                pointer_events: longhands::pointer_events::get_initial_value(),
                                _moz_inert: longhands::_moz_inert::get_initial_value(),
                                _moz_user_input: longhands::_moz_user_input::get_initial_value(),
                                _moz_user_modify: longhands::_moz_user_modify::get_initial_value(),
                                _moz_user_focus: longhands::_moz_user_focus::get_initial_value(),
                                caret_color: longhands::caret_color::get_initial_value(),
                                accent_color: longhands::accent_color::get_initial_value(),
                                color_scheme: longhands::color_scheme::get_initial_value(),
                                scrollbar_color: longhands::scrollbar_color::get_initial_value(),
                                _moz_theme: longhands::_moz_theme::get_initial_value(),
                    }),
                    list: Arc::new(style_structs::List {
                                list_style_position: longhands::list_style_position::get_initial_value(),
                                list_style_type: longhands::list_style_type::get_initial_value(),
                                list_style_image: longhands::list_style_image::get_initial_value(),
                                quotes: longhands::quotes::get_initial_value(),
                    }),
                    margin: Arc::new(style_structs::Margin {
                                margin_top: longhands::margin_top::get_initial_value(),
                                margin_right: longhands::margin_right::get_initial_value(),
                                margin_bottom: longhands::margin_bottom::get_initial_value(),
                                margin_left: longhands::margin_left::get_initial_value(),
                                overflow_clip_margin: longhands::overflow_clip_margin::get_initial_value(),
                                scroll_margin_top: longhands::scroll_margin_top::get_initial_value(),
                                scroll_margin_right: longhands::scroll_margin_right::get_initial_value(),
                                scroll_margin_bottom: longhands::scroll_margin_bottom::get_initial_value(),
                                scroll_margin_left: longhands::scroll_margin_left::get_initial_value(),
                    }),
                    outline: Arc::new(style_structs::Outline {
                                outline_color: longhands::outline_color::get_initial_value(),
                                outline_style: longhands::outline_style::get_initial_value(),
                                outline_width: longhands::outline_width::get_initial_value(),
                                outline_offset: longhands::outline_offset::get_initial_value(),
                    }),
                    padding: Arc::new(style_structs::Padding {
                                padding_top: longhands::padding_top::get_initial_value(),
                                padding_right: longhands::padding_right::get_initial_value(),
                                padding_bottom: longhands::padding_bottom::get_initial_value(),
                                padding_left: longhands::padding_left::get_initial_value(),
                                scroll_padding_top: longhands::scroll_padding_top::get_initial_value(),
                                scroll_padding_right: longhands::scroll_padding_right::get_initial_value(),
                                scroll_padding_bottom: longhands::scroll_padding_bottom::get_initial_value(),
                                scroll_padding_left: longhands::scroll_padding_left::get_initial_value(),
                    }),
                    page: Arc::new(style_structs::Page {
                                size: longhands::size::get_initial_value(),
                                page: longhands::page::get_initial_value(),
                                page_orientation: longhands::page_orientation::get_initial_value(),
                    }),
                    position: Arc::new(style_structs::Position {
                                top: longhands::top::get_initial_value(),
                                right: longhands::right::get_initial_value(),
                                bottom: longhands::bottom::get_initial_value(),
                                left: longhands::left::get_initial_value(),
                                z_index: longhands::z_index::get_initial_value(),
                                flex_direction: longhands::flex_direction::get_initial_value(),
                                flex_wrap: longhands::flex_wrap::get_initial_value(),
                                justify_content: longhands::justify_content::get_initial_value(),
                                align_content: longhands::align_content::get_initial_value(),
                                align_items: longhands::align_items::get_initial_value(),
                                justify_items: longhands::justify_items::get_initial_value(),
                                flex_grow: longhands::flex_grow::get_initial_value(),
                                flex_shrink: longhands::flex_shrink::get_initial_value(),
                                align_self: longhands::align_self::get_initial_value(),
                                justify_self: longhands::justify_self::get_initial_value(),
                                order: longhands::order::get_initial_value(),
                                flex_basis: longhands::flex_basis::get_initial_value(),
                                height: longhands::height::get_initial_value(),
                                min_height: longhands::min_height::get_initial_value(),
                                max_height: longhands::max_height::get_initial_value(),
                                width: longhands::width::get_initial_value(),
                                min_width: longhands::min_width::get_initial_value(),
                                max_width: longhands::max_width::get_initial_value(),
                                position_anchor: longhands::position_anchor::get_initial_value(),
                                position_visibility: longhands::position_visibility::get_initial_value(),
                                inset_area: longhands::inset_area::get_initial_value(),
                                position_try_options: longhands::position_try_options::get_initial_value(),
                                position_try_order: longhands::position_try_order::get_initial_value(),
                                box_sizing: longhands::box_sizing::get_initial_value(),
                                object_fit: longhands::object_fit::get_initial_value(),
                                object_position: longhands::object_position::get_initial_value(),
                                grid_row_start: longhands::grid_row_start::get_initial_value(),
                                grid_row_end: longhands::grid_row_end::get_initial_value(),
                                grid_auto_rows: longhands::grid_auto_rows::get_initial_value(),
                                grid_template_rows: longhands::grid_template_rows::get_initial_value(),
                                grid_column_start: longhands::grid_column_start::get_initial_value(),
                                grid_column_end: longhands::grid_column_end::get_initial_value(),
                                grid_auto_columns: longhands::grid_auto_columns::get_initial_value(),
                                grid_template_columns: longhands::grid_template_columns::get_initial_value(),
                                masonry_auto_flow: longhands::masonry_auto_flow::get_initial_value(),
                                grid_auto_flow: longhands::grid_auto_flow::get_initial_value(),
                                grid_template_areas: longhands::grid_template_areas::get_initial_value(),
                                column_gap: longhands::column_gap::get_initial_value(),
                                row_gap: longhands::row_gap::get_initial_value(),
                                aspect_ratio: longhands::aspect_ratio::get_initial_value(),
                                contain_intrinsic_height: longhands::contain_intrinsic_height::get_initial_value(),
                                contain_intrinsic_width: longhands::contain_intrinsic_width::get_initial_value(),
                    }),
                    svg: Arc::new(style_structs::SVG {
                                vector_effect: longhands::vector_effect::get_initial_value(),
                                stop_color: longhands::stop_color::get_initial_value(),
                                stop_opacity: longhands::stop_opacity::get_initial_value(),
                                flood_color: longhands::flood_color::get_initial_value(),
                                flood_opacity: longhands::flood_opacity::get_initial_value(),
                                lighting_color: longhands::lighting_color::get_initial_value(),
                                mask_type: longhands::mask_type::get_initial_value(),
                                clip_path: longhands::clip_path::get_initial_value(),
                                mask_mode: longhands::mask_mode::get_initial_value(),
                                mask_repeat: longhands::mask_repeat::get_initial_value(),
                                mask_position_x: longhands::mask_position_x::get_initial_value(),
                                mask_position_y: longhands::mask_position_y::get_initial_value(),
                                mask_clip: longhands::mask_clip::get_initial_value(),
                                mask_origin: longhands::mask_origin::get_initial_value(),
                                mask_size: longhands::mask_size::get_initial_value(),
                                mask_composite: longhands::mask_composite::get_initial_value(),
                                mask_image: longhands::mask_image::get_initial_value(),
                                x: longhands::x::get_initial_value(),
                                y: longhands::y::get_initial_value(),
                                cx: longhands::cx::get_initial_value(),
                                cy: longhands::cy::get_initial_value(),
                                rx: longhands::rx::get_initial_value(),
                                ry: longhands::ry::get_initial_value(),
                                r: longhands::r::get_initial_value(),
                                d: longhands::d::get_initial_value(),
                    }),
                    table: Arc::new(style_structs::Table {
                                table_layout: longhands::table_layout::get_initial_value(),
                                _x_span: longhands::_x_span::get_initial_value(),
                    }),
                    text: Arc::new(style_structs::Text {
                                text_overflow: longhands::text_overflow::get_initial_value(),
                                unicode_bidi: longhands::unicode_bidi::get_initial_value(),
                                text_decoration_line: longhands::text_decoration_line::get_initial_value(),
                                text_decoration_style: longhands::text_decoration_style::get_initial_value(),
                                text_decoration_color: longhands::text_decoration_color::get_initial_value(),
                                initial_letter: longhands::initial_letter::get_initial_value(),
                                text_decoration_thickness: longhands::text_decoration_thickness::get_initial_value(),
                    }),
                    ui: Arc::new(style_structs::UI {
                                ime_mode: longhands::ime_mode::get_initial_value(),
                                scrollbar_width: longhands::scrollbar_width::get_initial_value(),
                                user_select: longhands::user_select::get_initial_value(),
                                _moz_window_dragging: longhands::_moz_window_dragging::get_initial_value(),
                                _moz_window_shadow: longhands::_moz_window_shadow::get_initial_value(),
                                _moz_window_opacity: longhands::_moz_window_opacity::get_initial_value(),
                                _moz_window_transform: longhands::_moz_window_transform::get_initial_value(),
                                _moz_window_transform_origin: longhands::_moz_window_transform_origin::get_initial_value(),
                                _moz_window_input_region_margin: longhands::_moz_window_input_region_margin::get_initial_value(),
                                _moz_subtree_hidden_only_visually: longhands::_moz_subtree_hidden_only_visually::get_initial_value(),
                                _moz_force_broken_image_icon: longhands::_moz_force_broken_image_icon::get_initial_value(),
                                transition_duration: longhands::transition_duration::get_initial_value(),
                                transition_timing_function: longhands::transition_timing_function::get_initial_value(),
                                transition_property: longhands::transition_property::get_initial_value(),
                                transition_delay: longhands::transition_delay::get_initial_value(),
                                transition_behavior: longhands::transition_behavior::get_initial_value(),
                                animation_name: longhands::animation_name::get_initial_value(),
                                animation_duration: longhands::animation_duration::get_initial_value(),
                                animation_timing_function: longhands::animation_timing_function::get_initial_value(),
                                animation_iteration_count: longhands::animation_iteration_count::get_initial_value(),
                                animation_direction: longhands::animation_direction::get_initial_value(),
                                animation_play_state: longhands::animation_play_state::get_initial_value(),
                                animation_fill_mode: longhands::animation_fill_mode::get_initial_value(),
                                animation_composition: longhands::animation_composition::get_initial_value(),
                                animation_delay: longhands::animation_delay::get_initial_value(),
                                animation_timeline: longhands::animation_timeline::get_initial_value(),
                                scroll_timeline_name: longhands::scroll_timeline_name::get_initial_value(),
                                scroll_timeline_axis: longhands::scroll_timeline_axis::get_initial_value(),
                                view_timeline_name: longhands::view_timeline_name::get_initial_value(),
                                view_timeline_axis: longhands::view_timeline_axis::get_initial_value(),
                                view_timeline_inset: longhands::view_timeline_inset::get_initial_value(),
                    }),
                    xul: Arc::new(style_structs::XUL {
                                _moz_box_align: longhands::_moz_box_align::get_initial_value(),
                                _moz_box_direction: longhands::_moz_box_direction::get_initial_value(),
                                _moz_box_flex: longhands::_moz_box_flex::get_initial_value(),
                                _moz_box_orient: longhands::_moz_box_orient::get_initial_value(),
                                _moz_box_pack: longhands::_moz_box_pack::get_initial_value(),
                                _moz_box_ordinal_group: longhands::_moz_box_ordinal_group::get_initial_value(),
                    }),
                custom_properties,
                writing_mode: WritingMode::empty(),
                rules: None,
                visited_style: None,
                flags: ComputedValueFlags::empty(),
            },
            pseudo: None,
        };
    }
}

/// A per-longhand function that performs the CSS cascade for that longhand.
pub type CascadePropertyFn =
    unsafe extern "Rust" fn(
        declaration: &PropertyDeclaration,
        context: &mut computed::Context,
    );

/// A per-longhand array of functions to perform the CSS cascade on each of
/// them, effectively doing virtual dispatch.
pub static CASCADE_PROPERTY: [CascadePropertyFn; 410] = [
        longhands::align_content::cascade_property,
        longhands::align_items::cascade_property,
        longhands::align_self::cascade_property,
        longhands::aspect_ratio::cascade_property,
        longhands::backface_visibility::cascade_property,
        longhands::baseline_source::cascade_property,
        longhands::border_collapse::cascade_property,
        longhands::border_image_repeat::cascade_property,
        longhands::box_decoration_break::cascade_property,
        longhands::box_sizing::cascade_property,
        longhands::break_inside::cascade_property,
        longhands::caption_side::cascade_property,
        longhands::clear::cascade_property,
        longhands::color_interpolation::cascade_property,
        longhands::color_interpolation_filters::cascade_property,
        longhands::column_count::cascade_property,
        longhands::column_fill::cascade_property,
        longhands::column_span::cascade_property,
        longhands::contain::cascade_property,
        longhands::container_type::cascade_property,
        longhands::content_visibility::cascade_property,
        longhands::direction::cascade_property,
        longhands::display::cascade_property,
        longhands::dominant_baseline::cascade_property,
        longhands::empty_cells::cascade_property,
        longhands::flex_direction::cascade_property,
        longhands::flex_wrap::cascade_property,
        longhands::float::cascade_property,
        longhands::font_kerning::cascade_property,
        longhands::font_language_override::cascade_property,
        longhands::font_optical_sizing::cascade_property,
        longhands::font_size_adjust::cascade_property,
        longhands::font_stretch::cascade_property,
        longhands::font_style::cascade_property,
        longhands::font_variant_caps::cascade_property,
        longhands::font_variant_east_asian::cascade_property,
        longhands::font_variant_emoji::cascade_property,
        longhands::font_variant_ligatures::cascade_property,
        longhands::font_variant_numeric::cascade_property,
        longhands::font_variant_position::cascade_property,
        longhands::font_weight::cascade_property,
        longhands::forced_color_adjust::cascade_property,
        longhands::grid_auto_flow::cascade_property,
        longhands::hyphens::cascade_property,
        longhands::image_orientation::cascade_property,
        longhands::image_rendering::cascade_property,
        longhands::ime_mode::cascade_property,
        longhands::initial_letter::cascade_property,
        longhands::inset_area::cascade_property,
        longhands::isolation::cascade_property,
        longhands::justify_content::cascade_property,
        longhands::justify_items::cascade_property,
        longhands::justify_self::cascade_property,
        longhands::line_break::cascade_property,
        longhands::list_style_position::cascade_property,
        longhands::mask_type::cascade_property,
        longhands::masonry_auto_flow::cascade_property,
        longhands::math_depth::cascade_property,
        longhands::math_style::cascade_property,
        longhands::mix_blend_mode::cascade_property,
        longhands::_moz_box_align::cascade_property,
        longhands::_moz_box_collapse::cascade_property,
        longhands::_moz_box_direction::cascade_property,
        longhands::_moz_box_orient::cascade_property,
        longhands::_moz_box_pack::cascade_property,
        longhands::_moz_control_character_visibility::cascade_property,
        longhands::_moz_float_edge::cascade_property,
        longhands::_moz_inert::cascade_property,
        longhands::_moz_math_variant::cascade_property,
        longhands::_moz_min_font_size_ratio::cascade_property,
        longhands::_moz_orient::cascade_property,
        longhands::_moz_osx_font_smoothing::cascade_property,
        longhands::_moz_text_size_adjust::cascade_property,
        longhands::_moz_theme::cascade_property,
        longhands::_moz_top_layer::cascade_property,
        longhands::_moz_user_focus::cascade_property,
        longhands::_moz_user_input::cascade_property,
        longhands::_moz_user_modify::cascade_property,
        longhands::_moz_window_dragging::cascade_property,
        longhands::_moz_window_shadow::cascade_property,
        longhands::object_fit::cascade_property,
        longhands::offset_rotate::cascade_property,
        longhands::outline_style::cascade_property,
        longhands::overflow_anchor::cascade_property,
        longhands::overflow_wrap::cascade_property,
        longhands::page_orientation::cascade_property,
        longhands::paint_order::cascade_property,
        longhands::pointer_events::cascade_property,
        longhands::position::cascade_property,
        longhands::position_try_order::cascade_property,
        longhands::position_visibility::cascade_property,
        longhands::print_color_adjust::cascade_property,
        longhands::resize::cascade_property,
        longhands::ruby_align::cascade_property,
        longhands::ruby_position::cascade_property,
        longhands::scroll_behavior::cascade_property,
        longhands::scroll_snap_align::cascade_property,
        longhands::scroll_snap_stop::cascade_property,
        longhands::scroll_snap_type::cascade_property,
        longhands::scrollbar_gutter::cascade_property,
        longhands::scrollbar_width::cascade_property,
        longhands::shape_rendering::cascade_property,
        longhands::stroke_linecap::cascade_property,
        longhands::stroke_linejoin::cascade_property,
        longhands::table_layout::cascade_property,
        longhands::text_align::cascade_property,
        longhands::text_align_last::cascade_property,
        longhands::text_anchor::cascade_property,
        longhands::text_combine_upright::cascade_property,
        longhands::text_decoration_line::cascade_property,
        longhands::text_decoration_skip_ink::cascade_property,
        longhands::text_decoration_style::cascade_property,
        longhands::text_emphasis_position::cascade_property,
        longhands::text_justify::cascade_property,
        longhands::text_orientation::cascade_property,
        longhands::text_rendering::cascade_property,
        longhands::text_transform::cascade_property,
        longhands::text_underline_position::cascade_property,
        longhands::text_wrap_mode::cascade_property,
        longhands::text_wrap_style::cascade_property,
        longhands::touch_action::cascade_property,
        longhands::transform_box::cascade_property,
        longhands::transform_style::cascade_property,
        longhands::unicode_bidi::cascade_property,
        longhands::user_select::cascade_property,
        longhands::vector_effect::cascade_property,
        longhands::visibility::cascade_property,
        longhands::_webkit_line_clamp::cascade_property,
        longhands::_webkit_text_security::cascade_property,
        longhands::white_space_collapse::cascade_property,
        longhands::word_break::cascade_property,
        longhands::writing_mode::cascade_property,
        longhands::_x_text_scale::cascade_property,
        longhands::z_index::cascade_property,
        longhands::zoom::cascade_property,
        longhands::appearance::cascade_property,
        longhands::_moz_default_appearance::cascade_property,
        longhands::_moz_force_broken_image_icon::cascade_property,
        longhands::_moz_subtree_hidden_only_visually::cascade_property,
        longhands::break_after::cascade_property,
        longhands::break_before::cascade_property,
        longhands::clip_rule::cascade_property,
        longhands::fill_rule::cascade_property,
        longhands::overflow_clip_box_block::cascade_property,
        longhands::overflow_clip_box_inline::cascade_property,
        longhands::fill_opacity::cascade_property,
        longhands::stroke_opacity::cascade_property,
        longhands::_moz_box_ordinal_group::cascade_property,
        longhands::order::cascade_property,
        longhands::_x_span::cascade_property,
        longhands::font_synthesis_position::cascade_property,
        longhands::font_synthesis_small_caps::cascade_property,
        longhands::font_synthesis_style::cascade_property,
        longhands::font_synthesis_weight::cascade_property,
        longhands::flex_grow::cascade_property,
        longhands::flex_shrink::cascade_property,
        longhands::_moz_box_flex::cascade_property,
        longhands::stroke_miterlimit::cascade_property,
        longhands::overflow_block::cascade_property,
        longhands::overflow_inline::cascade_property,
        longhands::overflow_x::cascade_property,
        longhands::overflow_y::cascade_property,
        longhands::overscroll_behavior_block::cascade_property,
        longhands::overscroll_behavior_inline::cascade_property,
        longhands::overscroll_behavior_x::cascade_property,
        longhands::overscroll_behavior_y::cascade_property,
        longhands::flood_opacity::cascade_property,
        longhands::_moz_window_opacity::cascade_property,
        longhands::opacity::cascade_property,
        longhands::shape_image_threshold::cascade_property,
        longhands::stop_opacity::cascade_property,
        longhands::border_block_end_style::cascade_property,
        longhands::border_block_start_style::cascade_property,
        longhands::border_bottom_style::cascade_property,
        longhands::border_inline_end_style::cascade_property,
        longhands::border_inline_start_style::cascade_property,
        longhands::border_left_style::cascade_property,
        longhands::border_right_style::cascade_property,
        longhands::border_top_style::cascade_property,
        longhands::column_rule_style::cascade_property,
        longhands::accent_color::cascade_property,
        longhands::anchor_name::cascade_property,
        longhands::anchor_scope::cascade_property,
        longhands::animation_composition::cascade_property,
        longhands::animation_delay::cascade_property,
        longhands::animation_direction::cascade_property,
        longhands::animation_duration::cascade_property,
        longhands::animation_fill_mode::cascade_property,
        longhands::animation_iteration_count::cascade_property,
        longhands::animation_name::cascade_property,
        longhands::animation_play_state::cascade_property,
        longhands::animation_timeline::cascade_property,
        longhands::animation_timing_function::cascade_property,
        longhands::backdrop_filter::cascade_property,
        longhands::background_attachment::cascade_property,
        longhands::background_blend_mode::cascade_property,
        longhands::background_clip::cascade_property,
        longhands::background_image::cascade_property,
        longhands::background_origin::cascade_property,
        longhands::background_position_x::cascade_property,
        longhands::background_position_y::cascade_property,
        longhands::background_repeat::cascade_property,
        longhands::background_size::cascade_property,
        longhands::border_image_outset::cascade_property,
        longhands::border_image_slice::cascade_property,
        longhands::border_image_width::cascade_property,
        longhands::border_spacing::cascade_property,
        longhands::box_shadow::cascade_property,
        longhands::caret_color::cascade_property,
        longhands::clip::cascade_property,
        longhands::clip_path::cascade_property,
        longhands::color::cascade_property,
        longhands::color_scheme::cascade_property,
        longhands::column_width::cascade_property,
        longhands::container_name::cascade_property,
        longhands::content::cascade_property,
        longhands::counter_increment::cascade_property,
        longhands::counter_reset::cascade_property,
        longhands::counter_set::cascade_property,
        longhands::cursor::cascade_property,
        longhands::d::cascade_property,
        longhands::filter::cascade_property,
        longhands::flex_basis::cascade_property,
        longhands::font_family::cascade_property,
        longhands::font_feature_settings::cascade_property,
        longhands::font_palette::cascade_property,
        longhands::font_size::cascade_property,
        longhands::font_variant_alternates::cascade_property,
        longhands::font_variation_settings::cascade_property,
        longhands::grid_template_areas::cascade_property,
        longhands::hyphenate_character::cascade_property,
        longhands::letter_spacing::cascade_property,
        longhands::line_height::cascade_property,
        longhands::list_style_type::cascade_property,
        longhands::mask_clip::cascade_property,
        longhands::mask_composite::cascade_property,
        longhands::mask_image::cascade_property,
        longhands::mask_mode::cascade_property,
        longhands::mask_origin::cascade_property,
        longhands::mask_position_x::cascade_property,
        longhands::mask_position_y::cascade_property,
        longhands::mask_repeat::cascade_property,
        longhands::mask_size::cascade_property,
        longhands::_moz_context_properties::cascade_property,
        longhands::offset_anchor::cascade_property,
        longhands::offset_path::cascade_property,
        longhands::offset_position::cascade_property,
        longhands::page::cascade_property,
        longhands::perspective::cascade_property,
        longhands::position_anchor::cascade_property,
        longhands::position_try_options::cascade_property,
        longhands::quotes::cascade_property,
        longhands::rotate::cascade_property,
        longhands::scale::cascade_property,
        longhands::scroll_timeline_axis::cascade_property,
        longhands::scroll_timeline_name::cascade_property,
        longhands::scrollbar_color::cascade_property,
        longhands::shape_outside::cascade_property,
        longhands::size::cascade_property,
        longhands::stroke_dasharray::cascade_property,
        longhands::stroke_dashoffset::cascade_property,
        longhands::stroke_width::cascade_property,
        longhands::tab_size::cascade_property,
        longhands::text_decoration_thickness::cascade_property,
        longhands::text_emphasis_style::cascade_property,
        longhands::text_indent::cascade_property,
        longhands::text_overflow::cascade_property,
        longhands::text_shadow::cascade_property,
        longhands::transition_behavior::cascade_property,
        longhands::transition_delay::cascade_property,
        longhands::transition_duration::cascade_property,
        longhands::transition_property::cascade_property,
        longhands::transition_timing_function::cascade_property,
        longhands::translate::cascade_property,
        longhands::vertical_align::cascade_property,
        longhands::view_timeline_axis::cascade_property,
        longhands::view_timeline_inset::cascade_property,
        longhands::view_timeline_name::cascade_property,
        longhands::_webkit_text_stroke_width::cascade_property,
        longhands::will_change::cascade_property,
        longhands::word_spacing::cascade_property,
        longhands::_x_lang::cascade_property,
        longhands::object_position::cascade_property,
        longhands::perspective_origin::cascade_property,
        longhands::fill::cascade_property,
        longhands::stroke::cascade_property,
        longhands::_moz_window_transform_origin::cascade_property,
        longhands::transform_origin::cascade_property,
        longhands::grid_template_columns::cascade_property,
        longhands::grid_template_rows::cascade_property,
        longhands::border_image_source::cascade_property,
        longhands::list_style_image::cascade_property,
        longhands::grid_auto_columns::cascade_property,
        longhands::grid_auto_rows::cascade_property,
        longhands::_moz_window_transform::cascade_property,
        longhands::transform::cascade_property,
        longhands::column_gap::cascade_property,
        longhands::row_gap::cascade_property,
        longhands::marker_end::cascade_property,
        longhands::marker_mid::cascade_property,
        longhands::marker_start::cascade_property,
        longhands::contain_intrinsic_block_size::cascade_property,
        longhands::contain_intrinsic_height::cascade_property,
        longhands::contain_intrinsic_inline_size::cascade_property,
        longhands::contain_intrinsic_width::cascade_property,
        longhands::grid_column_end::cascade_property,
        longhands::grid_column_start::cascade_property,
        longhands::grid_row_end::cascade_property,
        longhands::grid_row_start::cascade_property,
        longhands::max_block_size::cascade_property,
        longhands::max_height::cascade_property,
        longhands::max_inline_size::cascade_property,
        longhands::max_width::cascade_property,
        longhands::cx::cascade_property,
        longhands::cy::cascade_property,
        longhands::offset_distance::cascade_property,
        longhands::x::cascade_property,
        longhands::y::cascade_property,
        longhands::border_bottom_left_radius::cascade_property,
        longhands::border_bottom_right_radius::cascade_property,
        longhands::border_end_end_radius::cascade_property,
        longhands::border_end_start_radius::cascade_property,
        longhands::border_start_end_radius::cascade_property,
        longhands::border_start_start_radius::cascade_property,
        longhands::border_top_left_radius::cascade_property,
        longhands::border_top_right_radius::cascade_property,
        longhands::block_size::cascade_property,
        longhands::height::cascade_property,
        longhands::inline_size::cascade_property,
        longhands::min_block_size::cascade_property,
        longhands::min_height::cascade_property,
        longhands::min_inline_size::cascade_property,
        longhands::min_width::cascade_property,
        longhands::width::cascade_property,
        longhands::border_block_end_width::cascade_property,
        longhands::border_block_start_width::cascade_property,
        longhands::border_bottom_width::cascade_property,
        longhands::border_inline_end_width::cascade_property,
        longhands::border_inline_start_width::cascade_property,
        longhands::border_left_width::cascade_property,
        longhands::border_right_width::cascade_property,
        longhands::border_top_width::cascade_property,
        longhands::column_rule_width::cascade_property,
        longhands::outline_width::cascade_property,
        longhands::padding_block_end::cascade_property,
        longhands::padding_block_start::cascade_property,
        longhands::padding_bottom::cascade_property,
        longhands::padding_inline_end::cascade_property,
        longhands::padding_inline_start::cascade_property,
        longhands::padding_left::cascade_property,
        longhands::padding_right::cascade_property,
        longhands::padding_top::cascade_property,
        longhands::r::cascade_property,
        longhands::shape_margin::cascade_property,
        longhands::rx::cascade_property,
        longhands::ry::cascade_property,
        longhands::scroll_padding_block_end::cascade_property,
        longhands::scroll_padding_block_start::cascade_property,
        longhands::scroll_padding_bottom::cascade_property,
        longhands::scroll_padding_inline_end::cascade_property,
        longhands::scroll_padding_inline_start::cascade_property,
        longhands::scroll_padding_left::cascade_property,
        longhands::scroll_padding_right::cascade_property,
        longhands::scroll_padding_top::cascade_property,
        longhands::_moz_window_input_region_margin::cascade_property,
        longhands::outline_offset::cascade_property,
        longhands::overflow_clip_margin::cascade_property,
        longhands::scroll_margin_block_end::cascade_property,
        longhands::scroll_margin_block_start::cascade_property,
        longhands::scroll_margin_bottom::cascade_property,
        longhands::scroll_margin_inline_end::cascade_property,
        longhands::scroll_margin_inline_start::cascade_property,
        longhands::scroll_margin_left::cascade_property,
        longhands::scroll_margin_right::cascade_property,
        longhands::scroll_margin_top::cascade_property,
        longhands::bottom::cascade_property,
        longhands::inset_block_end::cascade_property,
        longhands::inset_block_start::cascade_property,
        longhands::inset_inline_end::cascade_property,
        longhands::inset_inline_start::cascade_property,
        longhands::left::cascade_property,
        longhands::margin_block_end::cascade_property,
        longhands::margin_block_start::cascade_property,
        longhands::margin_bottom::cascade_property,
        longhands::margin_inline_end::cascade_property,
        longhands::margin_inline_start::cascade_property,
        longhands::margin_left::cascade_property,
        longhands::margin_right::cascade_property,
        longhands::margin_top::cascade_property,
        longhands::right::cascade_property,
        longhands::text_underline_offset::cascade_property,
        longhands::top::cascade_property,
        longhands::background_color::cascade_property,
        longhands::border_block_end_color::cascade_property,
        longhands::border_block_start_color::cascade_property,
        longhands::border_bottom_color::cascade_property,
        longhands::border_inline_end_color::cascade_property,
        longhands::border_inline_start_color::cascade_property,
        longhands::border_left_color::cascade_property,
        longhands::border_right_color::cascade_property,
        longhands::border_top_color::cascade_property,
        longhands::column_rule_color::cascade_property,
        longhands::flood_color::cascade_property,
        longhands::lighting_color::cascade_property,
        longhands::outline_color::cascade_property,
        longhands::stop_color::cascade_property,
        longhands::text_decoration_color::cascade_property,
        longhands::text_emphasis_color::cascade_property,
        longhands::_webkit_text_fill_color::cascade_property,
        longhands::_webkit_text_stroke_color::cascade_property,
];

/// See StyleAdjuster::adjust_for_border_width.
pub fn adjust_border_width(style: &mut StyleBuilder) {
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_top_style().none_or_hidden() &&
           style.get_border().border_top_has_nonzero_width() {
            style.set_border_top_width(Au(0));
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_right_style().none_or_hidden() &&
           style.get_border().border_right_has_nonzero_width() {
            style.set_border_right_width(Au(0));
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_bottom_style().none_or_hidden() &&
           style.get_border().border_bottom_has_nonzero_width() {
            style.set_border_bottom_width(Au(0));
        }
        // Like calling to_computed_value, which wouldn't type check.
        if style.get_border().clone_border_left_style().none_or_hidden() &&
           style.get_border().border_left_has_nonzero_width() {
            style.set_border_left_width(Au(0));
        }
}

/// An identifier for a given alias property.
#[derive(Clone, Copy, Eq, PartialEq, MallocSizeOf)]
#[repr(u16)]
pub enum AliasId {
        /// -webkit-background-clip
        WebkitBackgroundClip = 0,
        /// -webkit-background-origin
        WebkitBackgroundOrigin = 1,
        /// -webkit-background-size
        WebkitBackgroundSize = 2,
        /// -moz-border-start-color
        MozBorderStartColor = 3,
        /// -moz-border-start-style
        MozBorderStartStyle = 4,
        /// -moz-border-start-width
        MozBorderStartWidth = 5,
        /// -moz-border-end-color
        MozBorderEndColor = 6,
        /// -moz-border-end-style
        MozBorderEndStyle = 7,
        /// -moz-border-end-width
        MozBorderEndWidth = 8,
        /// -webkit-border-top-left-radius
        WebkitBorderTopLeftRadius = 9,
        /// -webkit-border-top-right-radius
        WebkitBorderTopRightRadius = 10,
        /// -webkit-border-bottom-right-radius
        WebkitBorderBottomRightRadius = 11,
        /// -webkit-border-bottom-left-radius
        WebkitBorderBottomLeftRadius = 12,
        /// -moz-transform
        MozTransform = 13,
        /// -webkit-transform
        WebkitTransform = 14,
        /// -moz-perspective
        MozPerspective = 15,
        /// -webkit-perspective
        WebkitPerspective = 16,
        /// -moz-perspective-origin
        MozPerspectiveOrigin = 17,
        /// -webkit-perspective-origin
        WebkitPerspectiveOrigin = 18,
        /// -moz-backface-visibility
        MozBackfaceVisibility = 19,
        /// -webkit-backface-visibility
        WebkitBackfaceVisibility = 20,
        /// -moz-transform-style
        MozTransformStyle = 21,
        /// -webkit-transform-style
        WebkitTransformStyle = 22,
        /// -moz-transform-origin
        MozTransformOrigin = 23,
        /// -webkit-transform-origin
        WebkitTransformOrigin = 24,
        /// -moz-appearance
        MozAppearance = 25,
        /// -webkit-appearance
        WebkitAppearance = 26,
        /// -webkit-box-shadow
        WebkitBoxShadow = 27,
        /// -webkit-filter
        WebkitFilter = 28,
        /// -moz-font-feature-settings
        MozFontFeatureSettings = 29,
        /// -moz-font-language-override
        MozFontLanguageOverride = 30,
        /// -webkit-font-smoothing
        WebkitFontSmoothing = 31,
        /// color-adjust
        ColorAdjust = 32,
        /// -moz-hyphens
        MozHyphens = 33,
        /// -webkit-text-size-adjust
        WebkitTextSizeAdjust = 34,
        /// word-wrap
        WordWrap = 35,
        /// -moz-tab-size
        MozTabSize = 36,
        /// -moz-margin-start
        MozMarginStart = 37,
        /// -moz-margin-end
        MozMarginEnd = 38,
        /// -moz-padding-start
        MozPaddingStart = 39,
        /// -moz-padding-end
        MozPaddingEnd = 40,
        /// -webkit-flex-direction
        WebkitFlexDirection = 41,
        /// -webkit-flex-wrap
        WebkitFlexWrap = 42,
        /// -webkit-justify-content
        WebkitJustifyContent = 43,
        /// -webkit-align-content
        WebkitAlignContent = 44,
        /// -webkit-align-items
        WebkitAlignItems = 45,
        /// -webkit-flex-grow
        WebkitFlexGrow = 46,
        /// -webkit-flex-shrink
        WebkitFlexShrink = 47,
        /// -webkit-align-self
        WebkitAlignSelf = 48,
        /// -webkit-order
        WebkitOrder = 49,
        /// -webkit-flex-basis
        WebkitFlexBasis = 50,
        /// -moz-box-sizing
        MozBoxSizing = 51,
        /// -webkit-box-sizing
        WebkitBoxSizing = 52,
        /// grid-column-gap
        GridColumnGap = 53,
        /// grid-row-gap
        GridRowGap = 54,
        /// -webkit-clip-path
        WebkitClipPath = 55,
        /// -webkit-mask-repeat
        WebkitMaskRepeat = 56,
        /// -webkit-mask-position-x
        WebkitMaskPositionX = 57,
        /// -webkit-mask-position-y
        WebkitMaskPositionY = 58,
        /// -webkit-mask-clip
        WebkitMaskClip = 59,
        /// -webkit-mask-origin
        WebkitMaskOrigin = 60,
        /// -webkit-mask-size
        WebkitMaskSize = 61,
        /// -webkit-mask-composite
        WebkitMaskComposite = 62,
        /// -webkit-mask-image
        WebkitMaskImage = 63,
        /// -moz-user-select
        MozUserSelect = 64,
        /// -webkit-user-select
        WebkitUserSelect = 65,
        /// -moz-transition-duration
        MozTransitionDuration = 66,
        /// -webkit-transition-duration
        WebkitTransitionDuration = 67,
        /// -moz-transition-timing-function
        MozTransitionTimingFunction = 68,
        /// -webkit-transition-timing-function
        WebkitTransitionTimingFunction = 69,
        /// -moz-transition-property
        MozTransitionProperty = 70,
        /// -webkit-transition-property
        WebkitTransitionProperty = 71,
        /// -moz-transition-delay
        MozTransitionDelay = 72,
        /// -webkit-transition-delay
        WebkitTransitionDelay = 73,
        /// -moz-animation-name
        MozAnimationName = 74,
        /// -webkit-animation-name
        WebkitAnimationName = 75,
        /// -moz-animation-duration
        MozAnimationDuration = 76,
        /// -webkit-animation-duration
        WebkitAnimationDuration = 77,
        /// -moz-animation-timing-function
        MozAnimationTimingFunction = 78,
        /// -webkit-animation-timing-function
        WebkitAnimationTimingFunction = 79,
        /// -moz-animation-iteration-count
        MozAnimationIterationCount = 80,
        /// -webkit-animation-iteration-count
        WebkitAnimationIterationCount = 81,
        /// -moz-animation-direction
        MozAnimationDirection = 82,
        /// -webkit-animation-direction
        WebkitAnimationDirection = 83,
        /// -moz-animation-play-state
        MozAnimationPlayState = 84,
        /// -webkit-animation-play-state
        WebkitAnimationPlayState = 85,
        /// -moz-animation-fill-mode
        MozAnimationFillMode = 86,
        /// -webkit-animation-fill-mode
        WebkitAnimationFillMode = 87,
        /// -moz-animation-delay
        MozAnimationDelay = 88,
        /// -webkit-animation-delay
        WebkitAnimationDelay = 89,
        /// -webkit-box-align
        WebkitBoxAlign = 90,
        /// -webkit-box-direction
        WebkitBoxDirection = 91,
        /// -webkit-box-flex
        WebkitBoxFlex = 92,
        /// -webkit-box-orient
        WebkitBoxOrient = 93,
        /// -webkit-box-pack
        WebkitBoxPack = 94,
        /// -webkit-box-ordinal-group
        WebkitBoxOrdinalGroup = 95,
        /// -moz-border-start
        MozBorderStart = 96,
        /// -moz-border-end
        MozBorderEnd = 97,
        /// -webkit-border-radius
        WebkitBorderRadius = 98,
        /// -moz-border-image
        MozBorderImage = 99,
        /// -webkit-border-image
        WebkitBorderImage = 100,
        /// -webkit-flex-flow
        WebkitFlexFlow = 101,
        /// -webkit-flex
        WebkitFlex = 102,
        /// grid-gap
        GridGap = 103,
        /// -webkit-mask
        WebkitMask = 104,
        /// -webkit-mask-position
        WebkitMaskPosition = 105,
        /// -moz-transition
        MozTransition = 106,
        /// -webkit-transition
        WebkitTransition = 107,
        /// -moz-animation
        MozAnimation = 108,
        /// -webkit-animation
        WebkitAnimation = 109,
}

impl fmt::Debug for AliasId {
    fn fmt(&self, formatter: &mut fmt::Formatter) -> fmt::Result {
        let name = NonCustomPropertyId::from(*self).name();
        formatter.write_str(name)
    }
}

impl AliasId {
    /// Returns the property we're aliasing, as a longhand or a shorthand.
    #[inline]
    pub fn aliased_property(self) -> NonCustomPropertyId {
        static MAP: [NonCustomPropertyId; 110] = [
            NonCustomPropertyId::from_longhand(LonghandId::BackgroundClip),
            NonCustomPropertyId::from_longhand(LonghandId::BackgroundOrigin),
            NonCustomPropertyId::from_longhand(LonghandId::BackgroundSize),
            NonCustomPropertyId::from_longhand(LonghandId::BorderInlineStartColor),
            NonCustomPropertyId::from_longhand(LonghandId::BorderInlineStartStyle),
            NonCustomPropertyId::from_longhand(LonghandId::BorderInlineStartWidth),
            NonCustomPropertyId::from_longhand(LonghandId::BorderInlineEndColor),
            NonCustomPropertyId::from_longhand(LonghandId::BorderInlineEndStyle),
            NonCustomPropertyId::from_longhand(LonghandId::BorderInlineEndWidth),
            NonCustomPropertyId::from_longhand(LonghandId::BorderTopLeftRadius),
            NonCustomPropertyId::from_longhand(LonghandId::BorderTopRightRadius),
            NonCustomPropertyId::from_longhand(LonghandId::BorderBottomRightRadius),
            NonCustomPropertyId::from_longhand(LonghandId::BorderBottomLeftRadius),
            NonCustomPropertyId::from_longhand(LonghandId::Transform),
            NonCustomPropertyId::from_longhand(LonghandId::Transform),
            NonCustomPropertyId::from_longhand(LonghandId::Perspective),
            NonCustomPropertyId::from_longhand(LonghandId::Perspective),
            NonCustomPropertyId::from_longhand(LonghandId::PerspectiveOrigin),
            NonCustomPropertyId::from_longhand(LonghandId::PerspectiveOrigin),
            NonCustomPropertyId::from_longhand(LonghandId::BackfaceVisibility),
            NonCustomPropertyId::from_longhand(LonghandId::BackfaceVisibility),
            NonCustomPropertyId::from_longhand(LonghandId::TransformStyle),
            NonCustomPropertyId::from_longhand(LonghandId::TransformStyle),
            NonCustomPropertyId::from_longhand(LonghandId::TransformOrigin),
            NonCustomPropertyId::from_longhand(LonghandId::TransformOrigin),
            NonCustomPropertyId::from_longhand(LonghandId::Appearance),
            NonCustomPropertyId::from_longhand(LonghandId::Appearance),
            NonCustomPropertyId::from_longhand(LonghandId::BoxShadow),
            NonCustomPropertyId::from_longhand(LonghandId::Filter),
            NonCustomPropertyId::from_longhand(LonghandId::FontFeatureSettings),
            NonCustomPropertyId::from_longhand(LonghandId::FontLanguageOverride),
            NonCustomPropertyId::from_longhand(LonghandId::MozOsxFontSmoothing),
            NonCustomPropertyId::from_longhand(LonghandId::PrintColorAdjust),
            NonCustomPropertyId::from_longhand(LonghandId::Hyphens),
            NonCustomPropertyId::from_longhand(LonghandId::MozTextSizeAdjust),
            NonCustomPropertyId::from_longhand(LonghandId::OverflowWrap),
            NonCustomPropertyId::from_longhand(LonghandId::TabSize),
            NonCustomPropertyId::from_longhand(LonghandId::MarginInlineStart),
            NonCustomPropertyId::from_longhand(LonghandId::MarginInlineEnd),
            NonCustomPropertyId::from_longhand(LonghandId::PaddingInlineStart),
            NonCustomPropertyId::from_longhand(LonghandId::PaddingInlineEnd),
            NonCustomPropertyId::from_longhand(LonghandId::FlexDirection),
            NonCustomPropertyId::from_longhand(LonghandId::FlexWrap),
            NonCustomPropertyId::from_longhand(LonghandId::JustifyContent),
            NonCustomPropertyId::from_longhand(LonghandId::AlignContent),
            NonCustomPropertyId::from_longhand(LonghandId::AlignItems),
            NonCustomPropertyId::from_longhand(LonghandId::FlexGrow),
            NonCustomPropertyId::from_longhand(LonghandId::FlexShrink),
            NonCustomPropertyId::from_longhand(LonghandId::AlignSelf),
            NonCustomPropertyId::from_longhand(LonghandId::Order),
            NonCustomPropertyId::from_longhand(LonghandId::FlexBasis),
            NonCustomPropertyId::from_longhand(LonghandId::BoxSizing),
            NonCustomPropertyId::from_longhand(LonghandId::BoxSizing),
            NonCustomPropertyId::from_longhand(LonghandId::ColumnGap),
            NonCustomPropertyId::from_longhand(LonghandId::RowGap),
            NonCustomPropertyId::from_longhand(LonghandId::ClipPath),
            NonCustomPropertyId::from_longhand(LonghandId::MaskRepeat),
            NonCustomPropertyId::from_longhand(LonghandId::MaskPositionX),
            NonCustomPropertyId::from_longhand(LonghandId::MaskPositionY),
            NonCustomPropertyId::from_longhand(LonghandId::MaskClip),
            NonCustomPropertyId::from_longhand(LonghandId::MaskOrigin),
            NonCustomPropertyId::from_longhand(LonghandId::MaskSize),
            NonCustomPropertyId::from_longhand(LonghandId::MaskComposite),
            NonCustomPropertyId::from_longhand(LonghandId::MaskImage),
            NonCustomPropertyId::from_longhand(LonghandId::UserSelect),
            NonCustomPropertyId::from_longhand(LonghandId::UserSelect),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionDuration),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionDuration),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionTimingFunction),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionTimingFunction),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionProperty),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionProperty),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionDelay),
            NonCustomPropertyId::from_longhand(LonghandId::TransitionDelay),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationName),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationName),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationDuration),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationDuration),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationTimingFunction),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationTimingFunction),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationIterationCount),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationIterationCount),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationDirection),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationDirection),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationPlayState),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationPlayState),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationFillMode),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationFillMode),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationDelay),
            NonCustomPropertyId::from_longhand(LonghandId::AnimationDelay),
            NonCustomPropertyId::from_longhand(LonghandId::MozBoxAlign),
            NonCustomPropertyId::from_longhand(LonghandId::MozBoxDirection),
            NonCustomPropertyId::from_longhand(LonghandId::MozBoxFlex),
            NonCustomPropertyId::from_longhand(LonghandId::MozBoxOrient),
            NonCustomPropertyId::from_longhand(LonghandId::MozBoxPack),
            NonCustomPropertyId::from_longhand(LonghandId::MozBoxOrdinalGroup),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::BorderInlineStart),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::BorderInlineEnd),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::BorderRadius),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::BorderImage),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::BorderImage),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::FlexFlow),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::Flex),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::Gap),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::Mask),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::MaskPosition),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::Transition),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::Transition),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::Animation),
            
            NonCustomPropertyId::from_shorthand(ShorthandId::Animation),
        ];
        MAP[self as usize]
    }
}

/// Call the given macro with tokens like this for each longhand and shorthand properties
/// that is enabled in content:
///
/// ```
/// [CamelCaseName, SetCamelCaseName, PropertyId::Longhand(LonghandId::CamelCaseName)],
/// ```
///
/// NOTE(emilio): Callers are responsible to deal with prefs.
#[macro_export]
macro_rules! css_properties_accessors {
    ($macro_name: ident) => {
        $macro_name! {
                                [Align_content, SetAlign_content,
                                 PropertyId::Longhand(LonghandId::AlignContent)],
                            [AlignContent, SetAlignContent,
                             PropertyId::Longhand(LonghandId::AlignContent)],
                                [_webkit_align_content, Set_webkit_align_content,
                                 PropertyId::Longhand(LonghandId::AlignContent)],
                            [WebkitAlignContent, SetWebkitAlignContent,
                             PropertyId::Longhand(LonghandId::AlignContent)],
                                [Align_items, SetAlign_items,
                                 PropertyId::Longhand(LonghandId::AlignItems)],
                            [AlignItems, SetAlignItems,
                             PropertyId::Longhand(LonghandId::AlignItems)],
                                [_webkit_align_items, Set_webkit_align_items,
                                 PropertyId::Longhand(LonghandId::AlignItems)],
                            [WebkitAlignItems, SetWebkitAlignItems,
                             PropertyId::Longhand(LonghandId::AlignItems)],
                                [Align_self, SetAlign_self,
                                 PropertyId::Longhand(LonghandId::AlignSelf)],
                            [AlignSelf, SetAlignSelf,
                             PropertyId::Longhand(LonghandId::AlignSelf)],
                                [_webkit_align_self, Set_webkit_align_self,
                                 PropertyId::Longhand(LonghandId::AlignSelf)],
                            [WebkitAlignSelf, SetWebkitAlignSelf,
                             PropertyId::Longhand(LonghandId::AlignSelf)],
                                [Aspect_ratio, SetAspect_ratio,
                                 PropertyId::Longhand(LonghandId::AspectRatio)],
                            [AspectRatio, SetAspectRatio,
                             PropertyId::Longhand(LonghandId::AspectRatio)],
                                [Backface_visibility, SetBackface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [BackfaceVisibility, SetBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [_moz_backface_visibility, Set_moz_backface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [MozBackfaceVisibility, SetMozBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [_webkit_backface_visibility, Set_webkit_backface_visibility,
                                 PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                            [WebkitBackfaceVisibility, SetWebkitBackfaceVisibility,
                             PropertyId::Longhand(LonghandId::BackfaceVisibility)],
                                [Baseline_source, SetBaseline_source,
                                 PropertyId::Longhand(LonghandId::BaselineSource)],
                            [BaselineSource, SetBaselineSource,
                             PropertyId::Longhand(LonghandId::BaselineSource)],
                                [Border_collapse, SetBorder_collapse,
                                 PropertyId::Longhand(LonghandId::BorderCollapse)],
                            [BorderCollapse, SetBorderCollapse,
                             PropertyId::Longhand(LonghandId::BorderCollapse)],
                                [Border_image_repeat, SetBorder_image_repeat,
                                 PropertyId::Longhand(LonghandId::BorderImageRepeat)],
                            [BorderImageRepeat, SetBorderImageRepeat,
                             PropertyId::Longhand(LonghandId::BorderImageRepeat)],
                                [Box_decoration_break, SetBox_decoration_break,
                                 PropertyId::Longhand(LonghandId::BoxDecorationBreak)],
                            [BoxDecorationBreak, SetBoxDecorationBreak,
                             PropertyId::Longhand(LonghandId::BoxDecorationBreak)],
                                [Box_sizing, SetBox_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [BoxSizing, SetBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [_moz_box_sizing, Set_moz_box_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [MozBoxSizing, SetMozBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [_webkit_box_sizing, Set_webkit_box_sizing,
                                 PropertyId::Longhand(LonghandId::BoxSizing)],
                            [WebkitBoxSizing, SetWebkitBoxSizing,
                             PropertyId::Longhand(LonghandId::BoxSizing)],
                                [Break_inside, SetBreak_inside,
                                 PropertyId::Longhand(LonghandId::BreakInside)],
                            [BreakInside, SetBreakInside,
                             PropertyId::Longhand(LonghandId::BreakInside)],
                                [Caption_side, SetCaption_side,
                                 PropertyId::Longhand(LonghandId::CaptionSide)],
                            [CaptionSide, SetCaptionSide,
                             PropertyId::Longhand(LonghandId::CaptionSide)],
                            [Clear, SetClear,
                             PropertyId::Longhand(LonghandId::Clear)],
                                [Color_interpolation, SetColor_interpolation,
                                 PropertyId::Longhand(LonghandId::ColorInterpolation)],
                            [ColorInterpolation, SetColorInterpolation,
                             PropertyId::Longhand(LonghandId::ColorInterpolation)],
                                [Color_interpolation_filters, SetColor_interpolation_filters,
                                 PropertyId::Longhand(LonghandId::ColorInterpolationFilters)],
                            [ColorInterpolationFilters, SetColorInterpolationFilters,
                             PropertyId::Longhand(LonghandId::ColorInterpolationFilters)],
                                [Column_count, SetColumn_count,
                                 PropertyId::Longhand(LonghandId::ColumnCount)],
                            [ColumnCount, SetColumnCount,
                             PropertyId::Longhand(LonghandId::ColumnCount)],
                                [Column_fill, SetColumn_fill,
                                 PropertyId::Longhand(LonghandId::ColumnFill)],
                            [ColumnFill, SetColumnFill,
                             PropertyId::Longhand(LonghandId::ColumnFill)],
                                [Column_span, SetColumn_span,
                                 PropertyId::Longhand(LonghandId::ColumnSpan)],
                            [ColumnSpan, SetColumnSpan,
                             PropertyId::Longhand(LonghandId::ColumnSpan)],
                            [Contain, SetContain,
                             PropertyId::Longhand(LonghandId::Contain)],
                                [Container_type, SetContainer_type,
                                 PropertyId::Longhand(LonghandId::ContainerType)],
                            [ContainerType, SetContainerType,
                             PropertyId::Longhand(LonghandId::ContainerType)],
                                [Content_visibility, SetContent_visibility,
                                 PropertyId::Longhand(LonghandId::ContentVisibility)],
                            [ContentVisibility, SetContentVisibility,
                             PropertyId::Longhand(LonghandId::ContentVisibility)],
                            [Direction, SetDirection,
                             PropertyId::Longhand(LonghandId::Direction)],
                            [Display, SetDisplay,
                             PropertyId::Longhand(LonghandId::Display)],
                                [Dominant_baseline, SetDominant_baseline,
                                 PropertyId::Longhand(LonghandId::DominantBaseline)],
                            [DominantBaseline, SetDominantBaseline,
                             PropertyId::Longhand(LonghandId::DominantBaseline)],
                                [Empty_cells, SetEmpty_cells,
                                 PropertyId::Longhand(LonghandId::EmptyCells)],
                            [EmptyCells, SetEmptyCells,
                             PropertyId::Longhand(LonghandId::EmptyCells)],
                                [Flex_direction, SetFlex_direction,
                                 PropertyId::Longhand(LonghandId::FlexDirection)],
                            [FlexDirection, SetFlexDirection,
                             PropertyId::Longhand(LonghandId::FlexDirection)],
                                [_webkit_flex_direction, Set_webkit_flex_direction,
                                 PropertyId::Longhand(LonghandId::FlexDirection)],
                            [WebkitFlexDirection, SetWebkitFlexDirection,
                             PropertyId::Longhand(LonghandId::FlexDirection)],
                                [Flex_wrap, SetFlex_wrap,
                                 PropertyId::Longhand(LonghandId::FlexWrap)],
                            [FlexWrap, SetFlexWrap,
                             PropertyId::Longhand(LonghandId::FlexWrap)],
                                [_webkit_flex_wrap, Set_webkit_flex_wrap,
                                 PropertyId::Longhand(LonghandId::FlexWrap)],
                            [WebkitFlexWrap, SetWebkitFlexWrap,
                             PropertyId::Longhand(LonghandId::FlexWrap)],
                            [Float, SetFloat,
                             PropertyId::Longhand(LonghandId::Float)],
                                [Font_kerning, SetFont_kerning,
                                 PropertyId::Longhand(LonghandId::FontKerning)],
                            [FontKerning, SetFontKerning,
                             PropertyId::Longhand(LonghandId::FontKerning)],
                                [Font_language_override, SetFont_language_override,
                                 PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                            [FontLanguageOverride, SetFontLanguageOverride,
                             PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                                [_moz_font_language_override, Set_moz_font_language_override,
                                 PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                            [MozFontLanguageOverride, SetMozFontLanguageOverride,
                             PropertyId::Longhand(LonghandId::FontLanguageOverride)],
                                [Font_optical_sizing, SetFont_optical_sizing,
                                 PropertyId::Longhand(LonghandId::FontOpticalSizing)],
                            [FontOpticalSizing, SetFontOpticalSizing,
                             PropertyId::Longhand(LonghandId::FontOpticalSizing)],
                                [Font_size_adjust, SetFont_size_adjust,
                                 PropertyId::Longhand(LonghandId::FontSizeAdjust)],
                            [FontSizeAdjust, SetFontSizeAdjust,
                             PropertyId::Longhand(LonghandId::FontSizeAdjust)],
                                [Font_stretch, SetFont_stretch,
                                 PropertyId::Longhand(LonghandId::FontStretch)],
                            [FontStretch, SetFontStretch,
                             PropertyId::Longhand(LonghandId::FontStretch)],
                                [Font_style, SetFont_style,
                                 PropertyId::Longhand(LonghandId::FontStyle)],
                            [FontStyle, SetFontStyle,
                             PropertyId::Longhand(LonghandId::FontStyle)],
                                [Font_variant_caps, SetFont_variant_caps,
                                 PropertyId::Longhand(LonghandId::FontVariantCaps)],
                            [FontVariantCaps, SetFontVariantCaps,
                             PropertyId::Longhand(LonghandId::FontVariantCaps)],
                                [Font_variant_east_asian, SetFont_variant_east_asian,
                                 PropertyId::Longhand(LonghandId::FontVariantEastAsian)],
                            [FontVariantEastAsian, SetFontVariantEastAsian,
                             PropertyId::Longhand(LonghandId::FontVariantEastAsian)],
                                [Font_variant_emoji, SetFont_variant_emoji,
                                 PropertyId::Longhand(LonghandId::FontVariantEmoji)],
                            [FontVariantEmoji, SetFontVariantEmoji,
                             PropertyId::Longhand(LonghandId::FontVariantEmoji)],
                                [Font_variant_ligatures, SetFont_variant_ligatures,
                                 PropertyId::Longhand(LonghandId::FontVariantLigatures)],
                            [FontVariantLigatures, SetFontVariantLigatures,
                             PropertyId::Longhand(LonghandId::FontVariantLigatures)],
                                [Font_variant_numeric, SetFont_variant_numeric,
                                 PropertyId::Longhand(LonghandId::FontVariantNumeric)],
                            [FontVariantNumeric, SetFontVariantNumeric,
                             PropertyId::Longhand(LonghandId::FontVariantNumeric)],
                                [Font_variant_position, SetFont_variant_position,
                                 PropertyId::Longhand(LonghandId::FontVariantPosition)],
                            [FontVariantPosition, SetFontVariantPosition,
                             PropertyId::Longhand(LonghandId::FontVariantPosition)],
                                [Font_weight, SetFont_weight,
                                 PropertyId::Longhand(LonghandId::FontWeight)],
                            [FontWeight, SetFontWeight,
                             PropertyId::Longhand(LonghandId::FontWeight)],
                                [Forced_color_adjust, SetForced_color_adjust,
                                 PropertyId::Longhand(LonghandId::ForcedColorAdjust)],
                            [ForcedColorAdjust, SetForcedColorAdjust,
                             PropertyId::Longhand(LonghandId::ForcedColorAdjust)],
                                [Grid_auto_flow, SetGrid_auto_flow,
                                 PropertyId::Longhand(LonghandId::GridAutoFlow)],
                            [GridAutoFlow, SetGridAutoFlow,
                             PropertyId::Longhand(LonghandId::GridAutoFlow)],
                            [Hyphens, SetHyphens,
                             PropertyId::Longhand(LonghandId::Hyphens)],
                                [_moz_hyphens, Set_moz_hyphens,
                                 PropertyId::Longhand(LonghandId::Hyphens)],
                            [MozHyphens, SetMozHyphens,
                             PropertyId::Longhand(LonghandId::Hyphens)],
                                [Image_orientation, SetImage_orientation,
                                 PropertyId::Longhand(LonghandId::ImageOrientation)],
                            [ImageOrientation, SetImageOrientation,
                             PropertyId::Longhand(LonghandId::ImageOrientation)],
                                [Image_rendering, SetImage_rendering,
                                 PropertyId::Longhand(LonghandId::ImageRendering)],
                            [ImageRendering, SetImageRendering,
                             PropertyId::Longhand(LonghandId::ImageRendering)],
                                [Ime_mode, SetIme_mode,
                                 PropertyId::Longhand(LonghandId::ImeMode)],
                            [ImeMode, SetImeMode,
                             PropertyId::Longhand(LonghandId::ImeMode)],
                                [Initial_letter, SetInitial_letter,
                                 PropertyId::Longhand(LonghandId::InitialLetter)],
                            [InitialLetter, SetInitialLetter,
                             PropertyId::Longhand(LonghandId::InitialLetter)],
                                [Inset_area, SetInset_area,
                                 PropertyId::Longhand(LonghandId::InsetArea)],
                            [InsetArea, SetInsetArea,
                             PropertyId::Longhand(LonghandId::InsetArea)],
                            [Isolation, SetIsolation,
                             PropertyId::Longhand(LonghandId::Isolation)],
                                [Justify_content, SetJustify_content,
                                 PropertyId::Longhand(LonghandId::JustifyContent)],
                            [JustifyContent, SetJustifyContent,
                             PropertyId::Longhand(LonghandId::JustifyContent)],
                                [_webkit_justify_content, Set_webkit_justify_content,
                                 PropertyId::Longhand(LonghandId::JustifyContent)],
                            [WebkitJustifyContent, SetWebkitJustifyContent,
                             PropertyId::Longhand(LonghandId::JustifyContent)],
                                [Justify_items, SetJustify_items,
                                 PropertyId::Longhand(LonghandId::JustifyItems)],
                            [JustifyItems, SetJustifyItems,
                             PropertyId::Longhand(LonghandId::JustifyItems)],
                                [Justify_self, SetJustify_self,
                                 PropertyId::Longhand(LonghandId::JustifySelf)],
                            [JustifySelf, SetJustifySelf,
                             PropertyId::Longhand(LonghandId::JustifySelf)],
                                [Line_break, SetLine_break,
                                 PropertyId::Longhand(LonghandId::LineBreak)],
                            [LineBreak, SetLineBreak,
                             PropertyId::Longhand(LonghandId::LineBreak)],
                                [List_style_position, SetList_style_position,
                                 PropertyId::Longhand(LonghandId::ListStylePosition)],
                            [ListStylePosition, SetListStylePosition,
                             PropertyId::Longhand(LonghandId::ListStylePosition)],
                                [Mask_type, SetMask_type,
                                 PropertyId::Longhand(LonghandId::MaskType)],
                            [MaskType, SetMaskType,
                             PropertyId::Longhand(LonghandId::MaskType)],
                                [Masonry_auto_flow, SetMasonry_auto_flow,
                                 PropertyId::Longhand(LonghandId::MasonryAutoFlow)],
                            [MasonryAutoFlow, SetMasonryAutoFlow,
                             PropertyId::Longhand(LonghandId::MasonryAutoFlow)],
                                [Math_depth, SetMath_depth,
                                 PropertyId::Longhand(LonghandId::MathDepth)],
                            [MathDepth, SetMathDepth,
                             PropertyId::Longhand(LonghandId::MathDepth)],
                                [Math_style, SetMath_style,
                                 PropertyId::Longhand(LonghandId::MathStyle)],
                            [MathStyle, SetMathStyle,
                             PropertyId::Longhand(LonghandId::MathStyle)],
                                [Mix_blend_mode, SetMix_blend_mode,
                                 PropertyId::Longhand(LonghandId::MixBlendMode)],
                            [MixBlendMode, SetMixBlendMode,
                             PropertyId::Longhand(LonghandId::MixBlendMode)],
                                [_moz_box_align, Set_moz_box_align,
                                 PropertyId::Longhand(LonghandId::MozBoxAlign)],
                            [MozBoxAlign, SetMozBoxAlign,
                             PropertyId::Longhand(LonghandId::MozBoxAlign)],
                                [_webkit_box_align, Set_webkit_box_align,
                                 PropertyId::Longhand(LonghandId::MozBoxAlign)],
                            [WebkitBoxAlign, SetWebkitBoxAlign,
                             PropertyId::Longhand(LonghandId::MozBoxAlign)],
                                [_moz_box_direction, Set_moz_box_direction,
                                 PropertyId::Longhand(LonghandId::MozBoxDirection)],
                            [MozBoxDirection, SetMozBoxDirection,
                             PropertyId::Longhand(LonghandId::MozBoxDirection)],
                                [_webkit_box_direction, Set_webkit_box_direction,
                                 PropertyId::Longhand(LonghandId::MozBoxDirection)],
                            [WebkitBoxDirection, SetWebkitBoxDirection,
                             PropertyId::Longhand(LonghandId::MozBoxDirection)],
                                [_moz_box_orient, Set_moz_box_orient,
                                 PropertyId::Longhand(LonghandId::MozBoxOrient)],
                            [MozBoxOrient, SetMozBoxOrient,
                             PropertyId::Longhand(LonghandId::MozBoxOrient)],
                                [_webkit_box_orient, Set_webkit_box_orient,
                                 PropertyId::Longhand(LonghandId::MozBoxOrient)],
                            [WebkitBoxOrient, SetWebkitBoxOrient,
                             PropertyId::Longhand(LonghandId::MozBoxOrient)],
                                [_moz_box_pack, Set_moz_box_pack,
                                 PropertyId::Longhand(LonghandId::MozBoxPack)],
                            [MozBoxPack, SetMozBoxPack,
                             PropertyId::Longhand(LonghandId::MozBoxPack)],
                                [_webkit_box_pack, Set_webkit_box_pack,
                                 PropertyId::Longhand(LonghandId::MozBoxPack)],
                            [WebkitBoxPack, SetWebkitBoxPack,
                             PropertyId::Longhand(LonghandId::MozBoxPack)],
                                [_moz_float_edge, Set_moz_float_edge,
                                 PropertyId::Longhand(LonghandId::MozFloatEdge)],
                            [MozFloatEdge, SetMozFloatEdge,
                             PropertyId::Longhand(LonghandId::MozFloatEdge)],
                                [_moz_orient, Set_moz_orient,
                                 PropertyId::Longhand(LonghandId::MozOrient)],
                            [MozOrient, SetMozOrient,
                             PropertyId::Longhand(LonghandId::MozOrient)],
                                [_moz_osx_font_smoothing, Set_moz_osx_font_smoothing,
                                 PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                            [MozOsxFontSmoothing, SetMozOsxFontSmoothing,
                             PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                                [_webkit_font_smoothing, Set_webkit_font_smoothing,
                                 PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                            [WebkitFontSmoothing, SetWebkitFontSmoothing,
                             PropertyId::Longhand(LonghandId::MozOsxFontSmoothing)],
                                [_moz_text_size_adjust, Set_moz_text_size_adjust,
                                 PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                            [MozTextSizeAdjust, SetMozTextSizeAdjust,
                             PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                                [_webkit_text_size_adjust, Set_webkit_text_size_adjust,
                                 PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                            [WebkitTextSizeAdjust, SetWebkitTextSizeAdjust,
                             PropertyId::Longhand(LonghandId::MozTextSizeAdjust)],
                                [_moz_user_input, Set_moz_user_input,
                                 PropertyId::Longhand(LonghandId::MozUserInput)],
                            [MozUserInput, SetMozUserInput,
                             PropertyId::Longhand(LonghandId::MozUserInput)],
                                [_moz_user_modify, Set_moz_user_modify,
                                 PropertyId::Longhand(LonghandId::MozUserModify)],
                            [MozUserModify, SetMozUserModify,
                             PropertyId::Longhand(LonghandId::MozUserModify)],
                                [_moz_window_dragging, Set_moz_window_dragging,
                                 PropertyId::Longhand(LonghandId::MozWindowDragging)],
                            [MozWindowDragging, SetMozWindowDragging,
                             PropertyId::Longhand(LonghandId::MozWindowDragging)],
                                [Object_fit, SetObject_fit,
                                 PropertyId::Longhand(LonghandId::ObjectFit)],
                            [ObjectFit, SetObjectFit,
                             PropertyId::Longhand(LonghandId::ObjectFit)],
                                [Offset_rotate, SetOffset_rotate,
                                 PropertyId::Longhand(LonghandId::OffsetRotate)],
                            [OffsetRotate, SetOffsetRotate,
                             PropertyId::Longhand(LonghandId::OffsetRotate)],
                                [Outline_style, SetOutline_style,
                                 PropertyId::Longhand(LonghandId::OutlineStyle)],
                            [OutlineStyle, SetOutlineStyle,
                             PropertyId::Longhand(LonghandId::OutlineStyle)],
                                [Overflow_anchor, SetOverflow_anchor,
                                 PropertyId::Longhand(LonghandId::OverflowAnchor)],
                            [OverflowAnchor, SetOverflowAnchor,
                             PropertyId::Longhand(LonghandId::OverflowAnchor)],
                                [Overflow_wrap, SetOverflow_wrap,
                                 PropertyId::Longhand(LonghandId::OverflowWrap)],
                            [OverflowWrap, SetOverflowWrap,
                             PropertyId::Longhand(LonghandId::OverflowWrap)],
                                [Word_wrap, SetWord_wrap,
                                 PropertyId::Longhand(LonghandId::OverflowWrap)],
                            [WordWrap, SetWordWrap,
                             PropertyId::Longhand(LonghandId::OverflowWrap)],
                                [Page_orientation, SetPage_orientation,
                                 PropertyId::Longhand(LonghandId::PageOrientation)],
                            [PageOrientation, SetPageOrientation,
                             PropertyId::Longhand(LonghandId::PageOrientation)],
                                [Paint_order, SetPaint_order,
                                 PropertyId::Longhand(LonghandId::PaintOrder)],
                            [PaintOrder, SetPaintOrder,
                             PropertyId::Longhand(LonghandId::PaintOrder)],
                                [Pointer_events, SetPointer_events,
                                 PropertyId::Longhand(LonghandId::PointerEvents)],
                            [PointerEvents, SetPointerEvents,
                             PropertyId::Longhand(LonghandId::PointerEvents)],
                            [Position, SetPosition,
                             PropertyId::Longhand(LonghandId::Position)],
                                [Position_try_order, SetPosition_try_order,
                                 PropertyId::Longhand(LonghandId::PositionTryOrder)],
                            [PositionTryOrder, SetPositionTryOrder,
                             PropertyId::Longhand(LonghandId::PositionTryOrder)],
                                [Position_visibility, SetPosition_visibility,
                                 PropertyId::Longhand(LonghandId::PositionVisibility)],
                            [PositionVisibility, SetPositionVisibility,
                             PropertyId::Longhand(LonghandId::PositionVisibility)],
                                [Print_color_adjust, SetPrint_color_adjust,
                                 PropertyId::Longhand(LonghandId::PrintColorAdjust)],
                            [PrintColorAdjust, SetPrintColorAdjust,
                             PropertyId::Longhand(LonghandId::PrintColorAdjust)],
                                [Color_adjust, SetColor_adjust,
                                 PropertyId::Longhand(LonghandId::PrintColorAdjust)],
                            [ColorAdjust, SetColorAdjust,
                             PropertyId::Longhand(LonghandId::PrintColorAdjust)],
                            [Resize, SetResize,
                             PropertyId::Longhand(LonghandId::Resize)],
                                [Ruby_align, SetRuby_align,
                                 PropertyId::Longhand(LonghandId::RubyAlign)],
                            [RubyAlign, SetRubyAlign,
                             PropertyId::Longhand(LonghandId::RubyAlign)],
                                [Ruby_position, SetRuby_position,
                                 PropertyId::Longhand(LonghandId::RubyPosition)],
                            [RubyPosition, SetRubyPosition,
                             PropertyId::Longhand(LonghandId::RubyPosition)],
                                [Scroll_behavior, SetScroll_behavior,
                                 PropertyId::Longhand(LonghandId::ScrollBehavior)],
                            [ScrollBehavior, SetScrollBehavior,
                             PropertyId::Longhand(LonghandId::ScrollBehavior)],
                                [Scroll_snap_align, SetScroll_snap_align,
                                 PropertyId::Longhand(LonghandId::ScrollSnapAlign)],
                            [ScrollSnapAlign, SetScrollSnapAlign,
                             PropertyId::Longhand(LonghandId::ScrollSnapAlign)],
                                [Scroll_snap_stop, SetScroll_snap_stop,
                                 PropertyId::Longhand(LonghandId::ScrollSnapStop)],
                            [ScrollSnapStop, SetScrollSnapStop,
                             PropertyId::Longhand(LonghandId::ScrollSnapStop)],
                                [Scroll_snap_type, SetScroll_snap_type,
                                 PropertyId::Longhand(LonghandId::ScrollSnapType)],
                            [ScrollSnapType, SetScrollSnapType,
                             PropertyId::Longhand(LonghandId::ScrollSnapType)],
                                [Scrollbar_gutter, SetScrollbar_gutter,
                                 PropertyId::Longhand(LonghandId::ScrollbarGutter)],
                            [ScrollbarGutter, SetScrollbarGutter,
                             PropertyId::Longhand(LonghandId::ScrollbarGutter)],
                                [Scrollbar_width, SetScrollbar_width,
                                 PropertyId::Longhand(LonghandId::ScrollbarWidth)],
                            [ScrollbarWidth, SetScrollbarWidth,
                             PropertyId::Longhand(LonghandId::ScrollbarWidth)],
                                [Shape_rendering, SetShape_rendering,
                                 PropertyId::Longhand(LonghandId::ShapeRendering)],
                            [ShapeRendering, SetShapeRendering,
                             PropertyId::Longhand(LonghandId::ShapeRendering)],
                                [Stroke_linecap, SetStroke_linecap,
                                 PropertyId::Longhand(LonghandId::StrokeLinecap)],
                            [StrokeLinecap, SetStrokeLinecap,
                             PropertyId::Longhand(LonghandId::StrokeLinecap)],
                                [Stroke_linejoin, SetStroke_linejoin,
                                 PropertyId::Longhand(LonghandId::StrokeLinejoin)],
                            [StrokeLinejoin, SetStrokeLinejoin,
                             PropertyId::Longhand(LonghandId::StrokeLinejoin)],
                                [Table_layout, SetTable_layout,
                                 PropertyId::Longhand(LonghandId::TableLayout)],
                            [TableLayout, SetTableLayout,
                             PropertyId::Longhand(LonghandId::TableLayout)],
                                [Text_align, SetText_align,
                                 PropertyId::Longhand(LonghandId::TextAlign)],
                            [TextAlign, SetTextAlign,
                             PropertyId::Longhand(LonghandId::TextAlign)],
                                [Text_align_last, SetText_align_last,
                                 PropertyId::Longhand(LonghandId::TextAlignLast)],
                            [TextAlignLast, SetTextAlignLast,
                             PropertyId::Longhand(LonghandId::TextAlignLast)],
                                [Text_anchor, SetText_anchor,
                                 PropertyId::Longhand(LonghandId::TextAnchor)],
                            [TextAnchor, SetTextAnchor,
                             PropertyId::Longhand(LonghandId::TextAnchor)],
                                [Text_combine_upright, SetText_combine_upright,
                                 PropertyId::Longhand(LonghandId::TextCombineUpright)],
                            [TextCombineUpright, SetTextCombineUpright,
                             PropertyId::Longhand(LonghandId::TextCombineUpright)],
                                [Text_decoration_line, SetText_decoration_line,
                                 PropertyId::Longhand(LonghandId::TextDecorationLine)],
                            [TextDecorationLine, SetTextDecorationLine,
                             PropertyId::Longhand(LonghandId::TextDecorationLine)],
                                [Text_decoration_skip_ink, SetText_decoration_skip_ink,
                                 PropertyId::Longhand(LonghandId::TextDecorationSkipInk)],
                            [TextDecorationSkipInk, SetTextDecorationSkipInk,
                             PropertyId::Longhand(LonghandId::TextDecorationSkipInk)],
                                [Text_decoration_style, SetText_decoration_style,
                                 PropertyId::Longhand(LonghandId::TextDecorationStyle)],
                            [TextDecorationStyle, SetTextDecorationStyle,
                             PropertyId::Longhand(LonghandId::TextDecorationStyle)],
                                [Text_emphasis_position, SetText_emphasis_position,
                                 PropertyId::Longhand(LonghandId::TextEmphasisPosition)],
                            [TextEmphasisPosition, SetTextEmphasisPosition,
                             PropertyId::Longhand(LonghandId::TextEmphasisPosition)],
                                [Text_justify, SetText_justify,
                                 PropertyId::Longhand(LonghandId::TextJustify)],
                            [TextJustify, SetTextJustify,
                             PropertyId::Longhand(LonghandId::TextJustify)],
                                [Text_orientation, SetText_orientation,
                                 PropertyId::Longhand(LonghandId::TextOrientation)],
                            [TextOrientation, SetTextOrientation,
                             PropertyId::Longhand(LonghandId::TextOrientation)],
                                [Text_rendering, SetText_rendering,
                                 PropertyId::Longhand(LonghandId::TextRendering)],
                            [TextRendering, SetTextRendering,
                             PropertyId::Longhand(LonghandId::TextRendering)],
                                [Text_transform, SetText_transform,
                                 PropertyId::Longhand(LonghandId::TextTransform)],
                            [TextTransform, SetTextTransform,
                             PropertyId::Longhand(LonghandId::TextTransform)],
                                [Text_underline_position, SetText_underline_position,
                                 PropertyId::Longhand(LonghandId::TextUnderlinePosition)],
                            [TextUnderlinePosition, SetTextUnderlinePosition,
                             PropertyId::Longhand(LonghandId::TextUnderlinePosition)],
                                [Text_wrap_mode, SetText_wrap_mode,
                                 PropertyId::Longhand(LonghandId::TextWrapMode)],
                            [TextWrapMode, SetTextWrapMode,
                             PropertyId::Longhand(LonghandId::TextWrapMode)],
                                [Text_wrap_style, SetText_wrap_style,
                                 PropertyId::Longhand(LonghandId::TextWrapStyle)],
                            [TextWrapStyle, SetTextWrapStyle,
                             PropertyId::Longhand(LonghandId::TextWrapStyle)],
                                [Touch_action, SetTouch_action,
                                 PropertyId::Longhand(LonghandId::TouchAction)],
                            [TouchAction, SetTouchAction,
                             PropertyId::Longhand(LonghandId::TouchAction)],
                                [Transform_box, SetTransform_box,
                                 PropertyId::Longhand(LonghandId::TransformBox)],
                            [TransformBox, SetTransformBox,
                             PropertyId::Longhand(LonghandId::TransformBox)],
                                [Transform_style, SetTransform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [TransformStyle, SetTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [_moz_transform_style, Set_moz_transform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [MozTransformStyle, SetMozTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [_webkit_transform_style, Set_webkit_transform_style,
                                 PropertyId::Longhand(LonghandId::TransformStyle)],
                            [WebkitTransformStyle, SetWebkitTransformStyle,
                             PropertyId::Longhand(LonghandId::TransformStyle)],
                                [Unicode_bidi, SetUnicode_bidi,
                                 PropertyId::Longhand(LonghandId::UnicodeBidi)],
                            [UnicodeBidi, SetUnicodeBidi,
                             PropertyId::Longhand(LonghandId::UnicodeBidi)],
                                [User_select, SetUser_select,
                                 PropertyId::Longhand(LonghandId::UserSelect)],
                            [UserSelect, SetUserSelect,
                             PropertyId::Longhand(LonghandId::UserSelect)],
                                [_moz_user_select, Set_moz_user_select,
                                 PropertyId::Longhand(LonghandId::UserSelect)],
                            [MozUserSelect, SetMozUserSelect,
                             PropertyId::Longhand(LonghandId::UserSelect)],
                                [_webkit_user_select, Set_webkit_user_select,
                                 PropertyId::Longhand(LonghandId::UserSelect)],
                            [WebkitUserSelect, SetWebkitUserSelect,
                             PropertyId::Longhand(LonghandId::UserSelect)],
                                [Vector_effect, SetVector_effect,
                                 PropertyId::Longhand(LonghandId::VectorEffect)],
                            [VectorEffect, SetVectorEffect,
                             PropertyId::Longhand(LonghandId::VectorEffect)],
                            [Visibility, SetVisibility,
                             PropertyId::Longhand(LonghandId::Visibility)],
                                [_webkit_line_clamp, Set_webkit_line_clamp,
                                 PropertyId::Longhand(LonghandId::WebkitLineClamp)],
                            [WebkitLineClamp, SetWebkitLineClamp,
                             PropertyId::Longhand(LonghandId::WebkitLineClamp)],
                                [_webkit_text_security, Set_webkit_text_security,
                                 PropertyId::Longhand(LonghandId::WebkitTextSecurity)],
                            [WebkitTextSecurity, SetWebkitTextSecurity,
                             PropertyId::Longhand(LonghandId::WebkitTextSecurity)],
                                [White_space_collapse, SetWhite_space_collapse,
                                 PropertyId::Longhand(LonghandId::WhiteSpaceCollapse)],
                            [WhiteSpaceCollapse, SetWhiteSpaceCollapse,
                             PropertyId::Longhand(LonghandId::WhiteSpaceCollapse)],
                                [Word_break, SetWord_break,
                                 PropertyId::Longhand(LonghandId::WordBreak)],
                            [WordBreak, SetWordBreak,
                             PropertyId::Longhand(LonghandId::WordBreak)],
                                [Writing_mode, SetWriting_mode,
                                 PropertyId::Longhand(LonghandId::WritingMode)],
                            [WritingMode, SetWritingMode,
                             PropertyId::Longhand(LonghandId::WritingMode)],
                                [Z_index, SetZ_index,
                                 PropertyId::Longhand(LonghandId::ZIndex)],
                            [ZIndex, SetZIndex,
                             PropertyId::Longhand(LonghandId::ZIndex)],
                            [Appearance, SetAppearance,
                             PropertyId::Longhand(LonghandId::Appearance)],
                                [_moz_appearance, Set_moz_appearance,
                                 PropertyId::Longhand(LonghandId::Appearance)],
                            [MozAppearance, SetMozAppearance,
                             PropertyId::Longhand(LonghandId::Appearance)],
                                [_webkit_appearance, Set_webkit_appearance,
                                 PropertyId::Longhand(LonghandId::Appearance)],
                            [WebkitAppearance, SetWebkitAppearance,
                             PropertyId::Longhand(LonghandId::Appearance)],
                                [_moz_force_broken_image_icon, Set_moz_force_broken_image_icon,
                                 PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon)],
                            [MozForceBrokenImageIcon, SetMozForceBrokenImageIcon,
                             PropertyId::Longhand(LonghandId::MozForceBrokenImageIcon)],
                                [Break_after, SetBreak_after,
                                 PropertyId::Longhand(LonghandId::BreakAfter)],
                            [BreakAfter, SetBreakAfter,
                             PropertyId::Longhand(LonghandId::BreakAfter)],
                                [Break_before, SetBreak_before,
                                 PropertyId::Longhand(LonghandId::BreakBefore)],
                            [BreakBefore, SetBreakBefore,
                             PropertyId::Longhand(LonghandId::BreakBefore)],
                                [Clip_rule, SetClip_rule,
                                 PropertyId::Longhand(LonghandId::ClipRule)],
                            [ClipRule, SetClipRule,
                             PropertyId::Longhand(LonghandId::ClipRule)],
                                [Fill_rule, SetFill_rule,
                                 PropertyId::Longhand(LonghandId::FillRule)],
                            [FillRule, SetFillRule,
                             PropertyId::Longhand(LonghandId::FillRule)],
                                [Fill_opacity, SetFill_opacity,
                                 PropertyId::Longhand(LonghandId::FillOpacity)],
                            [FillOpacity, SetFillOpacity,
                             PropertyId::Longhand(LonghandId::FillOpacity)],
                                [Stroke_opacity, SetStroke_opacity,
                                 PropertyId::Longhand(LonghandId::StrokeOpacity)],
                            [StrokeOpacity, SetStrokeOpacity,
                             PropertyId::Longhand(LonghandId::StrokeOpacity)],
                                [_moz_box_ordinal_group, Set_moz_box_ordinal_group,
                                 PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [MozBoxOrdinalGroup, SetMozBoxOrdinalGroup,
                             PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                                [_webkit_box_ordinal_group, Set_webkit_box_ordinal_group,
                                 PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [WebkitBoxOrdinalGroup, SetWebkitBoxOrdinalGroup,
                             PropertyId::Longhand(LonghandId::MozBoxOrdinalGroup)],
                            [Order, SetOrder,
                             PropertyId::Longhand(LonghandId::Order)],
                                [_webkit_order, Set_webkit_order,
                                 PropertyId::Longhand(LonghandId::Order)],
                            [WebkitOrder, SetWebkitOrder,
                             PropertyId::Longhand(LonghandId::Order)],
                                [Font_synthesis_position, SetFont_synthesis_position,
                                 PropertyId::Longhand(LonghandId::FontSynthesisPosition)],
                            [FontSynthesisPosition, SetFontSynthesisPosition,
                             PropertyId::Longhand(LonghandId::FontSynthesisPosition)],
                                [Font_synthesis_small_caps, SetFont_synthesis_small_caps,
                                 PropertyId::Longhand(LonghandId::FontSynthesisSmallCaps)],
                            [FontSynthesisSmallCaps, SetFontSynthesisSmallCaps,
                             PropertyId::Longhand(LonghandId::FontSynthesisSmallCaps)],
                                [Font_synthesis_style, SetFont_synthesis_style,
                                 PropertyId::Longhand(LonghandId::FontSynthesisStyle)],
                            [FontSynthesisStyle, SetFontSynthesisStyle,
                             PropertyId::Longhand(LonghandId::FontSynthesisStyle)],
                                [Font_synthesis_weight, SetFont_synthesis_weight,
                                 PropertyId::Longhand(LonghandId::FontSynthesisWeight)],
                            [FontSynthesisWeight, SetFontSynthesisWeight,
                             PropertyId::Longhand(LonghandId::FontSynthesisWeight)],
                                [Flex_grow, SetFlex_grow,
                                 PropertyId::Longhand(LonghandId::FlexGrow)],
                            [FlexGrow, SetFlexGrow,
                             PropertyId::Longhand(LonghandId::FlexGrow)],
                                [_webkit_flex_grow, Set_webkit_flex_grow,
                                 PropertyId::Longhand(LonghandId::FlexGrow)],
                            [WebkitFlexGrow, SetWebkitFlexGrow,
                             PropertyId::Longhand(LonghandId::FlexGrow)],
                                [Flex_shrink, SetFlex_shrink,
                                 PropertyId::Longhand(LonghandId::FlexShrink)],
                            [FlexShrink, SetFlexShrink,
                             PropertyId::Longhand(LonghandId::FlexShrink)],
                                [_webkit_flex_shrink, Set_webkit_flex_shrink,
                                 PropertyId::Longhand(LonghandId::FlexShrink)],
                            [WebkitFlexShrink, SetWebkitFlexShrink,
                             PropertyId::Longhand(LonghandId::FlexShrink)],
                                [_moz_box_flex, Set_moz_box_flex,
                                 PropertyId::Longhand(LonghandId::MozBoxFlex)],
                            [MozBoxFlex, SetMozBoxFlex,
                             PropertyId::Longhand(LonghandId::MozBoxFlex)],
                                [_webkit_box_flex, Set_webkit_box_flex,
                                 PropertyId::Longhand(LonghandId::MozBoxFlex)],
                            [WebkitBoxFlex, SetWebkitBoxFlex,
                             PropertyId::Longhand(LonghandId::MozBoxFlex)],
                                [Stroke_miterlimit, SetStroke_miterlimit,
                                 PropertyId::Longhand(LonghandId::StrokeMiterlimit)],
                            [StrokeMiterlimit, SetStrokeMiterlimit,
                             PropertyId::Longhand(LonghandId::StrokeMiterlimit)],
                                [Overflow_block, SetOverflow_block,
                                 PropertyId::Longhand(LonghandId::OverflowBlock)],
                            [OverflowBlock, SetOverflowBlock,
                             PropertyId::Longhand(LonghandId::OverflowBlock)],
                                [Overflow_inline, SetOverflow_inline,
                                 PropertyId::Longhand(LonghandId::OverflowInline)],
                            [OverflowInline, SetOverflowInline,
                             PropertyId::Longhand(LonghandId::OverflowInline)],
                                [Overflow_x, SetOverflow_x,
                                 PropertyId::Longhand(LonghandId::OverflowX)],
                            [OverflowX, SetOverflowX,
                             PropertyId::Longhand(LonghandId::OverflowX)],
                                [Overflow_y, SetOverflow_y,
                                 PropertyId::Longhand(LonghandId::OverflowY)],
                            [OverflowY, SetOverflowY,
                             PropertyId::Longhand(LonghandId::OverflowY)],
                                [Overscroll_behavior_block, SetOverscroll_behavior_block,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorBlock)],
                            [OverscrollBehaviorBlock, SetOverscrollBehaviorBlock,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorBlock)],
                                [Overscroll_behavior_inline, SetOverscroll_behavior_inline,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorInline)],
                            [OverscrollBehaviorInline, SetOverscrollBehaviorInline,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorInline)],
                                [Overscroll_behavior_x, SetOverscroll_behavior_x,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorX)],
                            [OverscrollBehaviorX, SetOverscrollBehaviorX,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorX)],
                                [Overscroll_behavior_y, SetOverscroll_behavior_y,
                                 PropertyId::Longhand(LonghandId::OverscrollBehaviorY)],
                            [OverscrollBehaviorY, SetOverscrollBehaviorY,
                             PropertyId::Longhand(LonghandId::OverscrollBehaviorY)],
                                [Flood_opacity, SetFlood_opacity,
                                 PropertyId::Longhand(LonghandId::FloodOpacity)],
                            [FloodOpacity, SetFloodOpacity,
                             PropertyId::Longhand(LonghandId::FloodOpacity)],
                            [Opacity, SetOpacity,
                             PropertyId::Longhand(LonghandId::Opacity)],
                                [Shape_image_threshold, SetShape_image_threshold,
                                 PropertyId::Longhand(LonghandId::ShapeImageThreshold)],
                            [ShapeImageThreshold, SetShapeImageThreshold,
                             PropertyId::Longhand(LonghandId::ShapeImageThreshold)],
                                [Stop_opacity, SetStop_opacity,
                                 PropertyId::Longhand(LonghandId::StopOpacity)],
                            [StopOpacity, SetStopOpacity,
                             PropertyId::Longhand(LonghandId::StopOpacity)],
                                [Border_block_end_style, SetBorder_block_end_style,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndStyle)],
                            [BorderBlockEndStyle, SetBorderBlockEndStyle,
                             PropertyId::Longhand(LonghandId::BorderBlockEndStyle)],
                                [Border_block_start_style, SetBorder_block_start_style,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartStyle)],
                            [BorderBlockStartStyle, SetBorderBlockStartStyle,
                             PropertyId::Longhand(LonghandId::BorderBlockStartStyle)],
                                [Border_bottom_style, SetBorder_bottom_style,
                                 PropertyId::Longhand(LonghandId::BorderBottomStyle)],
                            [BorderBottomStyle, SetBorderBottomStyle,
                             PropertyId::Longhand(LonghandId::BorderBottomStyle)],
                                [Border_inline_end_style, SetBorder_inline_end_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                            [BorderInlineEndStyle, SetBorderInlineEndStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                                [_moz_border_end_style, Set_moz_border_end_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                            [MozBorderEndStyle, SetMozBorderEndStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineEndStyle)],
                                [Border_inline_start_style, SetBorder_inline_start_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                            [BorderInlineStartStyle, SetBorderInlineStartStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                                [_moz_border_start_style, Set_moz_border_start_style,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                            [MozBorderStartStyle, SetMozBorderStartStyle,
                             PropertyId::Longhand(LonghandId::BorderInlineStartStyle)],
                                [Border_left_style, SetBorder_left_style,
                                 PropertyId::Longhand(LonghandId::BorderLeftStyle)],
                            [BorderLeftStyle, SetBorderLeftStyle,
                             PropertyId::Longhand(LonghandId::BorderLeftStyle)],
                                [Border_right_style, SetBorder_right_style,
                                 PropertyId::Longhand(LonghandId::BorderRightStyle)],
                            [BorderRightStyle, SetBorderRightStyle,
                             PropertyId::Longhand(LonghandId::BorderRightStyle)],
                                [Border_top_style, SetBorder_top_style,
                                 PropertyId::Longhand(LonghandId::BorderTopStyle)],
                            [BorderTopStyle, SetBorderTopStyle,
                             PropertyId::Longhand(LonghandId::BorderTopStyle)],
                                [Column_rule_style, SetColumn_rule_style,
                                 PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                            [ColumnRuleStyle, SetColumnRuleStyle,
                             PropertyId::Longhand(LonghandId::ColumnRuleStyle)],
                                [Accent_color, SetAccent_color,
                                 PropertyId::Longhand(LonghandId::AccentColor)],
                            [AccentColor, SetAccentColor,
                             PropertyId::Longhand(LonghandId::AccentColor)],
                                [Anchor_name, SetAnchor_name,
                                 PropertyId::Longhand(LonghandId::AnchorName)],
                            [AnchorName, SetAnchorName,
                             PropertyId::Longhand(LonghandId::AnchorName)],
                                [Anchor_scope, SetAnchor_scope,
                                 PropertyId::Longhand(LonghandId::AnchorScope)],
                            [AnchorScope, SetAnchorScope,
                             PropertyId::Longhand(LonghandId::AnchorScope)],
                                [Animation_composition, SetAnimation_composition,
                                 PropertyId::Longhand(LonghandId::AnimationComposition)],
                            [AnimationComposition, SetAnimationComposition,
                             PropertyId::Longhand(LonghandId::AnimationComposition)],
                                [Animation_delay, SetAnimation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [AnimationDelay, SetAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [_moz_animation_delay, Set_moz_animation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [MozAnimationDelay, SetMozAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [_webkit_animation_delay, Set_webkit_animation_delay,
                                 PropertyId::Longhand(LonghandId::AnimationDelay)],
                            [WebkitAnimationDelay, SetWebkitAnimationDelay,
                             PropertyId::Longhand(LonghandId::AnimationDelay)],
                                [Animation_direction, SetAnimation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [AnimationDirection, SetAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [_moz_animation_direction, Set_moz_animation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [MozAnimationDirection, SetMozAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [_webkit_animation_direction, Set_webkit_animation_direction,
                                 PropertyId::Longhand(LonghandId::AnimationDirection)],
                            [WebkitAnimationDirection, SetWebkitAnimationDirection,
                             PropertyId::Longhand(LonghandId::AnimationDirection)],
                                [Animation_duration, SetAnimation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [AnimationDuration, SetAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [_moz_animation_duration, Set_moz_animation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [MozAnimationDuration, SetMozAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [_webkit_animation_duration, Set_webkit_animation_duration,
                                 PropertyId::Longhand(LonghandId::AnimationDuration)],
                            [WebkitAnimationDuration, SetWebkitAnimationDuration,
                             PropertyId::Longhand(LonghandId::AnimationDuration)],
                                [Animation_fill_mode, SetAnimation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [AnimationFillMode, SetAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [_moz_animation_fill_mode, Set_moz_animation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [MozAnimationFillMode, SetMozAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [_webkit_animation_fill_mode, Set_webkit_animation_fill_mode,
                                 PropertyId::Longhand(LonghandId::AnimationFillMode)],
                            [WebkitAnimationFillMode, SetWebkitAnimationFillMode,
                             PropertyId::Longhand(LonghandId::AnimationFillMode)],
                                [Animation_iteration_count, SetAnimation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [AnimationIterationCount, SetAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [_moz_animation_iteration_count, Set_moz_animation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [MozAnimationIterationCount, SetMozAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [_webkit_animation_iteration_count, Set_webkit_animation_iteration_count,
                                 PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                            [WebkitAnimationIterationCount, SetWebkitAnimationIterationCount,
                             PropertyId::Longhand(LonghandId::AnimationIterationCount)],
                                [Animation_name, SetAnimation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [AnimationName, SetAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [_moz_animation_name, Set_moz_animation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [MozAnimationName, SetMozAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [_webkit_animation_name, Set_webkit_animation_name,
                                 PropertyId::Longhand(LonghandId::AnimationName)],
                            [WebkitAnimationName, SetWebkitAnimationName,
                             PropertyId::Longhand(LonghandId::AnimationName)],
                                [Animation_play_state, SetAnimation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [AnimationPlayState, SetAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [_moz_animation_play_state, Set_moz_animation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [MozAnimationPlayState, SetMozAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [_webkit_animation_play_state, Set_webkit_animation_play_state,
                                 PropertyId::Longhand(LonghandId::AnimationPlayState)],
                            [WebkitAnimationPlayState, SetWebkitAnimationPlayState,
                             PropertyId::Longhand(LonghandId::AnimationPlayState)],
                                [Animation_timeline, SetAnimation_timeline,
                                 PropertyId::Longhand(LonghandId::AnimationTimeline)],
                            [AnimationTimeline, SetAnimationTimeline,
                             PropertyId::Longhand(LonghandId::AnimationTimeline)],
                                [Animation_timing_function, SetAnimation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [AnimationTimingFunction, SetAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [_moz_animation_timing_function, Set_moz_animation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [MozAnimationTimingFunction, SetMozAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [_webkit_animation_timing_function, Set_webkit_animation_timing_function,
                                 PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                            [WebkitAnimationTimingFunction, SetWebkitAnimationTimingFunction,
                             PropertyId::Longhand(LonghandId::AnimationTimingFunction)],
                                [Backdrop_filter, SetBackdrop_filter,
                                 PropertyId::Longhand(LonghandId::BackdropFilter)],
                            [BackdropFilter, SetBackdropFilter,
                             PropertyId::Longhand(LonghandId::BackdropFilter)],
                                [Background_attachment, SetBackground_attachment,
                                 PropertyId::Longhand(LonghandId::BackgroundAttachment)],
                            [BackgroundAttachment, SetBackgroundAttachment,
                             PropertyId::Longhand(LonghandId::BackgroundAttachment)],
                                [Background_blend_mode, SetBackground_blend_mode,
                                 PropertyId::Longhand(LonghandId::BackgroundBlendMode)],
                            [BackgroundBlendMode, SetBackgroundBlendMode,
                             PropertyId::Longhand(LonghandId::BackgroundBlendMode)],
                                [Background_clip, SetBackground_clip,
                                 PropertyId::Longhand(LonghandId::BackgroundClip)],
                            [BackgroundClip, SetBackgroundClip,
                             PropertyId::Longhand(LonghandId::BackgroundClip)],
                                [_webkit_background_clip, Set_webkit_background_clip,
                                 PropertyId::Longhand(LonghandId::BackgroundClip)],
                            [WebkitBackgroundClip, SetWebkitBackgroundClip,
                             PropertyId::Longhand(LonghandId::BackgroundClip)],
                                [Background_image, SetBackground_image,
                                 PropertyId::Longhand(LonghandId::BackgroundImage)],
                            [BackgroundImage, SetBackgroundImage,
                             PropertyId::Longhand(LonghandId::BackgroundImage)],
                                [Background_origin, SetBackground_origin,
                                 PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                            [BackgroundOrigin, SetBackgroundOrigin,
                             PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                                [_webkit_background_origin, Set_webkit_background_origin,
                                 PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                            [WebkitBackgroundOrigin, SetWebkitBackgroundOrigin,
                             PropertyId::Longhand(LonghandId::BackgroundOrigin)],
                                [Background_position_x, SetBackground_position_x,
                                 PropertyId::Longhand(LonghandId::BackgroundPositionX)],
                            [BackgroundPositionX, SetBackgroundPositionX,
                             PropertyId::Longhand(LonghandId::BackgroundPositionX)],
                                [Background_position_y, SetBackground_position_y,
                                 PropertyId::Longhand(LonghandId::BackgroundPositionY)],
                            [BackgroundPositionY, SetBackgroundPositionY,
                             PropertyId::Longhand(LonghandId::BackgroundPositionY)],
                                [Background_repeat, SetBackground_repeat,
                                 PropertyId::Longhand(LonghandId::BackgroundRepeat)],
                            [BackgroundRepeat, SetBackgroundRepeat,
                             PropertyId::Longhand(LonghandId::BackgroundRepeat)],
                                [Background_size, SetBackground_size,
                                 PropertyId::Longhand(LonghandId::BackgroundSize)],
                            [BackgroundSize, SetBackgroundSize,
                             PropertyId::Longhand(LonghandId::BackgroundSize)],
                                [_webkit_background_size, Set_webkit_background_size,
                                 PropertyId::Longhand(LonghandId::BackgroundSize)],
                            [WebkitBackgroundSize, SetWebkitBackgroundSize,
                             PropertyId::Longhand(LonghandId::BackgroundSize)],
                                [Border_image_outset, SetBorder_image_outset,
                                 PropertyId::Longhand(LonghandId::BorderImageOutset)],
                            [BorderImageOutset, SetBorderImageOutset,
                             PropertyId::Longhand(LonghandId::BorderImageOutset)],
                                [Border_image_slice, SetBorder_image_slice,
                                 PropertyId::Longhand(LonghandId::BorderImageSlice)],
                            [BorderImageSlice, SetBorderImageSlice,
                             PropertyId::Longhand(LonghandId::BorderImageSlice)],
                                [Border_image_width, SetBorder_image_width,
                                 PropertyId::Longhand(LonghandId::BorderImageWidth)],
                            [BorderImageWidth, SetBorderImageWidth,
                             PropertyId::Longhand(LonghandId::BorderImageWidth)],
                                [Border_spacing, SetBorder_spacing,
                                 PropertyId::Longhand(LonghandId::BorderSpacing)],
                            [BorderSpacing, SetBorderSpacing,
                             PropertyId::Longhand(LonghandId::BorderSpacing)],
                                [Box_shadow, SetBox_shadow,
                                 PropertyId::Longhand(LonghandId::BoxShadow)],
                            [BoxShadow, SetBoxShadow,
                             PropertyId::Longhand(LonghandId::BoxShadow)],
                                [_webkit_box_shadow, Set_webkit_box_shadow,
                                 PropertyId::Longhand(LonghandId::BoxShadow)],
                            [WebkitBoxShadow, SetWebkitBoxShadow,
                             PropertyId::Longhand(LonghandId::BoxShadow)],
                                [Caret_color, SetCaret_color,
                                 PropertyId::Longhand(LonghandId::CaretColor)],
                            [CaretColor, SetCaretColor,
                             PropertyId::Longhand(LonghandId::CaretColor)],
                            [Clip, SetClip,
                             PropertyId::Longhand(LonghandId::Clip)],
                                [Clip_path, SetClip_path,
                                 PropertyId::Longhand(LonghandId::ClipPath)],
                            [ClipPath, SetClipPath,
                             PropertyId::Longhand(LonghandId::ClipPath)],
                                [_webkit_clip_path, Set_webkit_clip_path,
                                 PropertyId::Longhand(LonghandId::ClipPath)],
                            [WebkitClipPath, SetWebkitClipPath,
                             PropertyId::Longhand(LonghandId::ClipPath)],
                            [Color, SetColor,
                             PropertyId::Longhand(LonghandId::Color)],
                                [Color_scheme, SetColor_scheme,
                                 PropertyId::Longhand(LonghandId::ColorScheme)],
                            [ColorScheme, SetColorScheme,
                             PropertyId::Longhand(LonghandId::ColorScheme)],
                                [Column_width, SetColumn_width,
                                 PropertyId::Longhand(LonghandId::ColumnWidth)],
                            [ColumnWidth, SetColumnWidth,
                             PropertyId::Longhand(LonghandId::ColumnWidth)],
                                [Container_name, SetContainer_name,
                                 PropertyId::Longhand(LonghandId::ContainerName)],
                            [ContainerName, SetContainerName,
                             PropertyId::Longhand(LonghandId::ContainerName)],
                            [Content, SetContent,
                             PropertyId::Longhand(LonghandId::Content)],
                                [Counter_increment, SetCounter_increment,
                                 PropertyId::Longhand(LonghandId::CounterIncrement)],
                            [CounterIncrement, SetCounterIncrement,
                             PropertyId::Longhand(LonghandId::CounterIncrement)],
                                [Counter_reset, SetCounter_reset,
                                 PropertyId::Longhand(LonghandId::CounterReset)],
                            [CounterReset, SetCounterReset,
                             PropertyId::Longhand(LonghandId::CounterReset)],
                                [Counter_set, SetCounter_set,
                                 PropertyId::Longhand(LonghandId::CounterSet)],
                            [CounterSet, SetCounterSet,
                             PropertyId::Longhand(LonghandId::CounterSet)],
                            [Cursor, SetCursor,
                             PropertyId::Longhand(LonghandId::Cursor)],
                            [D, SetD,
                             PropertyId::Longhand(LonghandId::D)],
                            [Filter, SetFilter,
                             PropertyId::Longhand(LonghandId::Filter)],
                                [_webkit_filter, Set_webkit_filter,
                                 PropertyId::Longhand(LonghandId::Filter)],
                            [WebkitFilter, SetWebkitFilter,
                             PropertyId::Longhand(LonghandId::Filter)],
                                [Flex_basis, SetFlex_basis,
                                 PropertyId::Longhand(LonghandId::FlexBasis)],
                            [FlexBasis, SetFlexBasis,
                             PropertyId::Longhand(LonghandId::FlexBasis)],
                                [_webkit_flex_basis, Set_webkit_flex_basis,
                                 PropertyId::Longhand(LonghandId::FlexBasis)],
                            [WebkitFlexBasis, SetWebkitFlexBasis,
                             PropertyId::Longhand(LonghandId::FlexBasis)],
                                [Font_family, SetFont_family,
                                 PropertyId::Longhand(LonghandId::FontFamily)],
                            [FontFamily, SetFontFamily,
                             PropertyId::Longhand(LonghandId::FontFamily)],
                                [Font_feature_settings, SetFont_feature_settings,
                                 PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                            [FontFeatureSettings, SetFontFeatureSettings,
                             PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                                [_moz_font_feature_settings, Set_moz_font_feature_settings,
                                 PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                            [MozFontFeatureSettings, SetMozFontFeatureSettings,
                             PropertyId::Longhand(LonghandId::FontFeatureSettings)],
                                [Font_palette, SetFont_palette,
                                 PropertyId::Longhand(LonghandId::FontPalette)],
                            [FontPalette, SetFontPalette,
                             PropertyId::Longhand(LonghandId::FontPalette)],
                                [Font_size, SetFont_size,
                                 PropertyId::Longhand(LonghandId::FontSize)],
                            [FontSize, SetFontSize,
                             PropertyId::Longhand(LonghandId::FontSize)],
                                [Font_variant_alternates, SetFont_variant_alternates,
                                 PropertyId::Longhand(LonghandId::FontVariantAlternates)],
                            [FontVariantAlternates, SetFontVariantAlternates,
                             PropertyId::Longhand(LonghandId::FontVariantAlternates)],
                                [Font_variation_settings, SetFont_variation_settings,
                                 PropertyId::Longhand(LonghandId::FontVariationSettings)],
                            [FontVariationSettings, SetFontVariationSettings,
                             PropertyId::Longhand(LonghandId::FontVariationSettings)],
                                [Grid_template_areas, SetGrid_template_areas,
                                 PropertyId::Longhand(LonghandId::GridTemplateAreas)],
                            [GridTemplateAreas, SetGridTemplateAreas,
                             PropertyId::Longhand(LonghandId::GridTemplateAreas)],
                                [Hyphenate_character, SetHyphenate_character,
                                 PropertyId::Longhand(LonghandId::HyphenateCharacter)],
                            [HyphenateCharacter, SetHyphenateCharacter,
                             PropertyId::Longhand(LonghandId::HyphenateCharacter)],
                                [Letter_spacing, SetLetter_spacing,
                                 PropertyId::Longhand(LonghandId::LetterSpacing)],
                            [LetterSpacing, SetLetterSpacing,
                             PropertyId::Longhand(LonghandId::LetterSpacing)],
                                [Line_height, SetLine_height,
                                 PropertyId::Longhand(LonghandId::LineHeight)],
                            [LineHeight, SetLineHeight,
                             PropertyId::Longhand(LonghandId::LineHeight)],
                                [List_style_type, SetList_style_type,
                                 PropertyId::Longhand(LonghandId::ListStyleType)],
                            [ListStyleType, SetListStyleType,
                             PropertyId::Longhand(LonghandId::ListStyleType)],
                                [Mask_clip, SetMask_clip,
                                 PropertyId::Longhand(LonghandId::MaskClip)],
                            [MaskClip, SetMaskClip,
                             PropertyId::Longhand(LonghandId::MaskClip)],
                                [_webkit_mask_clip, Set_webkit_mask_clip,
                                 PropertyId::Longhand(LonghandId::MaskClip)],
                            [WebkitMaskClip, SetWebkitMaskClip,
                             PropertyId::Longhand(LonghandId::MaskClip)],
                                [Mask_composite, SetMask_composite,
                                 PropertyId::Longhand(LonghandId::MaskComposite)],
                            [MaskComposite, SetMaskComposite,
                             PropertyId::Longhand(LonghandId::MaskComposite)],
                                [_webkit_mask_composite, Set_webkit_mask_composite,
                                 PropertyId::Longhand(LonghandId::MaskComposite)],
                            [WebkitMaskComposite, SetWebkitMaskComposite,
                             PropertyId::Longhand(LonghandId::MaskComposite)],
                                [Mask_image, SetMask_image,
                                 PropertyId::Longhand(LonghandId::MaskImage)],
                            [MaskImage, SetMaskImage,
                             PropertyId::Longhand(LonghandId::MaskImage)],
                                [_webkit_mask_image, Set_webkit_mask_image,
                                 PropertyId::Longhand(LonghandId::MaskImage)],
                            [WebkitMaskImage, SetWebkitMaskImage,
                             PropertyId::Longhand(LonghandId::MaskImage)],
                                [Mask_mode, SetMask_mode,
                                 PropertyId::Longhand(LonghandId::MaskMode)],
                            [MaskMode, SetMaskMode,
                             PropertyId::Longhand(LonghandId::MaskMode)],
                                [Mask_origin, SetMask_origin,
                                 PropertyId::Longhand(LonghandId::MaskOrigin)],
                            [MaskOrigin, SetMaskOrigin,
                             PropertyId::Longhand(LonghandId::MaskOrigin)],
                                [_webkit_mask_origin, Set_webkit_mask_origin,
                                 PropertyId::Longhand(LonghandId::MaskOrigin)],
                            [WebkitMaskOrigin, SetWebkitMaskOrigin,
                             PropertyId::Longhand(LonghandId::MaskOrigin)],
                                [Mask_position_x, SetMask_position_x,
                                 PropertyId::Longhand(LonghandId::MaskPositionX)],
                            [MaskPositionX, SetMaskPositionX,
                             PropertyId::Longhand(LonghandId::MaskPositionX)],
                                [_webkit_mask_position_x, Set_webkit_mask_position_x,
                                 PropertyId::Longhand(LonghandId::MaskPositionX)],
                            [WebkitMaskPositionX, SetWebkitMaskPositionX,
                             PropertyId::Longhand(LonghandId::MaskPositionX)],
                                [Mask_position_y, SetMask_position_y,
                                 PropertyId::Longhand(LonghandId::MaskPositionY)],
                            [MaskPositionY, SetMaskPositionY,
                             PropertyId::Longhand(LonghandId::MaskPositionY)],
                                [_webkit_mask_position_y, Set_webkit_mask_position_y,
                                 PropertyId::Longhand(LonghandId::MaskPositionY)],
                            [WebkitMaskPositionY, SetWebkitMaskPositionY,
                             PropertyId::Longhand(LonghandId::MaskPositionY)],
                                [Mask_repeat, SetMask_repeat,
                                 PropertyId::Longhand(LonghandId::MaskRepeat)],
                            [MaskRepeat, SetMaskRepeat,
                             PropertyId::Longhand(LonghandId::MaskRepeat)],
                                [_webkit_mask_repeat, Set_webkit_mask_repeat,
                                 PropertyId::Longhand(LonghandId::MaskRepeat)],
                            [WebkitMaskRepeat, SetWebkitMaskRepeat,
                             PropertyId::Longhand(LonghandId::MaskRepeat)],
                                [Mask_size, SetMask_size,
                                 PropertyId::Longhand(LonghandId::MaskSize)],
                            [MaskSize, SetMaskSize,
                             PropertyId::Longhand(LonghandId::MaskSize)],
                                [_webkit_mask_size, Set_webkit_mask_size,
                                 PropertyId::Longhand(LonghandId::MaskSize)],
                            [WebkitMaskSize, SetWebkitMaskSize,
                             PropertyId::Longhand(LonghandId::MaskSize)],
                                [Offset_anchor, SetOffset_anchor,
                                 PropertyId::Longhand(LonghandId::OffsetAnchor)],
                            [OffsetAnchor, SetOffsetAnchor,
                             PropertyId::Longhand(LonghandId::OffsetAnchor)],
                                [Offset_path, SetOffset_path,
                                 PropertyId::Longhand(LonghandId::OffsetPath)],
                            [OffsetPath, SetOffsetPath,
                             PropertyId::Longhand(LonghandId::OffsetPath)],
                                [Offset_position, SetOffset_position,
                                 PropertyId::Longhand(LonghandId::OffsetPosition)],
                            [OffsetPosition, SetOffsetPosition,
                             PropertyId::Longhand(LonghandId::OffsetPosition)],
                            [Page, SetPage,
                             PropertyId::Longhand(LonghandId::Page)],
                            [Perspective, SetPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [_moz_perspective, Set_moz_perspective,
                                 PropertyId::Longhand(LonghandId::Perspective)],
                            [MozPerspective, SetMozPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [_webkit_perspective, Set_webkit_perspective,
                                 PropertyId::Longhand(LonghandId::Perspective)],
                            [WebkitPerspective, SetWebkitPerspective,
                             PropertyId::Longhand(LonghandId::Perspective)],
                                [Position_anchor, SetPosition_anchor,
                                 PropertyId::Longhand(LonghandId::PositionAnchor)],
                            [PositionAnchor, SetPositionAnchor,
                             PropertyId::Longhand(LonghandId::PositionAnchor)],
                                [Position_try_options, SetPosition_try_options,
                                 PropertyId::Longhand(LonghandId::PositionTryOptions)],
                            [PositionTryOptions, SetPositionTryOptions,
                             PropertyId::Longhand(LonghandId::PositionTryOptions)],
                            [Quotes, SetQuotes,
                             PropertyId::Longhand(LonghandId::Quotes)],
                            [Rotate, SetRotate,
                             PropertyId::Longhand(LonghandId::Rotate)],
                            [Scale, SetScale,
                             PropertyId::Longhand(LonghandId::Scale)],
                                [Scroll_timeline_axis, SetScroll_timeline_axis,
                                 PropertyId::Longhand(LonghandId::ScrollTimelineAxis)],
                            [ScrollTimelineAxis, SetScrollTimelineAxis,
                             PropertyId::Longhand(LonghandId::ScrollTimelineAxis)],
                                [Scroll_timeline_name, SetScroll_timeline_name,
                                 PropertyId::Longhand(LonghandId::ScrollTimelineName)],
                            [ScrollTimelineName, SetScrollTimelineName,
                             PropertyId::Longhand(LonghandId::ScrollTimelineName)],
                                [Scrollbar_color, SetScrollbar_color,
                                 PropertyId::Longhand(LonghandId::ScrollbarColor)],
                            [ScrollbarColor, SetScrollbarColor,
                             PropertyId::Longhand(LonghandId::ScrollbarColor)],
                                [Shape_outside, SetShape_outside,
                                 PropertyId::Longhand(LonghandId::ShapeOutside)],
                            [ShapeOutside, SetShapeOutside,
                             PropertyId::Longhand(LonghandId::ShapeOutside)],
                            [Size, SetSize,
                             PropertyId::Longhand(LonghandId::Size)],
                                [Stroke_dasharray, SetStroke_dasharray,
                                 PropertyId::Longhand(LonghandId::StrokeDasharray)],
                            [StrokeDasharray, SetStrokeDasharray,
                             PropertyId::Longhand(LonghandId::StrokeDasharray)],
                                [Stroke_dashoffset, SetStroke_dashoffset,
                                 PropertyId::Longhand(LonghandId::StrokeDashoffset)],
                            [StrokeDashoffset, SetStrokeDashoffset,
                             PropertyId::Longhand(LonghandId::StrokeDashoffset)],
                                [Stroke_width, SetStroke_width,
                                 PropertyId::Longhand(LonghandId::StrokeWidth)],
                            [StrokeWidth, SetStrokeWidth,
                             PropertyId::Longhand(LonghandId::StrokeWidth)],
                                [Tab_size, SetTab_size,
                                 PropertyId::Longhand(LonghandId::TabSize)],
                            [TabSize, SetTabSize,
                             PropertyId::Longhand(LonghandId::TabSize)],
                                [_moz_tab_size, Set_moz_tab_size,
                                 PropertyId::Longhand(LonghandId::TabSize)],
                            [MozTabSize, SetMozTabSize,
                             PropertyId::Longhand(LonghandId::TabSize)],
                                [Text_decoration_thickness, SetText_decoration_thickness,
                                 PropertyId::Longhand(LonghandId::TextDecorationThickness)],
                            [TextDecorationThickness, SetTextDecorationThickness,
                             PropertyId::Longhand(LonghandId::TextDecorationThickness)],
                                [Text_emphasis_style, SetText_emphasis_style,
                                 PropertyId::Longhand(LonghandId::TextEmphasisStyle)],
                            [TextEmphasisStyle, SetTextEmphasisStyle,
                             PropertyId::Longhand(LonghandId::TextEmphasisStyle)],
                                [Text_indent, SetText_indent,
                                 PropertyId::Longhand(LonghandId::TextIndent)],
                            [TextIndent, SetTextIndent,
                             PropertyId::Longhand(LonghandId::TextIndent)],
                                [Text_overflow, SetText_overflow,
                                 PropertyId::Longhand(LonghandId::TextOverflow)],
                            [TextOverflow, SetTextOverflow,
                             PropertyId::Longhand(LonghandId::TextOverflow)],
                                [Text_shadow, SetText_shadow,
                                 PropertyId::Longhand(LonghandId::TextShadow)],
                            [TextShadow, SetTextShadow,
                             PropertyId::Longhand(LonghandId::TextShadow)],
                                [Transition_behavior, SetTransition_behavior,
                                 PropertyId::Longhand(LonghandId::TransitionBehavior)],
                            [TransitionBehavior, SetTransitionBehavior,
                             PropertyId::Longhand(LonghandId::TransitionBehavior)],
                                [Transition_delay, SetTransition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [TransitionDelay, SetTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [_moz_transition_delay, Set_moz_transition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [MozTransitionDelay, SetMozTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [_webkit_transition_delay, Set_webkit_transition_delay,
                                 PropertyId::Longhand(LonghandId::TransitionDelay)],
                            [WebkitTransitionDelay, SetWebkitTransitionDelay,
                             PropertyId::Longhand(LonghandId::TransitionDelay)],
                                [Transition_duration, SetTransition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [TransitionDuration, SetTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [_moz_transition_duration, Set_moz_transition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [MozTransitionDuration, SetMozTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [_webkit_transition_duration, Set_webkit_transition_duration,
                                 PropertyId::Longhand(LonghandId::TransitionDuration)],
                            [WebkitTransitionDuration, SetWebkitTransitionDuration,
                             PropertyId::Longhand(LonghandId::TransitionDuration)],
                                [Transition_property, SetTransition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [TransitionProperty, SetTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [_moz_transition_property, Set_moz_transition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [MozTransitionProperty, SetMozTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [_webkit_transition_property, Set_webkit_transition_property,
                                 PropertyId::Longhand(LonghandId::TransitionProperty)],
                            [WebkitTransitionProperty, SetWebkitTransitionProperty,
                             PropertyId::Longhand(LonghandId::TransitionProperty)],
                                [Transition_timing_function, SetTransition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [TransitionTimingFunction, SetTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                                [_moz_transition_timing_function, Set_moz_transition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [MozTransitionTimingFunction, SetMozTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                                [_webkit_transition_timing_function, Set_webkit_transition_timing_function,
                                 PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [WebkitTransitionTimingFunction, SetWebkitTransitionTimingFunction,
                             PropertyId::Longhand(LonghandId::TransitionTimingFunction)],
                            [Translate, SetTranslate,
                             PropertyId::Longhand(LonghandId::Translate)],
                                [Vertical_align, SetVertical_align,
                                 PropertyId::Longhand(LonghandId::VerticalAlign)],
                            [VerticalAlign, SetVerticalAlign,
                             PropertyId::Longhand(LonghandId::VerticalAlign)],
                                [View_timeline_axis, SetView_timeline_axis,
                                 PropertyId::Longhand(LonghandId::ViewTimelineAxis)],
                            [ViewTimelineAxis, SetViewTimelineAxis,
                             PropertyId::Longhand(LonghandId::ViewTimelineAxis)],
                                [View_timeline_inset, SetView_timeline_inset,
                                 PropertyId::Longhand(LonghandId::ViewTimelineInset)],
                            [ViewTimelineInset, SetViewTimelineInset,
                             PropertyId::Longhand(LonghandId::ViewTimelineInset)],
                                [View_timeline_name, SetView_timeline_name,
                                 PropertyId::Longhand(LonghandId::ViewTimelineName)],
                            [ViewTimelineName, SetViewTimelineName,
                             PropertyId::Longhand(LonghandId::ViewTimelineName)],
                                [_webkit_text_stroke_width, Set_webkit_text_stroke_width,
                                 PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth)],
                            [WebkitTextStrokeWidth, SetWebkitTextStrokeWidth,
                             PropertyId::Longhand(LonghandId::WebkitTextStrokeWidth)],
                                [Will_change, SetWill_change,
                                 PropertyId::Longhand(LonghandId::WillChange)],
                            [WillChange, SetWillChange,
                             PropertyId::Longhand(LonghandId::WillChange)],
                                [Word_spacing, SetWord_spacing,
                                 PropertyId::Longhand(LonghandId::WordSpacing)],
                            [WordSpacing, SetWordSpacing,
                             PropertyId::Longhand(LonghandId::WordSpacing)],
                                [Object_position, SetObject_position,
                                 PropertyId::Longhand(LonghandId::ObjectPosition)],
                            [ObjectPosition, SetObjectPosition,
                             PropertyId::Longhand(LonghandId::ObjectPosition)],
                                [Perspective_origin, SetPerspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [PerspectiveOrigin, SetPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                                [_moz_perspective_origin, Set_moz_perspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [MozPerspectiveOrigin, SetMozPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                                [_webkit_perspective_origin, Set_webkit_perspective_origin,
                                 PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [WebkitPerspectiveOrigin, SetWebkitPerspectiveOrigin,
                             PropertyId::Longhand(LonghandId::PerspectiveOrigin)],
                            [Fill, SetFill,
                             PropertyId::Longhand(LonghandId::Fill)],
                            [Stroke, SetStroke,
                             PropertyId::Longhand(LonghandId::Stroke)],
                                [Transform_origin, SetTransform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [TransformOrigin, SetTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [_moz_transform_origin, Set_moz_transform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [MozTransformOrigin, SetMozTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [_webkit_transform_origin, Set_webkit_transform_origin,
                                 PropertyId::Longhand(LonghandId::TransformOrigin)],
                            [WebkitTransformOrigin, SetWebkitTransformOrigin,
                             PropertyId::Longhand(LonghandId::TransformOrigin)],
                                [Grid_template_columns, SetGrid_template_columns,
                                 PropertyId::Longhand(LonghandId::GridTemplateColumns)],
                            [GridTemplateColumns, SetGridTemplateColumns,
                             PropertyId::Longhand(LonghandId::GridTemplateColumns)],
                                [Grid_template_rows, SetGrid_template_rows,
                                 PropertyId::Longhand(LonghandId::GridTemplateRows)],
                            [GridTemplateRows, SetGridTemplateRows,
                             PropertyId::Longhand(LonghandId::GridTemplateRows)],
                                [Border_image_source, SetBorder_image_source,
                                 PropertyId::Longhand(LonghandId::BorderImageSource)],
                            [BorderImageSource, SetBorderImageSource,
                             PropertyId::Longhand(LonghandId::BorderImageSource)],
                                [List_style_image, SetList_style_image,
                                 PropertyId::Longhand(LonghandId::ListStyleImage)],
                            [ListStyleImage, SetListStyleImage,
                             PropertyId::Longhand(LonghandId::ListStyleImage)],
                                [Grid_auto_columns, SetGrid_auto_columns,
                                 PropertyId::Longhand(LonghandId::GridAutoColumns)],
                            [GridAutoColumns, SetGridAutoColumns,
                             PropertyId::Longhand(LonghandId::GridAutoColumns)],
                                [Grid_auto_rows, SetGrid_auto_rows,
                                 PropertyId::Longhand(LonghandId::GridAutoRows)],
                            [GridAutoRows, SetGridAutoRows,
                             PropertyId::Longhand(LonghandId::GridAutoRows)],
                            [Transform, SetTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                                [_moz_transform, Set_moz_transform,
                                 PropertyId::Longhand(LonghandId::Transform)],
                            [MozTransform, SetMozTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                                [_webkit_transform, Set_webkit_transform,
                                 PropertyId::Longhand(LonghandId::Transform)],
                            [WebkitTransform, SetWebkitTransform,
                             PropertyId::Longhand(LonghandId::Transform)],
                                [Column_gap, SetColumn_gap,
                                 PropertyId::Longhand(LonghandId::ColumnGap)],
                            [ColumnGap, SetColumnGap,
                             PropertyId::Longhand(LonghandId::ColumnGap)],
                                [Grid_column_gap, SetGrid_column_gap,
                                 PropertyId::Longhand(LonghandId::ColumnGap)],
                            [GridColumnGap, SetGridColumnGap,
                             PropertyId::Longhand(LonghandId::ColumnGap)],
                                [Row_gap, SetRow_gap,
                                 PropertyId::Longhand(LonghandId::RowGap)],
                            [RowGap, SetRowGap,
                             PropertyId::Longhand(LonghandId::RowGap)],
                                [Grid_row_gap, SetGrid_row_gap,
                                 PropertyId::Longhand(LonghandId::RowGap)],
                            [GridRowGap, SetGridRowGap,
                             PropertyId::Longhand(LonghandId::RowGap)],
                                [Marker_end, SetMarker_end,
                                 PropertyId::Longhand(LonghandId::MarkerEnd)],
                            [MarkerEnd, SetMarkerEnd,
                             PropertyId::Longhand(LonghandId::MarkerEnd)],
                                [Marker_mid, SetMarker_mid,
                                 PropertyId::Longhand(LonghandId::MarkerMid)],
                            [MarkerMid, SetMarkerMid,
                             PropertyId::Longhand(LonghandId::MarkerMid)],
                                [Marker_start, SetMarker_start,
                                 PropertyId::Longhand(LonghandId::MarkerStart)],
                            [MarkerStart, SetMarkerStart,
                             PropertyId::Longhand(LonghandId::MarkerStart)],
                                [Contain_intrinsic_block_size, SetContain_intrinsic_block_size,
                                 PropertyId::Longhand(LonghandId::ContainIntrinsicBlockSize)],
                            [ContainIntrinsicBlockSize, SetContainIntrinsicBlockSize,
                             PropertyId::Longhand(LonghandId::ContainIntrinsicBlockSize)],
                                [Contain_intrinsic_height, SetContain_intrinsic_height,
                                 PropertyId::Longhand(LonghandId::ContainIntrinsicHeight)],
                            [ContainIntrinsicHeight, SetContainIntrinsicHeight,
                             PropertyId::Longhand(LonghandId::ContainIntrinsicHeight)],
                                [Contain_intrinsic_inline_size, SetContain_intrinsic_inline_size,
                                 PropertyId::Longhand(LonghandId::ContainIntrinsicInlineSize)],
                            [ContainIntrinsicInlineSize, SetContainIntrinsicInlineSize,
                             PropertyId::Longhand(LonghandId::ContainIntrinsicInlineSize)],
                                [Contain_intrinsic_width, SetContain_intrinsic_width,
                                 PropertyId::Longhand(LonghandId::ContainIntrinsicWidth)],
                            [ContainIntrinsicWidth, SetContainIntrinsicWidth,
                             PropertyId::Longhand(LonghandId::ContainIntrinsicWidth)],
                                [Grid_column_end, SetGrid_column_end,
                                 PropertyId::Longhand(LonghandId::GridColumnEnd)],
                            [GridColumnEnd, SetGridColumnEnd,
                             PropertyId::Longhand(LonghandId::GridColumnEnd)],
                                [Grid_column_start, SetGrid_column_start,
                                 PropertyId::Longhand(LonghandId::GridColumnStart)],
                            [GridColumnStart, SetGridColumnStart,
                             PropertyId::Longhand(LonghandId::GridColumnStart)],
                                [Grid_row_end, SetGrid_row_end,
                                 PropertyId::Longhand(LonghandId::GridRowEnd)],
                            [GridRowEnd, SetGridRowEnd,
                             PropertyId::Longhand(LonghandId::GridRowEnd)],
                                [Grid_row_start, SetGrid_row_start,
                                 PropertyId::Longhand(LonghandId::GridRowStart)],
                            [GridRowStart, SetGridRowStart,
                             PropertyId::Longhand(LonghandId::GridRowStart)],
                                [Max_block_size, SetMax_block_size,
                                 PropertyId::Longhand(LonghandId::MaxBlockSize)],
                            [MaxBlockSize, SetMaxBlockSize,
                             PropertyId::Longhand(LonghandId::MaxBlockSize)],
                                [Max_height, SetMax_height,
                                 PropertyId::Longhand(LonghandId::MaxHeight)],
                            [MaxHeight, SetMaxHeight,
                             PropertyId::Longhand(LonghandId::MaxHeight)],
                                [Max_inline_size, SetMax_inline_size,
                                 PropertyId::Longhand(LonghandId::MaxInlineSize)],
                            [MaxInlineSize, SetMaxInlineSize,
                             PropertyId::Longhand(LonghandId::MaxInlineSize)],
                                [Max_width, SetMax_width,
                                 PropertyId::Longhand(LonghandId::MaxWidth)],
                            [MaxWidth, SetMaxWidth,
                             PropertyId::Longhand(LonghandId::MaxWidth)],
                            [Cx, SetCx,
                             PropertyId::Longhand(LonghandId::Cx)],
                            [Cy, SetCy,
                             PropertyId::Longhand(LonghandId::Cy)],
                                [Offset_distance, SetOffset_distance,
                                 PropertyId::Longhand(LonghandId::OffsetDistance)],
                            [OffsetDistance, SetOffsetDistance,
                             PropertyId::Longhand(LonghandId::OffsetDistance)],
                            [X, SetX,
                             PropertyId::Longhand(LonghandId::X)],
                            [Y, SetY,
                             PropertyId::Longhand(LonghandId::Y)],
                                [Border_bottom_left_radius, SetBorder_bottom_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                            [BorderBottomLeftRadius, SetBorderBottomLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                                [_webkit_border_bottom_left_radius, Set_webkit_border_bottom_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                            [WebkitBorderBottomLeftRadius, SetWebkitBorderBottomLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomLeftRadius)],
                                [Border_bottom_right_radius, SetBorder_bottom_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                            [BorderBottomRightRadius, SetBorderBottomRightRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                                [_webkit_border_bottom_right_radius, Set_webkit_border_bottom_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                            [WebkitBorderBottomRightRadius, SetWebkitBorderBottomRightRadius,
                             PropertyId::Longhand(LonghandId::BorderBottomRightRadius)],
                                [Border_end_end_radius, SetBorder_end_end_radius,
                                 PropertyId::Longhand(LonghandId::BorderEndEndRadius)],
                            [BorderEndEndRadius, SetBorderEndEndRadius,
                             PropertyId::Longhand(LonghandId::BorderEndEndRadius)],
                                [Border_end_start_radius, SetBorder_end_start_radius,
                                 PropertyId::Longhand(LonghandId::BorderEndStartRadius)],
                            [BorderEndStartRadius, SetBorderEndStartRadius,
                             PropertyId::Longhand(LonghandId::BorderEndStartRadius)],
                                [Border_start_end_radius, SetBorder_start_end_radius,
                                 PropertyId::Longhand(LonghandId::BorderStartEndRadius)],
                            [BorderStartEndRadius, SetBorderStartEndRadius,
                             PropertyId::Longhand(LonghandId::BorderStartEndRadius)],
                                [Border_start_start_radius, SetBorder_start_start_radius,
                                 PropertyId::Longhand(LonghandId::BorderStartStartRadius)],
                            [BorderStartStartRadius, SetBorderStartStartRadius,
                             PropertyId::Longhand(LonghandId::BorderStartStartRadius)],
                                [Border_top_left_radius, SetBorder_top_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                            [BorderTopLeftRadius, SetBorderTopLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                                [_webkit_border_top_left_radius, Set_webkit_border_top_left_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                            [WebkitBorderTopLeftRadius, SetWebkitBorderTopLeftRadius,
                             PropertyId::Longhand(LonghandId::BorderTopLeftRadius)],
                                [Border_top_right_radius, SetBorder_top_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                            [BorderTopRightRadius, SetBorderTopRightRadius,
                             PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                                [_webkit_border_top_right_radius, Set_webkit_border_top_right_radius,
                                 PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                            [WebkitBorderTopRightRadius, SetWebkitBorderTopRightRadius,
                             PropertyId::Longhand(LonghandId::BorderTopRightRadius)],
                                [Block_size, SetBlock_size,
                                 PropertyId::Longhand(LonghandId::BlockSize)],
                            [BlockSize, SetBlockSize,
                             PropertyId::Longhand(LonghandId::BlockSize)],
                            [Height, SetHeight,
                             PropertyId::Longhand(LonghandId::Height)],
                                [Inline_size, SetInline_size,
                                 PropertyId::Longhand(LonghandId::InlineSize)],
                            [InlineSize, SetInlineSize,
                             PropertyId::Longhand(LonghandId::InlineSize)],
                                [Min_block_size, SetMin_block_size,
                                 PropertyId::Longhand(LonghandId::MinBlockSize)],
                            [MinBlockSize, SetMinBlockSize,
                             PropertyId::Longhand(LonghandId::MinBlockSize)],
                                [Min_height, SetMin_height,
                                 PropertyId::Longhand(LonghandId::MinHeight)],
                            [MinHeight, SetMinHeight,
                             PropertyId::Longhand(LonghandId::MinHeight)],
                                [Min_inline_size, SetMin_inline_size,
                                 PropertyId::Longhand(LonghandId::MinInlineSize)],
                            [MinInlineSize, SetMinInlineSize,
                             PropertyId::Longhand(LonghandId::MinInlineSize)],
                                [Min_width, SetMin_width,
                                 PropertyId::Longhand(LonghandId::MinWidth)],
                            [MinWidth, SetMinWidth,
                             PropertyId::Longhand(LonghandId::MinWidth)],
                            [Width, SetWidth,
                             PropertyId::Longhand(LonghandId::Width)],
                                [Border_block_end_width, SetBorder_block_end_width,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndWidth)],
                            [BorderBlockEndWidth, SetBorderBlockEndWidth,
                             PropertyId::Longhand(LonghandId::BorderBlockEndWidth)],
                                [Border_block_start_width, SetBorder_block_start_width,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartWidth)],
                            [BorderBlockStartWidth, SetBorderBlockStartWidth,
                             PropertyId::Longhand(LonghandId::BorderBlockStartWidth)],
                                [Border_bottom_width, SetBorder_bottom_width,
                                 PropertyId::Longhand(LonghandId::BorderBottomWidth)],
                            [BorderBottomWidth, SetBorderBottomWidth,
                             PropertyId::Longhand(LonghandId::BorderBottomWidth)],
                                [Border_inline_end_width, SetBorder_inline_end_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                            [BorderInlineEndWidth, SetBorderInlineEndWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                                [_moz_border_end_width, Set_moz_border_end_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                            [MozBorderEndWidth, SetMozBorderEndWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineEndWidth)],
                                [Border_inline_start_width, SetBorder_inline_start_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                            [BorderInlineStartWidth, SetBorderInlineStartWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                                [_moz_border_start_width, Set_moz_border_start_width,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                            [MozBorderStartWidth, SetMozBorderStartWidth,
                             PropertyId::Longhand(LonghandId::BorderInlineStartWidth)],
                                [Border_left_width, SetBorder_left_width,
                                 PropertyId::Longhand(LonghandId::BorderLeftWidth)],
                            [BorderLeftWidth, SetBorderLeftWidth,
                             PropertyId::Longhand(LonghandId::BorderLeftWidth)],
                                [Border_right_width, SetBorder_right_width,
                                 PropertyId::Longhand(LonghandId::BorderRightWidth)],
                            [BorderRightWidth, SetBorderRightWidth,
                             PropertyId::Longhand(LonghandId::BorderRightWidth)],
                                [Border_top_width, SetBorder_top_width,
                                 PropertyId::Longhand(LonghandId::BorderTopWidth)],
                            [BorderTopWidth, SetBorderTopWidth,
                             PropertyId::Longhand(LonghandId::BorderTopWidth)],
                                [Column_rule_width, SetColumn_rule_width,
                                 PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                            [ColumnRuleWidth, SetColumnRuleWidth,
                             PropertyId::Longhand(LonghandId::ColumnRuleWidth)],
                                [Outline_width, SetOutline_width,
                                 PropertyId::Longhand(LonghandId::OutlineWidth)],
                            [OutlineWidth, SetOutlineWidth,
                             PropertyId::Longhand(LonghandId::OutlineWidth)],
                                [Padding_block_end, SetPadding_block_end,
                                 PropertyId::Longhand(LonghandId::PaddingBlockEnd)],
                            [PaddingBlockEnd, SetPaddingBlockEnd,
                             PropertyId::Longhand(LonghandId::PaddingBlockEnd)],
                                [Padding_block_start, SetPadding_block_start,
                                 PropertyId::Longhand(LonghandId::PaddingBlockStart)],
                            [PaddingBlockStart, SetPaddingBlockStart,
                             PropertyId::Longhand(LonghandId::PaddingBlockStart)],
                                [Padding_bottom, SetPadding_bottom,
                                 PropertyId::Longhand(LonghandId::PaddingBottom)],
                            [PaddingBottom, SetPaddingBottom,
                             PropertyId::Longhand(LonghandId::PaddingBottom)],
                                [Padding_inline_end, SetPadding_inline_end,
                                 PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                            [PaddingInlineEnd, SetPaddingInlineEnd,
                             PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                                [_moz_padding_end, Set_moz_padding_end,
                                 PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                            [MozPaddingEnd, SetMozPaddingEnd,
                             PropertyId::Longhand(LonghandId::PaddingInlineEnd)],
                                [Padding_inline_start, SetPadding_inline_start,
                                 PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                            [PaddingInlineStart, SetPaddingInlineStart,
                             PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                                [_moz_padding_start, Set_moz_padding_start,
                                 PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                            [MozPaddingStart, SetMozPaddingStart,
                             PropertyId::Longhand(LonghandId::PaddingInlineStart)],
                                [Padding_left, SetPadding_left,
                                 PropertyId::Longhand(LonghandId::PaddingLeft)],
                            [PaddingLeft, SetPaddingLeft,
                             PropertyId::Longhand(LonghandId::PaddingLeft)],
                                [Padding_right, SetPadding_right,
                                 PropertyId::Longhand(LonghandId::PaddingRight)],
                            [PaddingRight, SetPaddingRight,
                             PropertyId::Longhand(LonghandId::PaddingRight)],
                                [Padding_top, SetPadding_top,
                                 PropertyId::Longhand(LonghandId::PaddingTop)],
                            [PaddingTop, SetPaddingTop,
                             PropertyId::Longhand(LonghandId::PaddingTop)],
                            [R, SetR,
                             PropertyId::Longhand(LonghandId::R)],
                                [Shape_margin, SetShape_margin,
                                 PropertyId::Longhand(LonghandId::ShapeMargin)],
                            [ShapeMargin, SetShapeMargin,
                             PropertyId::Longhand(LonghandId::ShapeMargin)],
                            [Rx, SetRx,
                             PropertyId::Longhand(LonghandId::Rx)],
                            [Ry, SetRy,
                             PropertyId::Longhand(LonghandId::Ry)],
                                [Scroll_padding_block_end, SetScroll_padding_block_end,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingBlockEnd)],
                            [ScrollPaddingBlockEnd, SetScrollPaddingBlockEnd,
                             PropertyId::Longhand(LonghandId::ScrollPaddingBlockEnd)],
                                [Scroll_padding_block_start, SetScroll_padding_block_start,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingBlockStart)],
                            [ScrollPaddingBlockStart, SetScrollPaddingBlockStart,
                             PropertyId::Longhand(LonghandId::ScrollPaddingBlockStart)],
                                [Scroll_padding_bottom, SetScroll_padding_bottom,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingBottom)],
                            [ScrollPaddingBottom, SetScrollPaddingBottom,
                             PropertyId::Longhand(LonghandId::ScrollPaddingBottom)],
                                [Scroll_padding_inline_end, SetScroll_padding_inline_end,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingInlineEnd)],
                            [ScrollPaddingInlineEnd, SetScrollPaddingInlineEnd,
                             PropertyId::Longhand(LonghandId::ScrollPaddingInlineEnd)],
                                [Scroll_padding_inline_start, SetScroll_padding_inline_start,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingInlineStart)],
                            [ScrollPaddingInlineStart, SetScrollPaddingInlineStart,
                             PropertyId::Longhand(LonghandId::ScrollPaddingInlineStart)],
                                [Scroll_padding_left, SetScroll_padding_left,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingLeft)],
                            [ScrollPaddingLeft, SetScrollPaddingLeft,
                             PropertyId::Longhand(LonghandId::ScrollPaddingLeft)],
                                [Scroll_padding_right, SetScroll_padding_right,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingRight)],
                            [ScrollPaddingRight, SetScrollPaddingRight,
                             PropertyId::Longhand(LonghandId::ScrollPaddingRight)],
                                [Scroll_padding_top, SetScroll_padding_top,
                                 PropertyId::Longhand(LonghandId::ScrollPaddingTop)],
                            [ScrollPaddingTop, SetScrollPaddingTop,
                             PropertyId::Longhand(LonghandId::ScrollPaddingTop)],
                                [Outline_offset, SetOutline_offset,
                                 PropertyId::Longhand(LonghandId::OutlineOffset)],
                            [OutlineOffset, SetOutlineOffset,
                             PropertyId::Longhand(LonghandId::OutlineOffset)],
                                [Overflow_clip_margin, SetOverflow_clip_margin,
                                 PropertyId::Longhand(LonghandId::OverflowClipMargin)],
                            [OverflowClipMargin, SetOverflowClipMargin,
                             PropertyId::Longhand(LonghandId::OverflowClipMargin)],
                                [Scroll_margin_block_end, SetScroll_margin_block_end,
                                 PropertyId::Longhand(LonghandId::ScrollMarginBlockEnd)],
                            [ScrollMarginBlockEnd, SetScrollMarginBlockEnd,
                             PropertyId::Longhand(LonghandId::ScrollMarginBlockEnd)],
                                [Scroll_margin_block_start, SetScroll_margin_block_start,
                                 PropertyId::Longhand(LonghandId::ScrollMarginBlockStart)],
                            [ScrollMarginBlockStart, SetScrollMarginBlockStart,
                             PropertyId::Longhand(LonghandId::ScrollMarginBlockStart)],
                                [Scroll_margin_bottom, SetScroll_margin_bottom,
                                 PropertyId::Longhand(LonghandId::ScrollMarginBottom)],
                            [ScrollMarginBottom, SetScrollMarginBottom,
                             PropertyId::Longhand(LonghandId::ScrollMarginBottom)],
                                [Scroll_margin_inline_end, SetScroll_margin_inline_end,
                                 PropertyId::Longhand(LonghandId::ScrollMarginInlineEnd)],
                            [ScrollMarginInlineEnd, SetScrollMarginInlineEnd,
                             PropertyId::Longhand(LonghandId::ScrollMarginInlineEnd)],
                                [Scroll_margin_inline_start, SetScroll_margin_inline_start,
                                 PropertyId::Longhand(LonghandId::ScrollMarginInlineStart)],
                            [ScrollMarginInlineStart, SetScrollMarginInlineStart,
                             PropertyId::Longhand(LonghandId::ScrollMarginInlineStart)],
                                [Scroll_margin_left, SetScroll_margin_left,
                                 PropertyId::Longhand(LonghandId::ScrollMarginLeft)],
                            [ScrollMarginLeft, SetScrollMarginLeft,
                             PropertyId::Longhand(LonghandId::ScrollMarginLeft)],
                                [Scroll_margin_right, SetScroll_margin_right,
                                 PropertyId::Longhand(LonghandId::ScrollMarginRight)],
                            [ScrollMarginRight, SetScrollMarginRight,
                             PropertyId::Longhand(LonghandId::ScrollMarginRight)],
                                [Scroll_margin_top, SetScroll_margin_top,
                                 PropertyId::Longhand(LonghandId::ScrollMarginTop)],
                            [ScrollMarginTop, SetScrollMarginTop,
                             PropertyId::Longhand(LonghandId::ScrollMarginTop)],
                            [Bottom, SetBottom,
                             PropertyId::Longhand(LonghandId::Bottom)],
                                [Inset_block_end, SetInset_block_end,
                                 PropertyId::Longhand(LonghandId::InsetBlockEnd)],
                            [InsetBlockEnd, SetInsetBlockEnd,
                             PropertyId::Longhand(LonghandId::InsetBlockEnd)],
                                [Inset_block_start, SetInset_block_start,
                                 PropertyId::Longhand(LonghandId::InsetBlockStart)],
                            [InsetBlockStart, SetInsetBlockStart,
                             PropertyId::Longhand(LonghandId::InsetBlockStart)],
                                [Inset_inline_end, SetInset_inline_end,
                                 PropertyId::Longhand(LonghandId::InsetInlineEnd)],
                            [InsetInlineEnd, SetInsetInlineEnd,
                             PropertyId::Longhand(LonghandId::InsetInlineEnd)],
                                [Inset_inline_start, SetInset_inline_start,
                                 PropertyId::Longhand(LonghandId::InsetInlineStart)],
                            [InsetInlineStart, SetInsetInlineStart,
                             PropertyId::Longhand(LonghandId::InsetInlineStart)],
                            [Left, SetLeft,
                             PropertyId::Longhand(LonghandId::Left)],
                                [Margin_block_end, SetMargin_block_end,
                                 PropertyId::Longhand(LonghandId::MarginBlockEnd)],
                            [MarginBlockEnd, SetMarginBlockEnd,
                             PropertyId::Longhand(LonghandId::MarginBlockEnd)],
                                [Margin_block_start, SetMargin_block_start,
                                 PropertyId::Longhand(LonghandId::MarginBlockStart)],
                            [MarginBlockStart, SetMarginBlockStart,
                             PropertyId::Longhand(LonghandId::MarginBlockStart)],
                                [Margin_bottom, SetMargin_bottom,
                                 PropertyId::Longhand(LonghandId::MarginBottom)],
                            [MarginBottom, SetMarginBottom,
                             PropertyId::Longhand(LonghandId::MarginBottom)],
                                [Margin_inline_end, SetMargin_inline_end,
                                 PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                            [MarginInlineEnd, SetMarginInlineEnd,
                             PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                                [_moz_margin_end, Set_moz_margin_end,
                                 PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                            [MozMarginEnd, SetMozMarginEnd,
                             PropertyId::Longhand(LonghandId::MarginInlineEnd)],
                                [Margin_inline_start, SetMargin_inline_start,
                                 PropertyId::Longhand(LonghandId::MarginInlineStart)],
                            [MarginInlineStart, SetMarginInlineStart,
                             PropertyId::Longhand(LonghandId::MarginInlineStart)],
                                [_moz_margin_start, Set_moz_margin_start,
                                 PropertyId::Longhand(LonghandId::MarginInlineStart)],
                            [MozMarginStart, SetMozMarginStart,
                             PropertyId::Longhand(LonghandId::MarginInlineStart)],
                                [Margin_left, SetMargin_left,
                                 PropertyId::Longhand(LonghandId::MarginLeft)],
                            [MarginLeft, SetMarginLeft,
                             PropertyId::Longhand(LonghandId::MarginLeft)],
                                [Margin_right, SetMargin_right,
                                 PropertyId::Longhand(LonghandId::MarginRight)],
                            [MarginRight, SetMarginRight,
                             PropertyId::Longhand(LonghandId::MarginRight)],
                                [Margin_top, SetMargin_top,
                                 PropertyId::Longhand(LonghandId::MarginTop)],
                            [MarginTop, SetMarginTop,
                             PropertyId::Longhand(LonghandId::MarginTop)],
                            [Right, SetRight,
                             PropertyId::Longhand(LonghandId::Right)],
                                [Text_underline_offset, SetText_underline_offset,
                                 PropertyId::Longhand(LonghandId::TextUnderlineOffset)],
                            [TextUnderlineOffset, SetTextUnderlineOffset,
                             PropertyId::Longhand(LonghandId::TextUnderlineOffset)],
                            [Top, SetTop,
                             PropertyId::Longhand(LonghandId::Top)],
                                [Background_color, SetBackground_color,
                                 PropertyId::Longhand(LonghandId::BackgroundColor)],
                            [BackgroundColor, SetBackgroundColor,
                             PropertyId::Longhand(LonghandId::BackgroundColor)],
                                [Border_block_end_color, SetBorder_block_end_color,
                                 PropertyId::Longhand(LonghandId::BorderBlockEndColor)],
                            [BorderBlockEndColor, SetBorderBlockEndColor,
                             PropertyId::Longhand(LonghandId::BorderBlockEndColor)],
                                [Border_block_start_color, SetBorder_block_start_color,
                                 PropertyId::Longhand(LonghandId::BorderBlockStartColor)],
                            [BorderBlockStartColor, SetBorderBlockStartColor,
                             PropertyId::Longhand(LonghandId::BorderBlockStartColor)],
                                [Border_bottom_color, SetBorder_bottom_color,
                                 PropertyId::Longhand(LonghandId::BorderBottomColor)],
                            [BorderBottomColor, SetBorderBottomColor,
                             PropertyId::Longhand(LonghandId::BorderBottomColor)],
                                [Border_inline_end_color, SetBorder_inline_end_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                            [BorderInlineEndColor, SetBorderInlineEndColor,
                             PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                                [_moz_border_end_color, Set_moz_border_end_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                            [MozBorderEndColor, SetMozBorderEndColor,
                             PropertyId::Longhand(LonghandId::BorderInlineEndColor)],
                                [Border_inline_start_color, SetBorder_inline_start_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                            [BorderInlineStartColor, SetBorderInlineStartColor,
                             PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                                [_moz_border_start_color, Set_moz_border_start_color,
                                 PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                            [MozBorderStartColor, SetMozBorderStartColor,
                             PropertyId::Longhand(LonghandId::BorderInlineStartColor)],
                                [Border_left_color, SetBorder_left_color,
                                 PropertyId::Longhand(LonghandId::BorderLeftColor)],
                            [BorderLeftColor, SetBorderLeftColor,
                             PropertyId::Longhand(LonghandId::BorderLeftColor)],
                                [Border_right_color, SetBorder_right_color,
                                 PropertyId::Longhand(LonghandId::BorderRightColor)],
                            [BorderRightColor, SetBorderRightColor,
                             PropertyId::Longhand(LonghandId::BorderRightColor)],
                                [Border_top_color, SetBorder_top_color,
                                 PropertyId::Longhand(LonghandId::BorderTopColor)],
                            [BorderTopColor, SetBorderTopColor,
                             PropertyId::Longhand(LonghandId::BorderTopColor)],
                                [Column_rule_color, SetColumn_rule_color,
                                 PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                            [ColumnRuleColor, SetColumnRuleColor,
                             PropertyId::Longhand(LonghandId::ColumnRuleColor)],
                                [Flood_color, SetFlood_color,
                                 PropertyId::Longhand(LonghandId::FloodColor)],
                            [FloodColor, SetFloodColor,
                             PropertyId::Longhand(LonghandId::FloodColor)],
                                [Lighting_color, SetLighting_color,
                                 PropertyId::Longhand(LonghandId::LightingColor)],
                            [LightingColor, SetLightingColor,
                             PropertyId::Longhand(LonghandId::LightingColor)],
                                [Outline_color, SetOutline_color,
                                 PropertyId::Longhand(LonghandId::OutlineColor)],
                            [OutlineColor, SetOutlineColor,
                             PropertyId::Longhand(LonghandId::OutlineColor)],
                                [Stop_color, SetStop_color,
                                 PropertyId::Longhand(LonghandId::StopColor)],
                            [StopColor, SetStopColor,
                             PropertyId::Longhand(LonghandId::StopColor)],
                                [Text_decoration_color, SetText_decoration_color,
                                 PropertyId::Longhand(LonghandId::TextDecorationColor)],
                            [TextDecorationColor, SetTextDecorationColor,
                             PropertyId::Longhand(LonghandId::TextDecorationColor)],
                                [Text_emphasis_color, SetText_emphasis_color,
                                 PropertyId::Longhand(LonghandId::TextEmphasisColor)],
                            [TextEmphasisColor, SetTextEmphasisColor,
                             PropertyId::Longhand(LonghandId::TextEmphasisColor)],
                                [_webkit_text_fill_color, Set_webkit_text_fill_color,
                                 PropertyId::Longhand(LonghandId::WebkitTextFillColor)],
                            [WebkitTextFillColor, SetWebkitTextFillColor,
                             PropertyId::Longhand(LonghandId::WebkitTextFillColor)],
                                [_webkit_text_stroke_color, Set_webkit_text_stroke_color,
                                 PropertyId::Longhand(LonghandId::WebkitTextStrokeColor)],
                            [WebkitTextStrokeColor, SetWebkitTextStrokeColor,
                             PropertyId::Longhand(LonghandId::WebkitTextStrokeColor)],
                            [Background, SetBackground,
                             PropertyId::Shorthand(ShorthandId::Background)],
                                [Background_position, SetBackground_position,
                                 PropertyId::Shorthand(ShorthandId::BackgroundPosition)],
                            [BackgroundPosition, SetBackgroundPosition,
                             PropertyId::Shorthand(ShorthandId::BackgroundPosition)],
                                [Border_color, SetBorder_color,
                                 PropertyId::Shorthand(ShorthandId::BorderColor)],
                            [BorderColor, SetBorderColor,
                             PropertyId::Shorthand(ShorthandId::BorderColor)],
                                [Border_style, SetBorder_style,
                                 PropertyId::Shorthand(ShorthandId::BorderStyle)],
                            [BorderStyle, SetBorderStyle,
                             PropertyId::Shorthand(ShorthandId::BorderStyle)],
                                [Border_width, SetBorder_width,
                                 PropertyId::Shorthand(ShorthandId::BorderWidth)],
                            [BorderWidth, SetBorderWidth,
                             PropertyId::Shorthand(ShorthandId::BorderWidth)],
                                [Border_top, SetBorder_top,
                                 PropertyId::Shorthand(ShorthandId::BorderTop)],
                            [BorderTop, SetBorderTop,
                             PropertyId::Shorthand(ShorthandId::BorderTop)],
                                [Border_right, SetBorder_right,
                                 PropertyId::Shorthand(ShorthandId::BorderRight)],
                            [BorderRight, SetBorderRight,
                             PropertyId::Shorthand(ShorthandId::BorderRight)],
                                [Border_bottom, SetBorder_bottom,
                                 PropertyId::Shorthand(ShorthandId::BorderBottom)],
                            [BorderBottom, SetBorderBottom,
                             PropertyId::Shorthand(ShorthandId::BorderBottom)],
                                [Border_left, SetBorder_left,
                                 PropertyId::Shorthand(ShorthandId::BorderLeft)],
                            [BorderLeft, SetBorderLeft,
                             PropertyId::Shorthand(ShorthandId::BorderLeft)],
                                [Border_block_start, SetBorder_block_start,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockStart)],
                            [BorderBlockStart, SetBorderBlockStart,
                             PropertyId::Shorthand(ShorthandId::BorderBlockStart)],
                                [Border_block_end, SetBorder_block_end,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockEnd)],
                            [BorderBlockEnd, SetBorderBlockEnd,
                             PropertyId::Shorthand(ShorthandId::BorderBlockEnd)],
                                [Border_inline_start, SetBorder_inline_start,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                            [BorderInlineStart, SetBorderInlineStart,
                             PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                                [_moz_border_start, Set_moz_border_start,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                            [MozBorderStart, SetMozBorderStart,
                             PropertyId::Shorthand(ShorthandId::BorderInlineStart)],
                                [Border_inline_end, SetBorder_inline_end,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [BorderInlineEnd, SetBorderInlineEnd,
                             PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                                [_moz_border_end, Set_moz_border_end,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [MozBorderEnd, SetMozBorderEnd,
                             PropertyId::Shorthand(ShorthandId::BorderInlineEnd)],
                            [Border, SetBorder,
                             PropertyId::Shorthand(ShorthandId::Border)],
                                [Border_radius, SetBorder_radius,
                                 PropertyId::Shorthand(ShorthandId::BorderRadius)],
                            [BorderRadius, SetBorderRadius,
                             PropertyId::Shorthand(ShorthandId::BorderRadius)],
                                [_webkit_border_radius, Set_webkit_border_radius,
                                 PropertyId::Shorthand(ShorthandId::BorderRadius)],
                            [WebkitBorderRadius, SetWebkitBorderRadius,
                             PropertyId::Shorthand(ShorthandId::BorderRadius)],
                                [Border_image, SetBorder_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [BorderImage, SetBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                                [_moz_border_image, Set_moz_border_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [MozBorderImage, SetMozBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                                [_webkit_border_image, Set_webkit_border_image,
                                 PropertyId::Shorthand(ShorthandId::BorderImage)],
                            [WebkitBorderImage, SetWebkitBorderImage,
                             PropertyId::Shorthand(ShorthandId::BorderImage)],
                                [Border_block_width, SetBorder_block_width,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockWidth)],
                            [BorderBlockWidth, SetBorderBlockWidth,
                             PropertyId::Shorthand(ShorthandId::BorderBlockWidth)],
                                [Border_block_style, SetBorder_block_style,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockStyle)],
                            [BorderBlockStyle, SetBorderBlockStyle,
                             PropertyId::Shorthand(ShorthandId::BorderBlockStyle)],
                                [Border_block_color, SetBorder_block_color,
                                 PropertyId::Shorthand(ShorthandId::BorderBlockColor)],
                            [BorderBlockColor, SetBorderBlockColor,
                             PropertyId::Shorthand(ShorthandId::BorderBlockColor)],
                                [Border_inline_width, SetBorder_inline_width,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineWidth)],
                            [BorderInlineWidth, SetBorderInlineWidth,
                             PropertyId::Shorthand(ShorthandId::BorderInlineWidth)],
                                [Border_inline_style, SetBorder_inline_style,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineStyle)],
                            [BorderInlineStyle, SetBorderInlineStyle,
                             PropertyId::Shorthand(ShorthandId::BorderInlineStyle)],
                                [Border_inline_color, SetBorder_inline_color,
                                 PropertyId::Shorthand(ShorthandId::BorderInlineColor)],
                            [BorderInlineColor, SetBorderInlineColor,
                             PropertyId::Shorthand(ShorthandId::BorderInlineColor)],
                                [Border_block, SetBorder_block,
                                 PropertyId::Shorthand(ShorthandId::BorderBlock)],
                            [BorderBlock, SetBorderBlock,
                             PropertyId::Shorthand(ShorthandId::BorderBlock)],
                                [Border_inline, SetBorder_inline,
                                 PropertyId::Shorthand(ShorthandId::BorderInline)],
                            [BorderInline, SetBorderInline,
                             PropertyId::Shorthand(ShorthandId::BorderInline)],
                            [Overflow, SetOverflow,
                             PropertyId::Shorthand(ShorthandId::Overflow)],
                                [Overscroll_behavior, SetOverscroll_behavior,
                                 PropertyId::Shorthand(ShorthandId::OverscrollBehavior)],
                            [OverscrollBehavior, SetOverscrollBehavior,
                             PropertyId::Shorthand(ShorthandId::OverscrollBehavior)],
                            [Container, SetContainer,
                             PropertyId::Shorthand(ShorthandId::Container)],
                                [Page_break_before, SetPage_break_before,
                                 PropertyId::Shorthand(ShorthandId::PageBreakBefore)],
                            [PageBreakBefore, SetPageBreakBefore,
                             PropertyId::Shorthand(ShorthandId::PageBreakBefore)],
                                [Page_break_after, SetPage_break_after,
                                 PropertyId::Shorthand(ShorthandId::PageBreakAfter)],
                            [PageBreakAfter, SetPageBreakAfter,
                             PropertyId::Shorthand(ShorthandId::PageBreakAfter)],
                                [Page_break_inside, SetPage_break_inside,
                                 PropertyId::Shorthand(ShorthandId::PageBreakInside)],
                            [PageBreakInside, SetPageBreakInside,
                             PropertyId::Shorthand(ShorthandId::PageBreakInside)],
                            [Offset, SetOffset,
                             PropertyId::Shorthand(ShorthandId::Offset)],
                            [Columns, SetColumns,
                             PropertyId::Shorthand(ShorthandId::Columns)],
                                [Column_rule, SetColumn_rule,
                                 PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [ColumnRule, SetColumnRule,
                             PropertyId::Shorthand(ShorthandId::ColumnRule)],
                            [Font, SetFont,
                             PropertyId::Shorthand(ShorthandId::Font)],
                                [Font_variant, SetFont_variant,
                                 PropertyId::Shorthand(ShorthandId::FontVariant)],
                            [FontVariant, SetFontVariant,
                             PropertyId::Shorthand(ShorthandId::FontVariant)],
                                [Font_synthesis, SetFont_synthesis,
                                 PropertyId::Shorthand(ShorthandId::FontSynthesis)],
                            [FontSynthesis, SetFontSynthesis,
                             PropertyId::Shorthand(ShorthandId::FontSynthesis)],
                            [Marker, SetMarker,
                             PropertyId::Shorthand(ShorthandId::Marker)],
                                [Text_emphasis, SetText_emphasis,
                                 PropertyId::Shorthand(ShorthandId::TextEmphasis)],
                            [TextEmphasis, SetTextEmphasis,
                             PropertyId::Shorthand(ShorthandId::TextEmphasis)],
                                [Text_wrap, SetText_wrap,
                                 PropertyId::Shorthand(ShorthandId::TextWrap)],
                            [TextWrap, SetTextWrap,
                             PropertyId::Shorthand(ShorthandId::TextWrap)],
                                [White_space, SetWhite_space,
                                 PropertyId::Shorthand(ShorthandId::WhiteSpace)],
                            [WhiteSpace, SetWhiteSpace,
                             PropertyId::Shorthand(ShorthandId::WhiteSpace)],
                                [_webkit_text_stroke, Set_webkit_text_stroke,
                                 PropertyId::Shorthand(ShorthandId::WebkitTextStroke)],
                            [WebkitTextStroke, SetWebkitTextStroke,
                             PropertyId::Shorthand(ShorthandId::WebkitTextStroke)],
                                [List_style, SetList_style,
                                 PropertyId::Shorthand(ShorthandId::ListStyle)],
                            [ListStyle, SetListStyle,
                             PropertyId::Shorthand(ShorthandId::ListStyle)],
                            [Margin, SetMargin,
                             PropertyId::Shorthand(ShorthandId::Margin)],
                                [Margin_block, SetMargin_block,
                                 PropertyId::Shorthand(ShorthandId::MarginBlock)],
                            [MarginBlock, SetMarginBlock,
                             PropertyId::Shorthand(ShorthandId::MarginBlock)],
                                [Margin_inline, SetMargin_inline,
                                 PropertyId::Shorthand(ShorthandId::MarginInline)],
                            [MarginInline, SetMarginInline,
                             PropertyId::Shorthand(ShorthandId::MarginInline)],
                                [Scroll_margin, SetScroll_margin,
                                 PropertyId::Shorthand(ShorthandId::ScrollMargin)],
                            [ScrollMargin, SetScrollMargin,
                             PropertyId::Shorthand(ShorthandId::ScrollMargin)],
                                [Scroll_margin_block, SetScroll_margin_block,
                                 PropertyId::Shorthand(ShorthandId::ScrollMarginBlock)],
                            [ScrollMarginBlock, SetScrollMarginBlock,
                             PropertyId::Shorthand(ShorthandId::ScrollMarginBlock)],
                                [Scroll_margin_inline, SetScroll_margin_inline,
                                 PropertyId::Shorthand(ShorthandId::ScrollMarginInline)],
                            [ScrollMarginInline, SetScrollMarginInline,
                             PropertyId::Shorthand(ShorthandId::ScrollMarginInline)],
                            [Outline, SetOutline,
                             PropertyId::Shorthand(ShorthandId::Outline)],
                            [Padding, SetPadding,
                             PropertyId::Shorthand(ShorthandId::Padding)],
                                [Padding_block, SetPadding_block,
                                 PropertyId::Shorthand(ShorthandId::PaddingBlock)],
                            [PaddingBlock, SetPaddingBlock,
                             PropertyId::Shorthand(ShorthandId::PaddingBlock)],
                                [Padding_inline, SetPadding_inline,
                                 PropertyId::Shorthand(ShorthandId::PaddingInline)],
                            [PaddingInline, SetPaddingInline,
                             PropertyId::Shorthand(ShorthandId::PaddingInline)],
                                [Scroll_padding, SetScroll_padding,
                                 PropertyId::Shorthand(ShorthandId::ScrollPadding)],
                            [ScrollPadding, SetScrollPadding,
                             PropertyId::Shorthand(ShorthandId::ScrollPadding)],
                                [Scroll_padding_block, SetScroll_padding_block,
                                 PropertyId::Shorthand(ShorthandId::ScrollPaddingBlock)],
                            [ScrollPaddingBlock, SetScrollPaddingBlock,
                             PropertyId::Shorthand(ShorthandId::ScrollPaddingBlock)],
                                [Scroll_padding_inline, SetScroll_padding_inline,
                                 PropertyId::Shorthand(ShorthandId::ScrollPaddingInline)],
                            [ScrollPaddingInline, SetScrollPaddingInline,
                             PropertyId::Shorthand(ShorthandId::ScrollPaddingInline)],
                                [Flex_flow, SetFlex_flow,
                                 PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [FlexFlow, SetFlexFlow,
                             PropertyId::Shorthand(ShorthandId::FlexFlow)],
                                [_webkit_flex_flow, Set_webkit_flex_flow,
                                 PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [WebkitFlexFlow, SetWebkitFlexFlow,
                             PropertyId::Shorthand(ShorthandId::FlexFlow)],
                            [Flex, SetFlex,
                             PropertyId::Shorthand(ShorthandId::Flex)],
                                [_webkit_flex, Set_webkit_flex,
                                 PropertyId::Shorthand(ShorthandId::Flex)],
                            [WebkitFlex, SetWebkitFlex,
                             PropertyId::Shorthand(ShorthandId::Flex)],
                            [Gap, SetGap,
                             PropertyId::Shorthand(ShorthandId::Gap)],
                                [Grid_gap, SetGrid_gap,
                                 PropertyId::Shorthand(ShorthandId::Gap)],
                            [GridGap, SetGridGap,
                             PropertyId::Shorthand(ShorthandId::Gap)],
                                [Grid_row, SetGrid_row,
                                 PropertyId::Shorthand(ShorthandId::GridRow)],
                            [GridRow, SetGridRow,
                             PropertyId::Shorthand(ShorthandId::GridRow)],
                                [Grid_column, SetGrid_column,
                                 PropertyId::Shorthand(ShorthandId::GridColumn)],
                            [GridColumn, SetGridColumn,
                             PropertyId::Shorthand(ShorthandId::GridColumn)],
                                [Grid_area, SetGrid_area,
                                 PropertyId::Shorthand(ShorthandId::GridArea)],
                            [GridArea, SetGridArea,
                             PropertyId::Shorthand(ShorthandId::GridArea)],
                                [Grid_template, SetGrid_template,
                                 PropertyId::Shorthand(ShorthandId::GridTemplate)],
                            [GridTemplate, SetGridTemplate,
                             PropertyId::Shorthand(ShorthandId::GridTemplate)],
                            [Grid, SetGrid,
                             PropertyId::Shorthand(ShorthandId::Grid)],
                                [Place_content, SetPlace_content,
                                 PropertyId::Shorthand(ShorthandId::PlaceContent)],
                            [PlaceContent, SetPlaceContent,
                             PropertyId::Shorthand(ShorthandId::PlaceContent)],
                                [Place_self, SetPlace_self,
                                 PropertyId::Shorthand(ShorthandId::PlaceSelf)],
                            [PlaceSelf, SetPlaceSelf,
                             PropertyId::Shorthand(ShorthandId::PlaceSelf)],
                                [Place_items, SetPlace_items,
                                 PropertyId::Shorthand(ShorthandId::PlaceItems)],
                            [PlaceItems, SetPlaceItems,
                             PropertyId::Shorthand(ShorthandId::PlaceItems)],
                            [Inset, SetInset,
                             PropertyId::Shorthand(ShorthandId::Inset)],
                                [Inset_block, SetInset_block,
                                 PropertyId::Shorthand(ShorthandId::InsetBlock)],
                            [InsetBlock, SetInsetBlock,
                             PropertyId::Shorthand(ShorthandId::InsetBlock)],
                                [Inset_inline, SetInset_inline,
                                 PropertyId::Shorthand(ShorthandId::InsetInline)],
                            [InsetInline, SetInsetInline,
                             PropertyId::Shorthand(ShorthandId::InsetInline)],
                                [Contain_intrinsic_size, SetContain_intrinsic_size,
                                 PropertyId::Shorthand(ShorthandId::ContainIntrinsicSize)],
                            [ContainIntrinsicSize, SetContainIntrinsicSize,
                             PropertyId::Shorthand(ShorthandId::ContainIntrinsicSize)],
                            [Mask, SetMask,
                             PropertyId::Shorthand(ShorthandId::Mask)],
                                [_webkit_mask, Set_webkit_mask,
                                 PropertyId::Shorthand(ShorthandId::Mask)],
                            [WebkitMask, SetWebkitMask,
                             PropertyId::Shorthand(ShorthandId::Mask)],
                                [Mask_position, SetMask_position,
                                 PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [MaskPosition, SetMaskPosition,
                             PropertyId::Shorthand(ShorthandId::MaskPosition)],
                                [_webkit_mask_position, Set_webkit_mask_position,
                                 PropertyId::Shorthand(ShorthandId::MaskPosition)],
                            [WebkitMaskPosition, SetWebkitMaskPosition,
                             PropertyId::Shorthand(ShorthandId::MaskPosition)],
                                [Text_decoration, SetText_decoration,
                                 PropertyId::Shorthand(ShorthandId::TextDecoration)],
                            [TextDecoration, SetTextDecoration,
                             PropertyId::Shorthand(ShorthandId::TextDecoration)],
                            [Transition, SetTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                                [_moz_transition, Set_moz_transition,
                                 PropertyId::Shorthand(ShorthandId::Transition)],
                            [MozTransition, SetMozTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                                [_webkit_transition, Set_webkit_transition,
                                 PropertyId::Shorthand(ShorthandId::Transition)],
                            [WebkitTransition, SetWebkitTransition,
                             PropertyId::Shorthand(ShorthandId::Transition)],
                            [Animation, SetAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [_moz_animation, Set_moz_animation,
                                 PropertyId::Shorthand(ShorthandId::Animation)],
                            [MozAnimation, SetMozAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [_webkit_animation, Set_webkit_animation,
                                 PropertyId::Shorthand(ShorthandId::Animation)],
                            [WebkitAnimation, SetWebkitAnimation,
                             PropertyId::Shorthand(ShorthandId::Animation)],
                                [Scroll_timeline, SetScroll_timeline,
                                 PropertyId::Shorthand(ShorthandId::ScrollTimeline)],
                            [ScrollTimeline, SetScrollTimeline,
                             PropertyId::Shorthand(ShorthandId::ScrollTimeline)],
                                [View_timeline, SetView_timeline,
                                 PropertyId::Shorthand(ShorthandId::ViewTimeline)],
                            [ViewTimeline, SetViewTimeline,
                             PropertyId::Shorthand(ShorthandId::ViewTimeline)],
                            [All, SetAll,
                             PropertyId::Shorthand(ShorthandId::All)],
        }
    }
}

/// Call the given macro with tokens like this for each longhand properties:
///
/// ```
/// { snake_case_ident }
/// ```
#[macro_export]
macro_rules! longhand_properties_idents {
    ($macro_name: ident) => {
        $macro_name! {
                { align_content }
                { align_items }
                { align_self }
                { aspect_ratio }
                { backface_visibility }
                { baseline_source }
                { border_collapse }
                { border_image_repeat }
                { box_decoration_break }
                { box_sizing }
                { break_inside }
                { caption_side }
                { clear }
                { color_interpolation }
                { color_interpolation_filters }
                { column_count }
                { column_fill }
                { column_span }
                { contain }
                { container_type }
                { content_visibility }
                { direction }
                { display }
                { dominant_baseline }
                { empty_cells }
                { flex_direction }
                { flex_wrap }
                { float }
                { font_kerning }
                { font_language_override }
                { font_optical_sizing }
                { font_size_adjust }
                { font_stretch }
                { font_style }
                { font_variant_caps }
                { font_variant_east_asian }
                { font_variant_emoji }
                { font_variant_ligatures }
                { font_variant_numeric }
                { font_variant_position }
                { font_weight }
                { forced_color_adjust }
                { grid_auto_flow }
                { hyphens }
                { image_orientation }
                { image_rendering }
                { ime_mode }
                { initial_letter }
                { inset_area }
                { isolation }
                { justify_content }
                { justify_items }
                { justify_self }
                { line_break }
                { list_style_position }
                { mask_type }
                { masonry_auto_flow }
                { math_depth }
                { math_style }
                { mix_blend_mode }
                { _moz_box_align }
                { _moz_box_collapse }
                { _moz_box_direction }
                { _moz_box_orient }
                { _moz_box_pack }
                { _moz_control_character_visibility }
                { _moz_float_edge }
                { _moz_inert }
                { _moz_math_variant }
                { _moz_min_font_size_ratio }
                { _moz_orient }
                { _moz_osx_font_smoothing }
                { _moz_text_size_adjust }
                { _moz_theme }
                { _moz_top_layer }
                { _moz_user_focus }
                { _moz_user_input }
                { _moz_user_modify }
                { _moz_window_dragging }
                { _moz_window_shadow }
                { object_fit }
                { offset_rotate }
                { outline_style }
                { overflow_anchor }
                { overflow_wrap }
                { page_orientation }
                { paint_order }
                { pointer_events }
                { position }
                { position_try_order }
                { position_visibility }
                { print_color_adjust }
                { resize }
                { ruby_align }
                { ruby_position }
                { scroll_behavior }
                { scroll_snap_align }
                { scroll_snap_stop }
                { scroll_snap_type }
                { scrollbar_gutter }
                { scrollbar_width }
                { shape_rendering }
                { stroke_linecap }
                { stroke_linejoin }
                { table_layout }
                { text_align }
                { text_align_last }
                { text_anchor }
                { text_combine_upright }
                { text_decoration_line }
                { text_decoration_skip_ink }
                { text_decoration_style }
                { text_emphasis_position }
                { text_justify }
                { text_orientation }
                { text_rendering }
                { text_transform }
                { text_underline_position }
                { text_wrap_mode }
                { text_wrap_style }
                { touch_action }
                { transform_box }
                { transform_style }
                { unicode_bidi }
                { user_select }
                { vector_effect }
                { visibility }
                { _webkit_line_clamp }
                { _webkit_text_security }
                { white_space_collapse }
                { word_break }
                { writing_mode }
                { _x_text_scale }
                { z_index }
                { zoom }
                { appearance }
                { _moz_default_appearance }
                { _moz_force_broken_image_icon }
                { _moz_subtree_hidden_only_visually }
                { break_after }
                { break_before }
                { clip_rule }
                { fill_rule }
                { overflow_clip_box_block }
                { overflow_clip_box_inline }
                { fill_opacity }
                { stroke_opacity }
                { _moz_box_ordinal_group }
                { order }
                { _x_span }
                { font_synthesis_position }
                { font_synthesis_small_caps }
                { font_synthesis_style }
                { font_synthesis_weight }
                { flex_grow }
                { flex_shrink }
                { _moz_box_flex }
                { stroke_miterlimit }
                { overflow_block }
                { overflow_inline }
                { overflow_x }
                { overflow_y }
                { overscroll_behavior_block }
                { overscroll_behavior_inline }
                { overscroll_behavior_x }
                { overscroll_behavior_y }
                { flood_opacity }
                { _moz_window_opacity }
                { opacity }
                { shape_image_threshold }
                { stop_opacity }
                { border_block_end_style }
                { border_block_start_style }
                { border_bottom_style }
                { border_inline_end_style }
                { border_inline_start_style }
                { border_left_style }
                { border_right_style }
                { border_top_style }
                { column_rule_style }
                { accent_color }
                { anchor_name }
                { anchor_scope }
                { animation_composition }
                { animation_delay }
                { animation_direction }
                { animation_duration }
                { animation_fill_mode }
                { animation_iteration_count }
                { animation_name }
                { animation_play_state }
                { animation_timeline }
                { animation_timing_function }
                { backdrop_filter }
                { background_attachment }
                { background_blend_mode }
                { background_clip }
                { background_image }
                { background_origin }
                { background_position_x }
                { background_position_y }
                { background_repeat }
                { background_size }
                { border_image_outset }
                { border_image_slice }
                { border_image_width }
                { border_spacing }
                { box_shadow }
                { caret_color }
                { clip }
                { clip_path }
                { color }
                { color_scheme }
                { column_width }
                { container_name }
                { content }
                { counter_increment }
                { counter_reset }
                { counter_set }
                { cursor }
                { d }
                { filter }
                { flex_basis }
                { font_family }
                { font_feature_settings }
                { font_palette }
                { font_size }
                { font_variant_alternates }
                { font_variation_settings }
                { grid_template_areas }
                { hyphenate_character }
                { letter_spacing }
                { line_height }
                { list_style_type }
                { mask_clip }
                { mask_composite }
                { mask_image }
                { mask_mode }
                { mask_origin }
                { mask_position_x }
                { mask_position_y }
                { mask_repeat }
                { mask_size }
                { _moz_context_properties }
                { offset_anchor }
                { offset_path }
                { offset_position }
                { page }
                { perspective }
                { position_anchor }
                { position_try_options }
                { quotes }
                { rotate }
                { scale }
                { scroll_timeline_axis }
                { scroll_timeline_name }
                { scrollbar_color }
                { shape_outside }
                { size }
                { stroke_dasharray }
                { stroke_dashoffset }
                { stroke_width }
                { tab_size }
                { text_decoration_thickness }
                { text_emphasis_style }
                { text_indent }
                { text_overflow }
                { text_shadow }
                { transition_behavior }
                { transition_delay }
                { transition_duration }
                { transition_property }
                { transition_timing_function }
                { translate }
                { vertical_align }
                { view_timeline_axis }
                { view_timeline_inset }
                { view_timeline_name }
                { _webkit_text_stroke_width }
                { will_change }
                { word_spacing }
                { _x_lang }
                { object_position }
                { perspective_origin }
                { fill }
                { stroke }
                { _moz_window_transform_origin }
                { transform_origin }
                { grid_template_columns }
                { grid_template_rows }
                { border_image_source }
                { list_style_image }
                { grid_auto_columns }
                { grid_auto_rows }
                { _moz_window_transform }
                { transform }
                { column_gap }
                { row_gap }
                { marker_end }
                { marker_mid }
                { marker_start }
                { contain_intrinsic_block_size }
                { contain_intrinsic_height }
                { contain_intrinsic_inline_size }
                { contain_intrinsic_width }
                { grid_column_end }
                { grid_column_start }
                { grid_row_end }
                { grid_row_start }
                { max_block_size }
                { max_height }
                { max_inline_size }
                { max_width }
                { cx }
                { cy }
                { offset_distance }
                { x }
                { y }
                { border_bottom_left_radius }
                { border_bottom_right_radius }
                { border_end_end_radius }
                { border_end_start_radius }
                { border_start_end_radius }
                { border_start_start_radius }
                { border_top_left_radius }
                { border_top_right_radius }
                { block_size }
                { height }
                { inline_size }
                { min_block_size }
                { min_height }
                { min_inline_size }
                { min_width }
                { width }
                { border_block_end_width }
                { border_block_start_width }
                { border_bottom_width }
                { border_inline_end_width }
                { border_inline_start_width }
                { border_left_width }
                { border_right_width }
                { border_top_width }
                { column_rule_width }
                { outline_width }
                { padding_block_end }
                { padding_block_start }
                { padding_bottom }
                { padding_inline_end }
                { padding_inline_start }
                { padding_left }
                { padding_right }
                { padding_top }
                { r }
                { shape_margin }
                { rx }
                { ry }
                { scroll_padding_block_end }
                { scroll_padding_block_start }
                { scroll_padding_bottom }
                { scroll_padding_inline_end }
                { scroll_padding_inline_start }
                { scroll_padding_left }
                { scroll_padding_right }
                { scroll_padding_top }
                { _moz_window_input_region_margin }
                { outline_offset }
                { overflow_clip_margin }
                { scroll_margin_block_end }
                { scroll_margin_block_start }
                { scroll_margin_bottom }
                { scroll_margin_inline_end }
                { scroll_margin_inline_start }
                { scroll_margin_left }
                { scroll_margin_right }
                { scroll_margin_top }
                { bottom }
                { inset_block_end }
                { inset_block_start }
                { inset_inline_end }
                { inset_inline_start }
                { left }
                { margin_block_end }
                { margin_block_start }
                { margin_bottom }
                { margin_inline_end }
                { margin_inline_start }
                { margin_left }
                { margin_right }
                { margin_top }
                { right }
                { text_underline_offset }
                { top }
                { background_color }
                { border_block_end_color }
                { border_block_start_color }
                { border_bottom_color }
                { border_inline_end_color }
                { border_inline_start_color }
                { border_left_color }
                { border_right_color }
                { border_top_color }
                { column_rule_color }
                { flood_color }
                { lighting_color }
                { outline_color }
                { stop_color }
                { text_decoration_color }
                { text_emphasis_color }
                { _webkit_text_fill_color }
                { _webkit_text_stroke_color }
        }
    }
}

// Large pages generate tens of thousands of ComputedValues.
size_of_test!(ComputedValues, 240);
// FFI relies on this.
size_of_test!(Option<Arc<ComputedValues>>, 8);

// There are two reasons for this test to fail:
//
//   * Your changes made a specified value type for a given property go
//     over the threshold. In that case, you should try to shrink it again
//     or, if not possible, mark the property as boxed in the property
//     definition.
//
//   * Your changes made a specified value type smaller, so that it no
//     longer needs to be boxed. In this case you just need to remove
//     boxed=True from the property definition. Nice job!
#[cfg(target_pointer_width = "64")]
#[allow(dead_code)] // https://github.com/rust-lang/rust/issues/96952
const BOX_THRESHOLD: usize = 24;
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::align_content::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::align_items::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::align_self::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::aspect_ratio::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::backface_visibility::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::baseline_source::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_collapse::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_image_repeat::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::box_decoration_break::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::box_sizing::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::break_inside::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::caption_side::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::clear::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::color_interpolation::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::color_interpolation_filters::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_count::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_fill::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_span::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::contain::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::container_type::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::content_visibility::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::direction::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::display::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::dominant_baseline::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::empty_cells::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::flex_direction::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::flex_wrap::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::float::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_kerning::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_language_override::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_optical_sizing::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_size_adjust::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_stretch::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variant_caps::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variant_east_asian::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variant_emoji::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variant_ligatures::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variant_numeric::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variant_position::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_weight::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::forced_color_adjust::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_auto_flow::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::hyphens::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::image_orientation::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::image_rendering::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::ime_mode::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::initial_letter::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::inset_area::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::isolation::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::justify_content::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::justify_items::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::justify_self::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::line_break::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::list_style_position::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_type::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::masonry_auto_flow::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::math_depth::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::math_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mix_blend_mode::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_box_align::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_box_collapse::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_box_direction::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_box_orient::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_box_pack::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_control_character_visibility::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_float_edge::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_inert::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_math_variant::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_min_font_size_ratio::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_orient::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_osx_font_smoothing::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_text_size_adjust::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_theme::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_top_layer::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_user_focus::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_user_input::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_user_modify::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_window_dragging::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_window_shadow::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::object_fit::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::offset_rotate::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::outline_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_anchor::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_wrap::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::page_orientation::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::paint_order::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::pointer_events::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::position::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::position_try_order::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::position_visibility::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::print_color_adjust::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::resize::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::ruby_align::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::ruby_position::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_behavior::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_snap_align::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_snap_stop::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_snap_type::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scrollbar_gutter::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scrollbar_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::shape_rendering::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke_linecap::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke_linejoin::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::table_layout::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_align::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_align_last::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_anchor::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_combine_upright::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_decoration_line::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_decoration_skip_ink::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_decoration_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_emphasis_position::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_justify::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_orientation::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_rendering::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_transform::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_underline_position::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_wrap_mode::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_wrap_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::touch_action::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transform_box::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transform_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::unicode_bidi::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::user_select::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::vector_effect::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::visibility::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_webkit_line_clamp::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_webkit_text_security::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::white_space_collapse::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::word_break::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::writing_mode::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_x_text_scale::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::z_index::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::zoom::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::appearance::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_default_appearance::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_force_broken_image_icon::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_subtree_hidden_only_visually::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::break_after::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::break_before::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::clip_rule::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::fill_rule::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_clip_box_block::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_clip_box_inline::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::fill_opacity::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke_opacity::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_box_ordinal_group::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::order::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_x_span::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_synthesis_position::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_synthesis_small_caps::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_synthesis_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_synthesis_weight::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::flex_grow::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::flex_shrink::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_box_flex::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke_miterlimit::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_block::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_inline::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_x::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_y::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overscroll_behavior_block::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overscroll_behavior_inline::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overscroll_behavior_x::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overscroll_behavior_y::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::flood_opacity::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_window_opacity::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::opacity::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::shape_image_threshold::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stop_opacity::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_block_end_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_block_start_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_bottom_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_inline_end_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_inline_start_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_left_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_right_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_top_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_rule_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::accent_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::anchor_name::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::anchor_scope::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_composition::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_delay::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_direction::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_duration::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_fill_mode::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_iteration_count::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_name::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_play_state::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_timeline::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::animation_timing_function::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::backdrop_filter::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_attachment::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_blend_mode::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_clip::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_image::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_origin::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_position_x::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_position_y::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_repeat::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_image_outset::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_image_slice::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_image_width::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_spacing::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::box_shadow::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::caret_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::clip::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::clip_path::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::color_scheme::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::container_name::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::content::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::counter_increment::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::counter_reset::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::counter_set::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::cursor::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::d::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::filter::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::flex_basis::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_family::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_feature_settings::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_palette::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variant_alternates::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::font_variation_settings::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_template_areas::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::hyphenate_character::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::letter_spacing::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::line_height::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::list_style_type::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_clip::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_composite::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_image::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_mode::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_origin::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_position_x::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_position_y::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_repeat::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::mask_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_context_properties::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::offset_anchor::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::offset_path::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::offset_position::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::page::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::perspective::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::position_anchor::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::position_try_options::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::quotes::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::rotate::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scale::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_timeline_axis::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_timeline_name::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scrollbar_color::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::shape_outside::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::size::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke_dasharray::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke_dashoffset::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::tab_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_decoration_thickness::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_emphasis_style::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_indent::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_overflow::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_shadow::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transition_behavior::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transition_delay::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transition_duration::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transition_property::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transition_timing_function::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::translate::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::vertical_align::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::view_timeline_axis::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::view_timeline_inset::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::view_timeline_name::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_webkit_text_stroke_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::will_change::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::word_spacing::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_x_lang::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::object_position::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::perspective_origin::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::fill::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stroke::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_window_transform_origin::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transform_origin::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_template_columns::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_template_rows::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_image_source::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::list_style_image::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_auto_columns::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_auto_rows::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_window_transform::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::transform::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_gap::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::row_gap::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::marker_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::marker_mid::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::marker_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::contain_intrinsic_block_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::contain_intrinsic_height::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::contain_intrinsic_inline_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::contain_intrinsic_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_column_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_column_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_row_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::grid_row_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::max_block_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::max_height::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::max_inline_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::max_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::cx::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::cy::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::offset_distance::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::x::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::y::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_bottom_left_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_bottom_right_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_end_end_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_end_start_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_start_end_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_start_start_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_top_left_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_top_right_radius::SpecifiedValue>() > BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::block_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::height::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::inline_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::min_block_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::min_height::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::min_inline_size::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::min_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_block_end_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_block_start_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_bottom_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_inline_end_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_inline_start_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_left_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_right_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_top_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_rule_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::outline_width::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_block_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_block_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_bottom::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_inline_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_inline_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_left::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_right::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::padding_top::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::r::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::shape_margin::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::rx::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::ry::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_block_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_block_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_bottom::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_inline_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_inline_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_left::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_right::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_padding_top::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_moz_window_input_region_margin::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::outline_offset::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::overflow_clip_margin::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_block_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_block_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_bottom::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_inline_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_inline_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_left::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_right::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::scroll_margin_top::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::bottom::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::inset_block_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::inset_block_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::inset_inline_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::inset_inline_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::left::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_block_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_block_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_bottom::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_inline_end::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_inline_start::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_left::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_right::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::margin_top::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::right::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_underline_offset::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::top::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::background_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_block_end_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_block_start_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_bottom_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_inline_end_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_inline_start_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_left_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_right_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::border_top_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::column_rule_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::flood_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::lighting_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::outline_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::stop_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_decoration_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::text_emphasis_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_webkit_text_fill_color::SpecifiedValue>() <= BOX_THRESHOLD);
#[cfg(target_pointer_width = "64")]
const_assert!(std::mem::size_of::<longhands::_webkit_text_stroke_color::SpecifiedValue>() <= BOX_THRESHOLD);

